package com.unis.indicator.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.ContributeArticleVO;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

/**
 * @author xmpu
 * @version 1.0
 * @Title: IndicatorFeign
 * @ProjectName IndicatorService
 * @Description: Indicator层fegin接口
 * @date 2019/7/7 18:05
 */
@FeignClient(name = "indicator-server")
@Component
public interface ContributeArticleFeign {

    @ApiOperation(value = "根据id查询文章投稿类型信息", notes = "参数：文章投稿类型信息id")
    @RequestMapping(method = RequestMethod.GET, value = "/contributeArticle/{id}/")
    public ResponseWrapper findById(@PathVariable("id") String id);

    @ApiOperation(value = "保存文章投稿信息", notes = "参数：文章投稿对象VO")
    @RequestMapping(method = RequestMethod.POST, value = "/contributeArticle/")
    public ResponseWrapper save(@RequestBody ContributeArticleVO VO);

    @ApiOperation(value = "更新文章投稿信息", notes = "参数：文章投稿VO")
    @RequestMapping(method = RequestMethod.PUT, value = "/contributeArticle/")
    public ResponseWrapper update(@RequestBody ContributeArticleVO VO);

    @ApiOperation(value = "提交文章投稿信息", notes = "参数：文章投稿id")
    @RequestMapping(method = RequestMethod.PUT, value = "/contributeArticle/sub/")
    public ResponseWrapper submit(@RequestBody ContributeArticleVO VO);

    @ApiOperation(value = "发布文章投稿信息", notes = "参数：文章投稿id")
    @RequestMapping(method = RequestMethod.PUT, value = "/contributeArticle/pub/")
    public ResponseWrapper publish(@RequestBody ContributeArticleVO VO);

    @ApiOperation(value = "删除文章投稿", notes = "参数：文章投稿id(可传入多个)，操作用户id")
    @RequestMapping(method = RequestMethod.DELETE, value = "/contributeArticles")
    public ResponseWrapper deletes(@RequestBody String[] ids, @RequestParam("userId") String userId);

    @ApiOperation(value = "查询所有文章投稿，分页", notes = "参数：文章投稿名模糊查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @RequestMapping(method = RequestMethod.POST, value = "/contributeArticles")
    public ResponseWrapper findByPage(@RequestBody ContributeArticleVO VO,
                                      @RequestParam("page") Integer page,
                                      @RequestParam("size") Integer size,
                                      @RequestParam("isUser") String isUser);
    @ApiOperation(value = "查询所有文章投稿，分页By", notes = "参数：文章投稿名模糊查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @RequestMapping(method = RequestMethod.POST, value = "/contributeArticlesBy")
    public ResponseWrapper findByPageBy(@RequestBody ContributeArticleVO VO,
                                        @RequestParam("page") Integer page,
                                        @RequestParam("size") Integer size,
                                        @RequestParam("isUser") String isUser);
//    @ApiOperation(value = "查询所有文章投稿，不分页", notes = "参数：无、当前页、页面大小")
//    @RequestMapping(method = RequestMethod.GET, value = "/contributeArticles")
//    public ResponseWrapper findAll();

    @ApiOperation(value = "文章汇总,分页", notes = "参数：监测点名、日期from、日期to、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @RequestMapping(method = RequestMethod.POST, value = "/articleGathers")
    public ResponseWrapper articleGathers(@RequestBody ContributeArticleVO VO,
                                          @RequestParam("page") Integer page,
                                          @RequestParam("size") Integer size);

    @ApiOperation(value = "文章汇总,查看", notes = "参数：机构id、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @RequestMapping(method = RequestMethod.GET,value = "/articles")
    public ResponseWrapper articles(@RequestParam("orgId") String orgId,
                                    @RequestParam("page") Integer page,
                                    @RequestParam("size") Integer size,
                                    @RequestParam("dateFrom") String dateFrom,
                                    @RequestParam("dateTo")String dateTo

    );
    
    /**
	 * 
	 * @Description: 方法描述
	 * @author: 王帅
	 * @param: @param  id
	 * @param: @param  status
	 * @param: @return
	 * @param: @throws Exception 参数
	 * @return: boolean 返回类型
	 */
	@GetMapping("modification/article/status")
	public ResponseWrapper updateArticleStatus(@RequestParam(value = "id", required = true) String id,
			@RequestParam(value = "status", required = true, defaultValue = "1") String status);
}
