package com.unis.indicator.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.bbzb.IndiBreedSpcVO;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author xmpu
 * @version 1.0
 * @Title: IndiBreedSpcFeign
 * @ProjectName IndicatorService
 * @Description: Indicator层fegin接口
 * @date 2019/7/7 18:05
 */
@FeignClient(name = "indicator-server")
@Component
public interface IndiBreedSpcFeign {

    @ApiOperation(value = "根据指标id查询指标品牌规格信息", notes = "参数：指标品牌规格信息指标id")
    @RequestMapping(method = RequestMethod.GET, value = "/indiBreedSpc/{id}/")
    public ResponseWrapper findById(@PathVariable("id") String id);

    @ApiOperation(value = "保存or更新指标品牌规格信息", notes = "参数：指标品牌规格对象VO集合")
    @RequestMapping(method = RequestMethod.POST, value = "/indiBreedSpc/")
    public ResponseWrapper save(@RequestBody IndiBreedSpcVO VO);

    @ApiOperation(value = "更新指标品牌规格配置的产地信息", notes = "参数：指标品牌规格VO")
    @RequestMapping(method = RequestMethod.PUT, value = "/indiBreedSpc/")
    public ResponseWrapper update(@RequestBody IndiBreedSpcVO VO);

    @ApiOperation(value = "删除指标品牌规格", notes = "参数：指标品牌规格id(可传入多个)，操作用户id")
    @RequestMapping(method = RequestMethod.DELETE, value = "/indiBreedSpcs")
    public ResponseWrapper deletes(@RequestBody String[] ids, @RequestParam("userId") String userId);

    @ApiOperation(value = "查询所有指标品牌规格，分页", notes = "参数：指标品牌规格名模糊查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @RequestMapping(method = RequestMethod.POST, value = "/indiBreedSpcs")
    public ResponseWrapper findByPage(@RequestBody IndiBreedSpcVO VO,
                                      @RequestParam("page") Integer page,
                                      @RequestParam("size") Integer size);

    @ApiOperation(value = "查询所有指标品牌规格，不分页", notes = "参数：无")
    @RequestMapping(method = RequestMethod.GET, value = "/indiBreedSpcs")
    public ResponseWrapper findAll();
}
