package com.unis.indicator.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.IndicatorMonitorVO;
import com.unis.indicator.common.vo.IndicatorPriceVO;
import com.unis.indicator.common.vo.IndicatorStandardVO;
import com.unis.indicator.common.vo.IndicatorVO;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

/**
 * @author xmpu
 * @version 1.0
 * @Title: IndicatorFeign
 * @ProjectName IndicatorService
 * @Description: Indicator层fegin接口
 * @date 2019/7/7 18:05
 */
@FeignClient(name = "indicator-server")
@Component
public interface IndicatorFeign {

    @ApiOperation(value = "根据id查询指标类型信息", notes = "参数：指标类型信息id")
    @RequestMapping(method = RequestMethod.GET, value = "/indicator/{id}/")
    public ResponseWrapper findById(@PathVariable("id") String id);

    @ApiOperation(value = "通过indicatorId查询指标和监测点关联信息", notes = "参数：指标信息id")
    @RequestMapping(method = RequestMethod.GET, value = "/indMonRel/{indicatorId}/")
    public ResponseWrapper findIndMonRel(@PathVariable("indicatorId") String indicatorId);

    @ApiOperation(value = "保存指标信息", notes = "参数：指标对象VO")
    @RequestMapping(method = RequestMethod.POST, value = "/indicator/")
    public ResponseWrapper save(@RequestBody IndicatorVO VO);

    @ApiOperation(value = "更新指标信息", notes = "参数：指标VO")
    @RequestMapping(method = RequestMethod.PUT, value = "/indicator/")
    public ResponseWrapper update(@RequestBody IndicatorVO VO);

    @ApiOperation(value = "删除指标", notes = "参数：指标id(可传入多个)，操作用户id")
    @RequestMapping(method = RequestMethod.DELETE, value = "/indicators")
    public ResponseWrapper deletes(@RequestBody String[] ids, @RequestParam("userId") String userId);

    @ApiOperation(value = "查询所有指标", notes = "参数：指标名模糊查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @RequestMapping(method = RequestMethod.POST, value = "/indicators")
    public ResponseWrapper findByPage(@RequestBody IndicatorVO VO,
                                      @RequestParam("page") Integer page,
                                      @RequestParam("size") Integer size);

    @ApiOperation(value = "查询所有指标(按品种分组)", notes = "参数：当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @RequestMapping(method = RequestMethod.POST, value = "/indicatorsGroup")
    public ResponseWrapper findByPageGroup(@RequestBody IndicatorVO VO,
                                           @RequestParam("page") Integer page,
                                           @RequestParam("size") Integer size);

    @ApiOperation(value = "查询所有指标，不分页", notes = "参数：无")
    @RequestMapping(method = RequestMethod.GET, value = "/indicators")
    public ResponseWrapper findAll();

    @ApiOperation(value = "获取指标信息树形结构", notes = "参数：treeCode(0：所有的指标树；1：父级指标树)")
    @RequestMapping(method = RequestMethod.GET, value = "/indicatorsTree")
    public ResponseWrapper indicatorsTree(@RequestParam("treeCode") String treeCode);

    @ApiOperation(value = "指标与监测点关联保存", notes = "参数：监测点与指标关联Model")
    @RequestMapping(method = RequestMethod.POST, value = "/indicatorMonitor/")
    public ResponseWrapper saveIndicatorMonitor(@RequestBody IndicatorMonitorVO VO);

    @ApiOperation(value = "查询监测点对应勾选了的指标", notes = "参数：监测点id")
    @RequestMapping(method = RequestMethod.GET, value = "/indicatorMonitor/")
    public ResponseWrapper findIndicatorMonitor(@RequestParam("monitorId") String monitorId);

    @ApiOperation(value = "指标标准与指标保存", notes = "参数：指标标准与指标关联Model")
    @RequestMapping(method = RequestMethod.POST, value = "/indicatorStandard/")
    public ResponseWrapper saveIndicatorStandard(@RequestBody IndicatorStandardVO VO);

    @ApiOperation(value = "查询指标对应勾选了的指标标准", notes = "参数：指标id")
    @RequestMapping(method = RequestMethod.GET, value = "/indicatorStandard/")
    public ResponseWrapper findIndicatorStandard(@RequestParam("indicatorId") String indicatorId);

    @ApiOperation(value = "价格类型与指标保存", notes = "参数：指标标准与指标关联Model")
    @RequestMapping(method = RequestMethod.POST, value = "/indicatorPriceType/")
    public ResponseWrapper saveIndicatorPriceType(@RequestBody IndicatorPriceVO VO);

    @ApiOperation(value = "查询指标对应勾选了的价格类型", notes = "参数：指标id")
    @RequestMapping(method = RequestMethod.GET, value = "/indicatorPriceType/")
    public ResponseWrapper findIndicatorPriceType(@RequestParam("indicatorId") String indicatorId);
}
