package com.unis.indicator.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.JournalVO;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

/**
 * @author xmpu
 * @version 1.0
 * @Title: JournalFeign
 * @ProjectName IndicatorService
 * @Description: Indicator层fegin接口
 * @date 2019/7/7 18:05
 */
@FeignClient(name = "indicator-server")
@Component
public interface JournalFeign {

    @ApiOperation(value = "根据id查询期刊类型信息", notes = "参数：期刊类型信息id")
    @RequestMapping(method = RequestMethod.GET, value = "/journal/{id}/")
    public ResponseWrapper findById(@PathVariable("id") String id);

    @ApiOperation(value = "保存期刊信息", notes = "参数：期刊对象VO")
    @RequestMapping(method = RequestMethod.POST, value = "/journal/")
    public ResponseWrapper save(@RequestBody JournalVO VO);

    @ApiOperation(value = "更新期刊信息", notes = "参数：期刊VO")
    @RequestMapping(method = RequestMethod.PUT, value = "/journal/")
    public ResponseWrapper update(@RequestBody JournalVO VO);

    @ApiOperation(value = "删除期刊", notes = "参数：期刊id(可传入多个)，操作用户id")
    @RequestMapping(method = RequestMethod.DELETE, value = "/journals")
    public ResponseWrapper deletes(@RequestBody String[] ids, @RequestParam("userId") String userId);

    @ApiOperation(value = "查询所有期刊，分页", notes = "参数：期刊名模糊查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @RequestMapping(method = RequestMethod.POST, value = "/journals")
    public ResponseWrapper findByPage(@RequestBody JournalVO VO,
                                      @RequestParam("page") Integer page,
                                      @RequestParam("size") Integer size);

    @ApiOperation(value = "查询所有期刊，不分页", notes = "参数：无")
    @RequestMapping(method = RequestMethod.GET, value = "/journals")
    public ResponseWrapper findAll();
}
