package com.unis.indicator.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.IndicatorMonitorVO;
import com.unis.indicator.common.vo.IndicatorPriceVO;
import com.unis.indicator.common.vo.IndicatorStandardVO;
import com.unis.indicator.common.vo.IndicatorVO;
import com.unis.indicator.common.vo.ReportRecordVO;

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

import java.util.Map;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

/**
 * @author lfx
 * @version 1.0
 * @Title: MarketTrendFeign
 * @ProjectName MarketTrendService
 * @Description: MarketTrend层fegin接口
 * @date 2019年8月28日16:12:10
 */
@FeignClient(name = "indicator-server")
@Component
public interface MarketTrendFeign {


	/**
	 * @Description: 查询本周行情--查询上报开始、结束时间
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
  
    @ApiOperation(value = "查询上报时间", notes = "参数：上报时间查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @PostMapping(value = "/queryReportTime")
    public ResponseWrapper queryReportTime(@RequestBody ReportRecordVO VO,
                                      @RequestParam("page") Integer page,
                                      @RequestParam("size") Integer size);
    
    /**
   	 * @Description: 查询本周行情--查询国家局详情
   	 * @date 2019年8月28日15:00:44
   	 * @author lifx
   	 * @version v1.0
   	 *
   	 * @param VO
   	 * @param page
   	 * @param size
   	 * @return Map
   	 * @throws Exception
   	 */
     
       @ApiOperation(value = "查询国家局详情", notes = "参数：上报时间查询、当前页、页面大小")
       @ApiImplicitParams({
               @ApiImplicitParam(name = "page", value = "起始页", required = true),
               @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @PostMapping(value = "/queryCountryDetails")
    public ResponseWrapper queryCountryDetails(@RequestBody ReportRecordVO VO,
											   @RequestParam("page") Integer page,
											   @RequestParam("size") Integer size);
       
       
       /**
   	 * @Description: 查询本周行情--查询库点详情
   	 * @date 2019年8月28日15:00:44
   	 * @author lifx
   	 * @version v1.0
   	 *
   	 * @param VO
   	 * @param page
   	 * @param size
   	 * @return Map
   	 * @throws Exception
   	 */
       @ApiOperation(value = "查询库点详情", notes = "参数：上报时间查询、当前页、页面大小")
       @ApiImplicitParams({
               @ApiImplicitParam(name = "page", value = "起始页", required = true),
               @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
       @PostMapping(value = "/queryPointDetails")
       public ResponseWrapper queryPointDetails(@RequestBody ReportRecordVO VO,
												@RequestParam("page") Integer page,
												@RequestParam("size") Integer size);
       
       
       
     /**
   	 * @Description: 价格走势-原粮
   	 * @date 2019年8月28日15:00:44
   	 * @author lifx
   	 * @version v1.0
   	 *
   	 * @param VO
   	 * @return Map
   	 * @throws Exception
   	 */
       @ApiOperation(value = "价格走势-原粮", notes = "参数：上报时间查询")
       @PostMapping(value = "/queryPriceYl")
       public ResponseWrapper queryPriceYl(@RequestBody ReportRecordVO VO );
       
   /**
  	 * @Description: 价格走势-成品粮
  	 * @date 2019年8月28日15:00:44
  	 * @author lifx
  	 * @version v1.0
  	 *
  	 * @param VO
  	 * @return Map
  	 * @throws Exception
  	 */
      @ApiOperation(value = "价格走势-成品粮", notes = "参数：上报时间查询")
      @PostMapping(value = "/queryPriceCPL")
      public ResponseWrapper queryPriceCPL(@RequestBody ReportRecordVO VO );
      
      /**
	 * @Description: 价格走势-食用油及油料
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @return Map
	 * @throws Exception
	 */
    @ApiOperation(value = "价格走势-食用油及油料", notes = "参数：上报时间查询")
    @PostMapping(value = "/queryPriceSYY")
    public ResponseWrapper queryPriceSYY(@RequestBody ReportRecordVO VO );
    
    /**
   	 * @Description: 价格走势-原粮
   	 * @date 2019年8月28日15:00:44
   	 * @author lifx
   	 * @version v1.0
   	 *
   	 * @param VO
   	 * @return Map
   	 * @throws Exception
   	 */
       @ApiOperation(value = "价格走势-监测点原粮", notes = "参数：上报时间查询")
       @PostMapping(value = "/queryPricePointYL")
       public ResponseWrapper queryPricePointYL(@RequestBody ReportRecordVO VO );
       
   /**
  	 * @Description: 价格走势-成品粮
  	 * @date 2019年8月28日15:00:44
  	 * @author lifx
  	 * @version v1.0
  	 *
  	 * @param VO
  	 * @return Map
  	 * @throws Exception
  	 */
      @ApiOperation(value = "价格走势-监测点成品粮", notes = "参数：上报时间查询")
      @PostMapping(value = "/queryPricePointCPL")
      public ResponseWrapper queryPricePointCPL(@RequestBody ReportRecordVO VO );
      
      /**
	 * @Description: 价格走势-食用油及油料
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @return Map
	 * @throws Exception
	 */
    @ApiOperation(value = "价格走势-监测点食用油及油料", notes = "参数：上报时间查询")
    @PostMapping(value = "/queryPricePointSYY")
    public ResponseWrapper queryPricePointSYY(@RequestBody ReportRecordVO VO );
    
    /**
   	 * @Description: 价格走势-原粮--指定价格
   	 * @date 2019年8月28日15:00:44
   	 * @author lifx
   	 * @version v1.0
   	 *
   	 * @param VO
   	 * @return Map
   	 * @throws Exception
   	 */
       @ApiOperation(value = "价格走势-原粮--指定价格", notes = "参数：上报时间查询")
       @PostMapping(value = "/queryPriceYLZD")
       public ResponseWrapper queryPriceYLZD(@RequestBody ReportRecordVO VO );
       
   /**
  	 * @Description: 价格走势-成品粮--指定价格
  	 * @date 2019年8月28日15:00:44
  	 * @author lifx
  	 * @version v1.0
  	 *
  	 * @param VO
  	 * @return Map
  	 * @throws Exception
  	 */
      @ApiOperation(value = "价格走势-成品粮--指定价格", notes = "参数：上报时间查询")
      @PostMapping(value = "/queryPriceCPLZD")
      public ResponseWrapper queryPriceCPLZD(@RequestBody ReportRecordVO VO );

	/**
	 * @Description: 工作台价格走势(每月均价)
	 * @date 2019/12/12 15:38
	 * @author yangshengjie
	 * @version v1.0
	 *
	 * @param VO
	 * @return Map
	 * @throws Exception
	 */
	@ApiOperation(value = "工台价格走势(每月均价)", notes = "参数：查询年份,价格类型，品种名称")
	@PostMapping(value = "/workbenchQueryPriceY/")
	public ResponseWrapper workbenchQueryPriceY(@RequestBody ReportRecordVO VO );

	/**
	 * @Description: 工作台价格走势(品种多选)
	 * @date 2019/12/12 19:48
	 * @author yangshengjie
	 * @version v1.0
	 *
	 * @param VO
	 * @return Map
	 * @throws Exception
	 */
	@ApiOperation(value = "工作台价格走势(品种多选)", notes = "参数：查询年份,价格类型，品种名称")
	@PostMapping(value = "/workbenchQueryPriceM/")
	public ResponseWrapper workbenchQueryPriceM(@RequestBody ReportRecordVO VO );
}
