package com.unis.indicator.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.PriceTypeVO;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

/**
 * @author xmpu
 * @version 1.0
 * @Title: PriceTypeFeign
 * @ProjectName IndicatorService
 * @Description: PriceType层fegin接口
 * @date 2019/7/7 18:05
 */
@FeignClient(name = "indicator-server")
@Component
public interface PriceTypeFeign {

    @ApiOperation(value = "根据id查询价格类型类型信息", notes = "参数：价格类型类型信息id")
    @RequestMapping(method = RequestMethod.GET, value = "/priceType/{id}/")
    public ResponseWrapper findById(@PathVariable("id") String id);

    @ApiOperation(value = "通过priceTypeId查询指标与价格类型关联信息", notes = "参数：价格类型信息id")
    @RequestMapping(method = RequestMethod.GET, value = "/priceTypeIndRel/{priceTypeId}/")
    public ResponseWrapper findPriceTypeIndRel(@PathVariable("priceTypeId") String priceTypeId);

    @ApiOperation(value = "保存价格类型信息", notes = "参数：价格类型对象VO")
    @RequestMapping(method = RequestMethod.POST, value = "/priceType/")
    public ResponseWrapper save(@RequestBody PriceTypeVO VO);

    @ApiOperation(value = "更新价格类型信息", notes = "参数：价格类型VO")
    @RequestMapping(method = RequestMethod.PUT, value = "/priceType/")
    public ResponseWrapper update(@RequestBody PriceTypeVO VO);

    @ApiOperation(value = "删除价格类型", notes = "参数：价格类型id(可传入多个)，操作用户id")
    @RequestMapping(method = RequestMethod.DELETE, value = "/priceTypes")
    public ResponseWrapper deletes(@RequestBody String[] ids, @RequestParam("userId") String userId);

    @ApiOperation(value = "查询所有价格类型,分页", notes = "参数：价格类型名模糊查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @RequestMapping(method = RequestMethod.POST, value = "/priceTypes")
    public ResponseWrapper findByPage(@RequestBody PriceTypeVO VO,
                                      @RequestParam("page") Integer page,
                                      @RequestParam("size") Integer size);

    @ApiOperation(value = "查询所有指标单位，不分页", notes = "参数：无")
    @RequestMapping(method = RequestMethod.GET, value = "/priceTypes")
    public ResponseWrapper findAll();

    @ApiOperation(value = "查询权重的价格类型", notes = "参数：无")
    @RequestMapping(method = RequestMethod.GET, value = "/priceWeightTypes")
    public ResponseWrapper findPriceWeightTypes();
}
