package com.unis.indicator.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.bbzb.ReportConfigVO;
import com.unis.indicator.common.vo.bbzb.ReportIndicatorVO;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

/**
 * @author xmpu
 * @version 1.0
 * @Title: reportIndicatorFeign
 * @ProjectName reportIndicatorFeign
 * @Description: report层fegin接口
 * @date 2019/7/7 18:05
 */
@FeignClient(name = "indicator-server")
@Component
public interface ReportIndicatorFeign {

    @ApiOperation(value = "根据id查询报表指标信息", notes = "参数：报表指标信息id")
    @RequestMapping(method = RequestMethod.GET, value = "/reportIndicator/{id}/")
    public ResponseWrapper findById(@PathVariable("id") String id);

    @ApiOperation(value = "根据报表id查询指标集合", notes = "参数：报表id")
    @RequestMapping(method = RequestMethod.GET,value = "/indicators/{reportTypeId}/")
    public ResponseWrapper findByReportTypeId(@PathVariable("reportTypeId") String reportTypeId);

    @ApiOperation(value = "保存报表指标信息", notes = "参数：报表指标对象VO")
    @RequestMapping(method = RequestMethod.POST, value = "/reportIndicator/")
    public ResponseWrapper save(@RequestBody ReportIndicatorVO VO);

    @ApiOperation(value = "更新报表指标信息", notes = "参数：报表指标VO")
    @RequestMapping(method = RequestMethod.PUT, value = "/reportIndicator/")
    public ResponseWrapper update(@RequestBody ReportIndicatorVO VO);

    @ApiOperation(value = "删除报表指标", notes = "参数：报表指标id(可传入多个)，操作用户id")
    @RequestMapping(method = RequestMethod.DELETE, value = "/reportIndicators")
    public ResponseWrapper deletes(@RequestBody String[] ids, @RequestParam("userId") String userId);

    @ApiOperation(value = "查询所有报表指标，分页", notes = "参数：报表类型名,指标名模糊查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @RequestMapping(method = RequestMethod.POST, value = "/reportIndicators")
    public ResponseWrapper findByPage(@RequestBody ReportIndicatorVO VO,
                                      @RequestParam("page") Integer page,
                                      @RequestParam("size") Integer size);

    @ApiOperation(value = "查询所有报表指标，不分页", notes = "参数：无")
    @RequestMapping(method = RequestMethod.GET, value = "/reportIndicators")
    public ResponseWrapper findAll();

    @ApiOperation(value = "查询报表指标的配置", notes = "参数：ReportConfigVO需要填写报表类型编码/报表指标编码/报表价格编码/监测点编码")
    @RequestMapping(method = RequestMethod.POST,value = "/reportConfigRecord/")
    public ResponseWrapper findBbpz(@RequestBody ReportConfigVO vo);

    @ApiOperation(value = "保存报表配置信息", notes = "参数：报表指标对象VO")
    @RequestMapping(method = RequestMethod.POST,value = "/reportConfig/")
    public ResponseWrapper saveReportConfig(@RequestBody ReportConfigVO VO);
}
