package com.unis.indicator.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.*;
import feign.Response;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.Map;

@FeignClient(name = "indicator-server")
@Component
public interface ReportRecordFeign {

    @ApiOperation(value = "粮食价格走势", notes = "参数：统计时间段、价格类别、品种、地区")
    @RequestMapping(method = RequestMethod.POST, value = "/price/")
    public ResponseWrapper price(@RequestBody ReportRecordVO bbvo);

    @ApiOperation(value = "粮油价格上报（一对多）", notes = "粮油价格上报新增")
    @RequestMapping(method = RequestMethod.POST, value = "/reportMany/")
    public ResponseWrapper save(@RequestBody ReportRecordInfoVO reportRecordInfoVO);

    @ApiOperation(value = "粮油价格上报（一对一）", notes = "天津粮油价格上报新增")
    @RequestMapping(method = RequestMethod.POST, value = "/reportOne/")
    public ResponseWrapper saveOne(@RequestBody ReportRecordInfoVO reportRecordInfoVO);

    @ApiOperation(value = "粮油价格编辑（一对多）", notes = "粮油价格修改")
    @RequestMapping(method = RequestMethod.PUT, value = "/reportMany/")
    public ResponseWrapper update(@RequestBody ReportRecordInfoVO reportRecordInfoVO);

    @ApiOperation(value = "粮油价格编辑(一对一)", notes = "粮油价格修改")
    @RequestMapping(method = RequestMethod.PUT, value = "/reportOne/")
    public ResponseWrapper updateOne(@RequestBody ReportRecordInfoVO reportRecordInfoVO);

    @ApiOperation(value = "填报记录状态修改", notes = "填报记录状态修改")
    @RequestMapping(method = RequestMethod.PUT, value = "/process/")
    public ResponseWrapper statusUpdate(@RequestBody ReportRecordStatusVo reportRecordStatusVo);

    @ApiOperation(value = "粮油价格详情(一对多)", notes = "参数:报表id")
    @RequestMapping(method = RequestMethod.GET, value = "/reportMany/{id}/")
    public ResponseWrapper info(@PathVariable("id") String id);

    @ApiOperation(value = "粮油价格详情(一对一)", notes = "参数:报表id")
    @RequestMapping(method = RequestMethod.GET, value = "/reportOne/{id}/")
    public ResponseWrapper infoOne(@PathVariable("id") String id);

    @ApiOperation(value = "粮油价格详情最新的", notes = "参数:报表id")
    /*@PostMapping("/reportOneLastest/")*/
    @RequestMapping(method = RequestMethod.POST, value = "/reportOneLastest/")
    public ResponseWrapper reportOneLastest(@RequestBody PriceTrendQueryVO vo);

    @ApiOperation(value = "天津粮油价格详情(多对一)",notes = "参数:报表id，价格类型")
    @RequestMapping(method = RequestMethod.GET, value = "/reportOneTj/{id}/{jglx}/")
    public ResponseWrapper infoOneTj(@PathVariable("id") String id,@PathVariable("jglx") String jglx);

    @ApiOperation(value = "数据上报列表", notes = "参数:上报时间段、监测点、上报地区、报表类型")
    @RequestMapping(method = RequestMethod.POST, value = "/reports/")
    public ResponseWrapper getByQuery(@RequestBody ReportRecordListVO reportRecordListVO);

    @ApiOperation(value = "驳回数据", notes = "参数:报表类型id")
    @RequestMapping(method = RequestMethod.POST, value = "/reject/")
    public ResponseWrapper getRejectReport(@RequestParam("bblxId") String bblxId,@RequestParam("pointId") String pointId);

    @ApiOperation(value = "上报数据回显", notes = "上报数据回显")
    @RequestMapping(method = RequestMethod.POST, value = "/rejectby/")
    public ResponseWrapper getRejectReportBy(@RequestParam("bblxId") String bblxId,@RequestParam("pointId") String pointId);

    @ApiOperation(value = "历史数据获取", notes = "参数:上报时间段、监测点、上报地区、报表类型")
    @RequestMapping(method = RequestMethod.POST, value = "/history/")
    public ResponseWrapper getHistoryReport(@RequestBody ReportRecordListVO reportRecordListVO);

    @ApiOperation(value = "填报记录列表", notes = "参数:上报时间段、监测点、报表期类型、上报地区、报表类型")
    @RequestMapping(method = RequestMethod.POST, value = "/priceTrends/")
    public ResponseWrapper getPriceTrends(@RequestBody PriceTrendQueryVO priceTrendQueryVO);

    @ApiOperation(value = "填报记录列表(天津)",notes = "参数:上报时间段、监测点、报表期类型、上报地区、报表类型")
    @RequestMapping(method = RequestMethod.POST, value = "/priceTrendsTj/")
    public ResponseWrapper getPriceTrendsTj(@RequestBody PriceTrendQueryVO priceTrendQueryVO);

    @ApiOperation(value = "填报记录列表(按上报时间查)", notes = "参数:上报时间段、监测点、报表期类型、上报地区、报表类型")
    @RequestMapping(method = RequestMethod.POST, value = "/priceTrendsCT/")
    public ResponseWrapper getPriceTrendsCT(@RequestBody PriceTrendQueryVO priceTrendQueryVO);

    @ApiOperation(value = "回显", notes = "价格期类型 (日报、周报、月报)、价格类型、开始时间、结束时间")
    @RequestMapping(method = RequestMethod.POST, value = "/priceTrend/")
    public ResponseWrapper getHistoryPrice(@RequestBody PriceTrendQueryVO priceTrendQueryVO,@RequestParam("orgName") String orgName,@RequestParam("orgCode") String orgCode);

    @ApiOperation(value = "报表类型对应指标列表", notes = "报表类型对应指标列表")
    @RequestMapping(method = RequestMethod.POST, value = "/reportofindicator/")
    public ResponseWrapper getReportofindicator(@RequestParam("bblxId") String bblxId,@RequestBody Map<String,Object> map);

    @ApiOperation(value = "根据报表期类型获取报表类型列表", notes = "报表期类型(日报、周报、月报)")
    @RequestMapping(method = RequestMethod.POST, value = "/reportOfTypes/")
    public ResponseWrapper getReportDateType(@RequestParam("reportDateType") String reportDateType);

    @ApiOperation(value = "全国价格指数上报", notes = "全国价格指数新增")
    @RequestMapping(method = RequestMethod.POST, value = "/nationIndex/")
    public ResponseWrapper save(@RequestBody NationIndexReportInfoVO nationIndexReportInfoVO);

    @ApiOperation(value = "全国价格指数报表编辑", notes = "全国价格指数报表修改")
    @RequestMapping(method = RequestMethod.PUT, value = "/nationIndex/")
    public ResponseWrapper update(@RequestBody NationIndexReportInfoVO nationIndexReportInfoVO);

    @ApiOperation(value = "全国价格指数报表查看", notes = "参数:报表id")
    @RequestMapping(method = RequestMethod.GET, value = "/nationIndex/{id}/")
    public ResponseWrapper nationIndexInfo(@PathVariable("id") String id);

    @ApiOperation(value = "价格走势根据报表类型获取指标列表", notes = "参数:报表id")
    @RequestMapping(method = RequestMethod.POST, value = "/chartIndicator/")
    public ResponseWrapper getChartIndicator(@RequestParam("bblxId") String bblxId);

    @ApiOperation(value = "定时任务调度", notes = "定时任务调度")
    @RequestMapping(method = RequestMethod.POST, value = "/taskAdd/")
    public ResponseWrapper taskAdd(@RequestBody TaskVO taskVO);

    @ApiOperation(value = "价格走势月批量导入", notes = "价格走势月批量导入")
    @RequestMapping(method = RequestMethod.POST, value = "/excelInput/",consumes = "multipart/form-data")
    public ResponseWrapper excelInput(@RequestPart(value = "file") MultipartFile file, @RequestParam("bblxId") String bblxId);

    @ApiOperation(value = "价格走势月录入模版下载", notes = "价格走势月录入模版下载")
    @RequestMapping(method = RequestMethod.GET, value = "/excelModel/")
    public Response excelModel(@RequestParam("bblxId") String bblxId);

    @ApiOperation(value = "获取价格类型对应月报表的价格类型", notes = "参数:报表id")
    @RequestMapping(method = RequestMethod.POST, value = "/monthPriceType/")
    public ResponseWrapper monthPriceType(@RequestParam("bblxId") String bblxId);

    @ApiOperation(value = "查询指定时间报表是否已存在", notes = "查询指定时间报表是否已存在")
    @RequestMapping(method = RequestMethod.POST, value = "/isReport/")
    public ResponseWrapper isReport(@RequestBody ReportRecordInfoVO info);

    @ApiOperation(value = "收购季周报上报", notes = "收购季周报上报")
    @RequestMapping(method = RequestMethod.POST, value = "/quarterlyReport/")
    public ResponseWrapper quarterlyReport(@RequestBody QuarterlyReportVO quarterlyReportVO);

    @ApiOperation(value = "收购季周报汇总", notes = "收购季周报汇总")
    @RequestMapping(method = RequestMethod.POST, value = "/quarterlyPool/")
    public ResponseWrapper quarterlyPool(@RequestBody QuarterlyReportInputVO quarterlyReportInputVO);

    @ApiOperation(value = "收购季周报监测点上报回显", notes = "收购季周报监测点上报回显")
    @RequestMapping(method = RequestMethod.POST, value = "/quarterlyPoint/")
    public ResponseWrapper quarterlyPoint(@RequestBody QuarterlyReportInputVO quarterlyReportInputVO);

    @ApiOperation(value = "价格走势录入月计算", notes = "价格走势录入月计算")
    @RequestMapping(method = RequestMethod.POST, value = "/calculation/")
    public ResponseWrapper calculation();

    @ApiOperation(value = "数据维护发布", notes = "参数:orgId、num")
    @RequestMapping(method = RequestMethod.POST, value = "/release/")
    public ResponseWrapper release(@RequestParam("orgId") String orgId, @RequestParam("num") Integer num);

    @ApiOperation(value = "生成本级数据", notes = "参数:orgId、num")
    @RequestMapping(method = RequestMethod.POST, value = "/level/")
    public ResponseWrapper level(@RequestParam("orgId") String orgId, @RequestParam("num") Integer num);

    @ApiOperation(value = "我的工作平台-用户信息", notes = "参数:orgId、num")
    @RequestMapping(method = RequestMethod.POST, value = "/information/")
    public ResponseWrapper information(@RequestParam("orgId") String orgId, @RequestParam("num") Integer num);
    
    @PostMapping("/nationalPriceIndexTrend")
	public ResponseWrapper showNationalPriceIndexTrend(@RequestBody ReportRecordVO record);
    
    @GetMapping("/nationalPriceIndexVarietys/{formType}")
	public ResponseWrapper getNationalPriceIndexVarietys(@PathVariable("formType")String formType);

    @ApiOperation(value = "定时任务调度-粮油价格日报", notes = "定时任务调度-粮油价格日报")
    @RequestMapping(method = RequestMethod.POST, value = "/lYPriceDailyTaskAdd/")
    public ResponseWrapper lYPriceDailyTaskAdd(@RequestBody TaskVO taskVO);
}
