package com.unis.indicator.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.bbzb.ReportTypePriceVO;
import com.unis.indicator.common.vo.bbzb.ReportTypeVO;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

/**
 * @author xmpu
 * @version 1.0
 * @Title: reportTypeFeign
 * @ProjectName IndicatorService
 * @Description: Indicator层fegin接口
 * @date 2019/7/7 18:05
 */
@FeignClient(name = "indicator-server")
@Component
public interface ReportTypeFeign {

    @ApiOperation(value = "根据id查询报表类型信息", notes = "参数：报表类型信息id")
    @RequestMapping(method = RequestMethod.GET, value = "/reportType/{id}/")
    public ResponseWrapper findById(@PathVariable("id") String id);

    @ApiOperation(value = "保存报表类型信息", notes = "参数：报表类型对象VO")
    @RequestMapping(method = RequestMethod.POST, value = "/reportType/")
    public ResponseWrapper save(@RequestBody ReportTypeVO VO);

    @ApiOperation(value = "更新报表类型信息", notes = "参数：报表类型VO")
    @RequestMapping(method = RequestMethod.PUT, value = "/reportType/")
    public ResponseWrapper update(@RequestBody ReportTypeVO VO);

    @ApiOperation(value = "删除报表类型", notes = "参数：报表类型id(可传入多个)，操作用户id")
    @RequestMapping(method = RequestMethod.DELETE, value = "/reportTypes")
    public ResponseWrapper deletes(@RequestBody String[] ids, @RequestParam("userId") String userId);

    @ApiOperation(value = "查询所有报表类型，分页", notes = "参数：报表类型名模糊查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @RequestMapping(method = RequestMethod.POST, value = "/reportTypes")
    public ResponseWrapper findByPage(@RequestBody ReportTypeVO VO,
                                      @RequestParam("page") Integer page,
                                      @RequestParam("size") Integer size);

    @ApiOperation(value = "查询所有报表类型，不分页", notes = "参数：无")
    @RequestMapping(method = RequestMethod.GET, value = "/reportTypes")
    public ResponseWrapper findAll();

    @ApiOperation(value = "价格类型与报表类型保存", notes = "参数：价格类型与报表类型关联Model")
    @RequestMapping(method = RequestMethod.POST, value = "/reportTypePriceType/")
    public ResponseWrapper saveReportTypePriceType(@RequestBody ReportTypePriceVO VO);

    @ApiOperation(value = "查询报表类型对应勾选了的价格类型", notes = "参数：报表类型id")
    @RequestMapping(method = RequestMethod.GET, value = "/reportTypePriceType/")
    public ResponseWrapper findReportTypePriceType(@RequestParam("reportTypeId") String reportTypeId);


}

