package com.unis.indicator.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.StandardVO;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

/**
 * @author xmpu
 * @version 1.0
 * @Title: IndicatorFeign
 * @ProjectName IndicatorService
 * @Description: Indicator层fegin接口
 * @date 2019/7/7 18:05
 */
@FeignClient(name = "indicator-server")
@Component
public interface StandardFeign {

    @ApiOperation(value = "根据id查询指标标准类型信息", notes = "参数：指标标准类型信息id")
    @RequestMapping(method = RequestMethod.GET, value = "/indStandard/{id}/")
    public ResponseWrapper findById(@PathVariable("id") String id);

    @ApiOperation(value = "通过standardId查询指标标准关联信息", notes = "参数：指标标准信息id")
    @RequestMapping(method = RequestMethod.GET, value = "/indStdRel/{standardId}/")
    public ResponseWrapper findStdRelById(@PathVariable("standardId") String standardId);

    @ApiOperation(value = "保存指标标准信息", notes = "参数：指标标准对象VO")
    @RequestMapping(method = RequestMethod.POST, value = "/indStandard/")
    public ResponseWrapper save(@RequestBody StandardVO VO);

    @ApiOperation(value = "更新指标标准信息", notes = "参数：指标标准VO")
    @RequestMapping(method = RequestMethod.PUT, value = "/indStandard/")
    public ResponseWrapper update(@RequestBody StandardVO VO);

    @ApiOperation(value = "删除指标标准", notes = "参数：指标标准id(可传入多个)，操作用户id")
    @RequestMapping(method = RequestMethod.DELETE, value = "/indStandards")
    public ResponseWrapper deletes(@RequestBody String[] ids, @RequestParam("userId") String userId);

    @ApiOperation(value = "查询所有指标标准，分页", notes = "参数：指标标准名模糊查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @RequestMapping(method = RequestMethod.POST, value = "/indStandards")
    public ResponseWrapper findByPage(@RequestBody StandardVO VO,
                                      @RequestParam("page") Integer page,
                                      @RequestParam("size") Integer size);

    @ApiOperation(value = "查询所有指标标准，不分页", notes = "参数：无、当前页、页面大小")
    @RequestMapping(method = RequestMethod.GET, value = "/indStandards")
    public ResponseWrapper findAll();
}
