package com.unis.indicator.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.PriceStatisticsInputVO;
import com.unis.indicator.common.vo.PriceTrendQueryVO;
import com.unis.indicator.common.vo.StatisticsInputVO;
import com.unis.indicator.common.vo.WeeklyReportVO;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

/**
 * @author renyu
 * @version 1.0
 * @Title: StatisticsFeign
 * @ProjectName
 * @Description:
 * @date
 */
@FeignClient(name = "indicator-server")
@Component
public interface StatisticsFeign {

    @ApiOperation(value = "天津上报统计", notes = "查询条件：统计时间段、检测点、价格类型、填报方式")
    @RequestMapping(method = RequestMethod.POST, value = "/reportStatisticsOne/")
    public ResponseWrapper getTjStatistics(@RequestBody StatisticsInputVO statisticsInputVO);

    @ApiOperation(value = "天津上报统计详情", notes = "查询条件：检测点、价格类型")
    @RequestMapping(method = RequestMethod.POST, value = "/reportStatisticsOneInfo/")
    public ResponseWrapper getTjStatisticsInfo(@RequestBody StatisticsInputVO statisticsInputVO);

    @ApiOperation(value = "内蒙上报统计查询", notes = "查询条件：统计时间段、检测点、价格类型")
    @RequestMapping(method = RequestMethod.POST, value = "/reportStatisticsMany/")
    public ResponseWrapper getNmStatistics(@RequestBody StatisticsInputVO statisticsInputVO);

    @ApiOperation(value = "价格统计日报表", notes = "参数：统计时间段、检测点、价格类型、统计品种")
    @RequestMapping(method = RequestMethod.POST, value = "/priceDay/")
    public ResponseWrapper getPriceDay(@RequestBody PriceStatisticsInputVO priceStatisticsInputVO);

    @ApiOperation(value = "价格统计周报表", notes = "参数：统计时间段、检测点、价格类型、统计品种")
    @RequestMapping(method = RequestMethod.POST, value = "/priceWeek/")
    public ResponseWrapper getPriceWeek(@RequestBody PriceStatisticsInputVO priceStatisticsInputVO);

    @ApiOperation(value = "价格统计月报表", notes = "参数：统计时间段、检测点、价格类型、统计品种")
    @RequestMapping(method = RequestMethod.POST, value = "/priceMonth/")
    public ResponseWrapper getPriceMonth(@RequestBody PriceStatisticsInputVO priceStatisticsInputVO);

    @ApiOperation(value = "无固定时间统计", notes = "参数：统计时间段、检测点、价格类型、统计品种")
    @RequestMapping(method = RequestMethod.POST, value = "/timePrice/")
    public ResponseWrapper getTimePrice(@RequestBody PriceStatisticsInputVO priceStatisticsInputVO);

    @ApiOperation(value = "周刊报表列表", notes = "参数：上报时间段、报表类型")
    @RequestMapping(method = RequestMethod.POST, value = "/weeklyReports/")
    public ResponseWrapper getWeeklyReportList(@RequestBody WeeklyReportVO weeklyReportVO);

    @ApiOperation(value = "周刊报表详情", notes = "参数：参数：上报结束时间、报表类型")
    @RequestMapping(method = RequestMethod.POST, value = "/weeklyReportInfo/")
    public ResponseWrapper getWeeklyReportInfo(@RequestBody WeeklyReportVO weeklyReportVO);

    @ApiOperation(value = "价格走势图表", notes = "参数：报表类型、报表期类型、统计开始时间、统计结束时间")
    @RequestMapping(method = RequestMethod.POST, value = "/trendChart/")
    public ResponseWrapper getTrendChart(@RequestBody PriceTrendQueryVO priceTrendQueryVO);

    @ApiOperation(value = "价格走势图表ByZs", notes = "参数：报表类型、报表期类型、统计开始时间、统计结束时间")
    @RequestMapping(method = RequestMethod.POST, value = "/trendChartByZs/")
    public ResponseWrapper getTrendChartByZs(@RequestBody PriceTrendQueryVO priceTrendQueryVO);

    @ApiOperation(value = "周报月统计", notes = "参数：统计时间月份、统计品种")
    @RequestMapping(method = RequestMethod.POST, value = "/PriceMonthAvg/")
    public ResponseWrapper getPriceMonthAvg(@RequestBody PriceStatisticsInputVO priceStatisticsInputVO);

    @ApiOperation(value = "周均价统计", notes = "参数：要统计的星期一和星期天的日期、统计品种")
    @RequestMapping(method = RequestMethod.POST, value = "/PriceWeekAvg/")
    public ResponseWrapper getPriceWeekAvg(@RequestBody PriceStatisticsInputVO priceStatisticsInputVO);
}
