package com.unis.indicator.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.UnitVO;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

/**
 * @author xmpu
 * @version 1.0
 * @Title: UnitFeign
 * @ProjectName IndicatorService
 * @Description: Indicator层fegin接口
 * @date 2019/7/7 18:05
 */
@FeignClient(name = "indicator-server")
@Component
public interface UnitFeign {

    @ApiOperation(value = "根据id查询指标单位类型信息", notes = "参数：指标单位类型信息id")
    @RequestMapping(method = RequestMethod.GET, value = "/indUnit/{id}/")
    public ResponseWrapper findById(@PathVariable("id") String id);



    @ApiOperation(value = "通过unitId查询指标和单位关联信息", notes = "参数：指标单位类型信息id")
    @RequestMapping(method = RequestMethod.GET, value = "/unitIndRel/{unitId}/")
    public ResponseWrapper findUnitIndRel(@PathVariable("unitId") String unitId);

    @ApiOperation(value = "保存指标单位信息", notes = "参数：指标单位对象VO")
    @RequestMapping(method = RequestMethod.POST, value = "/indUnit/")
    public ResponseWrapper save(@RequestBody UnitVO VO);

    @ApiOperation(value = "更新指标单位信息", notes = "参数：指标单位VO")
    @RequestMapping(method = RequestMethod.PUT, value = "/indUnit/")
    public ResponseWrapper update(@RequestBody UnitVO VO);

    @ApiOperation(value = "删除指标单位", notes = "参数：指标单位id(可传入多个)，操作用户id")
    @RequestMapping(method = RequestMethod.DELETE, value = "/indUnits")
    public ResponseWrapper deletes(@RequestBody String[] ids, @RequestParam("userId") String userId);

    @ApiOperation(value = "查询所有指标单位，分页", notes = "参数：指标单位名模糊查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @RequestMapping(method = RequestMethod.POST, value = "/indUnits")
    public ResponseWrapper findByPage(@RequestBody UnitVO VO,
                                      @RequestParam("page") Integer page,
                                      @RequestParam("size") Integer size);

    @ApiOperation(value = "查询所有指标单位，不分页", notes = "参数：无")
    @RequestMapping(method = RequestMethod.GET, value = "/indUnits")
    public ResponseWrapper findAll();
}
