package com.unis.indicator.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.WeightVO;
import com.unis.indicator.common.vo.WeightValueVO;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author xmpu
 * @version 1.0
 * @Title: WeightFeign
 * @ProjectName IndicatorService
 * @Description: Indicator层fegin接口
 * @date 2019/7/7 18:05
 */
@FeignClient(name = "indicator-server")
@Component
public interface WeightFeign {

    @ApiOperation(value = "根据id查询权重类型信息", notes = "参数：权重类型信息id")
    @RequestMapping(method = RequestMethod.GET, value = "/weight/{id}/")
    public ResponseWrapper findById(@PathVariable("id") String id);

    @ApiOperation(value = "保存权重信息", notes = "参数：权重对象VO")
    @RequestMapping(method = RequestMethod.POST, value = "/weight/")
    public ResponseWrapper save(@RequestBody WeightVO VO);

    @ApiOperation(value = "更新权重信息", notes = "参数：权重VO")
    @RequestMapping(method = RequestMethod.PUT, value = "/weight/")
    public ResponseWrapper update(@RequestBody WeightVO VO);

    @ApiOperation(value = "删除权重", notes = "参数：权重id(可传入多个)，操作用户id")
    @RequestMapping(method = RequestMethod.DELETE, value = "/weights")
    public ResponseWrapper deletes(@RequestBody String[] ids, @RequestParam("userId") String userId);

    @ApiOperation(value = "查询所有权重，分页", notes = "参数：权重名模糊查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @RequestMapping(method = RequestMethod.POST, value = "/weights")
    public ResponseWrapper findByPage(@RequestBody WeightVO VO,
                                      @RequestParam("page") Integer page,
                                      @RequestParam("size") Integer size);

    @ApiOperation(value = "查询所有权重，不分页", notes = "参数：无")
    @RequestMapping(method = RequestMethod.GET, value = "/weights")
    public ResponseWrapper findAll();

    @ApiOperation(value = "通过权重code查询权重值信息", notes = "参数：权重code")
    @RequestMapping(method = RequestMethod.GET, value = "/weightVals/{weightCode}/")
    public ResponseWrapper findWeightValByWeightCode(@PathVariable("weightCode") String weightCode);

    @ApiOperation(value = "通过权重type查询权重值信息", notes = "参数：权重type")
    @RequestMapping(method = RequestMethod.GET, value = "/weightValsByType/{weightType}/")
    public ResponseWrapper findWeightValByWeightType(@PathVariable("weightType") String weightType);

    @ApiOperation(value = "获取权重流水号", notes = "参数：无")
    @RequestMapping(method = RequestMethod.GET, value = "/serialNumber/")
    public ResponseWrapper serialNumber();

//    @ApiOperation(value = "保存权重值信息", notes = "参数：权重值对象集合")
//    @RequestMapping(method = RequestMethod.POST, value = "/weightVals")
//    public ResponseWrapper saveWeightVals(@RequestBody List<WeightValueVO> VOList,
//                                          @RequestParam String weightCode);
}
