/*
 * DataFloatController.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2020-08-11 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.indicator.server.controller;

import com.unis.common.constant.BaseStatusConstant;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.common.vo.groups.InsertGroup;
import com.unis.common.vo.groups.UpdateGroup;
import com.unis.indicator.common.vo.log.DataFloatListVO;
import com.unis.indicator.common.vo.log.DataFloatShowVO;
import com.unis.indicator.common.vo.log.DataFloatVO;
import com.unis.indicator.server.service.DataFloatService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

//import org.springframework.web.bind.annotation.GetMapping;

/**
 * DATA_FLOAT-数据浮动记录表
 * @author lipenghe at 2020-08-11 15:36:32
 */
@RestController
@RequestMapping("/manager/log")
@Api( tags = "数据浮动记录表---数据浮动记录表")
public class DataFloatController {

    @Autowired
    private DataFloatService dataFloatService;

    @ApiOperation(value = "数据浮动记录表---数据浮动记录表---选择性保存,包含新增和修改", notes = "数据浮动记录表")
    @PostMapping("/dataFloat/saveEntitySelective")
    public ResponseWrapper saveEntitySelective(
        @RequestBody DataFloatVO dataFloatVO) {
        return dataFloatService.saveEntitySelectiveResult(dataFloatVO);
    }

    @ApiOperation(value = "数据浮动记录表---数据浮动记录表---选择性插入字段", notes = "数据浮动记录表")
    @PostMapping("/dataFloat/insertEntitySelective")
    public ResponseWrapper insertEntitySelective(
        @Validated({InsertGroup.class}) @RequestBody DataFloatVO dataFloatVO
        , BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return dataFloatService.insertEntitySelectiveResult(dataFloatVO);
        }
    }

    @ApiOperation(value = "数据浮动记录表---数据浮动记录表----根据实体不为空的属性,选择性更新字段", notes = "数据浮动记录表")
    @PostMapping("/dataFloat/updateByEntitySelective")
    public ResponseWrapper updateByEntitySelective(
        @Validated({UpdateGroup.class}) @RequestBody DataFloatVO dataFloatVO
        , BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return dataFloatService.updateByEntitySelectiveResult(dataFloatVO,null);
        }
    }

    @ApiOperation(value = "数据浮动记录表---数据浮动记录表---更改状态", notes = "数据浮动记录表")
    @PostMapping("/dataFloat/updateStatusByEntity")
    public ResponseWrapper updateStatusByEntity(
        @RequestBody DataFloatVO dataFloatVO) {
        if(dataFloatVO!=null){
            return dataFloatService.updateStatusByEntityResult(dataFloatVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "数据浮动记录表---数据浮动记录表---[真删除]根据实体的某些属性进行单条或者批量删除", notes = "数据浮动记录表")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "id", value = "id#<唯一>", dataType = "Long", paramType = "header")
        ,@ApiImplicitParam(name = "idStr", value = "id字符串#<唯一>", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "folatId", value = "数据浮动表主键#<主键><唯一><非空>", dataType = "Long", paramType = "header")
    })
    @PostMapping("/dataFloat/deleteByEntity")
    public ResponseWrapper deleteByEntity(
        @RequestBody DataFloatShowVO dataFloatShowVO){
        if(dataFloatShowVO!=null){
            DataFloatVO dataFloatVO= JsonUtils.parse(
                JsonUtils.serialize(dataFloatShowVO), DataFloatVO.class);
            dataFloatVO.setStatus(Integer.valueOf(BaseStatusConstant.STATUS_DELETED));
            return dataFloatService.deleteByEntityResult(dataFloatVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "数据浮动记录表---数据浮动记录表---根据实体(唯一标示)查询一条数据", notes = "数据浮动记录表")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "id", value = "id#<唯一>", dataType = "Long", paramType = "header")
        ,@ApiImplicitParam(name = "idStr", value = "id字符串#<唯一>", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "folatId", value = "数据浮动表主键#<主键><唯一><非空>", dataType = "Long", paramType = "header")
    })
    @PostMapping("/dataFloat/selectById")
    public ResponseWrapper selectById(
        @RequestBody DataFloatShowVO dataFloatShowVO){
        if(dataFloatShowVO!=null){
            DataFloatVO dataFloatVO= JsonUtils.parse(
                JsonUtils.serialize(dataFloatShowVO), DataFloatVO.class);
            return dataFloatService.selectByIdResult(dataFloatVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "数据浮动记录表---数据浮动记录表---根据实体的某些属性查询分页数据,pageSize,pageNum从url传", notes = "数据浮动记录表")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query")
        ,@ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/dataFloat/selectPageByEntity")
    public ResponseWrapper selectPageByEntity(
        @RequestParam(value = "pageNum", defaultValue = "1") int pageNum
        ,@RequestParam(value = "pageSize", defaultValue = "10") int pageSize
        ,@RequestBody DataFloatListVO dataFloatListVO) {
        DataFloatVO dataFloatVO= JsonUtils.parse(
            JsonUtils.serialize(dataFloatListVO), DataFloatVO.class);
        return dataFloatService.selectPageByEntityResult(pageNum,pageSize
            , dataFloatVO,"FOLAT_ID DESC");
    }

    @ApiOperation(value = "数据浮动记录表---数据浮动记录表---根据实体的某些属性查询列表", notes = "数据浮动记录表")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query")
        ,@ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/dataFloat/selectByEntity")
    public ResponseWrapper selectByEntity(
        @RequestBody DataFloatListVO dataFloatListVO) {
        DataFloatVO dataFloatVO= JsonUtils.parse(
            JsonUtils.serialize(dataFloatListVO), DataFloatVO.class);
        return dataFloatService.selectByEntityResult(dataFloatVO);
    }

    @ApiOperation(value = "数据浮动记录表---数据浮动记录表---初始化数据", notes = "数据浮动记录表")
    @PostMapping("/dataFloat/selectInitData")
    public ResponseWrapper selectInitData(
        @RequestBody DataFloatVO dataFloatVO){
        if(dataFloatVO!=null){
            return dataFloatService.selectInitDataResult(dataFloatVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }
}
