package com.unis.indicator.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.bbzb.IndiBreedSpcVO;
import com.unis.indicator.server.service.IndiBreedSpcService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * @ClassName ZbppggController
 * @Description 指标品牌规格管理controller
 * @Author xmpu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@RestController
@Slf4j
@Api(tags = "指标品牌规格管理controller")
public class IndiBreedSpcController {

    @Autowired
    private IndiBreedSpcService indiBreedSpcService;

    /**
     * @Description: 通过id查询指标品牌规格信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param id
     * @return ResponseWrapper
     */
    @ApiOperation(value = "根据指标id查询指标品牌规格信息", notes = "参数：指标品牌规格信息指标id")
    @GetMapping(value = "/indiBreedSpc/{id}/")
    public ResponseWrapper findById(@PathVariable("id") String id) throws Exception {
        List<String> resVO = indiBreedSpcService.findByIndicatorId(id);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                resVO);
    }

    /**
     * @Description: 保存指标品牌规格信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "保存or更新指标品牌规格信息", notes = "参数：指标品牌规格对象VO")
    @PostMapping(value = "/indiBreedSpc/")
    public ResponseWrapper save(@RequestBody IndiBreedSpcVO VO) throws Exception {
//        IndiBreedSpcVO indiBreedSpc = indiBreedSpcService.findByIndicatorId(VO);
        boolean flag;
//        if(indiBreedSpc != null) {
//            flag = indiBreedSpcService.update(VO);
//
//        } else {
            flag = indiBreedSpcService.save(VO);
//        }
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "对象已存在无法添加");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 更新
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "更新指标品牌规格配置的产地信息", notes = "参数：指标品牌规格VO")
    @PutMapping(value = "/indiBreedSpc/")
    public ResponseWrapper update(@RequestBody IndiBreedSpcVO VO) throws Exception {

        boolean flag = indiBreedSpcService.update(VO);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "更新对象失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 删除指标品牌规格
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @param ids
     * @return ResponseWrapper
     */
    @ApiOperation(value = "删除指标品牌规格", notes = "参数：指标品牌规格id(可传入多个), 操作用户id")
    @DeleteMapping(value = "/indiBreedSpcs")
    public ResponseWrapper deletes(@RequestBody String[] ids, String userId) throws Exception {
        boolean flag = indiBreedSpcService.deletes(ids, userId);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "删除指标品牌规格失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 指标品牌规格
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @param page
     * @param size
     * @return ResponseWrapper
     */
    @ApiOperation(value = "查询所有指标品牌规格，分页", notes = "参数：指标品牌规格名模糊查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @PostMapping(value = "/indiBreedSpcs")
    public ResponseWrapper findByPage(@RequestBody IndiBreedSpcVO VO,
                                      Integer page,
                                      Integer size) throws Exception {
        Map<String, Object> result = indiBreedSpcService.findByPage(VO, page, size);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }

    /**
     * @Description: 指标品牌规格
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "查询所有指标品牌规格，不分页", notes = "参数：无")
    @GetMapping(value = "/indiBreedSpcs")
    public ResponseWrapper findAll() throws Exception {
        Map<String, Object> result = indiBreedSpcService.findByPage(new IndiBreedSpcVO(), 1, 999);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }
}
