/*
 * LogDataChangeController.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2020-08-06 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.indicator.server.controller;

import com.unis.common.constant.BaseStatusConstant;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.common.vo.groups.InsertGroup;
import com.unis.common.vo.groups.UpdateGroup;
import com.unis.indicator.common.vo.log.LogDataChangeListVO;
import com.unis.indicator.common.vo.log.LogDataChangeShowVO;
import com.unis.indicator.common.vo.log.LogDataChangeVO;
import com.unis.indicator.server.service.LogDataChangeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

//import org.springframework.web.bind.annotation.GetMapping;

/**
 * LOG_DATA_CHANGE-数据变动日志表
 * @author lipenghe at 2020-08-06 15:42:51
 */
@RestController
@RequestMapping("/manager/log")
@Api( tags = "数据改动---数据变动日志表")
public class LogDataChangeController {

    @Autowired
    private LogDataChangeService logDataChangeService;

    @ApiOperation(value = "数据改动---数据变动日志表---选择性保存,包含新增和修改", notes = "数据改动")
    @PostMapping("/logDataChange/saveEntitySelective")
    public ResponseWrapper saveEntitySelective(
        @RequestBody LogDataChangeVO dataChangeVO) {
        return logDataChangeService.saveEntitySelectiveResult(dataChangeVO);
    }

    @ApiOperation(value = "数据改动---数据变动日志表---选择性插入字段", notes = "数据改动")
    @PostMapping("/logDataChange/insertEntitySelective")
    public ResponseWrapper insertEntitySelective(
        @Validated({InsertGroup.class}) @RequestBody LogDataChangeVO dataChangeVO
        , BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return logDataChangeService.insertEntitySelectiveResult(dataChangeVO);
        }
    }

    @ApiOperation(value = "数据改动---数据变动日志表----根据实体不为空的属性,选择性更新字段", notes = "数据改动")
    @PostMapping("/logDataChange/updateByEntitySelective")
    public ResponseWrapper updateByEntitySelective(
        @Validated({UpdateGroup.class}) @RequestBody LogDataChangeVO dataChangeVO
        , BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return logDataChangeService.updateByEntitySelectiveResult(dataChangeVO,null);
        }
    }

    @ApiOperation(value = "数据改动---数据变动日志表---更改状态", notes = "数据改动")
    @PostMapping("/logDataChange/updateStatusByEntity")
    public ResponseWrapper updateStatusByEntity(
        @RequestBody LogDataChangeVO dataChangeVO) {
        if(dataChangeVO!=null){
            return logDataChangeService.updateStatusByEntityResult(dataChangeVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "数据改动---数据变动日志表---[真删除]根据实体的某些属性进行单条或者批量删除", notes = "数据改动")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "id", value = "id#<唯一>", dataType = "Long", paramType = "header")
        ,@ApiImplicitParam(name = "idStr", value = "id字符串#<唯一>", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "logId", value = "数据变动日志表主键#<主键><唯一><非空>", dataType = "Long", paramType = "header")
    })
    @PostMapping("/logDataChange/deleteByEntity")
    public ResponseWrapper deleteByEntity(
        @RequestBody LogDataChangeShowVO dataChangeShowVO){
        if(dataChangeShowVO!=null){
            LogDataChangeVO dataChangeVO= JsonUtils.parse(
                JsonUtils.serialize(dataChangeShowVO), LogDataChangeVO.class);
            dataChangeVO.setStatus(Integer.valueOf(BaseStatusConstant.STATUS_DELETED));
            return logDataChangeService.deleteByEntityResult(dataChangeVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "数据改动---数据变动日志表---根据实体(唯一标示)查询一条数据", notes = "数据改动")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "id", value = "id#<唯一>", dataType = "Long", paramType = "header")
        ,@ApiImplicitParam(name = "idStr", value = "id字符串#<唯一>", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "logId", value = "数据变动日志表主键#<主键><唯一><非空>", dataType = "Long", paramType = "header")
    })
    @PostMapping("/logDataChange/selectById")
    public ResponseWrapper selectById(
        @RequestBody LogDataChangeShowVO dataChangeShowVO){
        if(dataChangeShowVO!=null){
            LogDataChangeVO dataChangeVO= JsonUtils.parse(
                JsonUtils.serialize(dataChangeShowVO), LogDataChangeVO.class);
            return logDataChangeService.selectByIdResult(dataChangeVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "数据改动---数据变动日志表---根据实体的某些属性查询分页数据,pageSize,pageNum从url传", notes = "数据改动")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query")
        ,@ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/logDataChange/selectPageByEntity")
    public ResponseWrapper selectPageByEntity(
        @RequestParam(value = "pageNum", defaultValue = "1") int pageNum
        ,@RequestParam(value = "pageSize", defaultValue = "10") int pageSize
        ,@RequestBody LogDataChangeListVO dataChangeListVO) {
        LogDataChangeVO dataChangeVO= JsonUtils.parse(
            JsonUtils.serialize(dataChangeListVO), LogDataChangeVO.class);
        return logDataChangeService.selectPageByEntityResult(pageNum,pageSize
            , dataChangeVO,"LOG_ID DESC");
    }

    @ApiOperation(value = "数据改动---数据变动日志表---根据实体的某些属性查询列表", notes = "数据改动")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query")
        ,@ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/logDataChange/selectByEntity")
    public ResponseWrapper selectByEntity(
        @RequestBody LogDataChangeListVO dataChangeListVO) {
        LogDataChangeVO dataChangeVO= JsonUtils.parse(
            JsonUtils.serialize(dataChangeListVO), LogDataChangeVO.class);
        return logDataChangeService.selectByEntityResult(dataChangeVO);
    }

    @ApiOperation(value = "数据改动---数据变动日志表---初始化数据", notes = "数据改动")
    @PostMapping("/logDataChange/selectInitData")
    public ResponseWrapper selectInitData(
        @RequestBody LogDataChangeVO dataChangeVO){
        if(dataChangeVO!=null){
            return logDataChangeService.selectInitDataResult(dataChangeVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }
}
