package com.unis.indicator.server.controller;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.ReportRecordVO;
import com.unis.indicator.server.service.MarketTrendService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;

/**
 * @ClassName MarketTrendController
 * @Description 本周行情、价格走势
 * @Author lifx
 * @Date 2019年8月28日11:26:22
 * @Version 0.0.1
 **/
@RestController
@Slf4j
@Api(tags = "本周行情controller")
public class MarketTrendController {

    @Autowired
    private MarketTrendService marketTrendService;


	/**
	 * @Description: 查询本周行情--查询上报开始、结束时间
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
  
    @ApiOperation(value = "查询上报时间", notes = "参数：上报时间查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @PostMapping(value = "/queryReportTime")
    public ResponseWrapper queryReportTime(@RequestBody ReportRecordVO VO,
                                      Integer page,
                                      Integer size) throws Exception {
        Map<String, Object> result = marketTrendService.queryReportTime(VO, page, size);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }
    
    /**
	 * @Description: 查询本周行情--查询国家局详情
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
  
    @ApiOperation(value = "查询国家局详情", notes = "参数：上报时间查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @PostMapping(value = "/queryCountryDetails")
    public ResponseWrapper queryCountryDetails(@RequestBody ReportRecordVO VO,
                                      Integer page,
                                      Integer size) throws Exception {
        Map<String, Object> result = marketTrendService.queryCountryDetails(VO, page, size);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }
    
	/**
	 * @Description: 查询本周行情--查询库点详情
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
    @ApiOperation(value = "查询库点详情", notes = "参数：上报时间查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @PostMapping(value = "/queryPointDetails")
    public ResponseWrapper queryPointDetails(@RequestBody ReportRecordVO VO,
                                      Integer page,
                                      Integer size) throws Exception {
        Map<String, Object> result = marketTrendService.queryPointDetails(VO, page, size);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }

    
    /**
	 * @Description: 价格走势-原粮
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
    @ApiOperation(value = "价格走势-原粮", notes = "参数：上报时间查询")
    @PostMapping(value = "/queryPriceYl")
    public ResponseWrapper queryPriceYl(@RequestBody ReportRecordVO VO ) throws Exception {
        Map<String, Object> result = marketTrendService.queryPriceYl(VO);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }
    
    /**
  	 * @Description: 价格走势-成品粮
  	 * @date 2019年8月28日15:00:44
  	 * @author lifx
  	 * @version v1.0
  	 *
  	 * @param VO
  	 * @param page
  	 * @param size
  	 * @return Map
  	 * @throws Exception
  	 */
      @ApiOperation(value = "价格走势-成品粮", notes = "参数：上报时间查询")
      @PostMapping(value = "/queryPriceCPL")
      public ResponseWrapper queryPriceCPL(@RequestBody ReportRecordVO VO )throws Exception {
          Map<String, Object> result = marketTrendService.queryPriceCPL(VO);
          return ResponseWrapper.success(
                  HttpStatus.OK.value(),
                  HttpStatus.OK.getReasonPhrase(),
                  result);
      }
    
    /**
   	 * @Description: 价格走势-食用油及油料
   	 * @date 2019年8月28日15:00:44
   	 * @author lifx
   	 * @version v1.0
   	 *
   	 * @param VO
   	 * @param page
   	 * @param size
   	 * @return Map
   	 * @throws Exception
   	 */
       @ApiOperation(value = "价格走势-食用油及油料", notes = "参数：上报时间查询")
       @PostMapping(value = "/queryPriceSYY")
       public ResponseWrapper queryPriceSYY(@RequestBody ReportRecordVO VO ) throws Exception{
    	   Map<String, Object> result = marketTrendService.queryPriceSYY(VO);
           return ResponseWrapper.success(
                   HttpStatus.OK.value(),
                   HttpStatus.OK.getReasonPhrase(),
                   result);
       }
    
       /**
   	 * @Description: 价格走势-原粮
   	 * @date 2019年8月28日15:00:44
   	 * @author lifx
   	 * @version v1.0
   	 *
   	 * @param VO
   	 * @param page
   	 * @param size
   	 * @return Map
   	 * @throws Exception
   	 */
       @ApiOperation(value = "价格走势-监测点原粮", notes = "参数：上报时间查询")
       @PostMapping(value = "/queryPricePointYL")
       public ResponseWrapper queryPricePointYL(@RequestBody ReportRecordVO VO ) throws Exception {
           Map<String, Object> result = marketTrendService.queryPricePointYL(VO);
           return ResponseWrapper.success(
                   HttpStatus.OK.value(),
                   HttpStatus.OK.getReasonPhrase(),
                   result);
       }
       
       /**
     	 * @Description: 价格走势-成品粮
     	 * @date 2019年8月28日15:00:44
     	 * @author lifx
     	 * @version v1.0
     	 *
     	 * @param VO
     	 * @param page
     	 * @param size
     	 * @return Map
     	 * @throws Exception
     	 */
         @ApiOperation(value = "价格走势-监测点成品粮", notes = "参数：上报时间查询")
         @PostMapping(value = "/queryPricePointCPL")
         public ResponseWrapper queryPricePointCPL(@RequestBody ReportRecordVO VO )throws Exception {
             Map<String, Object> result = marketTrendService.queryPricePointCPL(VO);
             return ResponseWrapper.success(
                     HttpStatus.OK.value(),
                     HttpStatus.OK.getReasonPhrase(),
                     result);
         }
       
       /**
      	 * @Description: 价格走势-食用油及油料
      	 * @date 2019年8月28日15:00:44
      	 * @author lifx
      	 * @version v1.0
      	 *
      	 * @param VO
      	 * @param page
      	 * @param size
      	 * @return Map
      	 * @throws Exception
      	 */
          @ApiOperation(value = "价格走势-监测点食用油及油料", notes = "参数：上报时间查询")
          @PostMapping(value = "/queryPricePointSYY")
          public ResponseWrapper queryPricePointSYY(@RequestBody ReportRecordVO VO ) throws Exception{
       	   Map<String, Object> result = marketTrendService.queryPricePointSYY(VO);
              return ResponseWrapper.success(
                      HttpStatus.OK.value(),
                      HttpStatus.OK.getReasonPhrase(),
                      result);
          }
       
          /**
      	 * @Description: 价格走势-原粮--指定价格
      	 * @date 2019年8月28日15:00:44
      	 * @author lifx
      	 * @version v1.0
      	 *
      	 * @param VO
      	 * @param page
      	 * @param size
      	 * @return Map
      	 * @throws Exception
      	 */
          @ApiOperation(value = "价格走势-原粮-指定价格", notes = "参数：上报时间查询")
          @PostMapping(value = "/queryPriceYLZD")
          public ResponseWrapper queryPriceYLZD(@RequestBody ReportRecordVO VO ) throws Exception {
              Map<String, Object> result = marketTrendService.queryPriceYLZD(VO);
              return ResponseWrapper.success(
                      HttpStatus.OK.value(),
                      HttpStatus.OK.getReasonPhrase(),
                      result);
          }
          
          /**
        	 * @Description: 价格走势-成品粮--指定价格
        	 * @date 2019年8月28日15:00:44
        	 * @author lifx
        	 * @version v1.0
        	 *
        	 * @param VO
        	 * @param page
        	 * @param size
        	 * @return Map
        	 * @throws Exception
        	 */
            @ApiOperation(value = "价格走势-成品粮-指定价格", notes = "参数：上报时间查询")
            @PostMapping(value = "/queryPriceCPLZD")
            public ResponseWrapper queryPriceCPLZD(@RequestBody ReportRecordVO VO )throws Exception {
                Map<String, Object> result = marketTrendService.queryPriceCPLZD(VO);
                return ResponseWrapper.success(
                        HttpStatus.OK.value(),
                        HttpStatus.OK.getReasonPhrase(),
                        result);
            }

	/**
	 * @Description: 工作台价格走势(每月均价)
	 * @date 2019/12/12 10:28
	 * @author yangshengjie
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	@ApiOperation(value = "工作台价格走势(每月均价)", notes = "参数：查询年份,价格类型，品种名称")
	@PostMapping(value = "/workbenchQueryPriceY/")
	public ResponseWrapper workbenchQueryPriceY(@RequestBody ReportRecordVO VO ) throws Exception{
		List result = marketTrendService.workbenchQueryPriceY(VO);
		return ResponseWrapper.success(
				HttpStatus.OK.value(),
				HttpStatus.OK.getReasonPhrase(),
				result);
	}

	/**
	 * @Description: 工作台价格走势(品种多选)
	 * @date 2019/12/12 17:26
	 * @author yangshengjie
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	@ApiOperation(value = "工作台价格走势(品种多选)", notes = "参数：查询年份,价格类型，品种名称")
	@PostMapping(value = "/workbenchQueryPriceM/")
	public ResponseWrapper workbenchQueryPriceM(@RequestBody ReportRecordVO VO ) throws Exception{
		List result = marketTrendService.workbenchQueryPriceM(VO);
		return ResponseWrapper.success(
				HttpStatus.OK.value(),
				HttpStatus.OK.getReasonPhrase(),
				result);
	}

}
