package com.unis.indicator.server.controller;

import com.alibaba.fastjson.JSONObject;
import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.*;
import com.unis.indicator.common.vo.bbzb.ReportTypeVO;
import com.unis.indicator.server.service.ReportRecordService;
import com.unis.indicator.server.service.ReportRecordTypeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

@RestController
@Slf4j
@Api(tags = "报表controller")
public class ReportRecordController {

    @Autowired
    private ReportRecordTypeService reportRecordTypeService;

    @Autowired
    private ReportRecordService reportRecordService;

    /**
     * @Description: 津粮网粮食价格走势
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食价格走势",notes = "参数：统计时间段、价格类别、品种、地区")
    @PostMapping(value = "/price/")
    public ResponseWrapper price(@RequestBody ReportRecordVO bbvo){
        try {
            Map<String,Object> price = reportRecordService.findByQuery(bbvo);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), price);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"查询失败");
        }
    }

    /**
     * @Description: 内蒙粮油价格上报
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮油价格上报（一对多）",notes = "粮油价格上报新增")
    @PostMapping(value = "/reportMany/")
    public ResponseWrapper save(@RequestBody ReportRecordInfoVO reportRecordInfoVO){
        try {
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
            Date date = new Date();
            if(sdf.format(date).compareTo(reportRecordInfoVO.getSbkssj()) >= 0 && sdf.format(date).compareTo(reportRecordInfoVO.getSbjssj()) <= 0){
                Boolean status = reportRecordService.save(reportRecordInfoVO);
                if(status){
                    return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), null);
                }else{
                    return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"已有当期填报记录");
                }
            }else{
                return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"不在该报表类型可填报时间内");
            }
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"添加失败");
        }
    }

    /**
     * @Description: 天津粮油价格上报
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮油价格上报（一对一）",notes = "天津粮油价格上报新增")
    @PostMapping(value = "/reportOne/")
    public ResponseWrapper saveOne(@RequestBody ReportRecordInfoVO reportRecordInfoVO){
        try {
            Boolean status = reportRecordService.saveOne(reportRecordInfoVO);
            if(status == true){
                return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), null);
            }else{
                return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"已有当期填报记录");
            }

        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"添加失败");
        }
    }

    /**
     * @Description: 天津粮油价格编辑
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮油价格编辑(一对一)",notes = "粮油价格修改")
    @PutMapping(value = "/reportOne/")
    public ResponseWrapper updateOne(@RequestBody ReportRecordInfoVO reportRecordInfoVO) throws ParseException {
        return reportRecordService.updateOne(reportRecordInfoVO);
    }

    /**
     * @Description: 内蒙粮油价格编辑
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮油价格编辑（一对多）",notes = "粮油价格修改")
    @PutMapping(value = "/reportMany/")
    public ResponseWrapper update(@RequestBody ReportRecordInfoVO reportRecordInfoVO){
        try {
            reportRecordService.update(reportRecordInfoVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), null);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"修改失败");
        }
    }

    /**
     * @Description: 填报记录状态修改
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "填报记录状态修改",notes = "填报记录状态修改")
    @PutMapping(value = "/process/")
    public ResponseWrapper statusUpdate(@RequestBody ReportRecordStatusVo reportRecordStatusVo){
        try {
            reportRecordService.updateStatus(reportRecordStatusVo);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), null);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"修改失败");
        }
    }

    /**
     * @Description: 内蒙粮油价格详情
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮油价格详情(一对多)",notes = "参数:报表id")
    @GetMapping(value = "/reportMany/{id}/")
    public ResponseWrapper info(@PathVariable("id") String id){
        try {
            ReportRecordInfoVO reportRecordInfoVO = reportRecordService.getById(id);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), reportRecordInfoVO);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"获取失败");
        }
    }

    /**
     * @Description: 天津粮油价格详情
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮油价格详情(一对一)",notes = "参数:报表id")
    @GetMapping(value = "/reportOne/{id}/")
    public ResponseWrapper infoOne(@PathVariable("id") String id){
        try {
            ReportRecordInfoVO reportRecordInfoVO = reportRecordService.getOneById(id);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), reportRecordInfoVO);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"获取失败");
        }
    }

    @ApiOperation(value = "粮油价格详情最新的",notes = "参数:报表id")
    @PostMapping(value = "/reportOneLastest")
    public ResponseWrapper reportOneLastest(@RequestBody PriceTrendQueryVO vo){
        try {
            ReportRecordInfoVO reportRecordInfoVO = reportRecordService.reportOneLastest(vo);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), reportRecordInfoVO);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"获取失败");
        }
    }

    /**
     * @Description: 天津粮油价格详情
     * @date
     * @author yangshengjie
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "天津粮油价格详情(多对一)",notes = "参数:报表id，价格类型")
    @GetMapping(value = "/reportOneTj/{id}/{jglx}/")
    public ResponseWrapper infoOneTj(@PathVariable("id") String id,@PathVariable("jglx") String jglx){
        try {
            ReportRecordInfoVO reportRecordInfoVO = reportRecordService.getOneByIdTj(id,jglx);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), reportRecordInfoVO);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"获取失败");
        }
    }

    /**
     * @Description: 填报记录列表
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "数据上报列表",notes = "参数:上报时间段、监测点、上报地区、报表类型")
    @PostMapping(value = "/reports/")
    public ResponseWrapper getByQuery(@RequestBody ReportRecordListVO reportRecordListVO
    ){
        try {
            Map<String,Object> results = reportRecordService.getByQuery(reportRecordListVO, reportRecordListVO.getPage(), reportRecordListVO.getSize());
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), results);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"查询失败");
        }
    }

    /**
     * @Description: 内蒙古获取上期数据
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "获取上一期数据",notes = "参数:价格类型")
    @PostMapping(value = "/lastReport/")
    public ResponseWrapper lastInfo(@RequestBody ReportRecordListVO reportRecordListVO){
        try {
            ReportRecordInfoVO reportRecordInfoVO = reportRecordService.lastInfo(reportRecordListVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), reportRecordInfoVO);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"获取失败");
        }
    }

    /**
     * @Description: 全国价格指数上报
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "全国价格指数上报",notes = "全国价格指数新增")
    @PostMapping(value = "/nationIndex/")
    public ResponseWrapper save(@RequestBody NationIndexReportInfoVO nationIndexReportInfoVO){
        try {

            Boolean status = reportRecordService.saveQgjgzs(nationIndexReportInfoVO);
            if(status == true){
                return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), null);
            }else{
                return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"已有当期填报记录");
            }
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"添加失败");
        }
    }

    /**
     * @Description: 全国价格指数报表编辑
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "全国价格指数报表编辑",notes = "全国价格指数报表修改")
    @PutMapping(value = "/nationIndex/")
    public ResponseWrapper update(@RequestBody NationIndexReportInfoVO nationIndexReportInfoVO){
        try {
            reportRecordService.updateQgjgzs(nationIndexReportInfoVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), null);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"修改失败");
        }
    }

    /**
     * @Description: 全国价格指数报表查看
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "全国价格指数报表查看",notes = "参数:报表id")
    @GetMapping(value = "/nationIndex/{id}/")
    public ResponseWrapper nationIndexInfo(@PathVariable("id") String id){
        try {
            NationIndexReportInfoVO nationIndexReportInfoVO = reportRecordService.getQgjgzsById(id);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), nationIndexReportInfoVO);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"获取失败");
        }
    }

    /**
     * @Description: 根据当前登录检测点 报表类型 获取驳回数据
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param bblxId
     * @return ResponseWrapper
     */
    @ApiOperation(value = "驳回数据",notes = "盟市和旗县的驳回数据，应以列表的方式展示，价格监测点的数据，应该是以报表的方式展示；")
    @PostMapping(value = "/reject/")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "bblxId", value = "报表类型Id", required = true)})
    public ResponseWrapper getRejectReport(String bblxId, String pointId){
        try {
            Map<String,Object> resultMap = reportRecordService.getRejectReport(bblxId,pointId);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), resultMap);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"获取失败");
        }
    }
    /**
     * @Description: 上报回显数据
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param bblxId
     * @return ResponseWrapper
     */
    @ApiOperation(value = "上报回显数据",notes = "上报回显数据")
    @PostMapping(value = "/rejectby/")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "bblxId", value = "报表类型Id", required = true)})
    public ResponseWrapper getRejectReportBy(String bblxId, String pointId){
        try {
            Map<String,Object> resultMap = reportRecordService.getRejectReportBy(bblxId,pointId);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), resultMap);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"获取失败");
        }
    }
    /**
     * @Description: 根据报表类型id查询的上报记录
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "历史数据获取",notes = "参数:上报时间段、监测点、上报地区、报表类型")
    @PostMapping(value = "/history/")
    public ResponseWrapper getHistoryReport(@RequestBody ReportRecordListVO reportRecordListVO
    ){
        try {
            reportRecordListVO.setPriceType("LtdXKgAUOJ3D7tpkHxP");
            Map<String,Object> results = reportRecordService.getByQuery(reportRecordListVO, reportRecordListVO.getPage(), reportRecordListVO.getSize());
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), results);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"查询失败");
        }
    }

    /**
     * @Description: 价格走势录入(周/月)列表
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "填报记录列表",notes = "")
    @PostMapping(value = "/priceTrends/")
    public ResponseWrapper getPriceTrends(@RequestBody PriceTrendQueryVO priceTrendQueryVO
    ){
        try {
            Map<String,Object> results = reportRecordService.getPriceTrend(priceTrendQueryVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), results);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"查询失败");
        }
    }

    /**
     * @Description: 价格走势录入(周/月)列表(天津)
     * @date
     * @author yangshengjie
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "填报记录列表(天津)",notes = "")
    @PostMapping(value = "/priceTrendsTj/")
    public ResponseWrapper getPriceTrendsTj(@RequestBody PriceTrendQueryVO priceTrendQueryVO
    ){
        try {
            Map<String,Object> results = reportRecordService.getPriceTrendTj(priceTrendQueryVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), results);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"查询失败");
        }
    }

    @ApiOperation(value = "填报记录列表(按创建时间查)",notes = "")
    @PostMapping(value = "/priceTrendsCT/")
    public ResponseWrapper getPriceTrendsCT(@RequestBody PriceTrendQueryVO priceTrendQueryVO
    ){
        try {
            Map<String,Object> results = reportRecordService.getPriceTrendCT(priceTrendQueryVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), results);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"查询失败");
        }
    }

    /**
     * @Description: (周/月)价格走势录入回显
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "回显",notes = "价格期类型 (日报、周报、月报)、价格类型、开始时间、结束时间")
    @PostMapping(value = "/priceTrend/")
    public ResponseWrapper getHistoryPrice(@RequestBody PriceTrendQueryVO priceTrendQueryVO, String orgName, String orgCode
    ){
        try {
            Map<String,Object> result = reportRecordService.getHistoryPrice(priceTrendQueryVO);
            result.put("orgName",orgName);
            result.put("orgCode",orgCode);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), result);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"查询失败");
        }
    }

    /**
     * @Description: 根据报表类型id  查询相应指标列表信息()
     * @date 2019年8月16日,下午5:54:00
     * @author 任宇
     * @version v1.0
     *
     * @param bblxId,type
     * @return ResponseWrapper
     */
    @ApiOperation(value = "报表类型对应指标列表",notes = "报表类型对应指标列表")
    @PostMapping(value = "/reportofindicator/")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "bblxId", value = "报表类型Id", required = true)})
    public ResponseWrapper getReportofindicator(String bblxId ,@RequestBody Map<String,Object> map){
        try {
            List<IndicatorReportVO> indicatorReportVOList = reportRecordTypeService.getReportofindicator(bblxId,map.get("orgCode").toString());
            map.put("list",indicatorReportVOList);
            if (indicatorReportVOList.get(0).getStartTime() != null){
                SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd");
                Calendar cld = Calendar.getInstance(Locale.CHINA);
                cld.setFirstDayOfWeek(Calendar.MONDAY);
                cld.setTimeInMillis(System.currentTimeMillis());

                switch (indicatorReportVOList.get(0).getStartTime()){
                    case "星期一":cld.set(Calendar.DAY_OF_WEEK, Calendar.MONDAY);break;
                    case "星期二":cld.set(Calendar.DAY_OF_WEEK, Calendar.TUESDAY);break;
                    case "星期三":cld.set(Calendar.DAY_OF_WEEK, Calendar.WEDNESDAY);break;
                    case "星期四":cld.set(Calendar.DAY_OF_WEEK, Calendar.THURSDAY);break;
                    case "星期五":cld.set(Calendar.DAY_OF_WEEK, Calendar.FRIDAY);break;
                    case "星期六":cld.set(Calendar.DAY_OF_WEEK, Calendar.SATURDAY);break;
                    case "星期日":cld.set(Calendar.DAY_OF_WEEK, Calendar.SUNDAY);break;
                }
                map.put("startTime",df.format(cld.getTime()));
                switch (indicatorReportVOList.get(0).getEndTime()){
                    case "星期一":cld.set(Calendar.DAY_OF_WEEK, Calendar.MONDAY);break;
                    case "星期二":cld.set(Calendar.DAY_OF_WEEK, Calendar.TUESDAY);break;
                    case "星期三":cld.set(Calendar.DAY_OF_WEEK, Calendar.WEDNESDAY);break;
                    case "星期四":cld.set(Calendar.DAY_OF_WEEK, Calendar.THURSDAY);break;
                    case "星期五":cld.set(Calendar.DAY_OF_WEEK, Calendar.FRIDAY);break;
                    case "星期六":cld.set(Calendar.DAY_OF_WEEK, Calendar.SATURDAY);break;
                    case "星期日":cld.set(Calendar.DAY_OF_WEEK, Calendar.SUNDAY);break;
                }
                map.put("endTime",df.format(cld.getTime()));
            }
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), map);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"获取失败");
        }
    }

    /**
     * @Description: 根据报表类型id  查询相应指标列表信息()
     * @date 2019年8月16日,下午5:54:00
     * @author 任宇
     * @version v1.0
     *
     * @param reportDateType
     * @return ResponseWrapper
     */
    @ApiOperation(value = "根据报表期类型获取报表类型列表",notes = "")
    @PostMapping(value = "/reportOfTypes/")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "reportDateType", value = "报表期类型(日报、周报、月报)", required = true)})
    public ResponseWrapper getReportDateType(String reportDateType){
        try {
            List<ReportTypeVO> reportTypeVOList = reportRecordTypeService.getReportDateType(reportDateType);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), reportTypeVOList);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"获取失败");
        }
    }

    /**
     * @Description: 价格走势根据报表类型获取指标列表
     * @date 2019年8月16日,下午5:54:00
     * @author 任宇
     * @version v1.0
     *
     * @param bblxId
     * @return ResponseWrapper
     */
    @ApiOperation(value = "价格走势根据报表类型获取指标列表",notes = "价格走势根据报表类型获取指标列表")
    @PostMapping(value = "/chartIndicator/")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "bblxId", value = "报表类型Id", required = true)})
    public ResponseWrapper getChartIndicator(String bblxId){
        try {
            List<IndicatorReportVO> indicatorReportVOList = reportRecordTypeService.getChartIndicator(bblxId);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), indicatorReportVOList);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"获取失败");
        }
    }

    /**
     * @Description: 价格走势月批量导入
     * @date 2019年8月16日,下午5:54:00
     * @author 任宇
     * @version v1.0
     *
     * @param file
     * @return ResponseWrapper
     */
    @ApiOperation(value = "价格走势月批量导入",notes = "价格走势月批量导入")
    @PostMapping(value = "/excelInput/")
    public ResponseWrapper excelInput(@RequestPart(value = "file")MultipartFile file,String bblxId){
        try {
           Map<String,Object> resultMap =  reportRecordService.excelInput(file,bblxId);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), resultMap);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"添加失败");
        }
    }

    /**
     * @Description: 定时任务调度(根据监测点、价格类型、日期判断并填充数据(1:判断当日有无上报过该类型数据2:如未上报则按上一期数据记录填充3如已上报则不执行操作))
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "定时任务调度",notes = "定时任务调度")
    @PostMapping(value = "/taskAdd/")
    public ResponseWrapper taskAdd(@RequestBody TaskVO taskVO){
        try {
            reportRecordService.taskAdd(taskVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), null);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"添加失败");
        }
    }

    /**
     * @Description: 价格上报列表导出（弃用）
     * @date 2019年8月16日,下午5:54:00
     * @author 任宇
     * @version v1.0
     *
     * @param id
     * @return ResponseWrapper
     */
    @ApiOperation(value = "价格上报导出",notes = "价格上报导出")
    @GetMapping(value = "/excelOutput/{id}/")
    public ResponseWrapper excelOutput(HttpServletResponse response, @PathVariable("id") String id){
        try {
            reportRecordService.excelOutput(id,response);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), null);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"添加失败");
        }
    }

    /**
     * @Description: 价格走势月录入模版下载(弃用)
     * @date 2019年8月16日,下午5:54:00
     * @author 任宇
     * @version v1.0
     *
     * @param bblxId
     * @return ResponseWrapper
     */
    @ApiOperation(value = "价格走势月录入模版下载",notes = "价格走势月录入模版下载")
    @GetMapping(value = "/excelModel/")
    public void excelModel(HttpServletResponse response,
                                      @RequestParam("bblxId") String bblxId){
        try {
            reportRecordService.excelModel(response,bblxId);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * @Description: 获取价格类型对应月报表的价格类型
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "获取价格类型对应月报表的价格类型",notes = "获取价格类型对应月报表的价格类型")
    @PostMapping(value = "/monthPriceType/")
    public ResponseWrapper monthPriceType(@RequestParam("bblxId") String bblxId){
        try {
            String priceType = reportRecordService.monthPriceType(bblxId);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), priceType);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"添加失败");
        }
    }

    /**
     * @Description: 查询指定时间报表是否已存在
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "查询指定时间报表是否已存在",notes = "查询指定时间报表是否已存在")
    @PostMapping(value = "/isReport/")
    public ResponseWrapper isReport(@RequestBody ReportRecordInfoVO info){
        try {
            Integer count = reportRecordService.isReport(info);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), count);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"添加失败");
        }
    }

    /**
     * @Description: 收购季周报上报
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "收购季周报上报",notes = "收购季周报上报")
    @PostMapping(value = "/quarterlyReport/")
    public ResponseWrapper quarterlyReport(@RequestBody QuarterlyReportVO quarterlyReportVO) {
        try {
            reportRecordService.quarterlyReport(quarterlyReportVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), null);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"上报成功");
        }
    }
    /**
     * @Description: 收购季周报监测点上报回显
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "收购季周报监测点上报回显",notes = "收购季周报监测点上报回显")
    @PostMapping(value = "/quarterlyPoint/")
    public ResponseWrapper quarterlyPoint(@RequestBody QuarterlyReportInputVO quarterlyReportInputVO){
        try {
            Map<String,Object> result = reportRecordService.quarterlyPoint(quarterlyReportInputVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), result);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"上报成功");
        }
    }
    @ApiOperation(value = "收购季周报上报update",notes = "收购季周报上报update")
    @PostMapping(value = "/quarterlyReportupdate/")
    public ResponseWrapper quarterlyReportupdate(@RequestBody QuarterlyReportVO quarterlyReportVO){
        try {
            reportRecordService.quarterlyReportupdate(quarterlyReportVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), null);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"上报成功");
        }
    }
    /**
     * @Description: 收购季周报汇总
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "收购季周报汇总",notes = "收购季周报汇总")
    @PostMapping(value = "/quarterlyPool/")
    public ResponseWrapper quarterlyPool(@RequestBody QuarterlyReportInputVO quarterlyReportInputVO){
        try {
            Map<String,Object> result = reportRecordService.quarterlyPool(quarterlyReportInputVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), result);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"获取失败");
        }
    }

    /**
     * @Description: 价格走势录入月计算
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "价格走势录入月计算",notes = "价格走势录入月计算")
    @PostMapping(value = "/calculation/")
    public ResponseWrapper calculation(){
        try {
            reportRecordService.calculation();
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), "计算完成");
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"计算失败");
        }
    }

    /**
     * @Description: 数据维护发布(盟市功能 )
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "数据维护发布",notes = "参数:orgId、num")
    @PostMapping(value = "/release/")
    public ResponseWrapper release(@RequestParam("orgId") String orgId,
                                   @RequestParam("num") Integer num){
        try {
            Boolean flag = reportRecordService.release(orgId,num);
            if(flag){
                return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), "发布成功");
            }else{
                return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"当期有监测点未上报数据，不能发布");
            }
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"发布失败");
        }
    }

    /**
     * @Description: 生成本级数据(盟市功能 )
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "生成本级数据",notes = "参数:orgId、num")
    @PostMapping(value = "/level/")
    public ResponseWrapper level(@RequestParam("orgId") String orgId,
                                   @RequestParam("num") Integer num){
        try {
            Boolean flag = reportRecordService.level(orgId,num);
            if(flag){
                return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), "生成成功");
            }else{
                return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"当期有监测点未上报数据，不能生成本级数据");
            }
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"生成失败");
        }
    }

    /**
     * @Description: 我的工作平台-用户信息(org_id登录用户组织机构 num本期需要填报的监测点数量)
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "我的工作平台-用户信息",notes = "参数:orgId、num")
    @PostMapping(value = "/information/")
    public ResponseWrapper information(@RequestParam("orgId") String orgId,
                                 @RequestParam("num") Integer num){
        try {
            Map<String,Object> resultMap = reportRecordService.getInformation(orgId,num);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), resultMap);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"生成失败");
        }
    }
    
	@ApiOperation(value = "修改填报记录中于指标编码不匹配的code", notes = "修改填报记录中于指标编码不匹配的code")
	@GetMapping("modify/varietyCode/{formType}")
	public ResponseWrapper modifyReportFormsRecordVarietyCode(@PathVariable("formType") String formType) {
		return reportRecordService.modifyReportFormsRecordVarietyCode(formType)
				? ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), "")
				: ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),
						HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "修改失败");
	}
	
	@ApiOperation(value = "展示全国价格指数走势（津粮网）", notes = "展示全国价格指数走势（津粮网）")
	@PostMapping("nationalPriceIndexTrend")
	public ResponseWrapper showNationalPriceIndexTrend(@RequestBody ReportRecordVO record) {
		return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), reportRecordService.showNationalPriceIndexTrend(record));
	}
	
	@ApiOperation(value = "获取全国价格指数走势所以品种集合（津粮网）", notes = "获取全国价格指数走势所以品种集合（津粮网）")
	@GetMapping("nationalPriceIndexVarietys/{formType}")
	public ResponseWrapper getNationalPriceIndexVarietys(@PathVariable("formType")String formType) {
		return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), reportRecordService.getNationalPriceIndexVarietys(formType));
	}
	
	@ApiOperation(value = "添加品种记录根据现有品种记录", notes = "添加品种记录根据现有品种记录")
	@GetMapping("addRecordVariety")
	public void addReportRecordVariety(@RequestParam(value = "reportType")String reportType, @RequestParam(value = "startTime")String startTime, @RequestParam(value = "endTime", required = false)Date endTime, @RequestParam("recordId")String recordId,
			@RequestParam("varietyName")String varietyName, @RequestParam("varietyCode")String varietyCode, @RequestParam("detailId")String detailId) {
		reportRecordService.addReportRecordVariety(reportType, startTime, endTime, recordId, varietyName, varietyCode, detailId);
	}

    /**
     * @Description: 定时任务调度(根据监测点、价格类型、日期判断并填充数据(1:判断当日有无上报过该类型数据2:如未上报则按上一期数据记录填充3如已上报则不执行操作))
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "定时任务调度-粮油价格日报",notes = "定时任务调度-粮油价格日报")
    @PostMapping(value = "/lYPriceDailyTaskAdd/")
    public ResponseWrapper lYPriceDailyTaskAdd(@RequestBody TaskVO taskVO){
        try {
            reportRecordService.lYPriceDailyTaskAdd(taskVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), null);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"添加失败");
        }
    }
}
