package com.unis.indicator.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.bbzb.ReportTypePriceVO;
import com.unis.indicator.common.vo.bbzb.ReportTypeVO;
import com.unis.indicator.server.service.ReportTypeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * @ClassName ReportTypeController
 * @Description 报表管理controller
 * @Author xmpu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@RestController
@Slf4j
@Api(tags = "报表类型管理controller")
public class ReportTypeController {

    @Autowired
    private ReportTypeService reportTypeService;

    /**
     * @Description: 通过id查询报表信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param id
     * @return ResponseWrapper
     */
    @ApiOperation(value = "根据id查询报表信息", notes = "参数：报表信息id")
    @GetMapping(value = "/reportType/{id}/")
    public ResponseWrapper findById(@PathVariable("id") String id) throws Exception {
        ReportTypeVO resVO = reportTypeService.findById(id);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                resVO);
    }

    /**
     * @Description: 保存报表信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "保存报表信息", notes = "参数：报表对象VO")
    @PostMapping(value = "/reportType/")
    public ResponseWrapper save(@RequestBody ReportTypeVO VO) throws Exception {
        boolean flag = reportTypeService.save(VO);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "对象已存在无法添加");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 更新
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "更新报表信息", notes = "参数：报表VO")
    @PutMapping(value = "/reportType/")
    public ResponseWrapper update(@RequestBody ReportTypeVO VO) throws Exception {

        boolean flag = reportTypeService.update(VO);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "更新对象失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 删除报表
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @param ids
     * @return ResponseWrapper
     */
    @ApiOperation(value = "删除报表", notes = "参数：报表id(可传入多个), 操作用户id")
    @DeleteMapping(value = "/reportTypes")
    public ResponseWrapper deletes(@RequestBody String[] ids, String userId) throws Exception {
        boolean flag = reportTypeService.deletes(ids, userId);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "删除报表失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 报表
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @param page
     * @param size
     * @return ResponseWrapper
     */
    @ApiOperation(value = "查询所有报表，分页", notes = "参数：报表名模糊查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @PostMapping(value = "/reportTypes")
    public ResponseWrapper findByPage(@RequestBody ReportTypeVO VO,
                                      Integer page,
                                      Integer size) throws Exception {
        Map<String, Object> result = reportTypeService.findByPage(VO, page, size);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }

    /**
     * @Description: 报表
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "查询所有报表，不分页", notes = "参数：无")
    @GetMapping(value = "/reportTypes")
    public ResponseWrapper findAll() throws Exception {
        Map<String, Object> result = reportTypeService.findByPage(new ReportTypeVO(), 1, 999);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }

    @ApiOperation(value = "价格类型与报表类型保存", notes = "参数：价格类型与报表类型关联Model")
    @PostMapping(value = "/reportTypePriceType/")
    public ResponseWrapper saveReportTypePriceType(@RequestBody ReportTypePriceVO VO) throws Exception {
        boolean flag = reportTypeService.saveReportTypePriceType(VO);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "对象已存在无法添加");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    @ApiOperation(value = "查询报表类型对应勾选了的价格类型", notes = "参数：报表类型id")
    @ApiImplicitParam(name = "reportTypeId", value = "报表类型id", required = true)
    @GetMapping(value = "/reportTypePriceType/")
    public ResponseWrapper findReportTypePriceType(String reportTypeId) throws Exception {
        ReportTypePriceVO res = reportTypeService.findReportTypePriceType(reportTypeId);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                res);
    }
}
