package com.unis.indicator.server.controller;

import java.util.Calendar;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.unis.common.utils.ResponseWrapper;
import com.unis.common.utils.UUIDUtils;
import com.unis.indicator.common.vo.ReportingOfIndexPriceAddVO;
import com.unis.indicator.common.vo.ReportingOfIndexPriceListVO;
import com.unis.indicator.common.vo.ReportingOfIndexPriceParamVO;
import com.unis.indicator.server.dao.ReportBaseDao;
import com.unis.indicator.server.dao.ReportingOfIndexPriceDao;
import com.unis.indicator.server.dao.ReportingOfIndexPriceDetailDao;
import com.unis.indicator.server.entity.indicator.ReportBaseDO;
import com.unis.indicator.server.entity.report.ReportingOfIndexPriceDO;
import com.unis.indicator.server.entity.report.ReportingOfIndexPriceDetailDO;
import com.unis.indicator.server.enums.ReportTypeEnum;
import com.unis.indicator.server.excel.model.PriceIndexReportModel;
import com.unis.indicator.server.excel.model.PriceIndexReportWholesaleModel;
import com.unis.indicator.server.excel.utils.ExcelUtils;
import com.unis.indicator.server.schedule.ReportingOfIndexPriceTask;
import com.unis.indicator.server.service.ReportingOfIndexPriceService;

import cn.hutool.core.date.DateUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 
 * @Description：指标价格填报记录
 * @author：王帅
 * @date: 2020年4月10
 */
@RestController
@Api(value = "指标价格填报记录（周和月）", tags = "指标价格填报记录（周和月）")
@RequestMapping("/indexPrice")
public class ReportingOfIndexPriceController {

	@Autowired
	private ReportingOfIndexPriceService indexPriceService;

	@Autowired
	private ReportingOfIndexPriceTask task;

	@Autowired
	private ReportBaseDao reportInfoDao;

	@Autowired
	private ReportingOfIndexPriceDao reportingOfIndexPriceDao;

	@Autowired
	private ReportingOfIndexPriceDetailDao reportingOfIndexPriceDetailDao;

	@ApiOperation(value = "新增指标价格填报记录", notes = "新增指标价格填报记录")
	@PostMapping("/addRecord")
	public ResponseWrapper insertReportedRecord(@RequestBody ReportingOfIndexPriceAddVO record) {
		return indexPriceService.insertReportedRecord(record) ? ResponseWrapper.success("新增记录成功")
				: ResponseWrapper.error("新增记录失败");
	}

	@ApiOperation(value = "修改指标价格填报记录", notes = "修改指标价格填报记录")
	@PostMapping("/modifyRecord")
	public ResponseWrapper updateReportedRecord(@RequestBody ReportingOfIndexPriceAddVO record) {
		return indexPriceService.updateReportedRecord(record) ? ResponseWrapper.success("修改记录成功")
				: ResponseWrapper.error("修改记录失败");
	}

	@ApiOperation(value = "查看指标价格填报记录", notes = "查看指标价格填报记录")
	@PostMapping("/showDetail")
	public ResponseWrapper showDetail(@RequestBody ReportingOfIndexPriceParamVO param) {
		return ResponseWrapper.success(indexPriceService.showDetail(param));
	}

	@ApiOperation(value = "填报记录列表", notes = "填报记录列表")
	@PostMapping("/showList/{pageNum}/{pageSize}")
	public ResponseWrapper showListByPage(@RequestBody ReportingOfIndexPriceParamVO param,
			@PathVariable(value = "pageSize") Integer pageSize, @PathVariable(value = "pageNum") Integer pageNum) {
		return ResponseWrapper.success(indexPriceService.showListByPage(param, pageSize, pageNum));
	}

	@ApiOperation(value = "系统报表（周报和月报）", notes = "系统报表（周报和月报）")
	@PostMapping("/reportForms")
	public ResponseWrapper showPriceIndexTrend(@RequestBody ReportingOfIndexPriceParamVO param) {
		return ResponseWrapper.success(indexPriceService.showPriceIndexTrend(param));
	}

	@ApiOperation(value = "津粮网对接天津月报统计图", notes = "津粮网对接天津月报统计图")
	@PostMapping("/monthTrend")
	public ResponseWrapper showMonthTrend(@RequestBody ReportingOfIndexPriceParamVO param) {
		return ResponseWrapper.success(indexPriceService.showMonthTrend(param));
	}

	@ApiOperation(value = "定时任务执行", notes = "定时任务执行")
	@GetMapping("/execTask")
	public void execTask() {
//		task.weekReportTaskExec();
//		task.monthReportTaskExec();
		task.weekHistoryRecordImport();
	}

	@SuppressWarnings("unchecked")
	@ApiOperation(value = "excel导入集贸零售价格历史数据", notes = "excel导入集贸零售价格历史数据")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "reportType", value = "报表类型（周报：WEEK，月报：MONTH）", required = true, paramType = "query"),
			@ApiImplicitParam(name = "reportTypeId", value = "报表类型主键", required = true, paramType = "query"),
			@ApiImplicitParam(name = "priceTypeId", value = "价格类型", required = true, paramType = "query"),
			@ApiImplicitParam(name = "priceTypeName", value = "价格类型名称", required = true, paramType = "query") })
	@PostMapping(value = "easyImport")
	public void easyExcelImport(@RequestParam(value = "reportType", required = true) String reportType,
			@RequestParam(value = "reportTypeId", required = true) String reportTypeId,
			@RequestParam(value = "priceTypeId", required = true) String priceTypeId,
			@RequestParam(value = "priceTypeName", required = true) String priceTypeName,
			@RequestParam MultipartFile file, HttpServletResponse response) {
		List<Object> peopleList = ExcelUtils.readExcel(file, new PriceIndexReportModel());
		Map<String, Object> retailMap = this.varietyCollection(reportTypeId);
		Map<String, Double> reportMap = (Map<String, Double>) retailMap.get("price");
		Map<String, String> varietyCodeAndName = (Map<String, String>) retailMap.get("variety");
		Map<String, Integer> varietyCodeAndOrder = (Map<String, Integer>) retailMap.get("order");
		peopleList.parallelStream().forEach(obj -> {
			PriceIndexReportModel model = (PriceIndexReportModel) obj;
			ReportingOfIndexPriceDO indexPriceEntity = new ReportingOfIndexPriceDO();
			indexPriceEntity.setId(UUIDUtils.uuid());
			indexPriceEntity.setCreateTime(model.getReportDate());
			indexPriceEntity.setType(reportType);
			indexPriceEntity.setSbkssj(model.getReportDate());
			indexPriceEntity.setSbjssj((Date) this.getMonthEnd(model.getReportDate()).get("end"));
			indexPriceEntity.setPriceTypeId(priceTypeId);
			indexPriceEntity.setPriceTypeName(priceTypeName);
			indexPriceEntity.setReportTypeId(reportTypeId);
			int result = reportingOfIndexPriceDao.insertSelective(indexPriceEntity);
			// 添加列表详情
			if (result > 0) {
				String reportId = indexPriceEntity.getId();
				// 面粉
				this.insertVarietyRecordDetail(reportId, "0005", model.getMf(), varietyCodeAndName, reportMap,
						varietyCodeAndOrder);
				// 大米
				this.insertVarietyRecordDetail(reportId, "0001", model.getDm(), varietyCodeAndName, reportMap,
						varietyCodeAndOrder);
				// 玉米面
				this.insertVarietyRecordDetail(reportId, "0006", model.getYmm(), varietyCodeAndName, reportMap,
						varietyCodeAndOrder);
				// 绿豆
				this.insertVarietyRecordDetail(reportId, "0009", model.getLd(), varietyCodeAndName, reportMap,
						varietyCodeAndOrder);
				// 大豆
				this.insertVarietyRecordDetail(reportId, "0007", model.getDd(), varietyCodeAndName, reportMap,
						varietyCodeAndOrder);
				// 一级豆油
				this.insertVarietyRecordDetail(reportId, "0010", model.getYjdy(), varietyCodeAndName, reportMap,
						varietyCodeAndOrder);
				// 四级豆油
				this.insertVarietyRecordDetail(reportId, "0011", model.getSjdy(), varietyCodeAndName, reportMap,
						varietyCodeAndOrder);
				// 花生油
				this.insertVarietyRecordDetail(reportId, "0012", model.getHsy(), varietyCodeAndName, reportMap,
						varietyCodeAndOrder);
			}
		});
	}

	@SuppressWarnings("unchecked")
	@ApiOperation(value = "excel导入集贸批发价格历史数据", notes = "excel导入集贸批发价格历史数据")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "reportType", value = "报表类型（周报：WEEK，月报：MONTH）", required = true, paramType = "query"),
			@ApiImplicitParam(name = "reportTypeId", value = "报表类型主键", required = true, paramType = "query"),
			@ApiImplicitParam(name = "priceTypeId", value = "价格类型", required = true, paramType = "query"),
			@ApiImplicitParam(name = "priceTypeName", value = "价格类型名称", required = true, paramType = "query") })
	@PostMapping(value = "easyImportWholesale")
	public void easyExcelImportWholesale(@RequestParam(value = "reportType", required = true) String reportType,
			@RequestParam(value = "reportTypeId", required = true) String reportTypeId,
			@RequestParam(value = "priceTypeId", required = true) String priceTypeId,
			@RequestParam(value = "priceTypeName", required = true) String priceTypeName,
			@RequestParam MultipartFile file, HttpServletResponse response) {
		List<Object> peopleList = ExcelUtils.readExcel(file, new PriceIndexReportWholesaleModel());
		Map<String, Object> retailMap = this.varietyCollection(reportTypeId);
		Map<String, Double> reportMap = (Map<String, Double>) retailMap.get("price");
		Map<String, String> varietyCodeAndName = (Map<String, String>) retailMap.get("variety");
		Map<String, Integer> varietyCodeAndOrder = (Map<String, Integer>) retailMap.get("order");
		peopleList.parallelStream().forEach(obj -> {
			PriceIndexReportWholesaleModel model = (PriceIndexReportWholesaleModel) obj;
			ReportingOfIndexPriceDO indexPriceEntity = new ReportingOfIndexPriceDO();
			indexPriceEntity.setId(UUIDUtils.uuid());
			indexPriceEntity.setCreateTime(model.getReportDate());
			indexPriceEntity.setType(reportType);
			indexPriceEntity.setSbkssj(model.getReportDate());
			indexPriceEntity.setSbjssj((Date) this.getMonthEnd(model.getReportDate()).get("end"));
			indexPriceEntity.setPriceTypeId(priceTypeId);
			indexPriceEntity.setPriceTypeName(priceTypeName);
			indexPriceEntity.setReportTypeId(reportTypeId);
			int result = reportingOfIndexPriceDao.insertSelective(indexPriceEntity);
			// 添加列表详情
			if (result > 0) {
				String reportId = indexPriceEntity.getId();
				// 小麦
				this.insertVarietyRecordDetail(reportId, "0027", model.getXm(), varietyCodeAndName, reportMap,
						varietyCodeAndOrder);
				// 大米
				this.insertVarietyRecordDetail(reportId, "0001", model.getDm(), varietyCodeAndName, reportMap,
						varietyCodeAndOrder);
				// 玉米
				this.insertVarietyRecordDetail(reportId, "0026", model.getYm(), varietyCodeAndName, reportMap,
						varietyCodeAndOrder);
				// 面粉
				this.insertVarietyRecordDetail(reportId, "0005", model.getMf(), varietyCodeAndName, reportMap,
						varietyCodeAndOrder);
				// 大豆
				this.insertVarietyRecordDetail(reportId, "0007", model.getDd(), varietyCodeAndName, reportMap,
						varietyCodeAndOrder);
				// 一级豆油
				this.insertVarietyRecordDetail(reportId, "0010", model.getYjdy(), varietyCodeAndName, reportMap,
						varietyCodeAndOrder);
				// 四级豆油
				this.insertVarietyRecordDetail(reportId, "0011", model.getSjdy(), varietyCodeAndName, reportMap,
						varietyCodeAndOrder);
				// 花生油
				this.insertVarietyRecordDetail(reportId, "0012", model.getHsy(), varietyCodeAndName, reportMap,
						varietyCodeAndOrder);
			}
		});
	}

	@ApiOperation(value = "excel导出")
	@GetMapping("/reportExport")
	public void exportPriceIndexTrend(@RequestParam(value = "priceOrIndex") String priceOrIndex,
			@RequestParam(value = "reportType") String reportType,
			@RequestParam(value = "priceTypeId") String priceTypeId,
			@RequestParam(value = "reportTypeId") String reportTypeId,
			@RequestParam(value = "recordStartDate") String recordStartDate,
			@RequestParam(value = "recordEndDate") String recordEndDate, HttpServletRequest request,
			HttpServletResponse response) {
		ReportingOfIndexPriceParamVO param = new ReportingOfIndexPriceParamVO();
		param.setPriceOrIndex(priceOrIndex);
		param.setPriceTypeId(priceTypeId);
		param.setReportTypeId(reportTypeId);
		param.setRecordEndDate(recordEndDate);
		param.setRecordStartDate(recordStartDate);
		param.setReportType(reportType);
		@SuppressWarnings("unchecked")
		List<ReportingOfIndexPriceListVO> showList = (List<ReportingOfIndexPriceListVO>) indexPriceService
				.showPriceIndexList(param).get("resultList");
		List<List<String>> objectList = Lists.newLinkedList();
		List<String> headTitleList = Lists.newLinkedList();
		if(CollectionUtils.isNotEmpty(showList)) {
			headTitleList.add("周期");
			showList.get(0).getDetailList().forEach( obj -> {
				headTitleList.add(obj.getPzmc()+"("+obj.getJlbz()+")");
			});
		}
		showList.forEach(obj -> {
			List<String> strList = Lists.newLinkedList();
			strList.add(obj.getShowTime());
			obj.getDetailList().forEach( detail -> {
				if(StringUtils.isNotEmpty(priceOrIndex) && ReportTypeEnum.PRICE.getCode().equals(priceOrIndex)) {
					strList.add(detail.getWholesalePrice());
				} else if(StringUtils.isNotEmpty(priceOrIndex) && ReportTypeEnum.INDEX.getCode().equals(priceOrIndex)) {
					strList.add(detail.getZs() + "");
				}
			});
			objectList.add(strList);
		});
		String title = "";
		if(StringUtils.isNotEmpty(priceTypeId) && "9NjKwnlSuIo6m55HuAO".equals(priceTypeId)) {
			if(StringUtils.isNotEmpty(priceOrIndex) && ReportTypeEnum.PRICE.getCode().equals(priceOrIndex)) {
				title = "集贸零售价格周期数据";
			} else if(StringUtils.isNotEmpty(priceOrIndex) && ReportTypeEnum.INDEX.getCode().equals(priceOrIndex)) {
				title = "集贸零售指数周期数据";
			}
		} else if(StringUtils.isNotEmpty(priceTypeId) && "NOrp6PUmnYCzNOonngt".equals(priceTypeId)) {
			if(StringUtils.isNotEmpty(priceOrIndex) && ReportTypeEnum.PRICE.getCode().equals(priceOrIndex)) {
				title = "集贸批发价格周期数据";
			} else if(StringUtils.isNotEmpty(priceOrIndex) && ReportTypeEnum.INDEX.getCode().equals(priceOrIndex)) {
				title = "集贸批发指数周期数据";
			}
		}else if(StringUtils.isNotEmpty(priceTypeId) && "qiyebaojia-week".equals(priceTypeId)) {
			if(StringUtils.isNotEmpty(priceOrIndex) && ReportTypeEnum.PRICE.getCode().equals(priceOrIndex)) {
				title = "企业报价价格周期数据";
			} else if(StringUtils.isNotEmpty(priceOrIndex) && ReportTypeEnum.INDEX.getCode().equals(priceOrIndex)) {
				title = "企业报价指数周期数据";
			}
		}
		String fileName = "报表数据导出" + DateUtil.currentSeconds() + ".xls";
		String filePath = fileName;
		ExcelUtils.dynamicHeadEasyExcel(request, response, "填报数据", fileName, filePath, objectList, 1, 0, headTitleList, title);
	}

	public void insertVarietyRecordDetail(String reportId, String key, Double price,
			Map<String, String> varietyCodeAndName, Map<String, Double> reportMap,
			Map<String, Integer> varietyCodeAndOrder) {
		ReportingOfIndexPriceDetailDO detailEntity = new ReportingOfIndexPriceDetailDO();
		detailEntity.setId(UUIDUtils.uuid());
		detailEntity.setZbbm(key);
		detailEntity.setXh(varietyCodeAndOrder.get(key));
		detailEntity.setPzmc(varietyCodeAndName.get(key));
		detailEntity.setReportId(reportId);
		detailEntity.setJg(price);
		detailEntity.setZs((price * 100) / reportMap.get(key));
		reportingOfIndexPriceDetailDao.insertSelective(detailEntity);
	}

	/**
	 * 
	 * @Description: 获取报表信息-基期价 指标名称
	 * @author: 王帅
	 * @param: @param  reportTypeId
	 * @param: @return 参数
	 * @return: Map<String,Object> 返回类型
	 */
	public Map<String, Object> varietyCollection(String reportTypeId) {
		List<ReportBaseDO> reportListRetail = reportInfoDao.findListByReportTypeId(reportTypeId);
		Map<String, Double> reportMap = reportListRetail.stream()
				.collect(Collectors.toMap(ReportBaseDO::getIndicatorId, ReportBaseDO::getJqj));
		Map<String, String> varietyCodeAndName = reportListRetail.stream()
				.collect(Collectors.toMap(ReportBaseDO::getIndicatorId, ReportBaseDO::getIndicatorName));

		Map<String, Integer> varietyCodeAndOrder = reportListRetail.stream()
				.collect(Collectors.toMap(ReportBaseDO::getIndicatorId, ReportBaseDO::getPzsx));

		Map<String, Object> collection = Maps.newHashMap();
		collection.put("price", reportMap);
		collection.put("variety", varietyCodeAndName);
		collection.put("order", varietyCodeAndOrder);

		return collection;
	}

	/**
	 * 
	 * @Description: 获取月末
	 * @author: 王帅
	 * @param: @param  date
	 * @param: @return 参数
	 * @return: Map<String,Object> 返回类型
	 */
	public Map<String, Object> getMonthEnd(Date date) {
		Calendar c = Calendar.getInstance();
		c.setTime(date);
		int lastMonthMaxDay = c.getActualMaximum(Calendar.DAY_OF_MONTH);
		c.set(c.get(Calendar.YEAR), c.get(Calendar.MONTH), lastMonthMaxDay, 23, 59, 59);
		Map<String, Object> result = Maps.newHashMap();
		result.put("end", c.getTime());

		return result;
	}
}
