package com.unis.indicator.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.StandardVO;
import com.unis.indicator.server.service.IndicatorService;
import com.unis.indicator.server.service.StandardService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * @ClassName StandardController
 * @Description 指标标准标准管理controller
 * @Author xmpu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@RestController
@Slf4j
@Api(tags = "指标标准管理controller")
public class StandardController {

    @Autowired
    private StandardService standardService;

    /**
     * @Description: 通过id查询指标标准信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param id
     * @return ResponseWrapper
     */
    @ApiOperation(value = "根据id查询指标标准信息", notes = "参数：指标标准信息id")
    @GetMapping(value = "/indStandard/{id}/")
    public ResponseWrapper findById(@PathVariable("id") String id) throws Exception {
        StandardVO resVO = standardService.findById(id);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                resVO);
    }

    @ApiOperation(value = "通过standardId查询指标标准关联信息", notes = "参数：指标标准信息id")
    @GetMapping(value = "/indStdRel/{standardId}/")
    public ResponseWrapper findStdRelById(@PathVariable("standardId") String standardId) throws Exception {
        boolean res = standardService.findStdRelById(standardId);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                res);
    }

    /**
     * @Description: 保存指标标准信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "保存指标标准信息", notes = "参数：指标标准对象VO")
    @PostMapping(value = "/indStandard/")
    public ResponseWrapper save(@RequestBody StandardVO VO) throws Exception {
        boolean flag = standardService.save(VO);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "对象已存在无法添加");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 更新执法人员信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "更新指标标准信息", notes = "参数：指标标准VO")
    @PutMapping(value = "/indStandard/")
    public ResponseWrapper update(@RequestBody StandardVO VO) throws Exception {

        boolean flag = standardService.update(VO);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "更新对象失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 删除指标标准
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @param ids
     * @return ResponseWrapper
     */
    @ApiOperation(value = "删除指标标准", notes = "参数：指标标准id(可传入多个), 操作用户id")
    @DeleteMapping(value = "/indStandards")
    public ResponseWrapper deletes(@RequestBody String[] ids, String userId) throws Exception {
        boolean flag = standardService.deletes(ids, userId);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "删除指标标准失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 查询所有指标标准
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @param page
     * @param size
     * @return ResponseWrapper
     */
    @ApiOperation(value = "查询所有指标标准，分页", notes = "参数：指标标准名模糊查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @PostMapping(value = "/indStandards")
    public ResponseWrapper findByPage(@RequestBody StandardVO VO,
                                      Integer page,
                                      Integer size) throws Exception {
        Map<String, Object> result = standardService.findByPage(VO, page, size);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }

    /**
     * @Description: 查询所有指标标准
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "查询所有指标标准，不分页", notes = "参数：无")
    @GetMapping(value = "/indStandards")
    public ResponseWrapper findAll() throws Exception {
        Map<String, Object> result = standardService.findByPage(new StandardVO(),1, 999);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }

}
