package com.unis.indicator.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.*;
import com.unis.indicator.server.service.ReportRecordService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;

/**
 * @ClassName StatisticsController
 * @Description 报表统计相关controller
 * @Author renyu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@RestController
@Slf4j
@Api(tags = "报表统计相关controller")
public class StatisticsController {

    @Autowired
    private ReportRecordService reportRecordService;

    /**
     * @Description: 天津上报统计查询
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "天津上报统计",notes = "参数：统计时间段、检测点、价格类型、填报方式")
    @PostMapping(value = "/reportStatisticsOne/")
    public ResponseWrapper getTjStatistics(@RequestBody StatisticsInputVO statisticsInputVO){
        try {
            Map<String,Object> results = reportRecordService.getTjStatistics(statisticsInputVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), results);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"查询失败");
        }
    }

    /**
     * @Description: 天津上报统计详情
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "天津上报统计详情",notes = "参数：检测点、价格类型")
    @PostMapping(value = "/reportStatisticsOneInfo/")
    public ResponseWrapper getTjStatisticsInfo(@RequestBody StatisticsInputVO statisticsInputVO){
        try {
            Map<String,Object> results = reportRecordService.getTjStatisticsInfo(statisticsInputVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), results);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"查询失败");
        }
    }

    /**
     * @Description: 内蒙上报统计查询
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "内蒙上报统计查询",notes = "参数：统计时间段、检测点、价格类型、填报方式")
    @PostMapping(value = "/reportStatisticsMany/")
    public ResponseWrapper getNmStatistics(@RequestBody StatisticsInputVO statisticsInputVO){
        try {
            Map<String,Object> results = reportRecordService.getNmStatistics(statisticsInputVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), results);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"查询失败");
        }
    }

    /**
     * @Description: 价格统计日报表
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "周报统计",notes = "参数：统计时间段、检测点、价格类型、统计品种")
    @PostMapping(value = "/priceDay/")
    public ResponseWrapper getPriceDay(@RequestBody PriceStatisticsInputVO priceStatisticsInputVO){
        try {
            Map<String,Object> results = reportRecordService.getPriceDay(priceStatisticsInputVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), results);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"查询失败");
        }
    }

    /**
     * @Description: 价格统计周报表
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "价格统计周报表",notes = "参数：统计时间段、检测点、价格类型、统计品种")
    @PostMapping(value = "/priceWeek/")
    public ResponseWrapper getPriceWeek(@RequestBody PriceStatisticsInputVO priceStatisticsInputVO){
        try {
            Map<String,Object> results = reportRecordService.getPriceWeek(priceStatisticsInputVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), results);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"查询失败");
        }
    }

    /**
     * @Description: 价格统计月报表
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "价格统计月报表",notes = "参数：统计时间段、检测点、价格类型、统计品种")
    @PostMapping(value = "/priceMonth/")
    public ResponseWrapper getPriceMonth(@RequestBody PriceStatisticsInputVO priceStatisticsInputVO){
        try {
            Map<String,Object> results = reportRecordService.getPriceMonth(priceStatisticsInputVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), results);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"查询失败");
        }
    }

    /**
     * @Description: 无固定时间统计
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "无固定时间统计",notes = "参数：统计时间段、价格类型、统计品种")
    @PostMapping(value = "/timePrice/")
    public ResponseWrapper getTimePrice(@RequestBody PriceStatisticsInputVO priceStatisticsInputVO){
        try {
            Map<String,Object> results = reportRecordService.getTimePrice(priceStatisticsInputVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), results);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"查询失败");
        }
    }

    /**
     * @Description: 周刊报表列表
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "周刊报表列表",notes = "参数：上报时间段、报表类型")
    @PostMapping(value = "/weeklyReports/")
    public ResponseWrapper getWeeklyReportList(@RequestBody WeeklyReportVO weeklyReportVO){
        try {
            Map<String,Object> results = reportRecordService.getWeeklyReportList(weeklyReportVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), results);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"查询失败");
        }
    }

    /**
     * @Description: 周刊报表详情
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "周刊报表详情",notes = "参数：上报结束时间、报表类型")
    @PostMapping(value = "/weeklyReportInfo/")
    public ResponseWrapper getWeeklyReportInfo(@RequestBody WeeklyReportVO weeklyReportVO){
        try {
            Map<String,Object> results = reportRecordService.getWeeklyReportInfo(weeklyReportVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), results);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"查询失败");
        }
    }

    /**
     * @Description: 价格走势图表
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "价格走势图表",notes = "参数：报表类型、报表期类型、指标名称(,分割)、统计开始时间、统计结束时间")
    @PostMapping(value = "/trendChart/")
    public ResponseWrapper getTrendChart(@RequestBody PriceTrendQueryVO priceTrendQueryVO){
        try {
            List<Map<String,Object>> results = reportRecordService.getTrendChart(priceTrendQueryVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), results);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"查询失败");
        }
    }
    /**
     * @Description: 价格走势图表
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "价格走势图表ByZs",notes = "参数：报表类型、报表期类型、指标名称(,分割)、统计开始时间、统计结束时间")
    @PostMapping(value = "/trendChartByZs/")
    public ResponseWrapper getTrendChartByZs(@RequestBody PriceTrendQueryVO priceTrendQueryVO){
        try {
            List<Map<String,Object>> results = reportRecordService.getTrendChartByZs(priceTrendQueryVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), results);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"查询失败");
        }
    }

    /**
     * @Description: 周报月统计
     * @date
     * @author yangshengjie
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "周报月统计",notes = "参数：统计月份、统计品种")
    @PostMapping(value = "/PriceMonthAvg/")
    public ResponseWrapper getPriceMonthAvg(@RequestBody PriceStatisticsInputVO priceStatisticsInputVO){
        try {
            List<Map<String, Object>> priceStatisticsAvgVO = reportRecordService.getPriceMonthAvg(priceStatisticsInputVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), priceStatisticsAvgVO);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"查询失败");
        }
    }

    /**
     * @Description: 周均价统计
     * @date
     * @author yangshengjie
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "周均价统计",notes = "参数：要统计的星期一和星期天的日期、统计品种")
    @PostMapping(value = "/PriceWeekAvg/")
    public ResponseWrapper getPriceWeekAvg(@RequestBody PriceStatisticsInputVO priceStatisticsInputVO){
        try {
            List<Map<String, Object>> priceStatisticsAvgVO = reportRecordService.getPriceWeekAvg(priceStatisticsInputVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), priceStatisticsAvgVO);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"查询失败");
        }
    }
}
