package com.unis.indicator.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.WarningRoleQueryVO;
import com.unis.indicator.common.vo.WarningRoleVO;
import com.unis.indicator.server.service.ReportRecordService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

@RestController
@Slf4j
@Api(tags = "预警规则controller")
public class WarningRoleController {

    @Autowired
    private ReportRecordService reportRecordService;
    /**
     * @Description: 预警规则新增
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "预警规则新增",notes = "预警规则新增")
    @PostMapping(value = "/warningRole/")
    public ResponseWrapper saveWarningRole(@RequestBody WarningRoleVO warningRoleVO){
        try {
            reportRecordService.saveWarningRole(warningRoleVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), null);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"添加失败");
        }
    }

    /**
     * @Description: 预警规则编辑
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "预警规则编辑",notes = "预警规则编辑")
    @PutMapping(value = "/warningRole/")
    public ResponseWrapper updateWarningRole(@RequestBody WarningRoleVO warningRoleVO){
        try {
            reportRecordService.updateWarningRole(warningRoleVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), null);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"修改失败");
        }
    }

    /**
     * @Description: 预警规则详情
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "预警规则详情",notes = "参数:id")
    @GetMapping(value = "/warningRole/{id}/")
    public ResponseWrapper getWarningRole(@PathVariable("id") String id){
        try {
            WarningRoleVO warningRoleVO = reportRecordService.getWarningRole(id);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), warningRoleVO);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"获取失败");
        }
    }

    /**
     * @Description: 预警规则删除
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "预警规则删除",notes = "参数:id")
    @DeleteMapping(value = "/warningRole/")
    public ResponseWrapper deleteWarningRole(@RequestParam String id){
        try {
            reportRecordService.deleteWarningRole(id);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), null);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"删除失败");
        }
    }

    /**
     * @Description: 预警规则列表()
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param5
     * @return ResponseWrapper
     */
    @ApiOperation(value = "预警规则列表",notes = "预警规则列表")
    @PostMapping(value = "/warningRoles/")
    public ResponseWrapper warningRoles(@RequestBody WarningRoleQueryVO warningRoleQueryVO){
        try {
            Map<String,Object> resultMap = reportRecordService.getWarningRoles(warningRoleQueryVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), resultMap);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"获取失败");
        }
    }
}
