package com.unis.indicator.server.domain;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.ValidationUtil;
import com.unis.indicator.common.vo.ContributeArticleVO;
import com.unis.indicator.server.config.SecurityUtil;
import com.unis.indicator.server.dao.WztgDao;
import com.unis.indicator.server.entity.WztgDO;
import com.unis.indicator.server.enums.AuditingStatusEnum;
import lombok.Getter;
import lombok.Setter;
import org.apache.catalina.security.SecurityConfig;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import tk.mybatis.mapper.entity.Example;

import java.util.*;

import static org.apache.xmlbeans.XmlBeans.getTitle;

/**
 * @ClassName ContributeArticleDomain
 * @Description 文章投稿领域对象
 * @Author xmpu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@Getter
@Setter
@Component
public class ContributeArticleDomain {

	@Autowired
	private WztgDao dao;

	/**
	 *
	 * @Description: 通过id查询文章投稿信息
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param id
	 * @return WztgDO
	 */
	public WztgDO findArtById(String id) throws Exception {
		Example example = new Example(WztgDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("id", id);
		WztgDO resDO = dao.selectOneByExample(example);
		if (ObjectUtils.equals(resDO, null)) {
			return null;
		}
		return resDO;
	}

	/**
	 *
	 * @Description: 查询所有文章投稿信息 模糊查询的条件可以包含：名称
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public Map<String, Object> findArtsByPage(ContributeArticleVO VO, Integer page, Integer size, String isUser) throws Exception {

		Example example = new Example(WztgDO.class);
		Example.Criteria criteria = example.createCriteria();
	      String	Title= SecurityUtil.filterStrSqlJs(VO.getTitle());
		// 添加按标题查询
		if (!"".equals(Title) && null != Title) {
			criteria.andLike("title", "%" + Title+ "%");
		}
		if("0".equals(isUser)){
//			criteria.andNotEqualTo("status",  AuditingStatusEnum.PUBLISHED.getCode());
		}
		if("1".equals(isUser)){
			criteria.andNotEqualTo("status",  AuditingStatusEnum.NOT_SUBMITED.getCode());
		}
		//按创建时间查询
		if(!"".equals(VO.getDateFrom()) && null != VO.getDateFrom()){
			criteria.andGreaterThanOrEqualTo("createTime",VO.getDateFrom());
		}
		if(!"".equals(VO.getDateTo()) && null != VO.getDateTo()){
			criteria.andLessThanOrEqualTo("createTime",VO.getDateTo());
		}
		// 添加按状态查询
		if (!"".equals(VO.getStatus()) && null != VO.getStatus()) {
			criteria.andEqualTo("status",  VO.getStatus());
		}
		// 添加按所属地区查询
		if (!"".equals(VO.getAreaCode()) && null != VO.getAreaCode()) {
			criteria.andEqualTo("areaCode",  VO.getAreaCode());
		}
		// 添加按所属监测点id查询
		if (!"".equals(VO.getOrgId()) && null != VO.getOrgId()) {
			criteria.andLike("orgId", "%" + VO.getOrgId()+"%" );
		}
		// 添加按所属监测点name查询
		if (!"".equals(VO.getOrgName()) && null != VO.getOrgName()) {
			criteria.andLike("orgName", "%" + VO.getOrgName() + "%");
		}
		// 添加按所属监测点name查询
		if (!"".equals(VO.getAreaName()) && null != VO.getAreaName()) {
			criteria.andLike("areaName", "%" + VO.getAreaName() + "%");
		}
		// 添加按用户名称查询
		if (!"".equals(VO.getCreateBy()) && null != VO.getCreateBy()) {
			criteria.andLike("createBy", "%" + VO.getCreateBy() + "%");
		}

		// 未删除
		criteria.andIsNull("deleteTime");
		PageHelper.startPage(page, size, "CREATE_TIME DESC");
		List<WztgDO> resultDOList = dao.selectByExample(example);
		PageInfo<WztgDO> pageInfo = new PageInfo<WztgDO>(resultDOList);

		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<ContributeArticleVO> resultVOList = new ArrayList<>();
		if (!resultDOList.isEmpty()) {
			for (WztgDO resultDO : resultDOList) {
				ContributeArticleVO resultVO = LsBeanUtils.copyProperties(resultDO, ContributeArticleVO.class);
				resultVOList.add(resultVO);
			}
		}
		resultMap.put("total", pageInfo.getTotal());
		resultMap.put("resultList", resultVOList);
		return resultMap;
	}
	/**
	 *
	 * @Description: 查询所有文章投稿信息 模糊查询的条件可以包含：名称
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public Map<String, Object> findArtsByPageBy(ContributeArticleVO VO, Integer page, Integer size, String isUser) throws Exception {

		Example example = new Example(WztgDO.class);
		Example.Criteria criteria = example.createCriteria();
		String	Title= SecurityUtil.filterStrSqlJs(VO.getTitle());
		// 添加按标题查询
		if (!"".equals(Title) && null != Title) {
			criteria.andLike("title", "%" + Title+ "%");
		}
		if("0".equals(isUser)){
//			criteria.andNotEqualTo("status",  AuditingStatusEnum.PUBLISHED.getCode());
		}
		if("1".equals(isUser)){
			criteria.andNotEqualTo("status",  AuditingStatusEnum.NOT_SUBMITED.getCode());
		}
		//按创建时间查询
		if(!"".equals(VO.getDateFrom()) && null != VO.getDateFrom()){
			criteria.andGreaterThanOrEqualTo("createTime",VO.getDateFrom());
		}
		if(!"".equals(VO.getDateTo()) && null != VO.getDateTo()){
			criteria.andLessThanOrEqualTo("createTime",VO.getDateTo());
		}
		// 添加按状态查询
		if (!"".equals(VO.getStatus()) && null != VO.getStatus()) {
			criteria.andEqualTo("status",  VO.getStatus());
		}
		// 添加按状态查询
		if (!"".equals(VO.getStatus()) && null != VO.getStatus()) {
			criteria.andNotEqualTo("status","0");
		}
		// 添加按所属地区查询
		if (!"".equals(VO.getAreaCode()) && null != VO.getAreaCode()) {
			criteria.andEqualTo("areaCode",  VO.getAreaCode());
		}
		// 添加按所属监测点id查询
		if (!"".equals(VO.getOrgId()) && null != VO.getOrgId()) {
			criteria.andLike("orgId", "%" + VO.getOrgId()+"%" );
		}
		// 添加按所属监测点name查询
		if (!"".equals(VO.getOrgName()) && null != VO.getOrgName()) {
			criteria.andLike("orgName", "%" + VO.getOrgName() + "%");
		}
		// 添加按所属监测点name查询
		if (!"".equals(VO.getAreaName()) && null != VO.getAreaName()) {
			criteria.andLike("areaName", "%" + VO.getAreaName() + "%");
		}
		// 添加按用户名称查询
		if (!"".equals(VO.getCreateBy()) && null != VO.getCreateBy()) {
			criteria.andLike("createBy", "%" + VO.getCreateBy() + "%");
		}

		// 未删除
		criteria.andIsNull("deleteTime");
		PageHelper.startPage(page, size, "CREATE_TIME DESC");
		List<WztgDO> resultDOList = dao.selectByExample(example);
		PageInfo<WztgDO> pageInfo = new PageInfo<WztgDO>(resultDOList);

		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<ContributeArticleVO> resultVOList = new ArrayList<>();
		if (!resultDOList.isEmpty()) {
			for (WztgDO resultDO : resultDOList) {
				ContributeArticleVO resultVO = LsBeanUtils.copyProperties(resultDO, ContributeArticleVO.class);
				resultVOList.add(resultVO);
			}
		}
		resultMap.put("total", pageInfo.getTotal());
		resultMap.put("resultList", resultVOList);
		return resultMap;
	}
	public Map<String, Object> findArtsByPagedl(ContributeArticleVO VO, Integer page, Integer size, String isUser) throws Exception {

		Example example = new Example(WztgDO.class);
		Example.Criteria criteria = example.createCriteria();
		String	Title= SecurityUtil.filterStrSqlJs(VO.getTitle());
		// 添加按标题查询
		if (!"".equals(Title) && null != Title) {
			criteria.andLike("title", "%" + Title+ "%");
		}
		if("0".equals(isUser)){
//			criteria.andNotEqualTo("status",  AuditingStatusEnum.PUBLISHED.getCode());
		}
		if("1".equals(isUser)){
			criteria.andNotEqualTo("status",  AuditingStatusEnum.NOT_SUBMITED.getCode());
		}
		//按创建时间查询
		if(!"".equals(VO.getDateFrom()) && null != VO.getDateFrom()){
			criteria.andGreaterThanOrEqualTo("createTime",VO.getDateFrom());
		}
		if(!"".equals(VO.getDateTo()) && null != VO.getDateTo()){
			criteria.andLessThanOrEqualTo("createTime",VO.getDateTo());
		}
		// 添加按状态查询
		if (!"".equals(VO.getStatus()) && null != VO.getStatus()) {
			criteria.andEqualTo("status",  VO.getStatus());
		}
		// 添加按所属地区查询
		if (!"".equals(VO.getAreaCode()) && null != VO.getAreaCode()) {
			criteria.andEqualTo("areaCode",  VO.getAreaCode());
		}
		// 添加按所属监测点id查询
		if (!"".equals(VO.getOrgId()) && null != VO.getOrgId()) {
			criteria.andEqualTo("orgId",  VO.getOrgId() );
		}
		// 添加按所属监测点name查询
		if (!"".equals(VO.getOrgName()) && null != VO.getOrgName()) {
			criteria.andLike("orgName", "%" + VO.getOrgName() + "%");
		}
		// 添加按所属监测点name查询
		if (!"".equals(VO.getAreaName()) && null != VO.getAreaName()) {
			criteria.andLike("areaName", "%" + VO.getAreaName() + "%");
		}
		// 添加按用户名称查询
		if (!"".equals(VO.getCreateBy()) && null != VO.getCreateBy()) {
			criteria.andLike("createBy", "%" + VO.getCreateBy() + "%");
		}

		// 未删除
		criteria.andIsNull("deleteTime");
		PageHelper.startPage(page, size, "CREATE_TIME DESC");
		List<WztgDO> resultDOList = dao.selectByExample(example);
		PageInfo<WztgDO> pageInfo = new PageInfo<WztgDO>(resultDOList);

		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<ContributeArticleVO> resultVOList = new ArrayList<>();
		if (!resultDOList.isEmpty()) {
			for (WztgDO resultDO : resultDOList) {
				ContributeArticleVO resultVO = LsBeanUtils.copyProperties(resultDO, ContributeArticleVO.class);
				resultVOList.add(resultVO);
			}
		}
		resultMap.put("total", pageInfo.getTotal());
		resultMap.put("resultList", resultVOList);
		return resultMap;
	}

	/**
	 *
	 * @Description: 文章投稿多选删除
	 * @date 2019年7月24日,下午8:58:47
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param ids
	 * @param userId
	 * @return Boolean
	 * @throws Exception
	 */
	public boolean deleteArts(String[] ids, String userId) throws Exception {
		for (String id : ids) {
			Example example = new Example(WztgDO.class);
			Example.Criteria criteria = example.createCriteria();
			criteria.andEqualTo("id", id);
			criteria.andIsNull("deleteTime");
			WztgDO udpDO = dao.selectOneByExample(example);
			if (ObjectUtils.notEqual(udpDO, null)) {
				udpDO.setDeleteBy(userId);
				udpDO.setDeleteTime(DateUtil.getNowDate());
				dao.updateByPrimaryKey(udpDO);
			}
		}
		return true;
	}

	/**
	 *
	 * @Description: 保存文章投稿信息
	 * @date 2019年7月24日,下午8:58:56
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean saveArt(ContributeArticleVO VO) throws Exception {
		ValidationUtil.validate(VO);
		Example example = new Example(WztgDO.class);
		Example.Criteria criteria = example.createCriteria();
		if (!"".equals(VO.getTitle()) && null != VO.getTitle()) {
			criteria.andEqualTo("title", VO.getTitle());
		}
		if (!"".equals(VO.getCreateBy()) && null != VO.getCreateBy()) {
			criteria.andEqualTo("createBy", VO.getCreateBy());
		}
		criteria.andIsNull("deleteTime");
		if (dao.selectCountByExample(example) > 0) {
			throw new RuntimeException(VO.getTitle() + "已存在");
		}
		WztgDO insDO = new WztgDO();
		LsBeanUtils.copyPropertiesIgnoreNull(VO, insDO);
		String status = insDO.getStatus();
		if(StringUtils.isEmpty(status)) {
			// 如果没有状态值则设置为未提交状态
			insDO.setStatus("0"); 
		}
		insDO.setCreateBy(VO.getOperator());
		insDO.setCreateTime(new Date());

		if (dao.insertSelective(insDO) < 1) {
			throw new RuntimeException(insDO.getTitle() + "无法保存成功，请检查数据。");
		}
		return true;
	}

	/**
	 *
	 * @Description: 更新文章投稿
	 * @date 2019年7月24日,下午8:59:05
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean updateArt(ContributeArticleVO VO) throws Exception {
		ValidationUtil.validate(VO);
		WztgDO udpDO = findArtById(VO.getId());
		if (ObjectUtils.equals(udpDO, null)) {
			return false;
		}
		LsBeanUtils.copyPropertiesIgnoreNull(VO, udpDO);
		// 如果是发布操作时，修改发布状态。
//		if (AuditingStatusEnum.PUBLISHED.getCode().equals(VO.getStatus())){
//			udpDO.setStatus(AuditingStatusEnum.UNPUBLISHED.getCode());
//		}
//		if (AuditingStatusEnum.UNPUBLISHED.getCode().equals(VO.getStatus())){
//			udpDO.setStatus(AuditingStatusEnum.PUBLISHED.getCode());
//		}
		udpDO.setUpdateBy(VO.getOperator());
		udpDO.setUpdateTime(DateUtil.getNowDate());
		if (dao.updateByPrimaryKeySelective(udpDO) < 1) {
			return false;
		}
		return true;
	}

	public Map<String, Object> articleGather(ContributeArticleVO VO, Integer page, Integer size) throws Exception {
		Map param = new HashMap();
		param.put("dateFrom", VO.getDateFrom());
		param.put("dateTo", VO.getDateTo());
		param.put("orgId", VO.getOrgId());
		PageHelper.startPage(page, size);
		List<ContributeArticleVO> resultVOList = dao.articleGather(param);
		PageInfo<ContributeArticleVO> pageInfo = new PageInfo<ContributeArticleVO>(resultVOList);

		Map<String, Object> resultMap = new HashMap<String, Object>();
		for (ContributeArticleVO cavo : resultVOList) {
			if(cavo.getPublishNum() == null){
				cavo.setPublishNum(0);
			}
		}
		resultMap.put("total", pageInfo.getTotal());
		resultMap.put("resultList", resultVOList);
		return resultMap;
	}

	public Integer getReportNum(Map<String, Object> queryMap) {

		int count = dao.countByExample(queryMap);
      return count;
	}
	
	/**
	 * 
	 * @Description: 方法描述
	 * @author: 王帅
	 * @param: @param  id
	 * @param: @param  status
	 * @param: @return
	 * @param: @throws Exception 参数
	 * @return: boolean 返回类型
	 */
	public boolean updateArticleStatus(String id, String status) throws Exception {
		// 校验是否存在
		WztgDO record = findArtById(id);
		if (ObjectUtils.equals(record, null)) {
			return false;
		}
		WztgDO entity = new WztgDO();
		entity.setId(id);
		entity.setStatus(status);
		if (dao.updateByPrimaryKeySelective(entity) < 1) {
			return false;
		}

		return true;
	}
}
