/*
 * DataFloatDomain.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2020-08-11 15:36:32 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.indicator.server.domain;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.util.IdsWorker;
import com.unis.indicator.common.vo.log.DataFloatVO;
import com.unis.indicator.server.dao.DataFloatDao;
import com.unis.indicator.server.entity.log.DataFloatDO;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * DATA_FLOAT-数据浮动记录表
 * DO处理自身,VO处理包括子表
 * @author lipenghe at 2020-08-11 15:36:32
 */
@Component
@Transactional
public class DataFloatDomain {

    @Autowired
    DataFloatDao dataFloatDao;

    @Autowired
    IdsWorker idsWorker;


    /**
    * 通用的插入处理
    * @param entity    <数据浮动记录表>对象
    */
    private void buildInsertData(DataFloatDO entity){
        Long pk=idsWorker.nextId();
        entity.buildInsertData(String.valueOf(pk));
        entity.setVersion("0");
        entity.setFolatId(pk);
    }

   /**
    * 通用的更新处理
    * @param entity    <数据浮动记录表>对象
    */
    private void buildUpdateData(DataFloatDO entity){
        entity.buildUpdateData();
    }

    /**
    * 通用的返回数据处理
    * @param dataFloatVO    <数据浮动记录表>对象
    */
    private DataFloatVO buildResult(DataFloatVO dataFloatVO){
        DataFloatVO dataFloatVOResult=new DataFloatVO();
        dataFloatVOResult.setFolatId(dataFloatVO.getFolatId());
        return dataFloatVOResult;
    }

    /**
    * 通用的数据处理
    * @param dataFloatVO    <数据浮动记录表>对象
    */
    private void buildData(DataFloatVO dataFloatVO){
        //DataFloatVO dataFloatVODb= selectById(dataFloatVO);
    }

    /**
    * <DATA_FLOAT-数据浮动记录表>非主键的业务唯一属性校验
    * @param dataFloatVO    <数据浮动记录表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public ResponseWrapper uniqueCheck(DataFloatVO dataFloatVO) {
        boolean bl=true;
        //非主键的业务唯一数据校验
        if((dataFloatVO.getId() !=null)
            || (StringUtils.isNotEmpty(dataFloatVO.getIdStr()))){
            int num= dataFloatDao.selectExistsByEntity(dataFloatVO);
            bl = num==0;
        }
        return ResponseWrapper.choose(bl?1:0);
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>选择性保存,包含新增和修改
     * @param dataFloatVO    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper saveEntitySelective(DataFloatVO dataFloatVO) {
        if((dataFloatVO.getFolatId() !=null)){
            return updateByEntitySelective(dataFloatVO);
        }else{
            return insertEntitySelective(dataFloatVO);
        }
    }

    /**
    * <DATA_FLOAT-数据浮动记录表>插入全部字段
    * @param entity    <数据浮动记录表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int insertEntity(DataFloatDO entity) {
        buildInsertData(entity);
        return dataFloatDao.insertEntity(entity);
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>插入全部字段
     * @param dataFloatVO    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntity(DataFloatVO dataFloatVO) {
        ResponseWrapper responseWrapper= uniqueCheck(dataFloatVO);
        if(responseWrapper.isSuccess()){
            buildData(dataFloatVO);
            //有属性操作则优先在vo处理
            DataFloatDO entity= JsonUtils.parse(
                JsonUtils.serialize(dataFloatVO), DataFloatDO.class);
            int num= insertEntity(entity);
            if(num>0){
                //主键设置回去
                dataFloatVO.setFolatId(entity.getFolatId());
                return ResponseWrapper.success(buildResult(dataFloatVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>选择性插入字段
     * @param entity    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int insertEntitySelective(DataFloatDO entity) {
        buildInsertData(entity);
        return dataFloatDao.insertEntitySelective(entity);
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>选择性插入字段
     * @param dataFloatVO    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntitySelective(DataFloatVO dataFloatVO) {
        ResponseWrapper responseWrapper= uniqueCheck(dataFloatVO);
        if(responseWrapper.isSuccess()){
            buildData(dataFloatVO);
            //有属性操作则优先在vo处理
            DataFloatDO entity= JsonUtils.parse(
                JsonUtils.serialize(dataFloatVO), DataFloatDO.class);
            int num= insertEntitySelective(entity);
            if(num>0){
                //主键设置回去
                dataFloatVO.setFolatId(entity.getFolatId());
                return ResponseWrapper.success(buildResult(dataFloatVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>更改状态
     * @param entity    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateStatusByEntity(DataFloatDO entity) {
        buildUpdateData(entity);
        return dataFloatDao.updateStatusByEntity(entity);
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>更改状态
     * @param dataFloatVO    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateStatusByEntity(DataFloatVO dataFloatVO) {
        ResponseWrapper responseWrapper= uniqueCheck(dataFloatVO);
        if(responseWrapper.isSuccess()){
            buildData(dataFloatVO);
            //有属性操作则优先在vo处理
            DataFloatDO entity= JsonUtils.parse(
                JsonUtils.serialize(dataFloatVO), DataFloatDO.class);
            int num= updateStatusByEntity(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                dataFloatVO.setFolatId(entity.getFolatId());
                return ResponseWrapper.success(buildResult(dataFloatVO));
            }else{
                return ResponseWrapper.fail();
            }
        }else{
            return responseWrapper;
        }
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>根据实体某些属性更新全部字段
     * @param entity    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntity(DataFloatDO entity) {
        buildUpdateData(entity);
        return dataFloatDao.updateByEntity(entity);
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>根据实体某些属性更新全部字段
     * @param dataFloatVO    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntity(DataFloatVO dataFloatVO) {
        ResponseWrapper responseWrapper= uniqueCheck(dataFloatVO);
        if(responseWrapper.isSuccess()){
            buildData(dataFloatVO);
            //有属性操作则优先在vo处理
            DataFloatDO entity= JsonUtils.parse(
                JsonUtils.serialize(dataFloatVO), DataFloatDO.class);
            int num= updateByEntity(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                dataFloatVO.setFolatId(entity.getFolatId());
                return ResponseWrapper.success(buildResult(dataFloatVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>根据实体不为空的属性,选择性更新字段
     * @param entity    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntitySelective(DataFloatDO entity) {
        buildUpdateData(entity);
        return dataFloatDao.updateByEntitySelective(entity);
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>根据实体不为空的属性,选择性更新字段(存在则更新,不存在则插入,其余删除)
     * @param dataFloatVO    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntitySelective(DataFloatVO dataFloatVO) {
        ResponseWrapper responseWrapper= uniqueCheck(dataFloatVO);
        if(responseWrapper.isSuccess()){
            buildData(dataFloatVO);
            //此处是直接更新,较为繁琐,适用于子表数据有关联(被其他数据使用),缺少排序在字段会出现顺序与修改数据的顺序不一致的问题,
            //有属性操作则优先在vo处理
            DataFloatDO entity= JsonUtils.parse(
                JsonUtils.serialize(dataFloatVO), DataFloatDO.class);
            int num= updateByEntitySelective(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                dataFloatVO.setFolatId(entity.getFolatId());
                return ResponseWrapper.success(buildResult(dataFloatVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>[真删除]根据实体的某些属性进行单条或者批量删除
     * @param dataFloatVO    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteByEntity(DataFloatVO dataFloatVO) {
        int num= dataFloatDao.deleteByEntity(dataFloatVO);
        return ResponseWrapper.choose(num);
    }

    /**
    * <DATA_FLOAT-数据浮动记录表>[真删除]根据实体的某些属性进行单条或者批量删除
    * @param entity    <数据浮动记录表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteByEntity(DataFloatDO entity) {
        DataFloatVO dataFloatVO= JsonUtils.parse(
            JsonUtils.serialize(entity), DataFloatVO.class);
        return dataFloatDao.deleteByEntity(dataFloatVO);
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>[假删除]根据实体的某些属性进行单条或者批量删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
     * @param dataFloatVO    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteShamByEntity(DataFloatVO dataFloatVO) {
        //自行在controller设置状态,则可删除,亦可还原
        int num= dataFloatDao.deleteShamByEntity(dataFloatVO);
        return ResponseWrapper.choose(num);
    }

    /**
    * <DATA_FLOAT-数据浮动记录表>[假删除]根据实体的某些属性进行单条或者批量删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
    * @param entity    <数据浮动记录表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteShamByEntity(DataFloatDO entity) {
        DataFloatVO dataFloatVO= JsonUtils.parse(
            JsonUtils.serialize(entity), DataFloatVO.class);
        return dataFloatDao.deleteShamByEntity(dataFloatVO);
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>根据实体的某些属性查询数量
     * @param dataFloatVO    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int selectCountByEntity(DataFloatVO dataFloatVO) {
        int num= dataFloatDao.selectCountByEntity(dataFloatVO);
        return num;
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>根据实体的业务唯一属性(且非指定主键数据)判断是否存在
     * @param dataFloatVO    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int selectExistsByEntity(DataFloatVO dataFloatVO) {
        int num= dataFloatDao.selectExistsByEntity(dataFloatVO);
        return num;
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>根据实体(唯一标示)查询一条数据
     * @param dataFloatVO    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public DataFloatVO selectById(DataFloatVO dataFloatVO) {
        DataFloatVO dataFloatVODb= dataFloatDao.selectById(dataFloatVO);
        return dataFloatVODb;
    }

    /**
    * <DATA_FLOAT-数据浮动记录表>根据实体(唯一标示)查询一条数据
    * @param entity    <数据浮动记录表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public DataFloatVO selectById(DataFloatDO entity) {
        DataFloatVO dataFloatVO= JsonUtils.parse(
            JsonUtils.serialize(entity), DataFloatVO.class);
        return dataFloatDao.selectById(dataFloatVO);
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>根据实体的某些属性查询分页数据
     * @param dataFloatVO    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public Page<DataFloatVO> selectPageByEntity(int pageNo, int pageSize
        , DataFloatVO dataFloatVO, String order) {
        PageHelper.startPage(pageNo,pageSize,order);
        return dataFloatDao.selectPageByEntity(dataFloatVO);
    }

    /**
    * <DATA_FLOAT-数据浮动记录表>根据实体的某些属性查询列表
    * @param dataFloatVO    <数据浮动记录表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public List<DataFloatVO> selectByEntity(DataFloatVO dataFloatVO) {
        return dataFloatDao.selectByEntity(dataFloatVO);
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>根据实体的某些属性查询列表
     * @param entity    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public List<DataFloatVO> selectByEntity(DataFloatDO entity) {
        DataFloatVO dataFloatVO= JsonUtils.parse(
            JsonUtils.serialize(entity), DataFloatVO.class);
        return dataFloatDao.selectByEntity(dataFloatVO);
    }

}
