package com.unis.indicator.server.domain;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.LsBeanUtils;
import com.unis.indicator.common.vo.bbzb.BreedVO;
import com.unis.indicator.common.vo.bbzb.IndiBreedSpcVO;
import com.unis.indicator.server.dao.ZbppggDao;
import com.unis.indicator.server.entity.indicator.ZbppggDO;
import lombok.Getter;
import lombok.Setter;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import tk.mybatis.mapper.entity.Example;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @ClassName IndiBreedSpcDomain
 * @Description 指标品牌规格领域对象
 * @Author xmpu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@Getter
@Setter
@Component
public class IndiBreedSpcDomain {

	@Autowired
	private ZbppggDao dao;

	/**
	 *
	 * @Description: 通过id查询指标品牌规格信息
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param id
	 * @return ZbppggDO
	 */
	public ZbppggDO findZbppggById(String id) throws Exception {
		Example example = new Example(ZbppggDO.class);
		Example.Criteria criteria = example.createCriteria();
//		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("id", id);
		ZbppggDO resDO = dao.selectOneByExample(example);
		if (ObjectUtils.equals(resDO, null)) {
			return null;
		}
		return resDO;
	}

	public List<ZbppggDO> findZbppggByIndicatorId(String indicatorId) throws Exception {
		Example example = new Example(ZbppggDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andEqualTo("indicatorId", indicatorId);
		return dao.selectByExample(example);
	}

	/**
	 *
	 * @Description: 查询所有指标品牌规格信息 模糊查询的条件可以包含：名称
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public Map<String, Object> findZbppggsByPage(IndiBreedSpcVO VO, Integer page, Integer size) throws Exception {

		Example example = new Example(ZbppggDO.class);
//		Example.Criteria criteria = example.createCriteria();

		// 添加按名称查询
//		if (!"".equals(VO.getZbppggName()) && null != VO.getZbppggName()) {
//			criteria.andLike("unitName", "%" + VO.getZbppggName() + "%");
//		}
		// 未删除
//		criteria.andIsNull("deleteTime");
		PageHelper.startPage(page, size, "ZB_NAME DESC");
		List<ZbppggDO> resultDOList = dao.selectByExample(example);
		PageInfo<ZbppggDO> pageInfo = new PageInfo<ZbppggDO>(resultDOList);

		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<IndiBreedSpcVO> resultVOList = new ArrayList<>();
		if (!resultDOList.isEmpty()) {
			for (ZbppggDO resultDO : resultDOList) {
				IndiBreedSpcVO resultVO = LsBeanUtils.copyProperties(resultDO, IndiBreedSpcVO.class);
				resultVOList.add(resultVO);
			}
		}
		resultMap.put("total", pageInfo.getTotal());
		resultMap.put("resultList", resultVOList);
		return resultMap;
	}

	/**
	 *
	 * @Description: 指标品牌规格多选删除
	 * @date 2019年7月24日,下午8:58:47
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param ids
	 * @param userId
	 * @return Boolean
	 * @throws Exception
	 */
	public boolean deleteZbppggs(String[] ids, String userId) throws Exception {
		for (String id : ids) {
			Example example = new Example(ZbppggDO.class);
			Example.Criteria criteria = example.createCriteria();
			criteria.andEqualTo("id", id);
			ZbppggDO udpDO = dao.selectOneByExample(example);
			if (ObjectUtils.notEqual(udpDO, null)) {
				dao.updateByPrimaryKey(udpDO);
			}
		}
		return true;
	}

	/**
	 *
	 * @Description: 保存指标品牌规格信息
	 * @date 2019年7月24日,下午8:58:56
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean saveZbppgg(IndiBreedSpcVO VO) throws Exception {

		if (VO == null){
			return false;
		}
		Example example = new Example(ZbppggDO.class);
		Example.Criteria criteria = example.createCriteria();
		if ("".equals(VO.getIndicatorId()) || null == VO.getIndicatorId()) {
			throw new RuntimeException("请点击指标。");
		}
		criteria.andEqualTo("indicatorId", VO.getIndicatorId());
		List<ZbppggDO> zbList = dao.selectByExample(example);
		// 先删除
		if(zbList != null && zbList.size() > 0) {
			for (ZbppggDO ip : zbList) {
				dao.delete(ip);
			}
		}

		if(VO.getBreedVOList() == null || VO.getBreedVOList().size() < 1) {
			throw new RuntimeException("请配置指标属性。");
		}
		List<BreedVO> requestList = VO.getBreedVOList();
		int count = 0;
		// 再插入
		for (BreedVO request : requestList) {
			if(!"0".equals(request.getPdictCode())){
				count++;
				ZbppggDO insDO = new ZbppggDO();
				LsBeanUtils.copyPropertiesIgnoreNull(VO, insDO);
				// 品牌
				insDO.setBreedId(request.getPdictCode());
				for(BreedVO vv : requestList){
					if(vv.getDictCode().equals(request.getPdictCode())){
						insDO.setBreedName(vv.getDictName());
					}
				}
				// 规格
				insDO.setSpecsId(request.getDictCode());
				insDO.setSpecsName(request.getDictName());
				if (dao.insertSelective(insDO) < 1) {
					throw new RuntimeException("无法保存成功，请检查数据。");
				}
			}

//		    if(breed.getSubDataDictionarys() != null && breed.getSubDataDictionarys().size() > 0){
//                for (BreedVO specs : breed.getSubDataDictionarys()) {
//                    ZbppggDO insDO = new ZbppggDO();
//                    LsBeanUtils.copyPropertiesIgnoreNull(VO, insDO);
//                    insDO.setBreedId(breed.getId());
//                    insDO.setBreedName(breed.getDictName());
//                    insDO.setSpecsId(specs.getId());
//                    insDO.setSpecsName(specs.getDictName());
//                    if (dao.insertSelective(insDO) < 1) {
//                        throw new RuntimeException("无法保存成功，请检查数据。");
//                    }
//                }
//            } else {
//                throw new RuntimeException("请配置品牌规格属性。");
////                ZbppggDO insDO = new ZbppggDO();
////                LsBeanUtils.copyPropertiesIgnoreNull(VO, insDO);
////                insDO.setBreedId(breed.getId());
////                insDO.setBreedName(breed.getDictName());
////                if (dao.insertSelective(insDO) < 1) {
////                    throw new RuntimeException("无法保存成功，请检查数据。");
////                }
//            }
		}
		if(count == 0){
			throw new RuntimeException("请配置品牌规格属性。");
		}

		return true;
	}

	/**
	 *
	 * @Description: 更新产地
	 * @date 2019年7月24日,下午8:59:05
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean updateZbppggPlace(IndiBreedSpcVO VO) throws Exception {

		ZbppggDO udpDO = findZbppggById(VO.getId());
		if (ObjectUtils.equals(udpDO, null)) {
			return false;
		}
		LsBeanUtils.copyPropertiesIgnoreNull(VO, udpDO);

		if (dao.updateByPrimaryKey(udpDO) < 1) {
			return false;
		}
		return true;
	}

}
