package com.unis.indicator.server.domain;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.ValidationUtil;
import com.unis.indicator.common.vo.*;
import com.unis.indicator.server.config.SecurityUtil;
import com.unis.indicator.server.dao.*;
import com.unis.indicator.server.entity.indicator.*;
import lombok.Getter;
import lombok.Setter;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import tk.mybatis.mapper.entity.Example;

import java.util.*;

/**
 * @ClassName IndicatorDomain
 * @Description 指标领域对象
 * @Author xmpu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@Getter
@Setter
@Component
public class IndicatorDomain {

	@Autowired
	private ZbDao indicatorDao;

	@Autowired
	private ZbJcdDao indicatorMonitorDao;

	@Autowired
	private ZbBzDao indicatorStandardDao;

	@Autowired
	private ZbJgLxDao indicatorPriceDao;

	@Autowired
	private PriceTypeDomain priceTypeDomain;

	@Autowired
	private StandardDomain standardDomain;
	
	@Autowired
    private LyjgDao lyjgDao;

	/**
	 *
	 * @Description: 通过id查询指标信息
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param id
	 * @return ZbDO
	 */
	public ZbDO findIndById(String id) throws Exception {
		Example example = new Example(ZbDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("id", id);
		ZbDO resDO = indicatorDao.selectOneByExample(example);
		if (ObjectUtils.equals(resDO, null)) {
			return null;
		}
		return resDO;
	}

	/**
	 * @Description: 通过品种名称查询指标的类型
	 * create by: yangshengjie
	 * create time: 2019/11/25 17:05
	 *
	 * @Param: indName
	 * @return indType
	 */
	public String findIndTypeByName(String indName) throws Exception {
		Example example = new Example(ZbDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("indName", indName);
		ZbDO resDO = indicatorDao.selectOneByExample(example);
		if (ObjectUtils.equals(resDO, null)) {
			return null;
		}
		return resDO.getIndType();
	}

	/**
	 *
	 * @Description: 通过indicatorId查询指标和监测点关联信息
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param indicatorId
	 * @return boolean
	 */
	public boolean findIndMonRel(String indicatorId) throws Exception {
		Example example = new Example(ZbjcdDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andEqualTo("indicatorId", indicatorId);
		List res = indicatorMonitorDao.selectByExample(example);
		if (res != null
				&& res.size() > 0) {
			return true;
		}
		return false;
	}

	/**
	 *
	 * @Description: 查询所有指标信息 模糊查询
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public Map<String, Object> findIndsByPage(IndicatorVO VO, Integer page, Integer size) throws Exception {

		Example example = new Example(ZbDO.class);
		Example.Criteria criteria = example.createCriteria();
		String	indName= SecurityUtil.filterStrSqlJs(VO.getIndName());

		// 添加按名称查询
		if (!"".equals(indName) && null !=indName) {
			criteria.andLike("indName", "%" + indName + "%");
		}
		// 未删除
		criteria.andIsNull("deleteTime");
		PageHelper.startPage(page, size, "CREATE_TIME DESC");
		List<ZbDO> resultDOList = indicatorDao.selectByExample(example);
		PageInfo<ZbDO> pageInfo = new PageInfo<ZbDO>(resultDOList);

		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<IndicatorVO> resultVOList = new ArrayList<>();
		if (!resultDOList.isEmpty()) {
			for (ZbDO resultDO : resultDOList) {
				IndicatorVO resultVO = LsBeanUtils.copyProperties(resultDO, IndicatorVO.class);
				resultVOList.add(resultVO);
			}
		}
		resultMap.put("total", pageInfo.getTotal());
		resultMap.put("resultList", resultVOList);
		return resultMap;
	}

	/**
	 *
	 * @Description: 查询所有用户(按品种分组)
	 * @date 2019/12/17 16:11
	 * @author yangshengjie
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return List
	 * @throws Exception
	 */
	public List findIndsByPageGroup(IndicatorVO VO, Integer page, Integer size) throws Exception {

		Example example = new Example(ZbDO.class);
		Example.Criteria criteria = example.createCriteria();
		String	indName= SecurityUtil.filterStrSqlJs(VO.getIndName());

		// 添加按名称查询
		if (!"".equals(indName) && null !=indName) {
			criteria.andLike("indName", "%" + indName + "%");
		}
		// 未删除
		criteria.andIsNull("deleteTime");
		PageHelper.startPage(page, size, "CREATE_TIME DESC");
		List<ZbDO> resultDOList = indicatorDao.selectByExample(example);
		PageInfo<ZbDO> pageInfo = new PageInfo<ZbDO>(resultDOList);

		List<IndicatorVO> resultVOList = new ArrayList<>();
		if (!resultDOList.isEmpty()) {
			for (ZbDO resultDO : resultDOList) {
				IndicatorVO resultVO = LsBeanUtils.copyProperties(resultDO, IndicatorVO.class);
				resultVOList.add(resultVO);
			}
		}
		List resultList = new ArrayList();
		List temList = new ArrayList();
		Map temMap = new HashMap<>();

		if(!resultVOList.isEmpty()){
			//找原粮
			temMap.put("name","原粮");
			temList.add(temMap);
			for (IndicatorVO resultVO : resultVOList){
				if ("1".equals(resultVO.getIndType()) || resultVO.getIndType() == "1"){
					if (!"原粮".equals(resultVO.getIndName()) && resultVO.getIndName() != "原粮"){
						temMap = new HashMap<>();
						temMap.put("name",resultVO.getIndName());
						temList.add(temMap);
					}
				}
			}
			resultList.add(temList);
			temMap = new HashMap<>();
			temList = new ArrayList();
			//找成品粮
			temMap.put("name","成品粮");
			temList.add(temMap);
			for (IndicatorVO resultVO : resultVOList){
				if ("2".equals(resultVO.getIndType()) || resultVO.getIndType() == "2"){
					if (!"成品粮".equals(resultVO.getIndName()) && resultVO.getIndName() != "成品粮"){
						temMap = new HashMap<>();
						temMap.put("name",resultVO.getIndName());
						temList.add(temMap);
					}
				}
			}
			resultList.add(temList);
			temMap = new HashMap<>();
			temList = new ArrayList();
			//找食用油及油料
			temMap.put("name","食用油及油料");
			temList.add(temMap);
			for (IndicatorVO resultVO : resultVOList){
				if ("3".equals(resultVO.getIndType()) || resultVO.getIndType() == "3"){
					if (!"食用油及油料".equals(resultVO.getIndName()) && resultVO.getIndName() != "食用油及油料"){
						temMap = new HashMap<>();
						temMap.put("name",resultVO.getIndName());
						temList.add(temMap);
					}
				}
			}
			resultList.add(temList);

		}


		return resultList;
	}

	/**
	 *
	 * @Description: 指标多选删除
	 * @date 2019年7月24日,下午8:58:47
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param ids
	 * @param userId
	 * @return Boolean
	 * @throws Exception
	 */
	public boolean deleteInds(String[] ids, String userId) throws Exception {
		for (String id : ids) {
			Example example = new Example(ZbDO.class);
			Example.Criteria criteria = example.createCriteria();
			criteria.andEqualTo("id", id);
			criteria.andIsNull("deleteTime");
			ZbDO udpDO = indicatorDao.selectOneByExample(example);
			if (ObjectUtils.notEqual(udpDO, null)) {
				udpDO.setDeleteBy(userId);
				udpDO.setDeleteTime(DateUtil.getNowDate());
				indicatorDao.updateByPrimaryKey(udpDO);
			}
		}
		return true;
	}

	/**
	 *
	 * @Description: 保存指标信息
	 * @date 2019年7月24日,下午8:58:56
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean saveInd(IndicatorVO VO) throws Exception {
		ValidationUtil.validate(VO);

		if (!"".equals(VO.getIndName()) && null != VO.getIndName()) {
			if (repeatCheck("indName", VO.getIndName())) {
				throw new RuntimeException("指标名称重复。");
			}
		}
		if (!"".equals(VO.getIndCode()) && null != VO.getIndCode()) {
			repeatCheck("indCode", VO.getIndCode());
			if (repeatCheck("indCode", VO.getIndCode())) {
				throw new RuntimeException("指标代码重复。");
			}
		}
		if (!"".equals(VO.getEnsCode()) && null != VO.getEnsCode()) {
			repeatCheck("ensCode", VO.getEnsCode());
			if (repeatCheck("ensCode", VO.getEnsCode())) {
				throw new RuntimeException("指标英文代码重复。");
			}
		}

		ZbDO insDO = new ZbDO();
		LsBeanUtils.copyPropertiesIgnoreNull(VO, insDO);
		insDO.setCreateBy(VO.getOperator());
		insDO.setCreateTime(new Date());
		if (indicatorDao.insertSelective(insDO) < 1) {
			throw new RuntimeException(insDO.getIndName() + "无法保存成功，请检查数据。");
		}
		return true;
	}

	private boolean repeatCheck(String property, String value){
		// 重复验证。
		Example example = new Example(ZbDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andEqualTo(property, value);
		criteria.andIsNull("deleteTime");
		if (indicatorDao.selectCountByExample(example) > 0) {
			return true;
		}
		return false;
	}

	/**
	 *
	 * @Description: 更新指标
	 * @date 2019年7月24日,下午8:59:05
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean updateInd(IndicatorVO VO) throws Exception {
//		ValidationUtil.validate(VO);
//		if (!"".equals(VO.getIndName()) && null != VO.getIndName()) {
//			if (repeatCheck("indName", VO.getIndName())) {
//				throw new RuntimeException("指标名称重复。");
//			}
//		}
//		if (!"".equals(VO.getIndCode()) && null != VO.getIndCode()) {
//			repeatCheck("indCode", VO.getIndCode());
//			if (repeatCheck("indCode", VO.getIndCode())) {
//				throw new RuntimeException("指标代码重复。");
//			}
//		}
//		if (!"".equals(VO.getEnsCode()) && null != VO.getEnsCode()) {
//			repeatCheck("ensCode", VO.getEnsCode());
//			if (repeatCheck("ensCode", VO.getEnsCode())) {
//				throw new RuntimeException("指标英文代码重复。");
//			}
//		}
		ZbDO udpDO = findIndById(VO.getId());
		if (ObjectUtils.equals(udpDO, null)) {
			throw new RuntimeException("此数据未存储到数据库中。");
		}
		String indicatorCodeCurrent = udpDO.getIndCode();
		String indicatorCodeModify = VO.getIndCode();
		LsBeanUtils.copyPropertiesIgnoreNull(VO, udpDO);

		udpDO.setUpdateBy(VO.getOperator());
		udpDO.setUpdateTime(DateUtil.getNowDate());
		if (indicatorDao.updateByPrimaryKey(udpDO) < 1) {
			throw new RuntimeException("更新失败，请检查数据格式。");
		} else {
			// 如果存在修改编码则修改填报记录中响应指标的编码值
			if (StringUtils.isNotEmpty(indicatorCodeCurrent) && StringUtils.isNotEmpty(indicatorCodeModify)
					&& !indicatorCodeCurrent.equals(indicatorCodeModify)) {
				lyjgDao.modifyRecordVarietiesCode(indicatorCodeModify, indicatorCodeCurrent, VO.getIndName(), "");
			}
		}
		return true;
	}


	/**
	 *
	 * @Description: 查询所有父指标信息树形结构
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @return List
	 * @throws Exception
	 */
	public List<IndicatorVO> findIndsTree(String treeCode) throws Exception {
		final String root = "0";
		Map param = new HashMap();
		param.put("id", root);
		param.put("treeCode", treeCode);
		List<IndicatorVO> resultList = new ArrayList<>();
		if ("0".equals(treeCode)) {
			resultList = indicatorDao.findAllIndsTree(param);
		}
		if ("1".equals(treeCode)) {
			resultList = indicatorDao.findIndsTree(param);
		}
		return resultList;
	}

	/**
	 *
	 * @Description: 指标与监测点保存
	 * @date 2019年7月24日,下午8:58:47
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param vo
	 * @return Boolean
	 * @throws Exception
	 */
	public boolean saveIndicatorMonitor(IndicatorMonitorVO vo) throws Exception {

		Example example = new Example(ZbjcdDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andEqualTo("monitorId", vo.getMonitorId());
		List<ZbjcdDO> IMList = indicatorMonitorDao.selectByExample(example);
		// 先删除
		if(IMList != null && IMList.size() > 0) {
			for (ZbjcdDO im : IMList) {
				indicatorMonitorDao.delete(im);
			}
		}
		// 再插入
		for (String indicatorId : vo.getIndicatorIds()) {
			ZbjcdDO insDO = new ZbjcdDO();
			insDO.setIndicatorId(indicatorId);
			insDO.setMonitorId(vo.getMonitorId());
			indicatorMonitorDao.insertSelective(insDO);
		}
		return true;
	}

	/**
	 *
	 * @Description: 查询监测点对应勾选了的指标
	 * @date 2019年7月24日,下午8:59:05
	 * @author xmpu
	 * @version v1.0
	 *
	 * @return IndicatorMonitorVO
	 * @throws Exception
	 */
	public IndicatorMonitorVO findIndicatorMonitor(String monitorId) throws Exception {

		Example example = new Example(ZbjcdDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andEqualTo("monitorId", monitorId);
		List<ZbjcdDO> IMList = indicatorMonitorDao.selectByExample(example);

		IndicatorMonitorVO res = new IndicatorMonitorVO();
		List<String> indicatorIds = new ArrayList<>();
		List<IndicatorVO> indicatorVOList = new ArrayList<>();
		for (ZbjcdDO im : IMList) {
			res.setMonitorId(im.getMonitorId());
			indicatorIds.add(im.getIndicatorId());
			indicatorVOList.add(LsBeanUtils.copyProperties(
					this.findIndById(im.getIndicatorId()),
					IndicatorVO.class));
		}
		res.setIndicatorVOList(indicatorVOList);
		res.setIndicatorIds(indicatorIds);
		return res;
	}

	/**
	 *
	 * @Description: 指标标准与指标保存
	 * @date 2019年7月24日,下午8:58:47
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param vo
	 * @return Boolean
	 * @throws Exception
	 */
	public boolean saveIndicatorStandard(IndicatorStandardVO vo) throws Exception {

		Example example = new Example(ZbbzDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andEqualTo("indicatorId", vo.getIndicatorId());
		List<ZbbzDO> ISList = indicatorStandardDao.selectByExample(example);
		// 先删除
		if(ISList != null && ISList.size() > 0) {
			for (ZbbzDO im : ISList) {
				indicatorStandardDao.delete(im);
			}
		}
		// 再插入
		for (String standardId : vo.getStandardIds()) {
			ZbbzDO insDO = new ZbbzDO();
			insDO.setStandardId(standardId);
			insDO.setIndicatorId(vo.getIndicatorId());
			indicatorStandardDao.insertSelective(insDO);
		}
		return true;
	}

	/**
	 *
	 * @Description: 查询指标对应勾选了的指标标准
	 * @date 2019年7月24日,下午8:59:05
	 * @author xmpu
	 * @version v1.0
	 *
	 * @return IndicatorStandardVO
	 * @throws Exception
	 */
	public IndicatorStandardVO findIndicatorStandard(String indicatorId) throws Exception {

		Example example = new Example(ZbbzDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andEqualTo("indicatorId", indicatorId);
		List<ZbbzDO> ISList = indicatorStandardDao.selectByExample(example);

		IndicatorStandardVO res = new IndicatorStandardVO();
		List<String> standardIds = new ArrayList<>();
		List<StandardVO> standardVOList = new ArrayList<>();
		for (ZbbzDO im : ISList) {
			res.setIndicatorId(im.getIndicatorId());
			standardIds.add(im.getStandardId());
			standardVOList.add(
					LsBeanUtils.copyProperties(
					standardDomain.findStdById(im.getStandardId()),
					StandardVO.class));
		}
		res.setStandardVOList(standardVOList);
		res.setStandardIds(standardIds);
		return res;
	}

	/**
	 *
	 * @Description: 价格类型与指标保存
	 * @date 2019年7月24日,下午8:58:47
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param vo
	 * @return Boolean
	 * @throws Exception
	 */
	public boolean saveIndicatorPriceType(IndicatorPriceVO vo) throws Exception {

		Example example = new Example(ZbjglxDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andEqualTo("indicatorId", vo.getIndicatorId());
		List<ZbjglxDO> IPList = indicatorPriceDao.selectByExample(example);
		// 先删除
		if(IPList != null && IPList.size() > 0) {
			for (ZbjglxDO ip : IPList) {
				indicatorPriceDao.delete(ip);
			}
		}
		// 再插入
		for (PriceTypeVO priceType : vo.getPriceTypeVO()) {
			ZbjglxDO insDO = new ZbjglxDO();
			if (priceType != null) {
				insDO.setPriceId(priceType.getId());
				insDO.setIndicatorId(vo.getIndicatorId());
				insDO.setMomVal(priceType.getMomVal());
				insDO.setDecimalDigit(priceType.getDecimalDigit());
				insDO.setRangeTips(priceType.getRangeTips());
				insDO.setStandardPrice(priceType.getStandardPrice());
				indicatorPriceDao.insertSelective(insDO);
			}
		}
		return true;
	}

	/**
	 *
	 * @Description: 查询指标对应勾选了的价格类型
	 * @date 2019年7月24日,下午8:59:05
	 * @author xmpu
	 * @version v1.0
	 *
	 * @return IndicatorPriceVO
	 * @throws Exception
	 */
	public IndicatorPriceVO findIndicatorPriceType(String indicatorId) throws Exception {

		Example example = new Example(ZbjglxDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andEqualTo("indicatorId", indicatorId);
		List<ZbjglxDO> ISList = indicatorPriceDao.selectByExample(example);

		IndicatorPriceVO res = new IndicatorPriceVO();
		List<PriceTypeVO> priceList = new ArrayList<>();
		// 价格类型包装
		for (ZbjglxDO ip : ISList) {
			res.setIndicatorId(ip.getIndicatorId());
			PriceTypeVO pt  = new PriceTypeVO();
			pt.setMomVal(ip.getMomVal());
			pt.setId(ip.getPriceId());
			pt.setDecimalDigit(ip.getDecimalDigit());
			pt.setRangeTips(ip.getRangeTips());
			pt.setStandardPrice(ip.getStandardPrice());
			JglxDO ptDO = priceTypeDomain.findPriceTypeById(ip.getPriceId());
			pt.setPriceTypeName(ptDO.getPriceTypeName());
			priceList.add(pt);
		}
		res.setPriceTypeVO(priceList);
		return res;
	}

}
