/*
 * LogDataChangeDomain.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2020-08-06 15:42:51 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.indicator.server.domain;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.log.LogDataChangeVO;
import com.unis.indicator.server.dao.LogDataChangeDao;
import com.unis.indicator.server.entity.log.LogDataChangeDO;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import com.unis.indicator.common.util.IdsWorker;

import java.util.List;

/**
 * LOG_DATA_CHANGE-数据变动日志表
 * DO处理自身,VO处理包括子表
 * @author lipenghe at 2020-08-06 15:42:51
 */
@Component
@Transactional
public class LogDataChangeDomain {

    @Autowired
    LogDataChangeDao logDataChangeDao;

    @Autowired
    IdsWorker idsWorker;

   /**
    * 通用的插入处理
    * @param entity    <数据变动日志表>对象
    */
    private void buildInsertData(LogDataChangeDO entity){
        Long pk=idsWorker.nextId();
        entity.buildInsertData(String.valueOf(pk));
        entity.setLogId(pk);
    }

   /**
    * 通用的更新处理
    * @param entity    <数据变动日志表>对象
    */
    private void buildUpdateData(LogDataChangeDO entity){
        entity.buildUpdateData();
    }

    /**
    * 通用的返回数据处理
    * @param dataChangeVO    <数据变动日志表>对象
    */
    private LogDataChangeVO buildResult(LogDataChangeVO dataChangeVO){
        LogDataChangeVO dataChangeVOResult=new LogDataChangeVO();
        dataChangeVOResult.setLogId(dataChangeVO.getLogId());
        return dataChangeVOResult;
    }

    /**
    * 通用的数据处理
    * @param dataChangeVO    <数据变动日志表>对象
    */
    private void buildData(LogDataChangeVO dataChangeVO){
        //LogDataChangeVO dataChangeVODb= selectById(dataChangeVO);
    }

    /**
    * <LOG_DATA_CHANGE-数据变动日志表>非主键的业务唯一属性校验
    * @param dataChangeVO    <数据变动日志表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public ResponseWrapper uniqueCheck(LogDataChangeVO dataChangeVO) {
        boolean bl=true;
        //非主键的业务唯一数据校验
        if((dataChangeVO.getId() !=null)
            || (StringUtils.isNotEmpty(dataChangeVO.getIdStr()))){
            int num= logDataChangeDao.selectExistsByEntity(dataChangeVO);
            bl = num==0;
        }
        return ResponseWrapper.choose(bl?1:0);
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>选择性保存,包含新增和修改
     * @param dataChangeVO    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper saveEntitySelective(LogDataChangeVO dataChangeVO) {
        if((dataChangeVO.getLogId() !=null)){
            return updateByEntitySelective(dataChangeVO);
        }else{
            return insertEntitySelective(dataChangeVO);
        }
    }

    /**
    * <LOG_DATA_CHANGE-数据变动日志表>插入全部字段
    * @param entity    <数据变动日志表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int insertEntity(LogDataChangeDO entity) {
        buildInsertData(entity);
        return logDataChangeDao.insertEntity(entity);
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>插入全部字段
     * @param dataChangeVO    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntity(LogDataChangeVO dataChangeVO) {
        ResponseWrapper responseWrapper= uniqueCheck(dataChangeVO);
        if(responseWrapper.isSuccess()){
            buildData(dataChangeVO);
            //有属性操作则优先在vo处理
            LogDataChangeDO entity= JsonUtils.parse(
                JsonUtils.serialize(dataChangeVO), LogDataChangeDO.class);
            int num= insertEntity(entity);
            if(num>0){
                //主键设置回去
                dataChangeVO.setLogId(entity.getLogId());
                return ResponseWrapper.success(buildResult(dataChangeVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>选择性插入字段
     * @param entity    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int insertEntitySelective(LogDataChangeDO entity) {
        buildInsertData(entity);
        return logDataChangeDao.insertEntitySelective(entity);
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>选择性插入字段
     * @param dataChangeVO    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntitySelective(LogDataChangeVO dataChangeVO) {
        ResponseWrapper responseWrapper= uniqueCheck(dataChangeVO);
        if(responseWrapper.isSuccess()){
            buildData(dataChangeVO);
            //有属性操作则优先在vo处理
            LogDataChangeDO entity= JsonUtils.parse(
                JsonUtils.serialize(dataChangeVO), LogDataChangeDO.class);
            int num= insertEntitySelective(entity);
            if(num>0){
                //主键设置回去
                dataChangeVO.setLogId(entity.getLogId());
                return ResponseWrapper.success(buildResult(dataChangeVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>更改状态
     * @param entity    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateStatusByEntity(LogDataChangeDO entity) {
        buildUpdateData(entity);
        return logDataChangeDao.updateStatusByEntity(entity);
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>更改状态
     * @param dataChangeVO    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateStatusByEntity(LogDataChangeVO dataChangeVO) {
        ResponseWrapper responseWrapper= uniqueCheck(dataChangeVO);
        if(responseWrapper.isSuccess()){
            buildData(dataChangeVO);
            //有属性操作则优先在vo处理
            LogDataChangeDO entity= JsonUtils.parse(
                JsonUtils.serialize(dataChangeVO), LogDataChangeDO.class);
            int num= updateStatusByEntity(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                dataChangeVO.setLogId(entity.getLogId());
                return ResponseWrapper.success(buildResult(dataChangeVO));
            }else{
                return ResponseWrapper.fail();
            }
        }else{
            return responseWrapper;
        }
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>根据实体某些属性更新全部字段
     * @param entity    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntity(LogDataChangeDO entity) {
        buildUpdateData(entity);
        return logDataChangeDao.updateByEntity(entity);
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>根据实体某些属性更新全部字段
     * @param dataChangeVO    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntity(LogDataChangeVO dataChangeVO) {
        ResponseWrapper responseWrapper= uniqueCheck(dataChangeVO);
        if(responseWrapper.isSuccess()){
            buildData(dataChangeVO);
            //有属性操作则优先在vo处理
            LogDataChangeDO entity= JsonUtils.parse(
                JsonUtils.serialize(dataChangeVO), LogDataChangeDO.class);
            int num= updateByEntity(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                dataChangeVO.setLogId(entity.getLogId());
                return ResponseWrapper.success(buildResult(dataChangeVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>根据实体不为空的属性,选择性更新字段
     * @param entity    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntitySelective(LogDataChangeDO entity) {
        buildUpdateData(entity);
        return logDataChangeDao.updateByEntitySelective(entity);
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>根据实体不为空的属性,选择性更新字段(存在则更新,不存在则插入,其余删除)
     * @param dataChangeVO    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntitySelective(LogDataChangeVO dataChangeVO) {
        ResponseWrapper responseWrapper= uniqueCheck(dataChangeVO);
        if(responseWrapper.isSuccess()){
            buildData(dataChangeVO);
            //此处是直接更新,较为繁琐,适用于子表数据有关联(被其他数据使用),缺少排序在字段会出现顺序与修改数据的顺序不一致的问题,
            //有属性操作则优先在vo处理
            LogDataChangeDO entity= JsonUtils.parse(
                JsonUtils.serialize(dataChangeVO), LogDataChangeDO.class);
            int num= updateByEntitySelective(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                dataChangeVO.setLogId(entity.getLogId());
                return ResponseWrapper.success(buildResult(dataChangeVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>[真删除]根据实体的某些属性进行单条或者批量删除
     * @param dataChangeVO    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteByEntity(LogDataChangeVO dataChangeVO) {
        int num= logDataChangeDao.deleteByEntity(dataChangeVO);
        return ResponseWrapper.choose(num);
    }

    /**
    * <LOG_DATA_CHANGE-数据变动日志表>[真删除]根据实体的某些属性进行单条或者批量删除
    * @param entity    <数据变动日志表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteByEntity(LogDataChangeDO entity) {
        LogDataChangeVO dataChangeVO= JsonUtils.parse(
            JsonUtils.serialize(entity), LogDataChangeVO.class);
        return logDataChangeDao.deleteByEntity(dataChangeVO);
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>[假删除]根据实体的某些属性进行单条或者批量删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
     * @param dataChangeVO    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteShamByEntity(LogDataChangeVO dataChangeVO) {
        //自行在controller设置状态,则可删除,亦可还原
        int num= logDataChangeDao.deleteShamByEntity(dataChangeVO);
        return ResponseWrapper.choose(num);
    }

    /**
    * <LOG_DATA_CHANGE-数据变动日志表>[假删除]根据实体的某些属性进行单条或者批量删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
    * @param entity    <数据变动日志表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteShamByEntity(LogDataChangeDO entity) {
        LogDataChangeVO dataChangeVO= JsonUtils.parse(
            JsonUtils.serialize(entity), LogDataChangeVO.class);
        return logDataChangeDao.deleteShamByEntity(dataChangeVO);
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>根据实体的某些属性查询数量
     * @param dataChangeVO    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int selectCountByEntity(LogDataChangeVO dataChangeVO) {
        int num= logDataChangeDao.selectCountByEntity(dataChangeVO);
        return num;
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>根据实体的业务唯一属性(且非指定主键数据)判断是否存在
     * @param dataChangeVO    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int selectExistsByEntity(LogDataChangeVO dataChangeVO) {
        int num= logDataChangeDao.selectExistsByEntity(dataChangeVO);
        return num;
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>根据实体(唯一标示)查询一条数据
     * @param dataChangeVO    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public LogDataChangeVO selectById(LogDataChangeVO dataChangeVO) {
        LogDataChangeVO dataChangeVODb= logDataChangeDao.selectById(dataChangeVO);
        return dataChangeVODb;
    }

    /**
    * <LOG_DATA_CHANGE-数据变动日志表>根据实体(唯一标示)查询一条数据
    * @param entity    <数据变动日志表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public LogDataChangeVO selectById(LogDataChangeDO entity) {
        LogDataChangeVO dataChangeVO= JsonUtils.parse(
            JsonUtils.serialize(entity), LogDataChangeVO.class);
        return logDataChangeDao.selectById(dataChangeVO);
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>根据实体的某些属性查询分页数据
     * @param dataChangeVO    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public Page<LogDataChangeVO> selectPageByEntity(int pageNo, int pageSize
        , LogDataChangeVO dataChangeVO, String order) {
        PageHelper.startPage(pageNo,pageSize,order);
        return logDataChangeDao.selectPageByEntity(dataChangeVO);
    }

    /**
    * <LOG_DATA_CHANGE-数据变动日志表>根据实体的某些属性查询列表
    * @param dataChangeVO    <数据变动日志表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public List<LogDataChangeVO> selectByEntity(LogDataChangeVO dataChangeVO) {
        return logDataChangeDao.selectByEntity(dataChangeVO);
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>根据实体的某些属性查询列表
     * @param entity    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public List<LogDataChangeVO> selectByEntity(LogDataChangeDO entity) {
        LogDataChangeVO dataChangeVO= JsonUtils.parse(
            JsonUtils.serialize(entity), LogDataChangeVO.class);
        return logDataChangeDao.selectByEntity(dataChangeVO);
    }

}
