package com.unis.indicator.server.domain;

import java.text.SimpleDateFormat;
import java.util.*;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.indicator.common.vo.ReportRecordVO;
import com.unis.indicator.server.dao.TbjlDao;

import lombok.Getter;
import lombok.Setter;

/**
 * @ClassName MarketTrendDomain
 * @Description 本周行情、价格走势
 * @Author lifx
 * @Date 2019年8月28日11:26:22
 * @Version 0.0.1
 **/
@Getter
@Setter
@Component
public class MarketTrendDomain {

	@Autowired
	private TbjlDao dao;

	

	/**
	 * @Description: 查询本周行情--查询上报开始、结束时间
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public Map<String, Object> queryReportTime(ReportRecordVO VO, Integer page, Integer size) throws Exception {
		PageHelper.startPage(page, size);
		List<Map> list = dao.queryReportTime(VO);
 		PageInfo<Map> pageInfo = new PageInfo<Map>(list);
		Map<String, Object> resultMap = new HashMap<String, Object>();
		resultMap.put("total", pageInfo.getTotal());
		resultMap.put("resultList", list);
		return resultMap;
	}
	
	/**
	 * @Description: 查询本周行情--查询上国家局详情
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public Map<String, Object> queryCountryDetails(ReportRecordVO VO, Integer page, Integer size) throws Exception {
		PageHelper.startPage(page, size);
		if(VO.getPzlb().equals("原粮")) {
			VO.setPzlb("1");
		}else if(VO.getPzlb().equals("成品粮")) {
			VO.setPzlb("2");
		}else if(VO.getPzlb().equals("食用油及油料")) {
			VO.setPzlb("3");
		}
		List<Map> list = dao.queryCountryDetails(VO);
 		PageInfo<Map> pageInfo = new PageInfo<Map>(list);
		Map<String, Object> resultMap = new HashMap<String, Object>();
		resultMap.put("total", pageInfo.getTotal());
		resultMap.put("resultList", list);
		return resultMap;
	}
	
	/**
	 * @Description: 查询本周行情--查询库点详情
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public Map<String, Object> queryPointDetails(ReportRecordVO VO, Integer page, Integer size) throws Exception {
		PageHelper.startPage(page, size);
		if(VO.getPzlb().equals("原粮")) {
			VO.setPzlb("1");
		}else if(VO.getPzlb().equals("成品粮")) {
			VO.setPzlb("2");
		}else if(VO.getPzlb().equals("食用油及油料")) {
			VO.setPzlb("3");
		}

			List<Map> list = dao.queryPointDetails(VO);
			PageInfo<Map> pageInfo = new PageInfo<Map>(list);
			Map<String, Object> resultMap = new HashMap<String, Object>();
			resultMap.put("total", pageInfo.getTotal());
			resultMap.put("resultList", list);
			return resultMap;



	}
	
	/**
	 * @Description: 查询价格走势--原粮
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public Map<String, Object> queryPriceYL(ReportRecordVO VO) throws Exception {
		Date date = new Date();
		SimpleDateFormat dateFormat= new SimpleDateFormat("yyyy-MM-dd");
		String sysdata=dateFormat.format(date);
		ReportRecordVO ckj=new ReportRecordVO();
		ckj.setEndTime(VO.getEndTime());
		ckj.setStartTime(VO.getStartTime());
		ckj.setSbdq(VO.getSbdq());
		ckj.setPzmc(VO.getPzmc());
		ckj.setJglx("出库价");
		ckj.setPzlb("1");//原粮
		ckj.setBblx("粮油价格监测周报表");
		List<Map> listckj = dao.queryPriceTrend(ckj);
		Map<String, Object> ckjMap=new HashMap<String, Object>();
	/*	if(listckj.size()==0) {
			ckjMap.put("bqjg", "0");
			ckjMap.put("pzdw", "");
			ckjMap.put("startTime", sysdata);
			listckj.add(ckjMap);
		}*/
		ReportRecordVO sgj=new ReportRecordVO();
		sgj.setEndTime(VO.getEndTime());
		sgj.setStartTime(VO.getStartTime());
		sgj.setSbdq(VO.getSbdq());
		sgj.setPzmc(VO.getPzmc());
		sgj.setJglx("收购价");
		sgj.setPzlb("1");//原粮
		sgj.setBblx("粮油价格监测周报表");
		List<Map> listsgj = dao.queryPriceTrend(sgj);
		Map<String, Object> sgjMap=new HashMap<String, Object>();
		System.out.println(listsgj.size()==0);
		/*if(listsgj.size()==0) {
			sgjMap.put("bqjg", "0");
			sgjMap.put("pzdw", "");
			sgjMap.put("startTime", sysdata);
			listsgj.add(sgjMap);
		}*/
		Map<String, Object> resultMap = new HashMap<String, Object>();
		resultMap.put("ckj", listckj);
		resultMap.put("sgj", listsgj);
		return resultMap;
	}

	/**
	 * @Description: 查询价格走势--成品粮
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public Map<String, Object> queryPriceCPL(ReportRecordVO VO) throws Exception {
		Date date = new Date();
		SimpleDateFormat dateFormat= new SimpleDateFormat("yyyy-MM-dd");
		String sysdata=dateFormat.format(date);
		ReportRecordVO lsj=new ReportRecordVO();
		lsj.setEndTime(VO.getEndTime());
		lsj.setStartTime(VO.getStartTime());
		lsj.setSbdq(VO.getSbdq());
		lsj.setPzmc(VO.getPzmc());
		lsj.setJglx("零售价");
		lsj.setPzlb("2");//成品粮
		lsj.setBblx("粮油价格监测周报表");
		List<Map> listlsj = dao.queryPriceTrend(lsj);
		Map<String, Object> lsjMap=new HashMap<String, Object>();
/*		if(listlsj.size()==0) {
			lsjMap.put("bqjg", "0");
			lsjMap.put("startTime", sysdata);
			lsjMap.put("pzdw", "");
			listlsj.add(lsjMap);
		}*/
		ReportRecordVO pfj=new ReportRecordVO();
		pfj.setEndTime(VO.getEndTime());
		pfj.setStartTime(VO.getStartTime());
		pfj.setSbdq(VO.getSbdq());
		pfj.setPzmc(VO.getPzmc());
		pfj.setJglx("批发价");
		pfj.setPzlb("2");//成品粮
		pfj.setBblx("粮油价格监测周报表");
		List<Map> listpfj = dao.queryPriceTrend(pfj);
		Map<String, Object> pfjMap=new HashMap<String, Object>();
		if(listpfj.size()==0) {
			pfjMap.put("bqjg", "0");
			pfjMap.put("startTime", sysdata);
			pfjMap.put("pzdw", "");
			listpfj.add(pfjMap);
		}
		ReportRecordVO ccj=new ReportRecordVO();
		ccj.setEndTime(VO.getEndTime());
		ccj.setStartTime(VO.getStartTime());
		ccj.setSbdq(VO.getSbdq());
		ccj.setPzmc(VO.getPzmc());
		ccj.setJglx("出厂价");
		ccj.setPzlb("2");//成品粮
		ccj.setBblx("粮油价格监测周报表");
		List<Map> listccj = dao.queryPriceTrend(ccj);
		Map<String, Object> ccjMap=new HashMap<String, Object>();
	/*	if(listccj.size()==0) {
			ccjMap.put("bqjg", "0");
			ccjMap.put("startTime", sysdata);
			ccjMap.put("pzdw", "");
			listccj.add(ccjMap);
		}*/
		Map<String, Object> resultMap = new HashMap<String, Object>();
		resultMap.put("lsj", listlsj);
		resultMap.put("pfj", listpfj);
		resultMap.put("ccj", listccj);
		return resultMap;
	}

	/**
	 * @Description: 查询价格走势--食用油及油料
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public Map<String, Object> queryPriceSYYT(ReportRecordVO VO) throws Exception {
		Date date = new Date();
		SimpleDateFormat dateFormat= new SimpleDateFormat("yyyy-MM-dd");
		String sysdata=dateFormat.format(date);
		ReportRecordVO ckj=new ReportRecordVO();
		ckj.setEndTime(VO.getEndTime());
		ckj.setStartTime(VO.getStartTime());
		ckj.setSbdq(VO.getSbdq());
		ckj.setPzmc(VO.getPzmc());
		ckj.setJglx("出库价");
		ckj.setPzlb("3");//食用油及油料
		ckj.setBblx("粮油价格监测周报表");
		List<Map> listckj = dao.queryPriceTrend(ckj);
		Map<String, Object> ckjMap=new HashMap<String, Object>();
	/*	if(listckj.size()==0) {
			ckjMap.put("bqjg", "0");
			ckjMap.put("startTime", sysdata);
			ckjMap.put("pzdw", "");
			listckj.add(ckjMap);
		}*/
		ReportRecordVO sgj=new ReportRecordVO();
		sgj.setEndTime(VO.getEndTime());
		sgj.setStartTime(VO.getStartTime());
		sgj.setSbdq(VO.getSbdq());
		sgj.setPzmc(VO.getPzmc());
		sgj.setJglx("收购价");
		sgj.setPzlb("3");//食用油及油料
		sgj.setBblx("粮油价格监测周报表");
		List<Map> listsgj = dao.queryPriceTrend(sgj);
		Map<String, Object> sgjMap=new HashMap<String, Object>();
	/*	if(listsgj.size()==0) {
			sgjMap.put("bqjg", "0");
			sgjMap.put("startTime", sysdata);
			sgjMap.put("pzdw", "");
			listsgj.add(sgjMap);
		}*/
		Map<String, Object> resultMap = new HashMap<String, Object>();
		resultMap.put("ckj", listckj);
		resultMap.put("sgj", listsgj);
		return resultMap;
	}


	/**
	 * create by: yangshengjie
	 * create time: 2019/11/25 16:52
	 *
	 * @return Map
	 * @Param: VO
 */
	public Map<String, Object> queryPriceSYYF(ReportRecordVO VO) throws Exception {
		Date date = new Date();
		SimpleDateFormat dateFormat= new SimpleDateFormat("yyyy-MM-dd");
		String sysdata=dateFormat.format(date);
		ReportRecordVO ckj=new ReportRecordVO();
		ckj.setEndTime(VO.getEndTime());
		ckj.setStartTime(VO.getStartTime());
		ckj.setSbdq(VO.getSbdq());
		ckj.setPzmc(VO.getPzmc());
		ckj.setJglx("出库价");
		ckj.setPzlb("4");//食用油及油料
		ckj.setBblx("粮油价格监测周报表");
		List<Map> listckj = dao.queryPriceTrend(ckj);
		Map<String, Object> ckjMap=new HashMap<String, Object>();
	/*	if(listckj.size()==0) {
			ckjMap.put("bqjg", "0");
			ckjMap.put("startTime", sysdata);
			ckjMap.put("pzdw", "");
			listckj.add(ckjMap);
		}*/
		ReportRecordVO sgj=new ReportRecordVO();
		sgj.setEndTime(VO.getEndTime());
		sgj.setStartTime(VO.getStartTime());
		sgj.setSbdq(VO.getSbdq());
		sgj.setPzmc(VO.getPzmc());
		sgj.setJglx("收购价");
		sgj.setPzlb("4");//食用油及油料
		sgj.setBblx("粮油价格监测周报表");
		List<Map> listsgj = dao.queryPriceTrend(sgj);
		Map<String, Object> sgjMap=new HashMap<String, Object>();
	/*	if(listsgj.size()==0) {
			sgjMap.put("bqjg", "0");
			sgjMap.put("startTime", sysdata);
			sgjMap.put("pzdw", "");
			listsgj.add(sgjMap);
		}*/
		Map<String, Object> resultMap = new HashMap<String, Object>();
		resultMap.put("ckj", listckj);
		resultMap.put("sgj", listsgj);
		return resultMap;
	}

	/**
	 * @Description: 查询价格走势--监测点原粮
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public Map<String, Object> queryPricePointYL(ReportRecordVO VO) throws Exception {
		Date date = new Date();
		SimpleDateFormat dateFormat= new SimpleDateFormat("yyyy-MM-dd");
		String sysdata=dateFormat.format(date);
		ReportRecordVO ckj=new ReportRecordVO();
		ckj.setEndTime(VO.getEndTime());
		ckj.setStartTime(VO.getStartTime());
		ckj.setSbdq(VO.getSbdq());
		ckj.setPzmc(VO.getPzmc());
		ckj.setJglx("出库价");
		ckj.setPzlb("1");
		ckj.setBblx("粮油价格监测周报表");
		List<Map> listckj = dao.queryPriceTrendPoint(ckj);
		Map<String, Object> ckjMap=new HashMap<String, Object>();
	/*	if(listckj.size()==0) {
			ckjMap.put("bqjg", "0");
			ckjMap.put("startTime", sysdata);
			ckjMap.put("pzdw", "");
			listckj.add(ckjMap);
		}*/
		ReportRecordVO sgj=new ReportRecordVO();
		sgj.setEndTime(VO.getEndTime());
		sgj.setStartTime(VO.getStartTime());
		sgj.setSbdq(VO.getSbdq());
		sgj.setPzmc(VO.getPzmc());
		sgj.setJglx("收购价");
		sgj.setPzlb("1");
		List<Map> listsgj = dao.queryPriceTrendPoint(sgj);
		Map<String, Object> sgjMap=new HashMap<String, Object>();
	/*	if(listsgj.size()==0) {
			sgjMap.put("bqjg", "0");
			sgjMap.put("startTime", sysdata);
			sgjMap.put("pzdw", "");
			listsgj.add(sgjMap);
		}*/
		Map<String, Object> resultMap = new HashMap<String, Object>();
		resultMap.put("ckj", listckj);
		resultMap.put("sgj", listsgj);
		return resultMap;
	}

	/**
	 * @Description: 查询价格走势--监测点成品粮
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public Map<String, Object> queryPricePointCPL(ReportRecordVO VO) throws Exception {
		Date date = new Date();
		SimpleDateFormat dateFormat= new SimpleDateFormat("yyyy-MM-dd");
		String sysdata=dateFormat.format(date);
		ReportRecordVO lsj=new ReportRecordVO();
		lsj.setEndTime(VO.getEndTime());
		lsj.setStartTime(VO.getStartTime());
		lsj.setSbdq(VO.getSbdq());
		lsj.setPzmc(VO.getPzmc());
		lsj.setJlbz(VO.getJlbz());
		lsj.setJglx("零售价");
		lsj.setPzlb("2");
		lsj.setBblx("粮油价格监测周报表");
		List<Map> listlsj = dao.queryPriceTrendPoint(lsj);
		Map<String, Object> lsjMap=new HashMap<String, Object>();
	/*	if(listlsj.size()==0) {
			lsjMap.put("bqjg", "0");
			lsjMap.put("startTime", sysdata);
			lsjMap.put("pzdw", "");
			listlsj.add(lsjMap);
		}*/
		ReportRecordVO pfj=new ReportRecordVO();
		pfj.setEndTime(VO.getEndTime());
		pfj.setStartTime(VO.getStartTime());
		pfj.setSbdq(VO.getSbdq());
		pfj.setPzmc(VO.getPzmc());
		lsj.setJlbz(VO.getJlbz());
		pfj.setJglx("批发价");
		pfj.setPzlb("2");
		pfj.setBblx("粮油价格监测周报表");
		List<Map> listpfj = dao.queryPriceTrendPoint(pfj);
		Map<String, Object> pfjMap=new HashMap<String, Object>();
	/*	if(listpfj.size()==0) {
			pfjMap.put("bqjg", "0");
			pfjMap.put("startTime", sysdata);
			pfjMap.put("pzdw", "");
			listpfj.add(pfjMap);
		}*/
		ReportRecordVO ccj=new ReportRecordVO();
		ccj.setEndTime(VO.getEndTime());
		ccj.setStartTime(VO.getStartTime());
		ccj.setSbdq(VO.getSbdq());
		ccj.setPzmc(VO.getPzmc());
		ccj.setJglx("出厂价");
		ccj.setPzlb("2");
		ccj.setBblx("粮油价格监测周报表");
		List<Map> listccj = dao.queryPriceTrendPoint(ccj);
		Map<String, Object> ccjMap=new HashMap<String, Object>();
		/*if(listccj.size()==0) {
			ccjMap.put("bqjg", "0");
			ccjMap.put("startTime", sysdata);
			ccjMap.put("pzdw", "");
			listccj.add(ccjMap);
		}*/
		Map<String, Object> resultMap = new HashMap<String, Object>();
		resultMap.put("lsj", listlsj);
		resultMap.put("pfj", listpfj);
		resultMap.put("ccj", listccj);
		return resultMap;
	}
	
	/**
	 * @Description: 查询价格走势--监测点食用油及油料
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public Map<String, Object> queryPricePointSYYT(ReportRecordVO VO) throws Exception {
		Date date = new Date();
		SimpleDateFormat dateFormat= new SimpleDateFormat("yyyy-MM-dd");
		String sysdata=dateFormat.format(date);
		ReportRecordVO ckj=new ReportRecordVO();
		ckj.setEndTime(VO.getEndTime());
		ckj.setStartTime(VO.getStartTime());
		ckj.setSbdq(VO.getSbdq());
		ckj.setPzmc(VO.getPzmc());
		ckj.setJglx("出库价");
		ckj.setPzlb("3");
		ckj.setBblx("粮油价格监测周报表");
		List<Map> listckj = dao.queryPriceTrendPoint(ckj);
		Map<String, Object> ckjMap=new HashMap<String, Object>();
/*		if(listckj.size()==0) {
			ckjMap.put("bqjg", "0");
			ckjMap.put("startTime", sysdata);
			ckjMap.put("pzdw", "");
			listckj.add(ckjMap);
		}*/
		ReportRecordVO sgj=new ReportRecordVO();
		sgj.setEndTime(VO.getEndTime());
		sgj.setStartTime(VO.getStartTime());
		sgj.setSbdq(VO.getSbdq());
		sgj.setPzmc(VO.getPzmc());
		sgj.setJglx("收购价");
		sgj.setPzlb("3");
		sgj.setBblx("粮油价格监测周报表");
		List<Map> listsgj = dao.queryPriceTrendPoint(sgj);
		Map<String, Object> sgjMap=new HashMap<String, Object>();
	/*	if(listsgj.size()==0) {
			sgjMap.put("bqjg", "0");
			sgjMap.put("startTime", sysdata);
			sgjMap.put("pzdw", "");
			listsgj.add(sgjMap);
		}*/
		Map<String, Object> resultMap = new HashMap<String, Object>();
		resultMap.put("ckj", listckj);
		resultMap.put("sgj", listsgj);
		return resultMap;
	}

	public Map<String, Object> queryPricePointSYYF(ReportRecordVO VO) throws Exception {
		Date date = new Date();
		SimpleDateFormat dateFormat= new SimpleDateFormat("yyyy-MM-dd");
		String sysdata=dateFormat.format(date);
		ReportRecordVO ckj=new ReportRecordVO();
		ckj.setEndTime(VO.getEndTime());
		ckj.setStartTime(VO.getStartTime());
		ckj.setSbdq(VO.getSbdq());
		ckj.setPzmc(VO.getPzmc());
		ckj.setJglx("出库价");
		ckj.setPzlb("4");
		ckj.setBblx("粮油价格监测周报表");
		List<Map> listckj = dao.queryPriceTrendPoint(ckj);
		Map<String, Object> ckjMap=new HashMap<String, Object>();
		/*if(listckj.size()==0) {
			ckjMap.put("bqjg", "0");
			ckjMap.put("startTime", sysdata);
			ckjMap.put("pzdw", "");
			listckj.add(ckjMap);
		}*/
		ReportRecordVO sgj=new ReportRecordVO();
		sgj.setEndTime(VO.getEndTime());
		sgj.setStartTime(VO.getStartTime());
		sgj.setSbdq(VO.getSbdq());
		sgj.setPzmc(VO.getPzmc());
		sgj.setJglx("收购价");
		sgj.setPzlb("4");
		sgj.setBblx("粮油价格监测周报表");
		List<Map> listsgj = dao.queryPriceTrendPoint(sgj);
		Map<String, Object> sgjMap=new HashMap<String, Object>();
	/*	if(listsgj.size()==0) {
			sgjMap.put("bqjg", "0");
			sgjMap.put("startTime", sysdata);
			sgjMap.put("pzdw", "");
			listsgj.add(sgjMap);
		}*/
		Map<String, Object> resultMap = new HashMap<String, Object>();
		resultMap.put("ckj", listckj);
		resultMap.put("sgj", listsgj);
		return resultMap;
	}
	
	
	/**
	 * @Description: 查询价格走势--原粮--指定价格
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public Map<String, Object> queryPriceYLZD(ReportRecordVO VO) throws Exception {
		Date date = new Date();
		SimpleDateFormat dateFormat= new SimpleDateFormat("yyyy-MM-dd");
		String sysdata=dateFormat.format(date);
		ReportRecordVO ckj=new ReportRecordVO();
		ckj.setEndTime(VO.getEndTime());
		ckj.setStartTime(VO.getStartTime());
		ckj.setSbdq(VO.getSbdq());
		ckj.setPzmc(VO.getPzmc());
		ckj.setJglx("出库价");
		ckj.setPzlb("1");
		ckj.setBblx("原粮报表");
		List<Map> listckj = dao.queryPriceTrendZD(ckj);
		Map<String, Object> ckjMap=new HashMap<String, Object>();
		/*if(listckj.size()==0) {
			ckjMap.put("bqjg", "0");
			ckjMap.put("startTime", sysdata);
			ckjMap.put("pzdw", "");
			listckj.add(ckjMap);
		}*/
		ReportRecordVO sgj=new ReportRecordVO();
		sgj.setEndTime(VO.getEndTime());
		sgj.setStartTime(VO.getStartTime());
		sgj.setSbdq(VO.getSbdq());
		sgj.setPzmc(VO.getPzmc());
		sgj.setJglx("收购价");
		sgj.setPzlb("1");
		sgj.setBblx("原粮报表");
		List<Map> listsgj = dao.queryPriceTrendZD(sgj);
		Map<String, Object> sgjMap=new HashMap<String, Object>();
/*		if(listsgj.size()==0) {
			sgjMap.put("bqjg", "0");
			sgjMap.put("startTime", sysdata);
			sgjMap.put("pzdw", "");
			listsgj.add(sgjMap);
		}*/
		Map<String, Object> resultMap = new HashMap<String, Object>();
		resultMap.put("ckj", listckj);
		resultMap.put("sgj", listsgj);
		return resultMap;
	}

	/**
	 * @Description: 查询价格走势--成品粮--指定价格
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public Map<String, Object> queryPriceCPLZD(ReportRecordVO VO) throws Exception {
		Date date = new Date();
		SimpleDateFormat dateFormat= new SimpleDateFormat("yyyy-MM-dd");
		String sysdata=dateFormat.format(date);
		ReportRecordVO lsj=new ReportRecordVO();
		lsj.setEndTime(VO.getEndTime());
		lsj.setStartTime(VO.getStartTime());
		lsj.setSbdq(VO.getSbdq());
		lsj.setPzmc(VO.getPzmc());
		lsj.setJglx("零售价");
		lsj.setPzlb("2");
		lsj.setBblx("成品粮报表");
		List<Map> listlsj = dao.queryPriceTrendZD(lsj);
		Map<String, Object> lsjMap=new HashMap<String, Object>();
	/*	if(listlsj.size()==0) {
			lsjMap.put("bqjg", "0");
			lsjMap.put("startTime", sysdata);
			lsjMap.put("pzdw", "");
			listlsj.add(lsjMap);
		}*/
		ReportRecordVO pfj=new ReportRecordVO();
		pfj.setEndTime(VO.getEndTime());
		pfj.setStartTime(VO.getStartTime());
		pfj.setSbdq(VO.getSbdq());
		pfj.setPzmc(VO.getPzmc());
		pfj.setJglx("批发价");
		pfj.setPzlb("2");
		pfj.setBblx("成品粮报表");
		List<Map> listpfj = dao.queryPriceTrendZD(pfj);
		Map<String, Object> pfjMap=new HashMap<String, Object>();
		/*if(listpfj.size()==0) {
			pfjMap.put("bqjg", "0");
			pfjMap.put("startTime", sysdata);
			pfjMap.put("pzdw", "");
			listpfj.add(pfjMap);
		}*/
		ReportRecordVO ccj=new ReportRecordVO();
		ccj.setEndTime(VO.getEndTime());
		ccj.setStartTime(VO.getStartTime());
		ccj.setSbdq(VO.getSbdq());
		ccj.setPzmc(VO.getPzmc());
		ccj.setJglx("出厂价");
		ccj.setPzlb("2");
		ccj.setBblx("成品粮报表");
		List<Map> listccj = dao.queryPriceTrendZD(ccj);
		Map<String, Object> ccjMap=new HashMap<String, Object>();
	/*	if(listccj.size()==0) {
			ccjMap.put("bqjg", "0");
			ccjMap.put("startTime", sysdata);
			ccjMap.put("pzdw", "");
			listccj.add(ccjMap);
		}*/
		Map<String, Object> resultMap = new HashMap<String, Object>();
		resultMap.put("lsj", listlsj);
		resultMap.put("pfj", listpfj);
		resultMap.put("ccj", listccj);
		return resultMap;
	}

	/**
	 * @Description: 工作台价格走势(每月均价)
	 * @date 2019/12/12 10:58
	 * @author yangshengjie
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public List<List> workbenchQueryPriceY(ReportRecordVO VO) throws Exception {
		List<List> resultList = new ArrayList<>();

		String yearS = new String();
		//设置默认为今年
		if(VO.getSelectYearS() == null || "".equals(VO.getSelectYearS())){
			Calendar calendar = Calendar.getInstance();
			SimpleDateFormat sdf = new SimpleDateFormat("yyyy");
			String def = sdf.format(calendar.getTime());
			VO.setSelectYearS(def);
			VO.setSelectYearE(def);
			yearS = def;
		}else if (VO.getSelectYearS().equals(VO.getSelectYearE())){
			yearS = VO.getSelectYearS();
		}else if (Integer.parseInt( VO.getSelectYearE() ) - 1 == Integer.parseInt( VO.getSelectYearS() )){
			yearS = VO.getSelectYearE()+","+VO.getSelectYearS();
		}else {
			yearS = VO.getSelectYearE();
			int temI = Integer.parseInt( VO.getSelectYearE() ) - Integer.parseInt( VO.getSelectYearS() );
			for (int k = 1;k < temI;k++){
				int temInt = Integer.parseInt( VO.getSelectYearE() ) - k;
				yearS = yearS +","+ temInt;
			}
			yearS = yearS +","+ VO.getSelectYearS();
		}
		//获取要查的年份
		StringTokenizer tokenizer = new StringTokenizer(yearS,",");
		String [] eveYear = new String[tokenizer .countTokens()];
		int i = 0;
		while(tokenizer. hasMoreTokens ())
		{
			eveYear[i++]=tokenizer.nextToken();
		}
		i = 0;

		//循环分别查出每年的数据
		String startTime = new String();
		String endTime = new String();
		String temM = new String();
		ReportRecordVO evemonth=new ReportRecordVO();
		evemonth.setPzmc(VO.getPzmc());
		evemonth.setJglx(VO.getJglx());
		evemonth.setPzlb(VO.getPzlb());
		evemonth.setBblx("粮油价格监测周报表");

		for (String temY : eveYear){
			List<Map<String, Object>> resList = new ArrayList<>();
			for (int j = 1;j <= 12;j++){
				if (j < 10){
					temM = "-0" + j;
				}else {
					temM = "-" + j;
				}
				startTime = temY + temM +"-01";
				endTime = temY + temM +"-31";
				evemonth.setStartTime(startTime);
				evemonth.setEndTime(endTime);
				Map resMap = new HashMap();

				Map temMap = dao.workbenchQueryPrice(evemonth);
				resMap.put("name",VO.getJglx());
				//resMap.put("startTime",temY+temM);
				resMap.put("startTime",j+"月");
				resMap.put("years",temY);
				if (temMap == null){
					resMap.put("bqjg","");
					resMap.put("pzdw","");
				}else {
					resMap.put("bqjg",temMap.get("bqjg"));
					resMap.put("pzdw",temMap.get("pzdw"));
				}
				resList.add(resMap);
			}
			resultList.add(resList);
		}

		return resultList;
	}

	/**
	 * @Description: 工作台价格走势(品种多选)
	 * @date 2019/12/12 17:51
	 * @author yangshengjie
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public List workbenchQueryPriceM(ReportRecordVO VO) throws Exception {
		List resList = new ArrayList();
		Map resultMap = new HashMap();
		for (int i = 0;i < VO.getPzmcsz().size();i++){
			ReportRecordVO lsj=new ReportRecordVO();
			lsj.setPzmc(VO.getPzmcsz().get(i));
			lsj.setStartTime(VO.getStartTime());
			lsj.setEndTime(VO.getEndTime());
			lsj.setJglx(VO.getJglx());
			lsj.setPzlb(VO.getPzlbsz().get(i));
			lsj.setBblx("粮油价格监测周报表");
			List<Map> listlsj = dao.queryPriceTrendPointM(lsj);

			for (Map temap : listlsj){
				temap.put("name",VO.getPzmcsz().get(i));
			}


			resList.add(listlsj);
			//resultMap.put(VO.getPzmcsz().get(i),listlsj);
		}

		return resList;
	}

}
