package com.unis.indicator.server.domain;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.ValidationUtil;
import com.unis.indicator.common.vo.PriceTypeVO;
import com.unis.indicator.server.config.SecurityUtil;
import com.unis.indicator.server.dao.BbLxJgLxDao;
import com.unis.indicator.server.dao.JgLxDao;
import com.unis.indicator.server.dao.ZbJgLxDao;
import com.unis.indicator.server.entity.indicator.BblxJglxDO;
import com.unis.indicator.server.entity.indicator.JglxDO;
import com.unis.indicator.server.entity.indicator.ZbjglxDO;
import com.unis.indicator.server.enums.PriceTypeEnum;
import lombok.Getter;
import lombok.Setter;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import tk.mybatis.mapper.entity.Example;

import java.util.*;

/**
 * @ClassName StandardDomain
 * @Description 价格类型领域对象
 * @Author xmpu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@Getter
@Setter
@Component
public class PriceTypeDomain {

	@Autowired
	private JgLxDao dao;

	@Autowired
	private ZbJgLxDao indicatorPriceDao;

	@Autowired
	private BbLxJgLxDao bbLxJgLxDao;

	/**
	 *
	 * @Description: 通过priceTypeId查询指标与价格类型/报表与价格类型关联信息
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param priceTypeId
	 * @return boolean
	 */
	public boolean findPriceTypeIndRel(String priceTypeId) throws Exception {
		Example example = new Example(ZbjglxDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andEqualTo("priceId", priceTypeId);
		List res = indicatorPriceDao.selectByExample(example);
		if (res != null
				&& res.size() > 0) {
			return true;
		}
		Example example1 = new Example(BblxJglxDO.class);
		Example.Criteria criteria1 = example1.createCriteria();
		criteria1.andEqualTo("priceTypeId", priceTypeId);
		List res1 = bbLxJgLxDao.selectByExample(example1);
		if (res1 != null
				&& res1.size() > 0) {
			return true;
		}
		return false;
	}

	/**
	 *
	 * @Description: 通过id查询价格类型信息
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param id
	 * @return JglxDO
	 */
	public JglxDO findPriceTypeById(String id) throws Exception {
		Example example = new Example(JglxDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("id", id);
		JglxDO resDO = dao.selectOneByExample(example);
		if (ObjectUtils.equals(resDO, null)) {
			return null;
		}
		return resDO;
	}

	/**
	 *
	 * @Description: 查询所有价格类型信息 模糊查询的条件可以包含：名称
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public Map<String, Object> findPriceTypesByPage(PriceTypeVO VO, Integer page, Integer size) throws Exception {

		Example example = new Example(JglxDO.class);
		Example.Criteria criteria = example.createCriteria();
		String	priceTypeName= SecurityUtil.filterStrSqlJs(VO.getPriceTypeName());

		// 添加按名称查询
		if (!"".equals(priceTypeName) && null != priceTypeName) {
			criteria.andLike("priceTypeName", "%" + priceTypeName + "%");
		}
		// 未删除
		criteria.andIsNull("deleteTime");
		PageHelper.startPage(page, size, "CREATE_TIME DESC");
		List<JglxDO> resultDOList = dao.selectByExample(example);
		PageInfo<JglxDO> pageInfo = new PageInfo<JglxDO>(resultDOList);

		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<PriceTypeVO> resultVOList = new ArrayList<>();
		if (!resultDOList.isEmpty()) {
			for (JglxDO resultDO : resultDOList) {
				PriceTypeVO resultVO = LsBeanUtils.copyProperties(resultDO, PriceTypeVO.class);
				resultVOList.add(resultVO);
			}
		}
		resultMap.put("total", pageInfo.getTotal());
		resultMap.put("resultList", resultVOList);
		return resultMap;
	}

	/**
	 *
	 * @Description: 价格类型多选删除
	 * @date 2019年7月24日,下午8:58:47
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param ids
	 * @param userId
	 * @return Boolean
	 * @throws Exception
	 */
	public boolean deletePriceTypes(String[] ids, String userId) throws Exception {
		for (String id : ids) {
			Example example = new Example(JglxDO.class);
			Example.Criteria criteria = example.createCriteria();
			criteria.andEqualTo("id", id);
			JglxDO udpDO = dao.selectOneByExample(example);
			if (ObjectUtils.notEqual(udpDO, null)) {
				dao.delete(udpDO);
			}
		}
		return true;
	}

	/**
	 *
	 * @Description: 保存价格类型信息
	 * @date 2019年7月24日,下午8:58:56
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean savePriceType(PriceTypeVO VO) throws Exception {

		ValidationUtil.validate(VO);

		Example example = new Example(JglxDO.class);
		Example.Criteria criteria = example.createCriteria();
		if (!"".equals(VO.getPriceTypeName()) && null != VO.getPriceTypeName()) {
			criteria.andEqualTo("priceTypeName", VO.getPriceTypeName());
		}
		criteria.andIsNull("deleteTime");
		if (dao.selectCountByExample(example) > 0) {
			throw new RuntimeException(VO.getPriceTypeName() + "已存在");
		}
		if (!"".equals(VO.getCode()) && null != VO.getCode()) {
			criteria.orEqualTo("code", VO.getCode());
		}
		if (dao.selectCountByExample(example) > 0) {
			throw new RuntimeException(VO.getCode() + "已存在");
		}
		JglxDO insDO = new JglxDO();
		LsBeanUtils.copyPropertiesIgnoreNull(VO, insDO);
		insDO.setCreateBy(VO.getOperator());
		insDO.setCreateTime(new Date());

		if (dao.insertSelective(insDO) < 1) {
			throw new RuntimeException(insDO.getPriceTypeName() + "无法保存成功，请检查数据。");
		}
		return true;
	}

	/**
	 *
	 * @Description: 更新价格类型
	 * @date 2019年7月24日,下午8:59:05
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean updatePriceType(PriceTypeVO VO) throws Exception {
		ValidationUtil.validate(VO);
		JglxDO udpDO = findPriceTypeById(VO.getId());
		if (ObjectUtils.equals(udpDO, null)) {
			return false;
		}
		LsBeanUtils.copyPropertiesIgnoreNull(VO, udpDO);

		udpDO.setUpdateBy(VO.getOperator());
		udpDO.setUpdateTime(DateUtil.getNowDate());
		if (dao.updateByPrimaryKey(udpDO) < 1) {
			return false;
		}
		return true;
	}

	/**
	 *
	 * @Description: 查询权重的价格类型
	 * @date 2019年7月24日,下午8:59:05
	 * @author xmpu
	 * @version v1.0
	 *
	 * @return List<JglxDO>
	 * @throws Exception
	 */
	public List<PriceTypeVO> findPriceWeightTypes() throws Exception {

		Example example = new Example(JglxDO.class);
		Example.Criteria criteria = example.createCriteria();

		criteria.orLike("priceTypeName", "%" + PriceTypeEnum.RETAIL.getMessage() + "%");
		criteria.orLike("priceTypeName", "%" + PriceTypeEnum.WHOLESALE.getMessage() + "%");
		List<JglxDO> resultDOList = dao.selectByExample(example);
		List<PriceTypeVO> resultVOList = new ArrayList<>();
		if (!resultDOList.isEmpty()) {
			for (JglxDO resultDO : resultDOList) {
				PriceTypeVO resultVO = LsBeanUtils.copyProperties(resultDO, PriceTypeVO.class);
				resultVOList.add(resultVO);
			}
		}
		return resultVOList;
	}
}
