package com.unis.indicator.server.domain;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.LsBeanUtils;
import com.unis.indicator.common.vo.bbzb.ReportConfigVO;
import com.unis.indicator.common.vo.bbzb.ReportIndicatorVO;
import com.unis.indicator.server.dao.BbpzDao;
import com.unis.indicator.server.dao.BbzbDao;
import com.unis.indicator.server.dao.LyjgDao;
import com.unis.indicator.server.entity.indicator.BbpzDO;
import com.unis.indicator.server.entity.indicator.BbzbDO;
import lombok.Getter;
import lombok.Setter;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import tk.mybatis.mapper.entity.Example;

import java.util.*;

/**
 * @ClassName ReportIndicatorDomain
 * @Description 报表指标领域对象
 * @Author xmpu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@Getter
@Setter
@Component
public class ReportIndicatorDomain {

	@Autowired
	private BbzbDao dao;

    @Autowired
    private BbpzDao zkbbpzDao;
    
    @Autowired
    private LyjgDao lyjgDao;


	/**
	 *
	 * @Description: 通过id查询报表指标信息
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param id
	 * @return BbzbDO
	 */
	public BbzbDO findZkbbzbById(String id) throws Exception {
		Example example = new Example(BbzbDO.class);
		Example.Criteria criteria = example.createCriteria();
//		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("id", id);
		BbzbDO resDO = dao.selectOneByExample(example);
		if (ObjectUtils.equals(resDO, null)) {
			return null;
		}
		return resDO;
	}

	/**
	 *
	 * @Description: 通过报表类型id查询报表指标信息
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param reportTypeId
	 * @return List<BbzbDO>
	 */
	public List<BbzbDO> findZkbbzbByReportTypeId(String reportTypeId) throws Exception {
		Example example = new Example(BbzbDO.class);
		Example.Criteria criteria = example.createCriteria();
//		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("reportTypeId", reportTypeId);
		List<BbzbDO> resDO = dao.selectByExample(example);
		if (ObjectUtils.equals(resDO, null)) {
			return null;
		}
		return resDO;
	}

	/**
	 *
	 * @Description: 查询所有报表指标信息 模糊查询的条件可以包含：名称
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public Map<String, Object> findZkbbzsByPage(ReportIndicatorVO VO, Integer page, Integer size) throws Exception {

		Example example = new Example(BbzbDO.class);
		Example.Criteria criteria = example.createCriteria();

		// 添加按粮食类型查询
		if (!"".equals(VO.getReportTypeName()) && null != VO.getReportTypeName()) {
			criteria.andLike("reportTypeName", "%" + VO.getReportTypeName() + "%");
		}
		// 添加按指标名称查询
		if (!"".equals(VO.getIndicatorName()) && null != VO.getIndicatorName()) {
			criteria.andLike("indicatorName", "%" + VO.getIndicatorName() + "%");
		}
		// 未删除
//		criteria.andIsNull("deleteTime");
		PageHelper.startPage(page, size, "BBLXMC DESC");
		List<BbzbDO> resultDOList = dao.selectByExample(example);
		PageInfo<BbzbDO> pageInfo = new PageInfo<BbzbDO>(resultDOList);

		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<ReportIndicatorVO> resultVOList = new ArrayList<>();
		if (!resultDOList.isEmpty()) {
			for (BbzbDO resultDO : resultDOList) {
				ReportIndicatorVO resultVO = LsBeanUtils.copyProperties(resultDO, ReportIndicatorVO.class);
				resultVOList.add(resultVO);
			}
		}
		resultMap.put("total", pageInfo.getTotal());
		resultMap.put("resultList", resultVOList);
		return resultMap;
	}

	/**
	 *
	 * @Description: 报表指标多选删除
	 * @date 2019年7月24日,下午8:58:47
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param ids
	 * @param userId
	 * @return Boolean
	 * @throws Exception
	 */
	public boolean deleteZkbbzbs(String[] ids, String userId) throws Exception {
		for (String id : ids) {
			Example example = new Example(BbzbDO.class);
			Example.Criteria criteria = example.createCriteria();
			criteria.andEqualTo("id", id);
//			criteria.andIsNull("deleteTime");
			BbzbDO udpDO = dao.selectOneByExample(example);
			if (ObjectUtils.notEqual(udpDO, null)) {
				dao.delete(udpDO);
			}
		}
		return true;
	}

	/**
	 *
	 * @Description: 保存报表指标信息
	 * @date 2019年7月24日,下午8:58:56
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean saveZkbbzb(ReportIndicatorVO VO) throws Exception {

		Example example = new Example(BbzbDO.class);
		Example.Criteria criteria = example.createCriteria();
		if (!"".equals(VO.getIndicatorId()) && null != VO.getIndicatorId()) {
			criteria.andEqualTo("indicatorId", VO.getIndicatorId());
		}
		if (!"".equals(VO.getReportTypeId()) && null != VO.getReportTypeId()) {
			criteria.andEqualTo("reportTypeId", VO.getReportTypeId());
		}
//		criteria.andIsNull("deleteTime");
		if (dao.selectCountByExample(example) > 0) {
			throw new RuntimeException(VO.getIndicatorName()+ "和" + VO.getReportTypeName() + "已存在");
		}
		BbzbDO insDO = new BbzbDO();
		LsBeanUtils.copyPropertiesIgnoreNull(VO, insDO);
		insDO.setCreateTime(new Date());

		if (dao.insertSelective(insDO) < 1) {
			throw new RuntimeException("无法保存成功，请检查数据。");
		}
		return true;
	}

	/**
	 *
	 * @Description: 更新报表指标
	 * @date 2019年7月24日,下午8:59:05
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean updateZkbbzb(ReportIndicatorVO VO) throws Exception {

		BbzbDO udpDO = findZkbbzbById(VO.getId());
		if (ObjectUtils.equals(udpDO, null)) {
            throw new RuntimeException("未存储过，更新失败。");
		}
		
		String indicatorStandardCurrent = udpDO.getZbbzMc();
		String indicatorStandardModify = VO.getZbbzMc();
		LsBeanUtils.copyPropertiesIgnoreNull(VO, udpDO);

		if (dao.updateByPrimaryKey(udpDO) < 1) {
            throw new RuntimeException("无法保存成功，请检查数据。");
		} else {
			//如果有修改指标标准则调整现有填报记录中的信息
			if(StringUtils.isNotEmpty(indicatorStandardModify) && StringUtils.isNotEmpty(indicatorStandardCurrent) && !indicatorStandardCurrent.equals(indicatorStandardModify)) {
				String code = VO.getIndicatorVO().getIndCode();
				String formType = VO.getReportTypeId();
				lyjgDao.modifyReportVarietiesThebenchmarkName(code, indicatorStandardModify, formType);
			}
		}
		
		return true;
	}

    public boolean saveOrUpdateZkbbpz(ReportConfigVO VO) throws Exception {

        Example example = new Example(BbpzDO.class);
        Example.Criteria criteria = example.createCriteria();
		criteria.andEqualTo("reportTypeCode", VO.getReportTypeCode());
		criteria.andEqualTo("reportIndicator", VO.getReportIndicator());
		criteria.andEqualTo("reportIndicatorPrice", VO.getReportIndicatorPrice());
//		criteria.andEqualTo("monitorId", VO.getMonitorId());
		criteria.andEqualTo("countyCode", VO.getCountyCode());
        BbpzDO udpDO = zkbbpzDao.selectOneByExample(example);
        if (udpDO != null) {
            LsBeanUtils.copyPropertiesIgnoreNull(VO, udpDO);
            if (zkbbpzDao.updateByPrimaryKey(udpDO) < 1) {
                throw new RuntimeException(udpDO.getIndicatorName() + "无法保存成功，请检查数据。");
            }
            return true;
        }
        BbpzDO insDO = new BbpzDO();
        LsBeanUtils.copyPropertiesIgnoreNull(VO, insDO);

        if (zkbbpzDao.insertSelective(insDO) < 1) {
            throw new RuntimeException(insDO.getIndicatorName() + "无法保存成功，请检查数据。");
        }
        return true;
    }

	/**
	 *
	 * @Description: 查询报表指标配置
	 * @date 2019年7月24日,下午8:59:05
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @return boolean
	 * @throws Exception
	 */
	public ReportConfigVO findZkbbpz(ReportConfigVO VO) throws Exception {

		Example example = new Example(BbpzDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andEqualTo("reportTypeCode", VO.getReportTypeCode());
		criteria.andEqualTo("reportIndicator", VO.getReportIndicator());
		criteria.andEqualTo("reportIndicatorPrice", VO.getReportIndicatorPrice());
		criteria.andEqualTo("monitorId", VO.getMonitorId());
		BbpzDO udpDO = zkbbpzDao.selectOneByExample(example);

		ReportConfigVO res = new ReportConfigVO();
		LsBeanUtils.copyPropertiesIgnoreNull(udpDO, res);
		return res;
	}
}
