package com.unis.indicator.server.domain;

import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.google.common.collect.Sets;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.UUIDUtils;
import com.unis.indicator.common.vo.*;
import com.unis.indicator.common.vo.bbzb.ReportTypeVO;
import com.unis.indicator.server.dao.*;
import com.unis.indicator.server.entity.indicator.BbzbDO;
import com.unis.indicator.server.entity.indicator.JglxDO;
import com.unis.indicator.server.entity.indicator.YjgzDO;
import com.unis.indicator.server.entity.indicator.YjgzmxDO;
import com.unis.indicator.server.entity.indicator.ZbDO;
import com.unis.indicator.server.entity.report.*;
import lombok.Getter;
import lombok.Setter;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.util.ObjectUtils;
import org.springframework.util.StringUtils;

import tk.mybatis.mapper.entity.Example;
import tk.mybatis.mapper.entity.Example.Criteria;

import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

@Getter
@Setter
@Component
public class ReportRecordDomain {

    @Autowired
    private TbjlDao tbjlDao;

    @Autowired
    private LyjgDao lyjgDao;

    @Autowired
    private LyjgmxDao lyjgmxDao;

    @Autowired
    private QgjgzsDao qgjgzsDao;

    @Autowired
    private BbLxDao bbLxDao;

    @Autowired
    private YjgzDao yjgzDao;
    @Autowired
    private YjgzMxDao yjgzMxDao;
    @Autowired
    private QzzDao qzzDao;
    @Autowired
    private QzjcxxDao qzjcxxDao;
    @Autowired
    private JgLxDao jgLxDao;
    
    @Autowired
    private ZbDao indicatorDao;
    
    @Autowired
    private BbzbDao reportDao;
    
    @Autowired
    private FillInRecordDao fileInReportDao;
    
    @Autowired
    private NationalPriceIndexDao nationalPriceIndexDao;
    
    @Autowired
    private GrainAndOilPricesDao grainAndOilPricesDao;
    
    @Autowired
    private GrainAndOilPricesDetailDao grainAndOilPricesDetailDao;
    
    /**
     * 查询价格走势
     *
     * @param bbvo
     */
    public Map<String, Object> findByQuery(ReportRecordVO bbvo) {
        bbvo.setReportDateType("日报");
        //时间查询
        List<String> timeList = tbjlDao.findTimeByQuery(bbvo);
        //产品名称查询
        List<String> pzlbList = tbjlDao.findPzlbByQuery(bbvo);

        List<Map<String, Object>> seriesLists = new ArrayList<>();
        List<Map<String, Object>> legends = new ArrayList<>();
        if (seriesLists != null) {
            for (String string : pzlbList) {
                bbvo.setPzlb(string);
                //产品对应时间信息查询
                List<String> resultList = tbjlDao.findSeriesByQuery(bbvo);
                Map<String, Object> map = new HashMap<>();
                map.put("name", string);
                map.put("data", resultList);
                seriesLists.add(map);
                Map<String, Object> legendMap = new HashMap<>();
                legendMap.put("name", string);
                legendMap.put("icon", "circle");
                legends.add(legendMap);
            }
        }
        Map<String, Object> map = new HashMap();
        map.put("xAxis", timeList);
        map.put("legend", legends);
        map.put("series", seriesLists);
        return map;
    }

    /**
     * @param reportRecordInfoVO
     * @Description: 内蒙粮油价格上报
     * @date
     * @author renyu
     * @version v1.0
     */
    public void saveBbInfo(ReportRecordInfoVO reportRecordInfoVO) {
        TbjlDO tbjlDO = new TbjlDO();
        LsBeanUtils.copyPropertiesIgnoreNull(reportRecordInfoVO, tbjlDO);
        tbjlDO.setCreateTime(new Date());
        tbjlDO.setId(UUIDUtils.uuid());
        tbjlDO.setUpdateNum(0);
        if (tbjlDO.getOrgId().length() == 5) {
            tbjlDO.setLcid("2");
        }
        tbjlDO.setRejectNum(0);
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        if (reportRecordInfoVO.getSbjssj() != null && reportRecordInfoVO.getSbjssj() != "") {
            try {
                tbjlDO.setSbjssj(sdf.parse(reportRecordInfoVO.getSbjssj()));
            } catch (ParseException e) {
                e.printStackTrace();
            }
        }
        if (reportRecordInfoVO.getSbkssj() != null && reportRecordInfoVO.getSbkssj() != "") {
            try {
                tbjlDO.setSbkssj(sdf.parse(reportRecordInfoVO.getSbkssj()));
            } catch (ParseException e) {
                e.printStackTrace();
            }
        }
        //保存报表信息
        tbjlDao.insert(tbjlDO);
        List<PriceInfoVO> priceInfoVOList = reportRecordInfoVO.getPriceInfoVOList();
        if (priceInfoVOList != null) {
            for (PriceInfoVO priceInfoVO : priceInfoVOList) {
                LyjgDO lyjgDO = new LyjgDO();
                LsBeanUtils.copyPropertiesIgnoreNull(priceInfoVO, lyjgDO);
                lyjgDO.setId(UUIDUtils.uuid());
                lyjgDO.setTbjlId(tbjlDO.getId());
                //保存粮油价格信息
                lyjgDao.insert(lyjgDO);
                //获取价格map 根据map长度获取价格明细
                List<PriceDedailInfoVO> priceDedailInfoVOList = priceInfoVO.getPriceDedailInfoVOList();
                if (priceDedailInfoVOList != null) {
                    for (PriceDedailInfoVO priceDedailInfoVO : priceDedailInfoVOList) {
                        LyjgmxDO lyjgmxDO = new LyjgmxDO();
                        LsBeanUtils.copyPropertiesIgnoreNull(priceDedailInfoVO, lyjgmxDO);
                        lyjgmxDO.setId(UUIDUtils.uuid());
                        lyjgmxDO.setLyjgId(lyjgDO.getId());
                        lyjgmxDao.insert(lyjgmxDO);
                    }

                }
               /* Map<String, Object> priceMap = priceInfoVO.getPriceMap();
                Map<String, Object> lastPriceMap = priceInfoVO.getLastPriceMap();
                Integer length = priceMap.size()/2;*/
                /*for(int i = 0 ; i < length; i++){
                    LyjgmxDO lyjgmxDO = new LyjgmxDO();
                    lyjgmxDO.setId(UUIDUtils.uuid());
                    lyjgmxDO.setLyjgId(lyjgDO.getId());
                     lyjgmxDO.setBqjg(Double.parseDouble((String)priceMap.get("nowPrice" + (1 + i))));
                    lyjgmxDO.setSqjg(Double.parseDouble((String)lastPriceMap.get("lastPrice" + (1 + i))));
                    lyjgmxDO.setHbzzl(Double.parseDouble(lastPriceMap.get("hbzzl" + (1 + i)).toString()));
                    lyjgmxDao.insert(lyjgmxDO);
                }*/
            }
        }

    }

    public ReportRecordInfoVO selectById(String id) {
        ReportRecordInfoVO reportRecordInfoVO = new ReportRecordInfoVO();
        //获取填报记录信息
        TbjlDO tbjlDO = tbjlDao.selectById(id);
        LsBeanUtils.copyPropertiesIgnoreNull(tbjlDO, reportRecordInfoVO);
        //获取粮油价格信息
        List<LyjgDO> lyjgInfoDOList = lyjgDao.selectInfoByFid(id);
        List<PriceInfoVO> priceInfoVOList = new ArrayList<>();
        for (LyjgDO lyjgDO : lyjgInfoDOList) {
            PriceInfoVO priceInfoVO = new PriceInfoVO();
            LsBeanUtils.copyPropertiesIgnoreNull(lyjgDO, priceInfoVO);
            //获取粮油价格明细信息
            LyjgmxDO lyjgmxDO=new LyjgmxDO();
            lyjgmxDO.setLyjgId(lyjgDO.getId());
            LyjgmxDO lyjgmx = lyjgmxDao.selectById(lyjgmxDO);
            priceInfoVO.setLyjgmxId(lyjgmx.getId());
            lyjgmx.setId(null);
            LsBeanUtils.copyPropertiesIgnoreNull(lyjgmx, priceInfoVO);
            priceInfoVOList.add(priceInfoVO);
        }
        reportRecordInfoVO.setPriceInfoVOList(priceInfoVOList);
        return reportRecordInfoVO;
    }

    /**
     * @param id
     * @return reportRecordInfoVO
     * @Description: 内蒙粮油价格详情
     * @date
     * @author renyu
     * @version v1.0
     */
    public ReportRecordInfoVO getBbInfo(String id) {
        //获取填报记录信息
        TbjlDO tbjlDO = tbjlDao.selectById(id);
        ReportRecordInfoVO reportRecordInfoVO = new ReportRecordInfoVO();
        LsBeanUtils.copyPropertiesIgnoreNull(tbjlDO, reportRecordInfoVO);
        if (tbjlDO.getSbkssj() != null) {
            reportRecordInfoVO.setSbkssj(getDay(tbjlDO.getSbkssj()));
        }
        if (tbjlDO.getSbjssj() != null) {
            reportRecordInfoVO.setSbjssj(getDay(tbjlDO.getSbjssj()));
        }
        //获取粮油价格信息
        List<LyjgDO> lyjgInfoDOList = lyjgDao.selectInfoByFid(id);
        List<PriceInfoVO> priceInfoVOList = new ArrayList<>();
        if (lyjgInfoDOList != null) {
            for (LyjgDO lyjgDO : lyjgInfoDOList) {
                PriceInfoVO priceInfoVO = new PriceInfoVO();
                LsBeanUtils.copyPropertiesIgnoreNull(lyjgDO, priceInfoVO);
                //获取粮油价格明细信息
                List<LyjgmxDO> lyjgmxDOList = lyjgmxDao.selectInfoByFid(priceInfoVO.getId());
                String indicatorId = lyjgDao.selectIndicatorIdByZbbm(lyjgDO.getZbbm());
                List<PriceDedailInfoVO> infoVo = bbLxDao.selectPriceTypeByIndicatorId(indicatorId);
                List<PriceDedailInfoVO> priceDedailInfoVOList = new ArrayList<>();
                if (lyjgmxDOList != null) {
                   /* Map<String,Object> priceMap = new HashMap<>();
                    Map<String,Object> lastPriceMap = new HashMap<>();*/
                    for (int i = 0; i < lyjgmxDOList.size(); i++) {
                        PriceDedailInfoVO priceDedailInfoVO = new PriceDedailInfoVO();
                        LsBeanUtils.copyPropertiesIgnoreNull(lyjgmxDOList.get(i), priceDedailInfoVO);
                        if (infoVo != null && infoVo.size() == lyjgmxDOList.size()) {
                            priceDedailInfoVO.setMomVal(infoVo.get(i).getMomVal());
                        }
                        priceDedailInfoVOList.add(priceDedailInfoVO);
                        if(lyjgmxDOList.get(i).getBqjg() == null || "".equals(lyjgmxDOList.get(i).getBqjg())){
                            priceDedailInfoVO.setBqjg(0.0);
                        }
                        if(lyjgmxDOList.get(i).getSqjg() == null || "".equals(lyjgmxDOList.get(i).getSqjg())){
                            priceDedailInfoVO.setSqjg(0.0);
                        }
                        //根据监测点、品种和价格类型获取预警规则的最高最低价格
                        if (reportRecordInfoVO.getOrgName() != null && priceInfoVO.getPzmc() != null && priceDedailInfoVO.getJglx() != null){
                            List<WarningRoleVO> warningRoleVOList = yjgzDao.selectListBy(priceInfoVO.getPzmc(),priceDedailInfoVO.getJglx(),priceInfoVO.getJlbz());
                            for (WarningRoleVO warningRoleVO : warningRoleVOList){
                                List<String> tempList = Arrays.asList(warningRoleVO.getJcd().split(","));
                                if (!tempList.contains(reportRecordInfoVO.getOrgName())){
                                    warningRoleVOList.remove(warningRoleVO);
                                }
                            }
                            for (WarningRoleVO warningRoleVO : warningRoleVOList){
                                List<WarningMxVO> warningMxVOList = yjgzMxDao.selectListByIdAndJglx(warningRoleVO.getId(),priceDedailInfoVO.getJglx());
                                warningRoleVO.setJgmx(warningMxVOList);
                            }
                            priceDedailInfoVO.setZdjg(warningRoleVOList.get(0).getJgmx().get(0).getZdjg());
                            priceDedailInfoVO.setZgjg(warningRoleVOList.get(0).getJgmx().get(0).getZgjg());
                        }
                        //价格类型
                       /* priceMap.put("priceType" + (i+1),lyjgmxDOList.get(i).getJglx());
                        lastPriceMap.put("priceType" + (i+1),lyjgmxDOList.get(i).getJglx());*/
                        //本期价格
                       /* if(lyjgmxDOList.get(i).getBqjg() != null){
                            priceMap.put("nowPrice" + (i+1),lyjgmxDOList.get(i).getBqjg() + "");
                        }else{
                            priceMap.put("nowPrice" + (i+1),"0.0");
                        }*/

                       /* if(lyjgmxDOList.get(i).getHbzzl() != null){
                            lastPriceMap.put("hbzzl" + (i+1),lyjgmxDOList.get(i).getHbzzl());
                        }else{
                            lastPriceMap.put("hbzzl" + (i+1),0);
                        }
                        if(infoVo != null && infoVo.size() > 0){
                            for (PriceDedailInfoVO dedailInfoVO : infoVo) {
                                if(dedailInfoVO.getJglx().equals(lyjgmxDOList.get(i).getJglx())){
                                    lastPriceMap.put("momVal"+ (i+1),dedailInfoVO.getMomVal());
                                }
                            }
                        }*/
                        //上期价格
                        /*if(lyjgmxDOList.get(i).getSqjg() != null){
                            lastPriceMap.put("lastPrice" + (i+1),lyjgmxDOList.get(i).getSqjg() + "");
                        }else{
                            lastPriceMap.put("lastPrice" + (i+1),"0.0");
                        }*/

                        //价格Id
                       /* priceMap.put("priceId" + (i+1),lyjgmxDOList.get(i).getId());
                        lastPriceMap.put("priceId" + (i+1),lyjgmxDOList.get(i).getId());*/
                    }
                   /* priceInfoVO.setPriceMap(priceMap);
                    priceInfoVO.setLastPriceMap(lastPriceMap);*/
                }
                priceInfoVO.setPriceDedailInfoVOList(priceDedailInfoVOList);
                priceInfoVOList.add(priceInfoVO);
            }
        }

        reportRecordInfoVO.setPriceInfoVOList(priceInfoVOList);
        return reportRecordInfoVO;
    }

    /**
     * @param id
     * @return reportRecordInfoVO
     * @Description: 内蒙粮油价格详情
     * @date
     * @author renyu
     * @version v1.0
     */
    public ReportRecordInfoVO getTjbbInfo(String id,String jglx) {
        //获取填报记录信息
        TbjlDO tbjlDO = new TbjlDO();
        if (tbjlDO.getBblxId() != null){
            tbjlDO = tbjlDao.selectById(id);
        }else{
            tbjlDO = tbjlDao.selectTbjlById(id,jglx);
        }
        ReportRecordInfoVO reportRecordInfoVO = new ReportRecordInfoVO();
        LsBeanUtils.copyPropertiesIgnoreNull(tbjlDO, reportRecordInfoVO);
        if (tbjlDO.getSbkssj() != null) {
            reportRecordInfoVO.setSbkssj(getDay(tbjlDO.getSbkssj()));
        }
        if (tbjlDO.getSbjssj() != null) {
            reportRecordInfoVO.setSbjssj(getDay(tbjlDO.getSbjssj()));
        }
        //获取粮油价格信息
        List<LyjgDO> lyjgInfoDOList = new ArrayList<>();
        if (tbjlDO.getBblxId() != null){
            lyjgInfoDOList = lyjgDao.selectInfoByFid(id);
        }else{
            lyjgInfoDOList = lyjgDao.selectInfoByFidAndJglx(id,jglx);
        }

        List<PriceInfoVO> priceInfoVOList = new ArrayList<>();
        String tem = new String();
        if(jglx.equals("批发价")){
            tem = "批发";
        }
        if(jglx.equals("超市价")){
            tem = "超市";
        }
        if(jglx.equals("集贸价")){
            tem = "零售";
        }
        if (lyjgInfoDOList != null) {
            for (LyjgDO lyjgDO : lyjgInfoDOList) {
                PriceInfoVO priceInfoVO = new PriceInfoVO();
                LsBeanUtils.copyPropertiesIgnoreNull(lyjgDO, priceInfoVO);
                //获取粮油价格明细信息
                List<LyjgmxDO> lyjgmxDOList = new ArrayList<>();
                if(tbjlDO.getBblxId() != null){
                    lyjgmxDOList = lyjgmxDao.selectInfoByFid(priceInfoVO.getId());
                }else{
                    lyjgmxDOList = lyjgmxDao.selectInfoByFidAndJglx(priceInfoVO.getId(),jglx);
                }
                String indicatorId = lyjgDao.selectIndicatorIdByZbbm(lyjgDO.getZbbm());
                List<PriceDedailInfoVO> infoVo = new ArrayList<>();

                if (tbjlDO.getBblxId() != null){
                    infoVo = bbLxDao.selectPriceTypeByIndicatorId(indicatorId);
                }else{
                    infoVo = bbLxDao.selectPriceTypeByIndIdAndJglx(indicatorId,tem);
                }

                List<PriceDedailInfoVO> priceDedailInfoVOList = new ArrayList<>();
                if (lyjgmxDOList != null) {
                   /* Map<String,Object> priceMap = new HashMap<>();
                    Map<String,Object> lastPriceMap = new HashMap<>();*/
                    for (int i = 0; i < lyjgmxDOList.size(); i++) {
                        PriceDedailInfoVO priceDedailInfoVO = new PriceDedailInfoVO();
                        LsBeanUtils.copyPropertiesIgnoreNull(lyjgmxDOList.get(i), priceDedailInfoVO);
                        if (infoVo != null && infoVo.size() == lyjgmxDOList.size()) {
                            priceDedailInfoVO.setMomVal(infoVo.get(i).getMomVal());
                        }
                        priceDedailInfoVOList.add(priceDedailInfoVO);
                        //价格类型
                       /* priceMap.put("priceType" + (i+1),lyjgmxDOList.get(i).getJglx());
                        lastPriceMap.put("priceType" + (i+1),lyjgmxDOList.get(i).getJglx());*/
                        //本期价格
                       /* if(lyjgmxDOList.get(i).getBqjg() != null){
                            priceMap.put("nowPrice" + (i+1),lyjgmxDOList.get(i).getBqjg() + "");
                        }else{
                            priceMap.put("nowPrice" + (i+1),"0.0");
                        }*/

                       /* if(lyjgmxDOList.get(i).getHbzzl() != null){
                            lastPriceMap.put("hbzzl" + (i+1),lyjgmxDOList.get(i).getHbzzl());
                        }else{
                            lastPriceMap.put("hbzzl" + (i+1),0);
                        }
                        if(infoVo != null && infoVo.size() > 0){
                            for (PriceDedailInfoVO dedailInfoVO : infoVo) {
                                if(dedailInfoVO.getJglx().equals(lyjgmxDOList.get(i).getJglx())){
                                    lastPriceMap.put("momVal"+ (i+1),dedailInfoVO.getMomVal());
                                }
                            }
                        }*/
                        //上期价格
                        /*if(lyjgmxDOList.get(i).getSqjg() != null){
                            lastPriceMap.put("lastPrice" + (i+1),lyjgmxDOList.get(i).getSqjg() + "");
                        }else{
                            lastPriceMap.put("lastPrice" + (i+1),"0.0");
                        }*/

                        //价格Id
                       /* priceMap.put("priceId" + (i+1),lyjgmxDOList.get(i).getId());
                        lastPriceMap.put("priceId" + (i+1),lyjgmxDOList.get(i).getId());*/
                    }
                   /* priceInfoVO.setPriceMap(priceMap);
                    priceInfoVO.setLastPriceMap(lastPriceMap);*/
                }
                priceInfoVO.setPriceDedailInfoVOList(priceDedailInfoVOList);
                priceInfoVOList.add(priceInfoVO);
            }
        }

        reportRecordInfoVO.setPriceInfoVOList(priceInfoVOList);
        return reportRecordInfoVO;
    }

    /**
     * @param reportRecordListVO
     * @return resultMap
     * @Description: 填报记录列表
     * @date
     * @author renyu
     * @version v1.0
     */
    public Map<String, Object> getByQuery(ReportRecordListVO reportRecordListVO, Integer page, Integer size) {
        Map<String, Object> resultMap = new HashMap<>();
        PageHelper.startPage(page, size);
        //获取填报信息列表
/*        if (reportRecordListVO.getAreaCode() != null && reportRecordListVO.getAreaCode()!="") {

            String Code=reportRecordListVO.getAreaCode();
        String strm = Code.substring(0,Code.length()-2);
        reportRecordListVO.setAreaCode(strm);}*/
        List<TbjlDO> tbjlDOList = tbjlDao.selectByQuery(reportRecordListVO);
        PageInfo<TbjlDO> pageInfo = new PageInfo<TbjlDO>(tbjlDOList);
        List<ReportRecordInfoVO> reportRecordInfoVOList = new ArrayList<>();
        if (tbjlDOList != null) {
            for (TbjlDO tbjlDO : tbjlDOList) {
                String lcid = tbjlDO.getLcid();
                ReportRecordInfoVO reportRecordInfoVO = new ReportRecordInfoVO();
                LsBeanUtils.copyPropertiesIgnoreNull(tbjlDO, reportRecordInfoVO);
                if (tbjlDO.getCreateBy() != null) {
                    reportRecordInfoVO.setFilingType("中心填报");
                } else {
                    reportRecordInfoVO.setFilingType("系统生成");
                }
                //日期
                reportRecordInfoVO.setDayTime(getDay(tbjlDO.getCreateTime()));
                if (tbjlDO.getSbkssj() != null) {
                    reportRecordInfoVO.setSbkssj(getDay(tbjlDO.getSbkssj()));
                }
                if (tbjlDO.getSbjssj() != null) {
                    reportRecordInfoVO.setSbjssj(getDay(tbjlDO.getSbjssj()));
                }
                //月份日期
                if (tbjlDO.getSbkssj() != null) {
                    reportRecordInfoVO.setMonthTime(getMonth(tbjlDO.getSbkssj()));
                }
                //string日期
                if (tbjlDO.getCreateTime() != null) {
                    reportRecordInfoVO.setReportTime(getStringTime(tbjlDO.getCreateTime()));
                }
                if (lcid != null) {
                    if (lcid.equals("3") || lcid.equals("13")) {
                        reportRecordInfoVO.setStatusName("驳回");
                    } else if (lcid.equals("1")) {
                        reportRecordInfoVO.setStatusName("提交");
                    } else if (lcid.equals("2")) {
                        reportRecordInfoVO.setStatusName("发布");
                    }
                }
                reportRecordInfoVOList.add(reportRecordInfoVO);
            }
        }
   /*     if(reportRecordListVO.getQueryType() != null){
            resultMap.put("orgType",reportRecordListVO.getQueryType());
        }else{
            resultMap.put("orgType",3);
        }*/
        resultMap.put("total", pageInfo.getTotal());
        resultMap.put("resultList", reportRecordInfoVOList);
        return resultMap;

    }

    /**
     * @param reportRecordInfoVO
     * @Description: 内蒙粮油价格编辑
     * @date
     * @author renyu
     * @version v1.0
     */
    public void update(ReportRecordInfoVO reportRecordInfoVO) {
        TbjlDO tbjlDO = new TbjlDO();
        LsBeanUtils.copyPropertiesIgnoreNull(reportRecordInfoVO, tbjlDO);
        TbjlDO tbjlDO1 = tbjlDao.selectById(reportRecordInfoVO.getId());
        tbjlDO.setId(reportRecordInfoVO.getId());
        tbjlDO.setUpdateTime(new Date());
        if (tbjlDO1.getUpdateNum() != null) {
            tbjlDO.setUpdateNum(tbjlDO1.getUpdateNum() + 1);
        } else {
            tbjlDO.setUpdateNum(1);
        }
        if (tbjlDO.getOrgId().length() == 5) {
            tbjlDO.setLcid("2");
        }
        //修改填报记录信息
        tbjlDao.update(tbjlDO);
        List<PriceInfoVO> priceInfoVOList = reportRecordInfoVO.getPriceInfoVOList();
        if (priceInfoVOList != null) {
            for (PriceInfoVO priceInfoVO : priceInfoVOList) {
                LyjgDO lyjgDO = new LyjgDO();
                LsBeanUtils.copyPropertiesIgnoreNull(priceInfoVO, lyjgDO);
                lyjgDO.setId(priceInfoVO.getId());
                //修改粮油价格信息
                lyjgDao.update(lyjgDO);

                List<PriceDedailInfoVO> priceDedailInfoVOList = priceInfoVO.getPriceDedailInfoVOList();
                if (priceDedailInfoVOList != null) {
                    for (PriceDedailInfoVO priceDedailInfoVO : priceDedailInfoVOList) {
                        LyjgmxDO lyjgmxDO = new LyjgmxDO();
                        LsBeanUtils.copyPropertiesIgnoreNull(priceDedailInfoVO, lyjgmxDO);
                        lyjgmxDao.update(lyjgmxDO);
                    }

                }
               /* Map<String, Object> priceMap = priceInfoVO.getPriceMap();
                Map<String, Object> lastPriceMap = priceInfoVO.getLastPriceMap();
                Integer length = priceMap.size()/3;
                for(int i = 0 ; i < length; i++){
                    LyjgmxDO lyjgmxDO = new LyjgmxDO();
                    lyjgmxDO.setLyjgId(lyjgDO.getId());
                    lyjgmxDO.setId((String)priceMap.get("priceId" + (1 + i)));
                    lyjgmxDO.setJglx((String)priceMap.get("priceType" + (1 + i)));
                    if(priceMap.get("nowPrice" + (1 + i)) != null){
                        lyjgmxDO.setBqjg(Double.parseDouble((String)priceMap.get("nowPrice" + (1 + i))));
                    }
                    if(lastPriceMap.get("lastPrice" + (1 + i)) != null){
                        lyjgmxDO.setSqjg(Double.parseDouble((String)lastPriceMap.get("lastPrice" + (1 + i))));
                    }
                    lyjgmxDO.setHbzzl(Double.parseDouble(lastPriceMap.get("hbzzl" + (1 + i)).toString()));
                    lyjgmxDao.update(lyjgmxDO);
                }*/
            }
        }
    }

    /**
     * @param reportRecordListVO
     * @return reportRecordInfoVO
     * @Description: 内蒙古获取上期数据
     * @date
     * @author renyu
     * @version v1.0
     */
    public ReportRecordInfoVO getLastInfoByQuery(ReportRecordListVO reportRecordListVO) {
        //获取上一条填报记录信息
        TbjlDO tbjlDO = tbjlDao.selectLastInfo(reportRecordListVO);
        ReportRecordInfoVO reportRecordInfoVO = new ReportRecordInfoVO();
        if (tbjlDO != null) {
            LsBeanUtils.copyPropertiesIgnoreNull(tbjlDO, reportRecordInfoVO);
            //获取粮油价格信息
            List<LyjgDO> lyjgInfoDOList = lyjgDao.selectInfoByFid(tbjlDO.getId());
            List<PriceInfoVO> priceInfoVOList = new ArrayList<>();
            if (lyjgInfoDOList != null) {
                for (LyjgDO lyjgDO : lyjgInfoDOList) {
                    PriceInfoVO priceInfoVO = new PriceInfoVO();
                    LsBeanUtils.copyPropertiesIgnoreNull(lyjgDO, priceInfoVO);
                    //获取粮油价格明细信息
                    List<LyjgmxDO> lyjgmxDOList = lyjgmxDao.selectInfoByFid(priceInfoVO.getId());
                    List<PriceDedailInfoVO> priceDedailInfoVOList = new ArrayList<>();
                    if (lyjgmxDOList != null) {
                        for (LyjgmxDO lyjgmxDO : lyjgmxDOList) {
                            PriceDedailInfoVO priceDedailInfoVO = new PriceDedailInfoVO();
                            LsBeanUtils.copyPropertiesIgnoreNull(lyjgmxDO, priceDedailInfoVO);
                            priceDedailInfoVOList.add(priceDedailInfoVO);
                        }
                    }
                    priceInfoVO.setPriceDedailInfoVOList(priceDedailInfoVOList);
                    priceInfoVOList.add(priceInfoVO);
                }
            }
            reportRecordInfoVO.setPriceInfoVOList(priceInfoVOList);
        }
        return reportRecordInfoVO;
    }

    /**
     * @param
     * @Description: 全国价格指数上报
     * @date
     * @author renyu
     * @version v1.0
     */
    public void saveQgjgzs(NationIndexReportInfoVO nationIndexReportInfoVO) {
        TbjlDO tbjlDO = new TbjlDO();
        LsBeanUtils.copyPropertiesIgnoreNull(nationIndexReportInfoVO, tbjlDO);
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        if (nationIndexReportInfoVO.getSbjssj() != null && nationIndexReportInfoVO.getSbjssj() != "") {
            try {
                tbjlDO.setSbjssj(sdf.parse(nationIndexReportInfoVO.getSbjssj()));
            } catch (ParseException e) {
                e.printStackTrace();
            }
        }
        if (nationIndexReportInfoVO.getSbkssj() != null && nationIndexReportInfoVO.getSbkssj() != "") {
            try {
                tbjlDO.setSbkssj(sdf.parse(nationIndexReportInfoVO.getSbkssj()));
            } catch (ParseException e) {
                e.printStackTrace();
            }
        }
        tbjlDO.setCreateTime(new Date());
        //保存报表信息
        tbjlDao.insert(tbjlDO);

        List<NationIndexInfoVO> nationIndexInfoVOList = nationIndexReportInfoVO.getNationIndexInfoVOList();
        if (nationIndexInfoVOList != null) {
            for (NationIndexInfoVO nationIndexInfoVO : nationIndexInfoVOList) {
                QgjgzsDO qgjgzsDO = new QgjgzsDO();
                LsBeanUtils.copyPropertiesIgnoreNull(nationIndexInfoVO, qgjgzsDO);
                if (nationIndexInfoVO.getZs() != null) {
                    qgjgzsDO.setZs(Double.parseDouble(getDoubleString(nationIndexInfoVO.getZs())));
                }
                if (nationIndexInfoVO.getHb() != null) {
                    qgjgzsDO.setHb(Double.parseDouble(getDoubleString(nationIndexInfoVO.getHb())));
                }
                if (nationIndexInfoVO.getTb() != null) {
                    qgjgzsDO.setTb(Double.parseDouble(getDoubleString(nationIndexInfoVO.getTb())));
                }
                qgjgzsDO.setTbjlId(tbjlDO.getId());
                qgjgzsDO.setId(UUIDUtils.uuid());
                qgjgzsDao.insert(qgjgzsDO);
            }
        }
    }

    /**
     * @param
     * @Description: 全国价格指数报表编辑
     * @date
     * @author renyu
     * @version v1.0
     */
    public void updateQgjgzs(NationIndexReportInfoVO nationIndexReportInfoVO) {
        TbjlDO tbjlDO = new TbjlDO();
        LsBeanUtils.copyPropertiesIgnoreNull(nationIndexReportInfoVO, tbjlDO);
        tbjlDO.setId(nationIndexReportInfoVO.getId());
        tbjlDO.setUpdateTime(new Date());
        //修改填报记录信息
        tbjlDao.update(tbjlDO);
        List<NationIndexInfoVO> nationIndexInfoVOList = nationIndexReportInfoVO.getNationIndexInfoVOList();
        if (nationIndexInfoVOList != null) {
            for (NationIndexInfoVO nationIndexInfoVO : nationIndexInfoVOList) {
                QgjgzsDO qgjgzsDO = new QgjgzsDO();
                LsBeanUtils.copyPropertiesIgnoreNull(nationIndexInfoVO, qgjgzsDO);
                qgjgzsDO.setId(nationIndexInfoVO.getId());
                if (nationIndexInfoVO.getZs() != null) {
                    qgjgzsDO.setZs(Double.parseDouble(getDoubleString(nationIndexInfoVO.getZs())));
                }
                if (nationIndexInfoVO.getHb() != null) {
                    qgjgzsDO.setHb(Double.parseDouble(getDoubleString(nationIndexInfoVO.getHb())));
                }
                if (nationIndexInfoVO.getTb() != null) {
                    qgjgzsDO.setTb(Double.parseDouble(getDoubleString(nationIndexInfoVO.getTb())));
                }
                //修改全国价格指数信息
                qgjgzsDao.update(qgjgzsDO);
            }
        }
    }

    /**
     * @param id
     * @return qgjgzsTbjlInfoVO
     * @Description: 全国价格指数报表查看
     * @date
     * @author renyu
     * @version v1.0
     */
    public NationIndexReportInfoVO getQgjgzsById(String id) {
        //获取填报记录信息
        TbjlDO tbjlDO = tbjlDao.selectById(id);
        NationIndexReportInfoVO nationIndexReportInfoVO = new NationIndexReportInfoVO();
        LsBeanUtils.copyPropertiesIgnoreNull(tbjlDO, nationIndexReportInfoVO);
        if (tbjlDO.getSbkssj() != null) {
            nationIndexReportInfoVO.setSbkssj(getDay(tbjlDO.getSbkssj()));
        }
        if (tbjlDO.getSbjssj() != null) {
            nationIndexReportInfoVO.setSbjssj(getDay(tbjlDO.getSbjssj()));
        }
        //获取粮油价格信息
        List<QgjgzsDO> qgjgzsDOList = qgjgzsDao.selectInfoByFid(id);
        List<NationIndexInfoVO> nationIndexInfoVOList = new ArrayList<>();
        if (qgjgzsDOList != null) {
            for (QgjgzsDO qgjgzsDO : qgjgzsDOList) {
                NationIndexInfoVO nationIndexInfoVO = new NationIndexInfoVO();
                LsBeanUtils.copyPropertiesIgnoreNull(qgjgzsDO, nationIndexInfoVO);
                nationIndexInfoVOList.add(nationIndexInfoVO);
            }
        }
        nationIndexReportInfoVO.setNationIndexInfoVOList(nationIndexInfoVOList);
        return nationIndexReportInfoVO;
    }

    /**
     * @param reportRecordListVO
     * @return resultMap
     * @Description: 全国价格指数报表查看
     * @date
     * @author renyu
     * @version v1.0
     */
    public Map<String, Object> getQgjgzsByQuery(ReportRecordListVO reportRecordListVO, Integer page, Integer size) {
        Map<String, Object> resultMap = new HashMap<>();
        PageHelper.startPage(page, size);
        //获取填报信息列表
        List<TbjlDO> tbjlDOList = tbjlDao.selectByQuery(reportRecordListVO);
        PageInfo<TbjlDO> pageInfo = new PageInfo<TbjlDO>(tbjlDOList);
        List<ReportRecordInfoVO> reportRecordInfoVOList = new ArrayList<>();
        if (tbjlDOList != null) {
            for (TbjlDO tbjlDO : tbjlDOList) {
                ReportRecordInfoVO reportRecordInfoVO = new ReportRecordInfoVO();
                LsBeanUtils.copyPropertiesIgnoreNull(tbjlDO, reportRecordInfoVO);
                reportRecordInfoVOList.add(reportRecordInfoVO);
            }
        }
        resultMap.put("total", pageInfo.getTotal());
        resultMap.put("resultList", reportRecordInfoVOList);
        return resultMap;

    }

    /**
     * @param reportRecordInfoVO
     * @Description: 天津粮油价格上报
     * @date
     * @author renyu
     * @version v1.0
     */
    public void saveOne(ReportRecordInfoVO reportRecordInfoVO) {
        TbjlDO tbjlDO = new TbjlDO();
        LsBeanUtils.copyPropertiesIgnoreNull(reportRecordInfoVO, tbjlDO);
        tbjlDO.setId(UUIDUtils.uuid());
        tbjlDO.setCreateTime(new Date());
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        if (reportRecordInfoVO.getSbjssj() != null && reportRecordInfoVO.getSbjssj() != "") {
            try {
                tbjlDO.setSbjssj(sdf.parse(reportRecordInfoVO.getSbjssj()));
            } catch (ParseException e) {
                e.printStackTrace();
            }
        }
        if (reportRecordInfoVO.getSbkssj() != null && reportRecordInfoVO.getSbkssj() != "") {
            try {
                tbjlDO.setSbkssj(sdf.parse(reportRecordInfoVO.getSbkssj()));
            } catch (ParseException e) {
                e.printStackTrace();
            }
        }
        //  用于判断该时间段是否已填报    1是已填报
        //  tbjlDO.setFillNum(1);
        //保存报表信息
        tbjlDao.insert(tbjlDO);
        List<PriceInfoVO> tjPriceInfoVOList = reportRecordInfoVO.getPriceInfoVOList();
        if (tjPriceInfoVOList != null) {
            for (PriceInfoVO tjPriceInfoVO : tjPriceInfoVOList) {
                LyjgDO lyjgDO = new LyjgDO();
                LsBeanUtils.copyPropertiesIgnoreNull(tjPriceInfoVO, lyjgDO);
                lyjgDO.setId(UUIDUtils.uuid());
                lyjgDO.setTbjlId(tbjlDO.getId());
                //保存粮油价格信息
                lyjgDao.insert(lyjgDO);

                LyjgmxDO lyjgmxDO = new LyjgmxDO();
                LsBeanUtils.copyPropertiesIgnoreNull(tjPriceInfoVO, lyjgmxDO);
                if (tjPriceInfoVO.getSqjg() != null) {
                    lyjgmxDO.setSqjg(Double.parseDouble(getDoubleString(tjPriceInfoVO.getSqjg())));
                }
                if (tjPriceInfoVO.getBqjg() != null) {
                    lyjgmxDO.setBqjg(Double.parseDouble(getDoubleString(tjPriceInfoVO.getBqjg())));
                }
                lyjgmxDO.setId(UUIDUtils.uuid());
                lyjgmxDO.setLyjgId(lyjgDO.getId());

                //保存粮油明细信息
                lyjgmxDao.insert(lyjgmxDO);
            }
        }

    }

    public void updateByEntity(TbjlDO tbjlDO) {
        tbjlDao.update(tbjlDO);
    }

    /**
     * @param
     * @Description: 天津粮油价格编辑
     * @date
     * @author renyu
     * @version v1.0
     */
    public void updateOne(ReportRecordInfoVO reportRecordInfoVO) {
        TbjlDO tbjlDO = new TbjlDO();
        LsBeanUtils.copyPropertiesIgnoreNull(reportRecordInfoVO, tbjlDO);
        tbjlDO.setId(reportRecordInfoVO.getId());
        tbjlDO.setUpdateTime(new Date());
        //修改填报记录信息
        tbjlDao.update(tbjlDO);
        List<PriceInfoVO> tjPriceInfoVOList = reportRecordInfoVO.getPriceInfoVOList();
        if (tjPriceInfoVOList != null) {
            for (PriceInfoVO tjPriceInfoVO : tjPriceInfoVOList) {
                LyjgDO lyjgDO = new LyjgDO();
                LsBeanUtils.copyPropertiesIgnoreNull(tjPriceInfoVO, lyjgDO);
                lyjgDO.setId(tjPriceInfoVO.getId());
                //修改粮油价格信息
                lyjgDao.update(lyjgDO);
                LyjgmxDO lyjgmxDO = new LyjgmxDO();
                LsBeanUtils.copyPropertiesIgnoreNull(tjPriceInfoVO, lyjgmxDO);
                if (tjPriceInfoVO.getSqjg() != null) {
                    lyjgmxDO.setSqjg(Double.parseDouble(getDoubleString(tjPriceInfoVO.getSqjg())));
                }
                if (tjPriceInfoVO.getBqjg() != null) {
                    lyjgmxDO.setBqjg(Double.parseDouble(getDoubleString(tjPriceInfoVO.getBqjg())));
                }
                if(StringUtils.isEmpty(tjPriceInfoVO.getLyjgmxId())){
                    lyjgmxDO.setId(UUIDUtils.uuid());
                    lyjgmxDO.setLyjgId(lyjgDO.getId());
                    lyjgmxDao.insert(lyjgmxDO);
                }else{
                    lyjgmxDO.setId(tjPriceInfoVO.getLyjgmxId());
                    lyjgmxDO.setLyjgId(lyjgDO.getId());
                    //修改粮油价格明细信息
                    lyjgmxDao.updateByEntity(lyjgmxDO);
                }
            }
        }
    }

    public ReportRecordInfoVO selectByServiceId(TbjlDO entity ){
        ReportRecordInfoVO reportRecordInfoVO =null;
        //获取填报记录信息
        TbjlDO tbjlDO = tbjlDao.selectByServiceId(entity);
        if(tbjlDO!=null){
            reportRecordInfoVO = new ReportRecordInfoVO();
            LsBeanUtils.copyPropertiesIgnoreNull(tbjlDO, reportRecordInfoVO);
            reportRecordInfoVO.setDayTime(getDay(tbjlDO.getCreateTime()));
            if (tbjlDO.getSbkssj() != null) {
                reportRecordInfoVO.setSbkssj(getDay(tbjlDO.getSbkssj()));
            }
            if (tbjlDO.getSbjssj() != null) {
                reportRecordInfoVO.setSbjssj(getDay(tbjlDO.getSbjssj()));
            }
            if (tbjlDO.getCreateTime() != null) {
                reportRecordInfoVO.setReportTime(getStringTime(tbjlDO.getCreateTime()));
            }
            //获取粮油价格信息
            List<LyjgInfoDO> lyjgInfoDOList = lyjgDao.selectTjInfoByFid(tbjlDO.getId());
            List<PriceInfoVO> tjPriceInfoVOList = new ArrayList<>();
            if (lyjgInfoDOList != null) {
                for (LyjgInfoDO lyjgInfoDO : lyjgInfoDOList) {
                    PriceInfoVO tjPriceInfoVO = new PriceInfoVO();
                    LsBeanUtils.copyPropertiesIgnoreNull(lyjgInfoDO, tjPriceInfoVO);
                    tjPriceInfoVOList.add(tjPriceInfoVO);
                }
            }
            reportRecordInfoVO.setPriceInfoVOList(tjPriceInfoVOList);
        }
        return reportRecordInfoVO;
    }

    /**
     * @param id
     * @return reportRecordInfoVO
     * @Description: 天津粮油价格详情
     * @date
     * @author renyu
     * @version v1.0
     */
    public ReportRecordInfoVO getOneById(String id) {
        //获取填报记录信息
        TbjlDO tbjlDO = tbjlDao.selectById(id);
        ReportRecordInfoVO reportRecordInfoVO = new ReportRecordInfoVO();
        LsBeanUtils.copyPropertiesIgnoreNull(tbjlDO, reportRecordInfoVO);
        reportRecordInfoVO.setDayTime(getDay(tbjlDO.getCreateTime()));
        if (tbjlDO.getSbkssj() != null) {
            reportRecordInfoVO.setSbkssj(getDay(tbjlDO.getSbkssj()));
        }
        if (tbjlDO.getSbjssj() != null) {
            reportRecordInfoVO.setSbjssj(getDay(tbjlDO.getSbjssj()));
        }
        if (tbjlDO.getCreateTime() != null) {
            reportRecordInfoVO.setReportTime(getStringTime(tbjlDO.getCreateTime()));
        }
        //获取粮油价格信息
        List<LyjgInfoDO> lyjgInfoDOList = lyjgDao.selectTjInfoByFid(id);
        List<PriceInfoVO> tjPriceInfoVOList = new ArrayList<>();
        if (lyjgInfoDOList != null) {
            for (LyjgInfoDO lyjgInfoDO : lyjgInfoDOList) {
                PriceInfoVO tjPriceInfoVO = new PriceInfoVO();
                LsBeanUtils.copyPropertiesIgnoreNull(lyjgInfoDO, tjPriceInfoVO);
                tjPriceInfoVOList.add(tjPriceInfoVO);
            }
        }
        reportRecordInfoVO.setPriceInfoVOList(tjPriceInfoVOList);
        return reportRecordInfoVO;
    }

    public ReportRecordInfoVO reportOneLastest(PriceTrendQueryVO vo) {
        //获取填报记录信息
       // 判断大于当前得时间不取价格  显示null
       /*if(vo.getPriceDateType().equals("周报")) {
			String currentDate1 = getDay(new Date());
			int res1=vo.getStartDate().compareTo(currentDate1);
			if(res1<0) {
				vo.setQueryType(1);
			}
    	}*/
        TbjlDO tbjlDO = tbjlDao.selectLastest(vo);
        /*if(vo.getPriceDateType().equals("月报")) {
        	String currentDate1 = getDay(new Date());
			int res1=vo.getEndDate().compareTo(currentDate1);
			if(res1>0) {
				tbjlDO.setFillNum(null);
			}
        }*/
        ReportRecordInfoVO reportRecordInfoVO =new ReportRecordInfoVO();;
        if(tbjlDO!=null){
            LsBeanUtils.copyPropertiesIgnoreNull(tbjlDO, reportRecordInfoVO);
            reportRecordInfoVO.setDayTime(getDay(tbjlDO.getCreateTime()));
            if (tbjlDO.getSbkssj() != null) {
                reportRecordInfoVO.setSbkssj(getDay(tbjlDO.getSbkssj()));
            }
            if (tbjlDO.getSbjssj() != null) {
                reportRecordInfoVO.setSbjssj(getDay(tbjlDO.getSbjssj()));
            }
            if (tbjlDO.getCreateTime() != null) {
                reportRecordInfoVO.setReportTime(getStringTime(tbjlDO.getCreateTime()));
            }
            List<TbjlAvgDO> tb=tbjlDao.selectAvg(vo);
            Map<String,TbjlAvgDO> map=tb.stream().collect(
                    Collectors.toMap(TbjlAvgDO :: getZbbm, a -> a));
            //获取粮油价格信息
            List<LyjgInfoDO> lyjgInfoDOList = lyjgDao.selectTjInfoByFid(tbjlDO.getId());
            List<PriceInfoVO> tjPriceInfoVOList = new ArrayList<>();
            TbjlAvgDO tbjlAvgDO=null;
            if (lyjgInfoDOList != null) {
                for (LyjgInfoDO lyjgInfoDO : lyjgInfoDOList) {
                    PriceInfoVO tjPriceInfoVO = new PriceInfoVO();
                    LsBeanUtils.copyPropertiesIgnoreNull(lyjgInfoDO, tjPriceInfoVO);
                   //tjPriceInfoVO.setPjjg(map.get(tjPriceInfoVO.getZbbm()).getBqjg());
                    tbjlAvgDO=map.get(tjPriceInfoVO.getZbbm());
                    if(tbjlAvgDO!=null){
                        tjPriceInfoVO.setPjjg(tbjlAvgDO.getBqjg());
                    }
                    // 判断取平均值(月)
                    if(vo.getPriceDateType().equals("月报")) {
                    	Map<String,Object> mapData = new HashMap<>();
                    	mapData.put("zbbm", lyjgInfoDO.getZbbm());
                    	mapData.put("startDate", vo.getStartDate());
                    	mapData.put("endDate", vo.getEndDate());	
                    	if(vo.getPriceType().equals("XXzDEKxWnuvvcdX7c2H")) {  //集贸零售价格    
                    		mapData.put("bblxid", "BPgRZ6VVTcJs0sVmQ9S");
                    		TbjlAvgDO avgDo = tbjlDao.queryAvgBqjg(mapData);
                    		if(avgDo != null) {
                    			tjPriceInfoVO.setBqjg(avgDo.getBqjg());
                    		}	 	 		
                        }else if(vo.getPriceType().equals("Te9PwGQFJvoPK63B5Ck")){  //集贸批发价格
                        	mapData.put("bblxid", "JAqcOZ136Tp8lFyuFlV");
                    		TbjlAvgDO avgDo = tbjlDao.queryAvgBqjg(mapData);
                    		if(avgDo != null) {
                    			tjPriceInfoVO.setBqjg(avgDo.getBqjg());
                    		}
                        }else if(vo.getPriceType().equals("nOClfCRJdCR3hIDLb9Z")) {  //超市价格
							/*
							 * mapData.put("xh", lyjgInfoDO.getXh().toString()); TbjlAvgDO avgDo =
							 * tbjlDao.queryAvgBqjgByCsjg(mapData); if(avgDo != null) {
							 * tjPriceInfoVO.setBqjg(avgDo.getBqjg()); }
							 */
                        }
                    }
                    
                    // 判断大于当前得时间不取价格  显示null
                    if(vo.getPriceDateType().equals("周报")) {
                    	String currentDate = getDay(new Date());
                    	int res=vo.getStartDate().compareTo(currentDate);
                    	if(res>0) {
                    		tjPriceInfoVO.setBqjg(null);
                    	}
                    }
                    tjPriceInfoVOList.add(tjPriceInfoVO);
                }
            }
            reportRecordInfoVO.setPriceInfoVOList(tjPriceInfoVOList);
        }
        return reportRecordInfoVO;
    }

    /**
     * @param reportRecordStatusVo
     * @Description: 填报记录状态修改
     * @date
     * @author renyu
     * @version v1.0
     */
    public void updateStatus(ReportRecordStatusVo reportRecordStatusVo) {
        String[] ids = reportRecordStatusVo.getIds().split(",");
        List<String> idsList = new ArrayList<>();
        String lcid = reportRecordStatusVo.getLcid();
        if (reportRecordStatusVo.getOrgType() != null) {
            //用户类型 (2:盟市 1:自治区 )
            Integer orgType = reportRecordStatusVo.getOrgType();
            if (orgType == 1) {
                if (reportRecordStatusVo.getLcid().equals("3")) {
                    for (String id : ids) {
                        TbjlDO tbjlDO = tbjlDao.selectById(id);
                        if (tbjlDO.getRejectNum() != null) {
                            tbjlDO.setRejectNum(tbjlDO.getRejectNum() + 1);
                        } else {
                            tbjlDO.setRejectNum(1);
                        }

                        tbjlDO.setLcid("13");
                        tbjlDao.update(tbjlDO);
                    }
                }
            } else if (orgType == 2) {
                if (reportRecordStatusVo.getLcid().equals("3")) {
                    for (String id : ids) {
                        TbjlDO tbjlDO = tbjlDao.selectById(id);
                        if (tbjlDO.getRejectNum() != null) {
                            tbjlDO.setRejectNum(tbjlDO.getRejectNum() + 1);
                        } else {
                            tbjlDO.setRejectNum(1);
                        }
                        tbjlDO.setLcid("3");
                        tbjlDao.update(tbjlDO);
                    }
                }
            }
        } else {
            for (String id : ids) {
                idsList.add(id);
            }
            Map<String, Object> map = new HashMap<>();
            map.put("ids", idsList);
            map.put("lcid", reportRecordStatusVo.getLcid());
            tbjlDao.updateStatus(map);
        }
    }

    /**
     * @param bblxId
     * @return resultMap
     * @Description: 根据当前登录检测点 获取驳回数据
     * @date
     * @author renyu
     * @version v1.0
     */
    public Map<String, Object> getRejectReport(String bblxId, String pointId) {
        Map<String, Object> map = new HashMap<>();
        map.put("bblxId", bblxId);
        map.put("pointId", pointId);
        SimpleDateFormat simdf = new SimpleDateFormat("yyyy-MM-dd");
        Calendar cal = Calendar.getInstance();
        cal.set(cal.DAY_OF_WEEK, cal.MONDAY);
        String weekhand = simdf.format(cal.getTime());
        map.put("time", weekhand);//当前周周一日期
        //需要判断当前检测点级别 如果是最下级 则只返回当前检测点的当期驳回数据报表；如果不是最下级则返回当前及所有下级当期的驳回数据列表
        List<TbjlDO> tbjlDOList = tbjlDao.selectRejectReport(map);
        Map<String, Object> resultMap = new HashMap<>();
        //最下层检测点 2:其他
        resultMap.put("type", 1);
        resultMap.put("tbjlDOList", tbjlDOList);
        return resultMap;
    }
    /**
     * @param bblxId
     * @return resultMap
     * @Description: 根据当前登录检测点 获取驳回数据
     * @date
     * @author renyu
     * @version v1.0
     */
    public Map<String, Object> getRejectReportBy(String bblxId, String pointId) {
        Map<String, Object> map = new HashMap<>();
        map.put("bblxId", bblxId);
        map.put("pointId", pointId);
        SimpleDateFormat simdf = new SimpleDateFormat("yyyy-MM-dd");
        Calendar cal = Calendar.getInstance();
        cal.set(cal.DAY_OF_WEEK, cal.MONDAY);
        String weekhand = simdf.format(cal.getTime());
        map.put("time", weekhand);//当前周周一日期
        //需要判断当前检测点级别 如果是最下级 则只返回当前检测点的当期驳回数据报表；如果不是最下级则返回当前及所有下级当期的驳回数据列表
        List<TbjlDO> tbjlDOList = tbjlDao.selectRejectReportBy(map);
        Map<String, Object> resultMap = new HashMap<>();
        //最下层检测点 2:其他
        resultMap.put("type", 1);
        resultMap.put("tbjlDOList", tbjlDOList);
        return resultMap;
    }
    /**
     * @param statisticsInputVO
     * @return resultMap
     * @Description: 天津上报统计查询
     * @date
     * @author renyu
     * @version v1.0
     */
    public Map<String, Object> getTjStatistics(StatisticsInputVO statisticsInputVO) {
        Map<String, Object> resultMap = new HashMap<>();
        PageHelper.startPage(statisticsInputVO.getPage(), statisticsInputVO.getSize());
        List<StatisticsOutputVO> tjStatisticsOutputVOList = tbjlDao.selectTjStatistics(statisticsInputVO);
        PageInfo<StatisticsOutputVO> pageInfo = new PageInfo<StatisticsOutputVO>(tjStatisticsOutputVOList);
        resultMap.put("total", pageInfo.getTotal());
        resultMap.put("list", tjStatisticsOutputVOList);
        return resultMap;
    }

    /**
     * @param statisticsInputVO
     * @return resultMap
     * @Description: 天津上报统计详情
     * @date
     * @author renyu
     * @version v1.0
     */
    public Map<String, Object> getTjStatisticsInfo(StatisticsInputVO statisticsInputVO) {
        Map<String, Object> resultMap = new HashMap<>();
        List<StatisticsInfoOutputVO> statisticsInfoOutputVOList = tbjlDao.selectTjStatisticsInfo(statisticsInputVO);
        for (StatisticsInfoOutputVO temVO : statisticsInfoOutputVOList){
            temVO.setPoint(statisticsInputVO.getPoint());
        }
        resultMap.put("list", statisticsInfoOutputVOList);
        return resultMap;
    }

    /**
     * @param statisticsInputVO
     * @return resultMap
     * @Description: 内蒙上报统计查询
     * @date
     * @author renyu
     * @version v1.0
     */
    public Map<String, Object> getNmStatistics(StatisticsInputVO statisticsInputVO) {
        Map<String, Object> resultMap = new HashMap<>();
        if (statisticsInputVO.getStartDate() != null && statisticsInputVO.getStartDate().length() > 11) {
            statisticsInputVO.setStartDate(statisticsInputVO.getStartDate().substring(0, 10));
            statisticsInputVO.setEndDate(statisticsInputVO.getStartDate().substring(0, 10));
        }
        PageHelper.startPage(statisticsInputVO.getPage(), statisticsInputVO.getSize());
        List<StatisticsOutputVO> nmStatisticsOutputVOList = tbjlDao.selectNmStatistics(statisticsInputVO);
        PageInfo<StatisticsOutputVO> pageInfo = new PageInfo<StatisticsOutputVO>(nmStatisticsOutputVOList);
        if (nmStatisticsOutputVOList != null) {
            for (StatisticsOutputVO statisticsOutputVO : nmStatisticsOutputVOList) {
                if (statisticsOutputVO.getRejectNum() == null) {
                    statisticsOutputVO.setRejectNum(0);
                }
                if (statisticsOutputVO.getUpdateNum() == null) {
                    statisticsOutputVO.setUpdateNum(0);
                }
            }
        }
        resultMap.put("total", pageInfo.getTotal());
        resultMap.put("list", nmStatisticsOutputVOList);
        return resultMap;
    }

    /**
     * @param priceStatisticsInputVO
     * @return resultMap
     * @Description: 价格统计日报表
     * @date
     * @author renyu
     * @version v1.0
     */
    public Map<String, Object> getPriceDay(PriceStatisticsInputVO priceStatisticsInputVO) {
        String startDate = null;
        String endDate = null;
        //默认查询上次记录
        if (priceStatisticsInputVO.getStartDate() == null) {
            TbjlDO tbjlDO = tbjlDao.selectLastReportTime(priceStatisticsInputVO);
            if (tbjlDO != null) {
                priceStatisticsInputVO.setStartDate(tbjlDO.getSbkssj());
                priceStatisticsInputVO.setEndDate(tbjlDO.getSbjssj());
                startDate = getDay(tbjlDO.getSbkssj());
                endDate = getDay(tbjlDO.getSbjssj());
            } else {
                Map<String, Object> map = getWeekDate1();
                startDate = getDay(getLastWeekDate((Date) map.get("mondayDate")));
                endDate = getDay(getLastWeekDate((Date) map.get("sundayDate")));
                priceStatisticsInputVO.setStartDate(getLastWeekDate((Date) map.get("mondayDate")));
                priceStatisticsInputVO.setEndDate(getLastWeekDate((Date) map.get("sundayDate")));
            }
        } else {
            startDate = getDay(priceStatisticsInputVO.getStartDate());
            endDate = getDay(priceStatisticsInputVO.getEndDate());
        }
        Map<String, Object> resultMap = new HashMap<>();
        /*PageHelper.startPage(priceStatisticsInputVO.getPage(), priceStatisticsInputVO.getSize());*/
        //获取检测点
        List<PriceStatisticsDayVO> priceStatisticsDayVOList = tbjlDao.selectJcd(priceStatisticsInputVO);
        /*PageInfo<PriceStatisticsDayVO> pageInfo = new PageInfo<PriceStatisticsDayVO>(priceStatisticsDayVOList);*/
        List<Map<String, Object>> listMap = new ArrayList<>();


        List<TrendChartVO> headList = new ArrayList<>();

        //获取报表类型对应的指标
        PriceTrendQueryVO priceTrendQueryVO = new PriceTrendQueryVO();
        priceTrendQueryVO.setPriceType(priceStatisticsInputVO.getPriceType());
        if (priceStatisticsInputVO.getStatisticsTypes() != null && priceStatisticsInputVO.getStatisticsTypes().size() > 0) {
            priceTrendQueryVO.setIndicators(priceStatisticsInputVO.getStatisticsTypes());
        }

        List<ReportTypeIndicatorVO> reportTypeIndicatorVOList = bbLxDao.selectIndicatorOfBz(priceTrendQueryVO);
        //设置表头
        for (int i = 0; i < reportTypeIndicatorVOList.size(); i++) {
            TrendChartVO trendChartVO = new TrendChartVO();
            TrendChartVO trendChartVO1 = new TrendChartVO();
            if (reportTypeIndicatorVOList.get(i).getJlbz() != null) {
                trendChartVO.setLable(reportTypeIndicatorVOList.get(i).getPzmc() + "(" + reportTypeIndicatorVOList.get(i).getJlbz() + ")" + "价格");
                trendChartVO1.setLable(reportTypeIndicatorVOList.get(i).getPzmc() + "(" + reportTypeIndicatorVOList.get(i).getJlbz() + ")" + "数量");
            } else {
                trendChartVO.setLable(reportTypeIndicatorVOList.get(i).getPzmc() + "价格");
                trendChartVO1.setLable(reportTypeIndicatorVOList.get(i).getPzmc() + "数量");
            }
            trendChartVO.setProp("price" + (i + 1));
            headList.add(trendChartVO);
            trendChartVO1.setProp("number" + (i + 1));
            headList.add(trendChartVO1);
        }
        for (PriceStatisticsDayVO priceStatisticsDayVO : priceStatisticsDayVOList) {
            priceStatisticsInputVO.setPoint(priceStatisticsDayVO.getPoint());
            priceStatisticsInputVO.setPointId(priceStatisticsDayVO.getPointId());
            List<Map<String, Object>> mapList = new ArrayList<>();
            Map<String, Object> map = new HashMap<>();
            map.put("point", priceStatisticsDayVO.getPoint());
            map.put("pointId", priceStatisticsDayVO.getPointId());
            //获取监测点下的指标价格信息
            /*List<PriceInfoVO> tjPriceInfoVOList = tbjlDao.selectPriceDay(priceStatisticsInputVO);*/

            for (int i = 0; i < reportTypeIndicatorVOList.size(); i++) {
                //根据监测点及指标信息查询指标对应的价格数据
                priceStatisticsInputVO.setIndicator(reportTypeIndicatorVOList.get(i).getPzmc());
                if (reportTypeIndicatorVOList.get(i).getJlbz() != null) {
                    priceStatisticsInputVO.setJlbz(reportTypeIndicatorVOList.get(i).getJlbz());
                } else {
                    priceStatisticsInputVO.setJlbz(null);
                }
                PriceInfoVO priceInfoVO = tbjlDao.selectDayPrice(priceStatisticsInputVO);
                if (priceInfoVO != null) {
                    map.put("price" + (i + 1), priceInfoVO.getBqjg());
                    map.put("number" + (i + 1), priceInfoVO.getBqsl());
                } else {
                    map.put("price" + (i + 1), "0");
                    map.put("number" + (i + 1), "0");
                }
            }



/*
            if(headList.size() < 1){
                for (int i = 0; i < tjPriceInfoVOList.size(); i++) {
                    TrendChartVO trendChartVO = new TrendChartVO();
                    trendChartVO.setLable(tjPriceInfoVOList.get(i).getPzmc()+"价格");
                    trendChartVO.setProp("price"+(i + 1));
                    headList.add(trendChartVO);
                    TrendChartVO trendChartVO1 = new TrendChartVO();
                    trendChartVO1.setLable(tjPriceInfoVOList.get(i).getPzmc()+"数量");
                    trendChartVO1.setProp("number"+(i + 1));
                    headList.add(trendChartVO1);
                *//*pzmap.put("price"+(i + 1), tjPriceInfoVOList.get(i).getPzmc()+"价格");
                pzmap.put("number"+(i + 1), tjPriceInfoVOList.get(i).getPzmc()+"数量");*//*
                    map.put("price"+(i + 1), tjPriceInfoVOList.get(i).getBqjg());
                    map.put("number"+(i + 1), tjPriceInfoVOList.get(i).getBqsl());
                }
            }else{
                for (int i = 0; i < tjPriceInfoVOList.size(); i++) {
                    map.put("price"+(i + 1), tjPriceInfoVOList.get(i).getBqjg());
                    map.put("number"+(i + 1), tjPriceInfoVOList.get(i).getBqsl());
                }
            }*/

            listMap.add(map);
        }
        /*  resultMap.put("total", pageInfo.getTotal());*/
        resultMap.put("list", listMap);
        resultMap.put("lineList", headList);
        resultMap.put("startDate", startDate);
        resultMap.put("endDate", endDate);

        return resultMap;
    }

    /**
     * @param priceStatisticsInputVO
     * @return resultMap
     * @Description: 价格统计月报表
     * @date
     * @author renyu
     * @version v1.0
     */
    public Map<String, Object> getPriceMonth(PriceStatisticsInputVO priceStatisticsInputVO) {
        Map<String, Object> resultMap = new HashMap<>();
        if (priceStatisticsInputVO.getStartDate() == null) {
            Map<String, Object> map = getNowMonthTime();
            priceStatisticsInputVO.setStartDate((Date) map.get("startDate"));
            priceStatisticsInputVO.setEndDate((Date) map.get("endDate"));
        }
        /*PageHelper.startPage(priceStatisticsInputVO.getPage(), priceStatisticsInputVO.getSize());*/
        //获取本月数据
        List<PriceStatisticsVO> priceStatisticsVOList = tbjlDao.selectTimePrice(priceStatisticsInputVO);
        /* PageInfo<PriceStatisticsVO> pageInfo = new PageInfo<PriceStatisticsVO>(priceStatisticsVOList);*/
        //获取上个月时间
        if (priceStatisticsVOList != null && priceStatisticsVOList.size() > 0) {
            Map<String, Object> map = getLastMonthTime(priceStatisticsInputVO.getStartDate());
            priceStatisticsInputVO.setStartDate((Date) map.get("startTime"));
            priceStatisticsInputVO.setEndDate((Date) map.get("endTime"));
            List<PriceStatisticsMonthVO> priceStatisticsMonthVOList = new ArrayList<>();
            if (priceStatisticsVOList != null && priceStatisticsVOList.size() > 0) {
                for (int i = 0; i < priceStatisticsVOList.size(); i++) {
                    PriceStatisticsMonthVO priceStatisticsMonthVO = new PriceStatisticsMonthVO();
                    LsBeanUtils.copyPropertiesIgnoreNull(priceStatisticsVOList.get(i), priceStatisticsMonthVO);
                    priceStatisticsInputVO.setStatisticsType(priceStatisticsVOList.get(i).getBm());
                    List<PriceStatisticsVO> priceStatisticsVOList1 = tbjlDao.selectTimePrice(priceStatisticsInputVO);
                    priceStatisticsMonthVO.setStartPrice(Double.parseDouble(getDoubleString(priceStatisticsMonthVO.getStartPrice())));
                    priceStatisticsMonthVO.setMinPrice(Double.parseDouble(getDoubleString(priceStatisticsMonthVO.getMinPrice())));
                    priceStatisticsMonthVO.setEndPrice(Double.parseDouble(getDoubleString(priceStatisticsMonthVO.getEndPrice())));
                    priceStatisticsMonthVO.setAvgPrice(Double.parseDouble(getDoubleString(priceStatisticsMonthVO.getAvgPrice())));
                    priceStatisticsMonthVO.setAvgNumber(Double.parseDouble(getDoubleString(priceStatisticsMonthVO.getAvgNumber())));
                    priceStatisticsMonthVO.setMaxPrice(Double.parseDouble(getDoubleString(priceStatisticsMonthVO.getMaxPrice())));
                    //与上月数据做比较
                    if (priceStatisticsVOList1 != null && priceStatisticsVOList1.size() > 0) {
                        if (priceStatisticsVOList1.get(0).getStartPrice() != null) {
                            priceStatisticsMonthVO.setCompareStartPrice(Double.parseDouble(getDoubleString(priceStatisticsMonthVO.getStartPrice() - priceStatisticsVOList1.get(0).getStartPrice())));
                        } else {
                            priceStatisticsMonthVO.setCompareStartPrice(0.0);
                        }
                        if (priceStatisticsVOList1.get(0).getEndPrice() != null) {
                            priceStatisticsMonthVO.setCompareEndPrice(Double.parseDouble(getDoubleString(priceStatisticsMonthVO.getEndPrice() - priceStatisticsVOList1.get(0).getEndPrice())));
                        } else {
                            priceStatisticsMonthVO.setCompareEndPrice(0.0);
                        }
                        if (priceStatisticsVOList1.get(0).getAvgPrice() != null) {
                            priceStatisticsMonthVO.setCompareAvgPrice(Double.parseDouble(getDoubleString(priceStatisticsMonthVO.getAvgPrice() - priceStatisticsVOList1.get(0).getAvgPrice())));
                        } else {
                            priceStatisticsMonthVO.setCompareAvgPrice(0.0);
                        }
                        if (priceStatisticsVOList1.get(0).getAvgNumber() != null) {
                            DecimalFormat format = new DecimalFormat("0.00");
                            Double avgNumber = convert(priceStatisticsVOList1.get(0).getAvgNumber());
                            priceStatisticsMonthVO.setCompareAvgNumber(format.format((priceStatisticsMonthVO.getAvgNumber() - avgNumber) / avgNumber * 100));
                        } else {
                            priceStatisticsMonthVO.setCompareAvgNumber("0.0");
                        }
                        if (priceStatisticsVOList1.get(0).getMaxPrice() != null) {
                            priceStatisticsMonthVO.setCompareMaxPrice(Double.parseDouble(getDoubleString(priceStatisticsMonthVO.getMaxPrice() - priceStatisticsVOList1.get(0).getMaxPrice())));
                        } else {
                            priceStatisticsMonthVO.setCompareMaxPrice(0.0);
                        }
                        if (priceStatisticsVOList1.get(0).getMinPrice() != null) {
                            priceStatisticsMonthVO.setCompareMinPrice(Double.parseDouble(getDoubleString(priceStatisticsMonthVO.getMinPrice() - priceStatisticsVOList1.get(0).getMinPrice())));
                        } else {
                            priceStatisticsMonthVO.setCompareMinPrice(0.0);
                        }
                    } else {
                        priceStatisticsMonthVO.setCompareStartPrice(0.0);
                        priceStatisticsMonthVO.setCompareEndPrice(0.0);
                        priceStatisticsMonthVO.setCompareAvgPrice(0.0);
                        priceStatisticsMonthVO.setCompareAvgNumber("0.0");
                        priceStatisticsMonthVO.setCompareMaxPrice(0.0);
                        priceStatisticsMonthVO.setCompareMinPrice(0.0);
                    }
                    priceStatisticsMonthVOList.add(priceStatisticsMonthVO);

                }
            }
            resultMap.put("list", priceStatisticsMonthVOList);
        } else {
            PriceTrendQueryVO priceTrendQueryVO = new PriceTrendQueryVO();
            priceTrendQueryVO.setPriceType(priceStatisticsInputVO.getPriceType());
            if (priceStatisticsInputVO.getStatisticsTypes() != null && priceStatisticsInputVO.getStatisticsTypes().size() > 0) {
                priceTrendQueryVO.setIndicators(priceStatisticsInputVO.getStatisticsTypes());
            }
            List<ReportTypeIndicatorVO> reportTypeIndicatorVOList = bbLxDao.selectIndicatorOfBz(priceTrendQueryVO);
            List<PriceStatisticsVO> priceStatisticsVOList1 = new ArrayList<>();
            for (int i = 0; i < reportTypeIndicatorVOList.size(); i++) {
                PriceStatisticsVO priceStatisticsVO = new PriceStatisticsVO();
                priceStatisticsVO.setName(reportTypeIndicatorVOList.get(i).getPzmc());
                priceStatisticsVO.setJlbz(reportTypeIndicatorVOList.get(i).getJlbz());
                priceStatisticsVOList1.add(priceStatisticsVO);
            }
            resultMap.put("list", priceStatisticsVOList1);
        }
        return resultMap;
    }

    private double convert(double value) {
        long l1 = Math.round(value * 100);
        double ret = l1 / 100.0;
        return ret;
    }

    /**
     * @param priceStatisticsInputVO
     * @return resultMap
     * @Description: 价格统计周报表
     * @date
     * @author renyu
     * @version v1.0
     */
    public Map<String, Object> getPriceWeek(PriceStatisticsInputVO priceStatisticsInputVO) {
        Map<String, Object> resultMap = new HashMap<>();
        if (priceStatisticsInputVO.getStartDate() == null) {
            Map<String, Object> map = getWeekDate();
            priceStatisticsInputVO.setStartDate((Date) map.get("mondayDate"));
            priceStatisticsInputVO.setEndDate((Date) map.get("sundayDate"));
        }
        /*PageHelper.startPage(priceStatisticsInputVO.getPage(), priceStatisticsInputVO.getSize());*/
        List<PriceStatisticsVO> priceStatisticsVOList = tbjlDao.selectTimePrice(priceStatisticsInputVO);
        /* PageInfo<PriceStatisticsVO> pageInfo = new PageInfo<PriceStatisticsVO>(priceStatisticsVOList);*/
        //设置时间为上一星期
        if (priceStatisticsVOList != null && priceStatisticsVOList.size() > 0) {
            priceStatisticsInputVO.setStartDate(getLastWeekDate(priceStatisticsInputVO.getStartDate()));
            priceStatisticsInputVO.setEndDate(getLastWeekDate(priceStatisticsInputVO.getEndDate()));
            List<PriceStatisticsWeekVO> priceStatisticsWeekVOList = new ArrayList<>();
            if (priceStatisticsVOList != null && priceStatisticsVOList.size() > 0) {
                for (int i = 0; i < priceStatisticsVOList.size(); i++) {
                    PriceStatisticsWeekVO priceStatisticsWeekVO = new PriceStatisticsWeekVO();
                    LsBeanUtils.copyPropertiesIgnoreNull(priceStatisticsVOList.get(i), priceStatisticsWeekVO);
                    priceStatisticsInputVO.setStatisticsType(priceStatisticsVOList.get(i).getBm());
                    priceStatisticsWeekVO.setStartPrice(Double.parseDouble(getDoubleString(priceStatisticsWeekVO.getStartPrice())));
                    priceStatisticsWeekVO.setEndPrice(Double.parseDouble(getDoubleString(priceStatisticsWeekVO.getEndPrice())));
                    priceStatisticsWeekVO.setAvgPrice(Double.parseDouble(getDoubleString(priceStatisticsWeekVO.getAvgPrice())));
                    priceStatisticsWeekVO.setAvgNumber(Double.parseDouble(getDoubleString(priceStatisticsWeekVO.getAvgNumber())));
                    
                    priceStatisticsWeekVO.setPp(priceStatisticsWeekVO.getPp());                    
                    priceStatisticsWeekVO.setJlbz(priceStatisticsWeekVO.getJlbz());
                    priceStatisticsWeekVO.setGg(priceStatisticsWeekVO.getGg());


                    List<PriceStatisticsVO> priceStatisticsVOList1 = tbjlDao.selectTimePrice(priceStatisticsInputVO);
                    if (priceStatisticsVOList1 != null && priceStatisticsVOList1.size() > 0) {
                        if (priceStatisticsVOList1.get(0).getStartPrice() != null) {
                            priceStatisticsWeekVO.setCompareStartPrice(Double.parseDouble(getDoubleString(priceStatisticsWeekVO.getStartPrice() - priceStatisticsVOList1.get(0).getStartPrice())));
                        }
                        if (priceStatisticsVOList1.get(0).getEndPrice() != null) {
                            priceStatisticsWeekVO.setCompareEndPrice(Double.parseDouble(getDoubleString(priceStatisticsWeekVO.getEndPrice() - priceStatisticsVOList1.get(0).getEndPrice())));
                        }
                        if (priceStatisticsVOList1.get(0).getAvgPrice() != null) {
                            priceStatisticsWeekVO.setCompareAvgPrice(Double.parseDouble(getDoubleString(priceStatisticsWeekVO.getAvgPrice() - priceStatisticsVOList1.get(0).getAvgPrice())));
                        }
                        if (priceStatisticsVOList1.get(0).getAvgNumber() != null) {
                            if(priceStatisticsVOList1.get(0).getAvgNumber()==null || priceStatisticsVOList1.get(0).getAvgNumber().compareTo(0d)==0){
                                priceStatisticsWeekVO.setCompareAvgNumber("0.00");
                            }else{
                                DecimalFormat format = new DecimalFormat("0.00");
                                priceStatisticsWeekVO.setCompareAvgNumber(format.format((priceStatisticsWeekVO.getAvgNumber() - priceStatisticsVOList1.get(0).getAvgNumber()) / priceStatisticsVOList1.get(0).getAvgNumber() * 100));
                            }
                        }
                    }
                    priceStatisticsWeekVOList.add(priceStatisticsWeekVO);

                }
            }
            /*resultMap.put("total", pageInfo.getTotal());*/
            resultMap.put("list", priceStatisticsWeekVOList);
        } else {
            PriceTrendQueryVO priceTrendQueryVO = new PriceTrendQueryVO();
            priceTrendQueryVO.setPriceType(priceStatisticsInputVO.getPriceType());
            if (priceStatisticsInputVO.getStatisticsTypes() != null && priceStatisticsInputVO.getStatisticsTypes().size() > 0) {
                priceTrendQueryVO.setIndicators(priceStatisticsInputVO.getStatisticsTypes());
            }
            List<ReportTypeIndicatorVO> reportTypeIndicatorVOList = bbLxDao.selectIndicatorOfBz(priceTrendQueryVO);
            List<PriceStatisticsVO> priceStatisticsVOList1 = new ArrayList<>();
            for (int i = 0; i < reportTypeIndicatorVOList.size(); i++) {
                PriceStatisticsVO priceStatisticsVO = new PriceStatisticsVO();
                priceStatisticsVO.setName(reportTypeIndicatorVOList.get(i).getPzmc());
                priceStatisticsVO.setJlbz(reportTypeIndicatorVOList.get(i).getJlbz());
                priceStatisticsVOList1.add(priceStatisticsVO);
            }
            resultMap.put("list", priceStatisticsVOList1);
        }

        return resultMap;
    }

    /**
     * @param priceTrendQueryVO
     * @return resultMap
     * @Description: 价格走势录入(周 / 月)列表
     * @date
     * @author renyu
     * @version v1.0
     */
    public Map<String, Object> getPriceTrend(PriceTrendQueryVO priceTrendQueryVO) {
        //判断当前查询全部已上报数据还是监测点对应所有数据
        if (priceTrendQueryVO.getPriceDateType() != null
                &&(("日报").equals(priceTrendQueryVO.getPriceDateType()) || ("日报-新").equals(priceTrendQueryVO.getPriceDateType()))
                && priceTrendQueryVO.getQueryType() == null) {
            priceTrendQueryVO.setQueryType(2);
        }
        Map<String, Object> resultMap = new HashMap<>();
        PageHelper.startPage(priceTrendQueryVO.getPage(), priceTrendQueryVO.getSize());
        List<TbjlDO> tbjlDOList = tbjlDao.selectPriceTrend(priceTrendQueryVO);
        PageInfo<TbjlDO> pageInfo = new PageInfo<TbjlDO>(tbjlDOList);
        List<ReportRecordInfoVO> reportRecordInfoVOList = new ArrayList<>();
        if (tbjlDOList != null) {
            for (TbjlDO tbjlDO : tbjlDOList) {
                ReportRecordInfoVO reportRecordInfoVO = new ReportRecordInfoVO();
                LsBeanUtils.copyPropertiesIgnoreNull(tbjlDO, reportRecordInfoVO);
                if (tbjlDO.getCreateBy() != null) {
                    reportRecordInfoVO.setFilingType("中心填报");
                } else {
                    reportRecordInfoVO.setFilingType("系统生成");
                }
                reportRecordInfoVO.setDayTime(getDay(tbjlDO.getCreateTime()));
                if (tbjlDO.getSbkssj() != null) {
                    reportRecordInfoVO.setSbkssj(getDay(tbjlDO.getSbkssj()));
                }
                if (tbjlDO.getSbjssj() != null) {
                    reportRecordInfoVO.setSbjssj(getDay(tbjlDO.getSbjssj()));
                }
                if (tbjlDO.getSbkssj() != null) {
                    reportRecordInfoVO.setMonthTime(getMonth(tbjlDO.getSbkssj()));
                }
                if (tbjlDO.getCreateTime() != null) {
                    reportRecordInfoVO.setReportTime(getStringTime(tbjlDO.getCreateTime()));
                }
                reportRecordInfoVOList.add(reportRecordInfoVO);
            }
        }
        resultMap.put("total", pageInfo.getTotal());
        resultMap.put("list", reportRecordInfoVOList);
        return resultMap;
    }

    /**
     * @param priceTrendQueryVO
     * @return resultMap
     * @Description: 价格走势录入(周 / 月)列表(天津)
     * @date
     * @author yangshengjie
     * @version v1.0
     */
    public Map<String, Object> getPriceTrendTj(PriceTrendQueryVO priceTrendQueryVO) {
        //判断当前查询全部已上报数据还是监测点对应所有数据
        if (priceTrendQueryVO.getPriceDateType() != null && ("日报").equals(priceTrendQueryVO.getPriceDateType()) && priceTrendQueryVO.getQueryType() == null) {
            priceTrendQueryVO.setQueryType(2);
        }
        Map<String, Object> resultMap = new HashMap<>();
        PageHelper.startPage(priceTrendQueryVO.getPage(), priceTrendQueryVO.getSize());
        List<TbjlDO> tbjlDOList = tbjlDao.selectPriceTrendN(priceTrendQueryVO);
        PageInfo<TbjlDO> pageInfo = new PageInfo<TbjlDO>(tbjlDOList);
        List<ReportRecordInfoVO> reportRecordInfoVOList = new ArrayList<>();
        if (tbjlDOList != null) {
            for (TbjlDO tbjlDO : tbjlDOList) {
                ReportRecordInfoVO reportRecordInfoVO = new ReportRecordInfoVO();
                LsBeanUtils.copyPropertiesIgnoreNull(tbjlDO, reportRecordInfoVO);
                if (tbjlDO.getCreateBy() != null) {
                    reportRecordInfoVO.setFilingType("中心填报");
                } else {
                    reportRecordInfoVO.setFilingType("系统生成");
                }
                reportRecordInfoVO.setDayTime(getDay(tbjlDO.getCreateTime()));
                if (tbjlDO.getSbkssj() != null) {
                    reportRecordInfoVO.setSbkssj(getDay(tbjlDO.getSbkssj()));
                }
                if (tbjlDO.getSbjssj() != null) {
                    reportRecordInfoVO.setSbjssj(getDay(tbjlDO.getSbjssj()));
                }
                if (tbjlDO.getSbkssj() != null) {
                    reportRecordInfoVO.setMonthTime(getMonth(tbjlDO.getSbkssj()));
                }
                if (tbjlDO.getCreateTime() != null) {
                    reportRecordInfoVO.setReportTime(getStringTime(tbjlDO.getCreateTime()));
                }
                reportRecordInfoVOList.add(reportRecordInfoVO);
            }
        }
        resultMap.put("total", pageInfo.getTotal());
        resultMap.put("list", reportRecordInfoVOList);
        return resultMap;
    }

    public Map<String, Object> getPriceTrendCT(PriceTrendQueryVO priceTrendQueryVO) {
        //判断当前查询全部已上报数据还是监测点对应所有数据
        if (priceTrendQueryVO.getPriceDateType() != null && ("日报").equals(priceTrendQueryVO.getPriceDateType()) && priceTrendQueryVO.getQueryType() == null) {
            priceTrendQueryVO.setQueryType(2);
        }
        Map<String, Object> resultMap = new HashMap<>();
        PageHelper.startPage(priceTrendQueryVO.getPage(), priceTrendQueryVO.getSize());
        List<TbjlDO> tbjlDOList = tbjlDao.selectPriceTrendCT(priceTrendQueryVO);
        PageInfo<TbjlDO> pageInfo = new PageInfo<TbjlDO>(tbjlDOList);
        List<ReportRecordInfoVO> reportRecordInfoVOList = new ArrayList<>();
        if (tbjlDOList != null) {
            for (TbjlDO tbjlDO : tbjlDOList) {
                ReportRecordInfoVO reportRecordInfoVO = new ReportRecordInfoVO();
                LsBeanUtils.copyPropertiesIgnoreNull(tbjlDO, reportRecordInfoVO);
                if (tbjlDO.getCreateBy() != null) {
                    reportRecordInfoVO.setFilingType("中心填报");
                } else {
                    reportRecordInfoVO.setFilingType("系统生成");
                }
                reportRecordInfoVO.setDayTime(getDay(tbjlDO.getCreateTime()));
                if (tbjlDO.getSbkssj() != null) {
                    reportRecordInfoVO.setSbkssj(getDay(tbjlDO.getSbkssj()));
                }
                if (tbjlDO.getSbjssj() != null) {
                    reportRecordInfoVO.setSbjssj(getDay(tbjlDO.getSbjssj()));
                }
                if (tbjlDO.getSbkssj() != null) {
                    reportRecordInfoVO.setMonthTime(getMonth(tbjlDO.getSbkssj()));
                }
                if (tbjlDO.getCreateTime() != null) {
                    reportRecordInfoVO.setReportTime(getStringTime(tbjlDO.getCreateTime()));
                }
                reportRecordInfoVOList.add(reportRecordInfoVO);
            }
        }
        resultMap.put("total", pageInfo.getTotal());
        resultMap.put("list", reportRecordInfoVOList);
        return resultMap;
    }

    /**
     * @param priceTrendQueryVO
     * @return reportTypeIndicatorVOList
     * @Description: (周 / 月)价格走势录入回显
     * @date
     * @author renyu
     * @version v1.0
     */
    public List<ReportTypeIndicatorVO> getHistoryPrice(PriceTrendQueryVO priceTrendQueryVO) {
        if (priceTrendQueryVO.getType() != null) {
            if (priceTrendQueryVO.getType() == 2) {
                return bbLxDao.selectIndicatorOfBz(priceTrendQueryVO);
            } else if (priceTrendQueryVO.getType() == 3) {
                return tbjlDao.selectIndicatorByBblxId(priceTrendQueryVO);
            } else {
                return tbjlDao.selectIndicatorByBblxId(priceTrendQueryVO);
            }
        } else {
            return tbjlDao.selectIndicatorByBblxId(priceTrendQueryVO);
        }

    }

    /**
     * @param priceTrendQueryVO
     * @return lastPriceInfoVO
     * @Description: 根据价格类型、检测点、指标获取上一期指标价格
     * @date
     * @author renyu
     * @version v1.0
     */
    public LastPriceInfoVO getLastPrice(PriceTrendQueryVO priceTrendQueryVO) {
        List<LastPriceInfoVO> lastPriceInfoVO = tbjlDao.selectLastPrice(priceTrendQueryVO);
        if (lastPriceInfoVO != null && lastPriceInfoVO.size() > 0) {
            return lastPriceInfoVO.get(0);
        } else {
            return null;
        }

    }

    /**
     * @param priceTrendQueryVO
     * @return lastPriceInfoVO
     * @Description: 获取指标周平均价
     * @date
     * @author renyu
     * @version v1.0
     */
    public LastPriceInfoVO getWeekPrice(PriceTrendQueryVO priceTrendQueryVO) {
        LastPriceInfoVO lastPriceInfoVO = tbjlDao.selectWeekPrice(priceTrendQueryVO);
        return lastPriceInfoVO;
    }

    /**
     * @param bblxId
     * @Description: 根据报表类型id 模块类型 查询相应指标列表信息(内蒙古需要根据当前用户检测点去获取对应指标列表信息)
     * @date 2019年8月16日, 下午5:54:00
     * @author 任宇
     * @version v1.0
     */
    public List<IndicatorReportVO> getReportofindicator(String bblxId, String orgId) {
        //获取全部指标
        List<IndicatorReportVO> indicatorReportVOList = bbLxDao.selectIndicatorByBblx(orgId);

        IndicatorReportVO temTimeList = bbLxDao.selectBblxTimeById(bblxId);
        //获取上一期数据
        ReportRecordListVO reportRecordListVO = new ReportRecordListVO();
        reportRecordListVO.setPriceType(bblxId);
        if (orgId != null) {
            reportRecordListVO.setOrgId(orgId);
        }
        TbjlDO tbjlDO = tbjlDao.selectLastInfo(reportRecordListVO);
        Map<String, Object> queryMap = new HashMap<>();
        if (tbjlDO != null) {
            queryMap.put("id", tbjlDO.getId());
        }
        if (indicatorReportVOList != null) {
            for (IndicatorReportVO indicatorReportVO : indicatorReportVOList) {
                //获取指标对应价格类型
                List<PriceDedailInfoVO> priceDedailInfoVOList = bbLxDao.selectPriceTypeByIndicatorId(indicatorReportVO.getId());
               /* Map<String,Object> lastPriceMap = new HashMap<>();
                Map<String,Object> priceMap = new HashMap<>();*/
                for (int i = 0; i < priceDedailInfoVOList.size(); i++) {
                    /*lastPriceMap.put("priceType" + (i + 1) , priceDedailInfoVOList.get(i).getJglx());*/
                    queryMap.put("zbbm", indicatorReportVO.getZbbm());
                    queryMap.put("jglx", priceDedailInfoVOList.get(i).getJglx());
                    queryMap.put("jlbz", indicatorReportVO.getJlbz());
                    queryMap.put("pp", indicatorReportVO.getPp());
                    queryMap.put("gg", indicatorReportVO.getGg());
                    //查询上一期某指标对应的某价格
                    if (queryMap.get("id") != null && !queryMap.get("id").equals("")) {
                        Double price = tbjlDao.selectPriceByType(queryMap);
                        if (price != null) {
                            priceDedailInfoVOList.get(i).setSqjg(price);
                            priceDedailInfoVOList.get(i).setBqjg(price);
                        }
                      String cd = tbjlDao.selectPriceByCd(queryMap);
                        String cdxzqhbm = tbjlDao.selectPriceByCdxzqhbm(queryMap);
                        if (cd != null) {

                            indicatorReportVOList.get(i).setCd(cd);}
                        if (cdxzqhbm != null) {
                            indicatorReportVOList.get(i).setCdxzqhbm(cdxzqhbm);}


                    }
                }
                if(temTimeList!= null){
                    indicatorReportVO.setStartTime(temTimeList.getStartTime());
                    indicatorReportVO.setEndTime(temTimeList.getEndTime());
                }
                if (priceDedailInfoVOList != null) {
                    indicatorReportVO.setPriceDedailInfoVOList(priceDedailInfoVOList);
                }

            }
        }
        return indicatorReportVOList;
    }

    /**
     * @param
     * @return ResponseWrapper
     * @Description: 根据时间段 价格类型 获取对应期初价、期末价、最高价、最低价、平均价、日均销量
     * @date
     * @author renyu
     * @version v1.0
     */
    public Map<String, Object> getTimePrice(PriceStatisticsInputVO priceStatisticsInputVO) {
        Map<String, Object> resultMap = new HashMap<>();
        /*PageHelper.startPage(priceStatisticsInputVO.getPage(), priceStatisticsInputVO.getSize());*/
        //查询条件内数据
        List<PriceStatisticsVO> priceStatisticsVOList = tbjlDao.selectTimePrice(priceStatisticsInputVO);
        if (priceStatisticsVOList != null && priceStatisticsVOList.size() > 0) {
            for (int i = 0; i < priceStatisticsVOList.size(); i++) {
                priceStatisticsVOList.get(i).setAvgPrice(Double.parseDouble(getDoubleString(priceStatisticsVOList.get(i).getAvgPrice())));
                priceStatisticsVOList.get(i).setAvgNumber(Double.parseDouble(getDoubleString(priceStatisticsVOList.get(i).getAvgNumber())));
            }
            resultMap.put("list", priceStatisticsVOList);
        } else {
            //没数据返回对应指标信息
            PriceTrendQueryVO priceTrendQueryVO = new PriceTrendQueryVO();
            priceTrendQueryVO.setPriceType(priceStatisticsInputVO.getPriceType());
            if (priceStatisticsInputVO.getStatisticsTypes() != null && priceStatisticsInputVO.getStatisticsTypes().size() > 0) {
                priceTrendQueryVO.setIndicators(priceStatisticsInputVO.getStatisticsTypes());
            }
            List<ReportTypeIndicatorVO> reportTypeIndicatorVOList = bbLxDao.selectIndicatorOfBz(priceTrendQueryVO);
            List<PriceStatisticsVO> priceStatisticsVOList1 = new ArrayList<>();
            for (int i = 0; i < reportTypeIndicatorVOList.size(); i++) {
                PriceStatisticsVO priceStatisticsVO = new PriceStatisticsVO();
                priceStatisticsVO.setName(reportTypeIndicatorVOList.get(i).getPzmc());
                priceStatisticsVO.setJlbz(reportTypeIndicatorVOList.get(i).getJlbz());
                priceStatisticsVOList1.add(priceStatisticsVO);
            }
            resultMap.put("list", priceStatisticsVOList1);
        }
        /* PageInfo<PriceStatisticsVO> pageInfo = new PageInfo<PriceStatisticsVO>(priceStatisticsVOList);*/
        /* resultMap.put("total", pageInfo.getTotal());*/

        return resultMap;
    }

    /**
     * @param reportDateType
     * @return ResponseWrapper
     * @Description: 根据报表类型id  查询相应指标列表信息()
     * @date 2019年8月16日, 下午5:54:00
     * @author 任宇
     * @version v1.0
     */
    public List<ReportTypeVO> getReportDateType(String reportDateType) {
        return bbLxDao.selectReportDateType(reportDateType);
    }
    //获取七天前的日期
    public Date getLastWeekDate(Date date) {
        Calendar c = Calendar.getInstance();
        c.setTime(date);
        int day = c.get(Calendar.DATE);
        c.set(Calendar.DATE, day - 7);
        System.out.println("获取7天前日期");
        return c.getTime();
    }

    public String getWeek(Date date) {
        return null;
    }

    public String getDay(Date date) {
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");
        return simpleDateFormat.format(date);
    }

    //获取当前月份
    public String getMonth(Date date) {
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy年MM月");
        return simpleDateFormat.format(date);
    }

    //获取当前月的上个月
    public String getLastMonth(Date date) {
        Calendar c = Calendar.getInstance();
        c.setTime(date);
        c.add(Calendar.MONTH, -1);
        Date m = c.getTime();
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM");
        String mon = simpleDateFormat.format(m);
        System.out.println("上个月是："+mon);
        return mon;
    }

    //获取去年同月
    public String getLastYear(Date date) {
        Calendar c = Calendar.getInstance();
        c.setTime(date);
        c.add(Calendar.YEAR, -1);
        Date y = c.getTime();
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM");
        String year = simpleDateFormat.format(y);
        System.out.println("去年同月是："+year);
        return year;
    }

    //获取上月初和末
    public Map<String, Object> getLastMonthTime(Date date) {
        Map<String, Object> map = new HashMap<>();
        Calendar c = Calendar.getInstance();
        c.setTime(date);
        c.add(Calendar.MONTH, -1);
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd  HH:mm:ss");
        String gtimelast = sdf.format(c.getTime());
        System.out.println(gtimelast);
        int lastMonthMaxDay = c.getActualMaximum(Calendar.DAY_OF_MONTH);
        System.out.println(lastMonthMaxDay);
        c.set(c.get(Calendar.YEAR), c.get(Calendar.MONTH), lastMonthMaxDay, 23, 59, 59);
        //按格式输出
        //上月最后一天
        Date gtime = c.getTime();
        System.out.println(gtime);
        int firstMonthMaxDay = c.getActualMinimum(Calendar.DAY_OF_MONTH);
        System.out.println(firstMonthMaxDay);
        c.set(c.get(Calendar.YEAR), c.get(Calendar.MONTH), firstMonthMaxDay, 00, 00, 00);
        SimpleDateFormat sdf2 = new SimpleDateFormat("yyyy-MM-01  00:00:00");
        //上月第一天
        Date gtime2 = c.getTime();
        map.put("startTime", gtime2);
        map.put("endTime", gtime);
        return map;
    }

    //获取指定时间月初月末
    public Map<String, Object> getMonthTime(Date date) {
        Map<String, Object> map = new HashMap<>();
        Calendar c = Calendar.getInstance();
        c.setTime(date);
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd  HH:mm:ss");
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");
        String gtimelast = sdf.format(c.getTime());
        System.out.println(gtimelast);
        int lastMonthMaxDay = c.getActualMaximum(Calendar.DAY_OF_MONTH);
        System.out.println(lastMonthMaxDay);
        c.set(c.get(Calendar.YEAR), c.get(Calendar.MONTH), lastMonthMaxDay, 23, 59, 59);
        //按格式输出
        //上月最后一天
        Date gtime = c.getTime();
        System.out.println(gtime);
        int firstMonthMaxDay = c.getActualMinimum(Calendar.DAY_OF_MONTH);
        System.out.println(firstMonthMaxDay);
        c.set(c.get(Calendar.YEAR), c.get(Calendar.MONTH), firstMonthMaxDay, 00, 00, 00);
        SimpleDateFormat sdf2 = new SimpleDateFormat("yyyy-MM-01  00:00:00");
        //上月第一天
        Date gtime2 = c.getTime();
        map.put("startDate", gtime2);
        map.put("endDate", gtime);
        map.put("startTime", simpleDateFormat.format(gtime2));
        map.put("endTime", simpleDateFormat.format(gtime));
        return map;
    }

    //获取当月初末
    public Map<String, Object> getNowMonthTime() {
        Map<String, Object> map = new HashMap<>();
        Calendar c = Calendar.getInstance();
        c.setTime(new Date());
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");
        String gtimelast = sdf.format(c.getTime());
        System.out.println(gtimelast);
        int lastMonthMaxDay = c.getActualMaximum(Calendar.DAY_OF_MONTH);
        System.out.println(lastMonthMaxDay);
        c.set(c.get(Calendar.YEAR), c.get(Calendar.MONTH), lastMonthMaxDay, 23, 59, 59);
        //按格式输出
        //月最后一天
        Date gtime = c.getTime();
        System.out.println(gtime);
        int firstMonthMaxDay = c.getActualMinimum(Calendar.DAY_OF_MONTH);
        System.out.println(firstMonthMaxDay);
        c.set(c.get(Calendar.YEAR), c.get(Calendar.MONTH), firstMonthMaxDay, 00, 00, 00);
        SimpleDateFormat sdf2 = new SimpleDateFormat("yyyy-MM-01  00:00:00");
        //月第一天
        Date gtime2 = c.getTime();
        map.put("startDate", gtime2);
        map.put("endDate", gtime);
        map.put("startTime", simpleDateFormat.format(gtime2));
        map.put("endTime", simpleDateFormat.format(gtime));
        return map;
    }

    /**
     * @param weeklyReportVO
     * @return resultMap
     * @Description: 周刊报表列表
     * @date
     * @author renyu
     * @version v1.0
     */
    public Map<String, Object> getWeeklyReportList(WeeklyReportVO weeklyReportVO) {
        Map<String, Object> resultMap = new HashMap<>();
        PageHelper.startPage(weeklyReportVO.getPage(), weeklyReportVO.getSize());
        List<WeeklyReportVO> weeklyReportList = tbjlDao.selectWeeklyReportList(weeklyReportVO);
        PageInfo<WeeklyReportVO> pageInfo = new PageInfo<WeeklyReportVO>(weeklyReportList);
        resultMap.put("total", pageInfo.getTotal());
        resultMap.put("list", weeklyReportList);
        return resultMap;
    }

    //获取当前日期周一到周五的时间
    public static Map<String, Object> getWeekDate() {
        Map<String, Object> map = new HashMap();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");

        Calendar cal = Calendar.getInstance();
        // 设置一个星期的第一天，按中国的习惯一个星期的第一天是星期一
        cal.setFirstDayOfWeek(Calendar.MONDAY);
        // 获得当前日期是一个星期的第几天
        int dayWeek = cal.get(Calendar.DAY_OF_WEEK);
        if (dayWeek == 1) {
            dayWeek = 8;
        }
        // 输出要计算日期
        System.out.println("要计算日期为:" + sdf.format(cal.getTime()));
        // 根据日历的规则，给当前日期减去星期几与一个星期第一天的差值
        cal.add(Calendar.DATE, cal.getFirstDayOfWeek() - dayWeek);
        Date mondayDate = cal.getTime();
        String weekBegin = sdf.format(mondayDate);
        System.out.println("所在周星期一的日期：" + weekBegin);


        cal.add(Calendar.DATE, 2 + cal.getFirstDayOfWeek());
        Date sundayDate = cal.getTime();
        String weekEnd = sdf.format(sundayDate);
        System.out.println("所在周星期日的日期：" + weekEnd);

        map.put("mondayDate", mondayDate);
        map.put("sundayDate", sundayDate);
        map.put("mondayTime", weekBegin);
        map.put("sundayTime", weekEnd);
        return map;
    }

    //根据输入时间返回所在周周一日期
    public static Date genMonday(Date date) {
        Calendar cal = Calendar.getInstance();
        cal.setTime(date);
        cal.set(Calendar.DAY_OF_WEEK, Calendar.MONDAY);
        return cal.getTime();
    }

    //获取当前日期周一到周日的时间
    public static Map<String, Object> getWeekDate1() {
        Map<String, Object> map = new HashMap();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        Calendar cal = Calendar.getInstance();
        // 设置一个星期的第一天，按中国的习惯一个星期的第一天是星期一
        cal.setFirstDayOfWeek(Calendar.MONDAY);
        // 获得当前日期是一个星期的第几天
        int dayWeek = cal.get(Calendar.DAY_OF_WEEK);
        if (dayWeek == 1) {
            dayWeek = 8;
        }
        // 输出要计算日期
        System.out.println("要计算日期为:" + sdf.format(cal.getTime()));
        // 根据日历的规则，给当前日期减去星期几与一个星期第一天的差值
        cal.add(Calendar.DATE, cal.getFirstDayOfWeek() - dayWeek);
        Date mondayDate = cal.getTime();
        String weekBegin = sdf.format(mondayDate);
        System.out.println("所在周星期一的日期：" + weekBegin);


        cal.add(Calendar.DATE, 4 + cal.getFirstDayOfWeek());
        Date sundayDate = cal.getTime();
        String weekEnd = sdf.format(sundayDate);
        System.out.println("所在周星期日的日期：" + weekEnd);

        map.put("mondayDate", mondayDate);
        map.put("sundayDate", sundayDate);
        map.put("mondayTime", weekBegin);
        map.put("sundayTime", weekEnd);
        return map;
    }

    /**
     * @param priceTrendQueryVO
     * @return resultMap
     * @Description: 条件查询价格信息
     * @date
     * @author renyu
     * @version v1.0
     */
    public LastPriceInfoVO getPriceByQuery(PriceTrendQueryVO priceTrendQueryVO) {
        LastPriceInfoVO lastPriceInfoVO = tbjlDao.selectPriceByQuery(priceTrendQueryVO);
        return lastPriceInfoVO;
    }

    //date转String
    public String getStringTime(Date date) {
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        return simpleDateFormat.format(date);
    }

    public List<JcdVO> getAllJcdByBblx(String priceType) {
        return tbjlDao.selectAllJcd(priceType);
    }

    /**
     * @param weeklyReportVO
     * @return resultMap
     * @Description: 查询某个时间周刊报表配置对应检测点的品种价格
     * @date
     * @author renyu
     * @version v1.0
     */
    public WeeklyPriceVO getPriceByWeeklyQuery(WeeklyReportVO weeklyReportVO) {
        return tbjlDao.selectPriceByWeeklyQuery(weeklyReportVO);
    }

    //double转为为2位小数
    public String getDoubleString(Double price) {
        if (price != null) {
            DecimalFormat format2 = new DecimalFormat("0.00 ");
            return format2.format(price);
        }
        return "0.0";
    }

    /**
     * @param
     * @return ResponseWrapper
     * @Description: 价格走势图表(周 / 月)
     * @date
     * @author renyu
     * @version v1.0
     */
    public List<Map<String, Object>> getTrendChart(PriceTrendQueryVO priceTrendQueryVO) {
        //查询报表类型对应周/月的指标类别
        List<Map<String, Object>> list = new ArrayList<>();
        List<String> indicatorTypes = tbjlDao.selectIndicatorType(priceTrendQueryVO);
        if (indicatorTypes != null) {
            for (int i = 0; i < indicatorTypes.size(); i++) {
                Map<String, Object> resultMap = new HashMap<>();
                Map<String, Object> map = new HashMap<>();
                map.put("ZBLB", indicatorTypes.get(i));
                //获取周/月报列表
                List<TbjlDO> tbjlDOList = tbjlDao.selectTrendChart(priceTrendQueryVO);
                List<String> timeList = new ArrayList<>();
                List<String> monthTimeList = new ArrayList<>();
                List<String> indicatorList = new ArrayList<>();
                List<Map<String, Object>> seriesLists = new ArrayList<>();
                List<Map<String, Object>> pricesList = new ArrayList<>();
                Map<String, Object> timeMap = new HashMap<>();
                List<TrendChartVO> headList = new ArrayList<>();
                SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");
                if (tbjlDOList != null) {
                    for (int i1 = 0; i1 < tbjlDOList.size(); i1++) {
                        //异常数据过滤
                        if (tbjlDOList.get(i1).getSbkssj() != null) {
                            TrendChartVO trendChartVO = new TrendChartVO();
                            if(getDay(tbjlDOList.get(i1).getSbkssj()).equals("2019-12-30")) {
                            	timeList.add(getWhereWeek("2020-01-01"));
                            	try {
									monthTimeList.add(getMonth(simpleDateFormat.parse("2020-01-01")));
								} catch (ParseException e) {
									e.printStackTrace();
								}
                            }else {
                            	timeList.add(getWhereWeek(getDay(tbjlDOList.get(i1).getSbkssj())));
                            	monthTimeList.add(getMonth(tbjlDOList.get(i1).getSbkssj()));
                            }
                            // timeList.add(getWhereWeek(getDay(tbjlDOList.get(i1).getSbkssj())));                  
                            // monthTimeList.add(getMonth(tbjlDOList.get(i1).getSbkssj()));
                            List<String> indicatorList1 = new ArrayList<>();
                            Map<String, Object> queryMap = new HashMap<>();
                            queryMap.put("id", tbjlDOList.get(i1).getId());
                            if (indicatorTypes.get(i).equals("原粮")) {
                                queryMap.put("pzlb", "1");
                            } else if (indicatorTypes.get(i).equals("成品粮")) {
                                queryMap.put("pzlb", "2");
                            } else if (indicatorTypes.get(i).equals("油料类")) {
                                queryMap.put("pzlb", "3");
                            } else {
                                queryMap.put("pzlb", "4");
                            }

                            queryMap.put("indicators", priceTrendQueryVO.getIndicators());
                            queryMap.put("priceType", priceTrendQueryVO.getPriceType());
                            if (priceTrendQueryVO.getPriceDateType() != null && "周报".equals(priceTrendQueryVO.getPriceDateType())) {
                            	if(getDay(tbjlDOList.get(i1).getSbkssj()).equals("2019-12-30")) {
                            		trendChartVO.setLable(getWhereWeek("2020-01-01"));
                            	}else {
                            		trendChartVO.setLable(getWhereWeek(getDay(tbjlDOList.get(i1).getSbkssj())));
                            	}
                                // trendChartVO.setLable(getWhereWeek(getDay(tbjlDOList.get(i1).getSbkssj())));
                                trendChartVO.setProp("price" + (i1 + 1));
                                timeMap.put("price" + (i1 + 1), getDay(tbjlDOList.get(i1).getSbkssj()) + "至" + getDay(tbjlDOList.get(i1).getSbjssj()));
                            } else {
                                trendChartVO.setLable(getMonth(tbjlDOList.get(i1).getSbkssj()));
                                timeMap.put("price" + (i1 + 1), getMonth(tbjlDOList.get(i1).getSbkssj()));
                                trendChartVO.setProp("price" + (i1 + 1));
                            }
                            headList.add(trendChartVO);
                            //获取日报表指标及详情
                            List<IndicatorReportVO> indicatorReportVOList = bbLxDao.selectIndicatorByQuery(queryMap);

                            /*List<LyjgInfoDO> lyjgInfoDOList = lyjgDao.selectInfoByQuery(queryMap);*/
                            if (seriesLists != null && seriesLists.size() > 0) {
                                if (indicatorReportVOList != null) {
                                    for (int i2 = 0; i2 < indicatorReportVOList.size(); i2++) {
                                        queryMap.put("indicator", indicatorReportVOList.get(i2).getPzmc());
                                        queryMap.put("jlbz", indicatorReportVOList.get(i2).getJlbz());
                                        String price = tbjlDao.selectPriceByMap(queryMap);
                                        List<String> priceList = (List<String>) seriesLists.get(i2).get("data");
                                        Map<String, Object> priceMap = pricesList.get(i2);
                                        if (price != null) {
                                            priceMap.put("price" + (i1 + 1), getDoubleString(Double.parseDouble(price)));
                                            priceList.add(price);
                                        } else {
                                            priceMap.put("price" + (i1 + 1), "0.0");
                                            priceList.add("0.0");
                                        }

                                    }
                                }
                            } else {
                                //获取粮油价格信息
                                if (indicatorReportVOList != null) {
                                    for (int i2 = 0; i2 < indicatorReportVOList.size(); i2++) {
                                        Map<String, Object> seriesMap = new HashMap<>();
                                        Map<String, Object> priceMap = new HashMap<>();
                                        //设置表格行属性设置坐标属性值
                                        if (indicatorReportVOList.get(i2).getJlbz() != null) {
                                            priceMap.put("name", indicatorReportVOList.get(i2).getPzmc() + "(" + indicatorReportVOList.get(i2).getJlbz() + ")");
                                            seriesMap.put("name", indicatorReportVOList.get(i2).getPzmc() + "(" + indicatorReportVOList.get(i2).getJlbz() + ")");
                                        } else {
                                            priceMap.put("name", indicatorReportVOList.get(i2).getPzmc());
                                            seriesMap.put("name", indicatorReportVOList.get(i2).getPzmc());
                                        }

                                        List<String> priceList = new ArrayList<>();
                                        queryMap.put("indicator", indicatorReportVOList.get(i2).getPzmc());
                                        queryMap.put("jlbz", indicatorReportVOList.get(i2).getJlbz());
                                        String price = tbjlDao.selectPriceByMap(queryMap);
                                        if (price != null) {
                                            priceMap.put("price" + (i1 + 1), getDoubleString(Double.parseDouble(price)));
                                            priceList.add(price);
                                        } else {
                                            priceMap.put("price" + (i1 + 1), "0.0");
                                            priceList.add("0.0");
                                        }

                                        indicatorList1.add(indicatorReportVOList.get(i2).getPzmc() + "(" + indicatorReportVOList.get(i2).getJlbz() + ")");
                                        seriesMap.put("data", priceList);
                                        seriesLists.add(seriesMap);
                                        pricesList.add(priceMap);
                                    }
                                    indicatorList = indicatorList1;
                                }
                            }
                        }
                    }
                }
                List<Map<String, Object>> listMap = new ArrayList<>();
                map.put("lineList", headList);
                map.put("pricesList", pricesList);
                map.put("legend", indicatorList);
                map.put("xAxisDay", timeList);
                map.put("xAxisMonth", monthTimeList);
                map.put("series", seriesLists);
                resultMap.put("ZBLB", map);
                list.add(resultMap);
            }
        }
        return list;
    }

    /**
     * @param bblxId
     * @return ResponseWrapper
     * @Description: 价格走势根据报表类型获取指标列表
     * @date 2019年8月16日, 下午5:54:00
     * @author 任宇
     * @version v1.0
     */
    public List<IndicatorReportVO> getChartIndicator(String bblxId) {
        List<IndicatorReportVO> indicatorReportVOList = bbLxDao.selectChartIndicator(bblxId);
        if (indicatorReportVOList != null) {
            for (IndicatorReportVO indicatorReportVO : indicatorReportVOList) {
                if (indicatorReportVO.getJlbz() != null) {
                    indicatorReportVO.setPzmc(indicatorReportVO.getPzmc());
                }
            }
        }
        return indicatorReportVOList;
    }

    /**
     * @param priceTrendQueryVO
     * @return ResponseWrapper
     * @Description: 查询报表类型对应指标(指标和等级 一对多关联)
     * @date 2019年8月16日, 下午5:54:00
     * @author 任宇
     * @version v1.0
     */
    public List<ReportTypeIndicatorVO> getIndicatorOfBz(PriceTrendQueryVO priceTrendQueryVO) {
        return bbLxDao.selectIndicatorOfBz(priceTrendQueryVO);
    }


    /**
     * @param reportRecordInfoVO
     * @return ResponseWrapper
     * @Description: 查询监测点指定时间是否已上报数据
     * @date 2019年8月16日, 下午5:54:00
     * @author 任宇
     * @version v1.0
     */
    public Integer isReport(ReportRecordInfoVO reportRecordInfoVO) {
        Map<String, Object> map = new HashMap<>();
        map.put("pointId", reportRecordInfoVO.getOrgId());
        map.put("sbkssj", reportRecordInfoVO.getSbkssj().trim());
        map.put("priceType", reportRecordInfoVO.getBblxId());
        Integer count = tbjlDao.selectByPointAndTime(map);
        return count;
    }

    /**
     * @param reportRecordInfoVO
     * @return ResponseWrapper
     * @Description: 查询监测点指定时间是否已上报数据
     * @date 2019年8月16日, 下午5:54:00
     * @author 任宇
     * @version v1.0
     */
    public TbjlDO selectByEntity(ReportRecordInfoVO reportRecordInfoVO) {
        Map<String, Object> map = new HashMap<>();
        map.put("pointId", reportRecordInfoVO.getOrgId());
        map.put("sbkssj", reportRecordInfoVO.getSbkssj().trim());
        map.put("priceType", reportRecordInfoVO.getBblxId());
        return tbjlDao.selectByEntity(map);
    }

    /**
     * @param taskVO
     * @return ResponseWrapper
     * @Description: 任务调度根据上一期价格新增数据
     * @date 2019年8月16日, 下午5:54:00
     * @author 任宇
     * @version v1.0
     */
    public void taskAdd(TaskVO taskVO) {
        //上期填报记录
        TbjlDO tbjlDO = tbjlDao.selectLastReport(taskVO);
        if (tbjlDO != null) {
            //新增当日记录
            TbjlDO newTbjlDO = new TbjlDO();
            newTbjlDO.setId(UUIDUtils.uuid());
            newTbjlDO.setCreateTime(new Date());
            newTbjlDO.setBblxId(taskVO.getPriceType());

            //设置时间为上一周周一和周日
            Map<String, Object> map = getWeekDate1();
            Date monday = getLastWeekDate((Date) map.get("mondayDate"));
            Date sunday = getLastWeekDate((Date) map.get("sundayDate"));

            newTbjlDO.setSbkssj(monday);
            newTbjlDO.setSbjssj(sunday);
            newTbjlDO.setLcid("2");
            newTbjlDO.setOrgId(tbjlDO.getOrgId());
            newTbjlDO.setOrgName(tbjlDO.getOrgName());
            newTbjlDO.setDeptName(tbjlDO.getDeptName());
            newTbjlDO.setDeptId(tbjlDO.getDeptId());
            newTbjlDO.setAreaCode(tbjlDO.getAreaCode());
            newTbjlDO.setAreaName(tbjlDO.getAreaName());
            tbjlDao.insert(newTbjlDO);
            //获取粮油价格信息
            List<LyjgInfoDO> lyjgInfoDOList = lyjgDao.selectTjInfoByFid(tbjlDO.getId());
            if (lyjgInfoDOList != null) {
                for (LyjgInfoDO lyjgInfoDO : lyjgInfoDOList) {
                    LyjgDO lyjgDO = new LyjgDO();
                    LsBeanUtils.copyPropertiesIgnoreNull(lyjgInfoDO, lyjgDO);
                    lyjgDO.setId(UUIDUtils.uuid());
                    lyjgDO.setTbjlId(newTbjlDO.getId());
                    //保存粮油价格信息
                    lyjgDao.insert(lyjgDO);

                    LyjgmxDO lyjgmxDO = new LyjgmxDO();
                    LsBeanUtils.copyPropertiesIgnoreNull(lyjgInfoDO, lyjgmxDO);
                    if (lyjgInfoDO.getSqjg() != null) {
                        //修复自动生成的上期价格错误问题
                        // lyjgmxDO.setSqjg(Double.parseDouble(getDoubleString(lyjgInfoDO.getSqjg())));
                        //lyjgmxDO.setSqjg(Double.parseDouble(getDoubleString(lyjgInfoDO.getBqjg())));
                        if(lyjgInfoDO.getBqjg() != null) {
                            lyjgmxDO.setSqjg(Double.parseDouble(getDoubleString(lyjgInfoDO.getBqjg())));
                        }
                    }
                    if (lyjgInfoDO.getBqjg() != null) {
                        lyjgmxDO.setBqjg(Double.parseDouble(getDoubleString(lyjgInfoDO.getBqjg())));
                    }
                    lyjgmxDO.setId(UUIDUtils.uuid());
                    lyjgmxDO.setLyjgId(lyjgDO.getId());

                    //保存粮油明细信息
                    lyjgmxDao.insert(lyjgmxDO);
                }
            }

        }

    }

    /**
     * @param bDate
     * @return ResponseWrapper
     * @Description: 判断是否为星期六日
     * @date 2019年8月16日, 下午5:54:00
     * @author 任宇
     * @version v1.0
     */
    public Boolean isWeekend(String bDate) {
        SimpleDateFormat format1 = new SimpleDateFormat("yyyy-MM-dd");
        Date bdate = null;
        try {
            bdate = format1.parse(bDate);
        } catch (ParseException e) {
            e.printStackTrace();
        }
        Calendar cal = Calendar.getInstance();
        cal.setTime(bdate);
        if (cal.get(Calendar.DAY_OF_WEEK) == Calendar.SATURDAY || cal.get(Calendar.DAY_OF_WEEK) == Calendar.SUNDAY) {
            return true;
        } else {
            return false;
        }

    }

    /**
     * @param bblxId
     * @return ResponseWrapper
     * @Description: 根据日报类型获取对应月报类型
     * @date 2019年8月16日, 下午5:54:00
     * @author 任宇
     * @version v1.0
     */
    public String getMonthPriceType(String bblxId) {
        return bbLxDao.selectMonthByDay(bblxId);
    }

    /**
     * @param
     * @return ResponseWrapper
     * @Description: 收购季周报上报
     * @date
     * @author renyu
     * @version v1.0
     */
    public void quarterlyReport(QuarterlyReportVO quarterlyReportVO) {
            TbjlDO tbjlDO1 = new TbjlDO();
            LsBeanUtils.copyPropertiesIgnoreNull(quarterlyReportVO, tbjlDO1);
            tbjlDO1.setSbkssj(getDate(quarterlyReportVO.getSbkssj()));
            tbjlDO1.setSbjssj(getDate(quarterlyReportVO.getSbjssj()));
            tbjlDO1.setOrgId(quarterlyReportVO.getOrgId());
            if(tbjlDao.selectCountByExample(tbjlDO1)<1) {
            TbjlDO tbjlDO = new TbjlDO();
            LsBeanUtils.copyPropertiesIgnoreNull(quarterlyReportVO, tbjlDO);
            tbjlDO.setCreateTime(new Date());
            tbjlDO.setId(UUIDUtils.uuid());
            tbjlDO.setSbkssj(getDate(quarterlyReportVO.getSbkssj()));
            tbjlDO.setSbjssj(getDate(quarterlyReportVO.getSbjssj()));
        tbjlDO.setLcid(quarterlyReportVO.getLcid());
        tbjlDao.insert(tbjlDO);


        QuarterlyPriceVO quarterlyPriceVO = quarterlyReportVO.getQuarterlyPriceVO();
        //玉米
        LyjgDO lyjgDO = new LyjgDO();
        lyjgDO.setId(UUIDUtils.uuid());
        lyjgDO.setTbjlId(tbjlDO.getId());
        lyjgDO.setPzmc("玉米");
        lyjgDO.setXh(1);
        lyjgDao.insert(lyjgDO);

        //玉米地方贸易明细
        LyjgmxDO lyjgmxDO = new LyjgmxDO();
        lyjgmxDO.setId(UUIDUtils.uuid());
        lyjgmxDO.setLyjgId(lyjgDO.getId());
        lyjgmxDO.setJglx("地方贸易");
        lyjgmxDO.setSqjg(quarterlyPriceVO.getPlacePrice());
        lyjgmxDO.setSbsl(Double.valueOf(quarterlyPriceVO.getPlaceNum().toString()));
        lyjgmxDao.insert(lyjgmxDO);

        //玉米深加工企业明细
        LyjgmxDO lyjgmxDO1 = new LyjgmxDO();
        lyjgmxDO1.setId(UUIDUtils.uuid());
        lyjgmxDO1.setLyjgId(lyjgDO.getId());
        lyjgmxDO1.setJglx("深加工企业");
        lyjgmxDO1.setSqjg(quarterlyPriceVO.getBusinessPrice());
        lyjgmxDO1.setSbsl(Double.valueOf(quarterlyPriceVO.getBusinessNum().toString()));
        lyjgmxDao.insert(lyjgmxDO1);

        //玉米中粮贸易公司明细
        LyjgmxDO lyjgmxDO2 = new LyjgmxDO();
        lyjgmxDO2.setId(UUIDUtils.uuid());
        lyjgmxDO2.setLyjgId(lyjgDO.getId());
        lyjgmxDO2.setJglx("中粮贸易公司");
        lyjgmxDO2.setSqjg(quarterlyPriceVO.getCompanyPrice());
        lyjgmxDO2.setSbsl(Double.valueOf(quarterlyPriceVO.getCompanyNum().toString()));
        lyjgmxDao.insert(lyjgmxDO2);

        //玉米累计明细
        LyjgmxDO lyjgmxDO3 = new LyjgmxDO();
        lyjgmxDO3.setId(UUIDUtils.uuid());
        lyjgmxDO3.setLyjgId(lyjgDO.getId());
        lyjgmxDO3.setJglx("累计");
        lyjgmxDO3.setSqzgjg(quarterlyReportVO.getYmMaxPrice());
        lyjgmxDO3.setSqzdjg(quarterlyReportVO.getYmMinPrice());
        lyjgmxDO3.setSbsl(Double.valueOf(quarterlyReportVO.getYmNum().toString()));
        lyjgmxDao.insert(lyjgmxDO3);

        //大豆
        LyjgDO lyjgDO1 = new LyjgDO();
        lyjgDO1.setId(UUIDUtils.uuid());
        lyjgDO1.setTbjlId(tbjlDO.getId());
        lyjgDO1.setPzmc("大豆");
        lyjgDO1.setXh(2);
        lyjgDao.insert(lyjgDO1);

        //大豆累计明细
        LyjgmxDO lyjgmxDO4 = new LyjgmxDO();
        lyjgmxDO4.setId(UUIDUtils.uuid());
        lyjgmxDO4.setLyjgId(lyjgDO1.getId());
        lyjgmxDO4.setJglx("累计");
        lyjgmxDO4.setSqzgjg(quarterlyPriceVO.getDdMaxPrice());
        lyjgmxDO4.setSqzdjg(quarterlyPriceVO.getDdMinPrice());
        lyjgmxDO4.setSbsl(Double.valueOf(quarterlyPriceVO.getDdNum().toString()));
        lyjgmxDao.insert(lyjgmxDO4);
    }else{
                quarterlyReportupdate(quarterlyReportVO);

            }

}
    //String转date
    public Date getDate(String time){
        if(time != null && !"".equals(time)){
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
            try {
                return sdf.parse(time);
            } catch (ParseException e) {
                e.printStackTrace();
            }
        }
        return null;
    }

    /**
     * @Description: 收购季周报查询
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return List
     */
    public List<QuarterlyReportVO> quarterlyQuery(QuarterlyReportInputVO quarterlyReportInputVO) {
        List<TbjlDO> tbjlDOList = tbjlDao.selectQuarterlyQuery(quarterlyReportInputVO);
        List<QuarterlyReportVO> quarterlyReportVOList = new ArrayList<>();
        if(tbjlDOList != null && tbjlDOList.size() > 0){
            QuarterlyReportVO quarterlyReportVOS = new QuarterlyReportVO();
            QuarterlyPriceVO quarterlyPriceVOS = new QuarterlyPriceVO();
            quarterlyReportVOS.setAreaName("合计");
            quarterlyReportVOS.setOrgName("合计");
            for (TbjlDO tbjlDO : tbjlDOList) {
                QuarterlyReportVO quarterlyReportVO = new QuarterlyReportVO();
                LsBeanUtils.copyPropertiesIgnoreNull(tbjlDO, quarterlyReportVO);
                quarterlyReportVO.setSbkssj(getDay(tbjlDO.getSbkssj()));
                quarterlyReportVO.setSbjssj(getDay(tbjlDO.getSbjssj()));
                QuarterlyPriceVO quarterlyPriceVO = new QuarterlyPriceVO();
                List<LyjgDO> lyjgDOList = lyjgDao.selectInfoByFid(tbjlDO.getId());
                if(lyjgDOList != null){
                    for (int i = 0; i < lyjgDOList.size(); i++) {
                        List<LyjgmxDO> lyjgmxDOList = lyjgmxDao.selectInfoByFid(lyjgDOList.get(i).getId());

                        if(lyjgmxDOList != null ){
                            if(lyjgDOList.get(i).getPzmc().equals("玉米")){
                                for (LyjgmxDO lyjgmxDO : lyjgmxDOList) {
                                    if(lyjgmxDO.getJglx().equals("地方贸易")){
                                        quarterlyPriceVO.setPlacePrice(lyjgmxDO.getSqjg());
                                        quarterlyPriceVO.setPlaceNum(lyjgmxDO.getSbsl().intValue());
                                    }else if(lyjgmxDO.getJglx().equals("深加工企业")){
                                        quarterlyPriceVO.setBusinessPrice(lyjgmxDO.getSqjg());
                                        quarterlyPriceVO.setBusinessNum(lyjgmxDO.getSbsl().intValue());
                                    }else if(lyjgmxDO.getJglx().equals("中粮贸易公司")){
                                        quarterlyPriceVO.setCompanyPrice(lyjgmxDO.getSqjg());
                                        quarterlyPriceVO.setCompanyNum(lyjgmxDO.getSbsl().intValue());
                                    }else if(lyjgmxDO.getJglx().equals("累计")){
                                        quarterlyPriceVO.setYmMaxPrice(lyjgmxDO.getSqzgjg());
                                        quarterlyPriceVO.setYmMinPrice(lyjgmxDO.getSqzdjg());
                                        quarterlyPriceVO.setYmNum(lyjgmxDO.getSbsl().intValue());
                                    }
                                }
                            }else{
                                for (LyjgmxDO lyjgmxDO : lyjgmxDOList) {
                                    quarterlyPriceVO.setDdMaxPrice(lyjgmxDO.getSqzgjg());
                                    quarterlyPriceVO.setDdMinPrice(lyjgmxDO.getSqzdjg());
                                    quarterlyPriceVO.setDdNum(lyjgmxDO.getSbsl().intValue());
                                }
                            }
                        }
                    }
                }
                //收购量
                quarterlyReportVO.setQuarterlyPriceVO(quarterlyPriceVO);
                quarterlyReportVOList.add(quarterlyReportVO);
                quarterlyPriceVOS.setYmNum((quarterlyPriceVOS.getYmNum()==null) ? quarterlyPriceVO.getYmNum() : quarterlyPriceVOS.getYmNum()+quarterlyPriceVO.getYmNum());
                quarterlyPriceVOS.setPlaceNum((quarterlyPriceVOS.getPlaceNum()==null) ? quarterlyPriceVO.getPlaceNum() : quarterlyPriceVOS.getPlaceNum()+quarterlyPriceVO.getPlaceNum());
                quarterlyPriceVOS.setDdNum( (quarterlyPriceVOS.getDdNum()==null) ? quarterlyPriceVO.getDdNum() : quarterlyPriceVOS.getDdNum()+quarterlyPriceVO.getDdNum());
                quarterlyPriceVOS.setCompanyNum( (quarterlyPriceVOS.getCompanyNum()==null) ? quarterlyPriceVO.getCompanyNum() : quarterlyPriceVOS.getCompanyNum()+quarterlyPriceVO.getCompanyNum());
                quarterlyPriceVOS.setBusinessNum( (quarterlyPriceVOS.getBusinessNum()==null) ? quarterlyPriceVO.getBusinessNum() : quarterlyPriceVOS.getBusinessNum()+quarterlyPriceVO.getBusinessNum());
                //收购价格
                quarterlyPriceVOS.setPlacePrice((quarterlyPriceVOS.getPlacePrice()==null) ? quarterlyPriceVO.getPlacePrice() : quarterlyPriceVOS.getPlacePrice()+quarterlyPriceVO.getPlacePrice());
                quarterlyPriceVOS.setCompanyPrice( (quarterlyPriceVOS.getCompanyPrice()==null) ? quarterlyPriceVO.getCompanyPrice() : quarterlyPriceVOS.getCompanyPrice()+quarterlyPriceVO.getCompanyPrice());
                quarterlyPriceVOS.setBusinessPrice( (quarterlyPriceVOS.getBusinessPrice()==null) ? quarterlyPriceVO.getBusinessPrice() : quarterlyPriceVOS.getBusinessPrice()+quarterlyPriceVO.getBusinessPrice());
                //价格区间
                quarterlyPriceVOS.setYmMinPrice((quarterlyPriceVOS.getYmMinPrice() != null && quarterlyPriceVOS.getYmMinPrice() < quarterlyPriceVO.getYmMinPrice()) ? quarterlyPriceVOS.getYmMinPrice() : quarterlyPriceVO.getYmMinPrice() );
                quarterlyPriceVOS.setYmMaxPrice((quarterlyPriceVOS.getYmMaxPrice() != null && quarterlyPriceVOS.getYmMaxPrice() > quarterlyPriceVO.getYmMaxPrice()) ? quarterlyPriceVOS.getYmMaxPrice() : quarterlyPriceVO.getYmMaxPrice() );
                quarterlyPriceVOS.setDdMinPrice((quarterlyPriceVOS.getDdMinPrice() != null && quarterlyPriceVOS.getDdMinPrice() < quarterlyPriceVO.getDdMinPrice()) ? quarterlyPriceVOS.getDdMinPrice() : quarterlyPriceVO.getDdMinPrice() );
                quarterlyPriceVOS.setDdMaxPrice((quarterlyPriceVOS.getDdMaxPrice() != null && quarterlyPriceVOS.getDdMaxPrice() > quarterlyPriceVO.getDdMaxPrice()) ? quarterlyPriceVOS.getDdMaxPrice() : quarterlyPriceVO.getDdMaxPrice());
            }
            quarterlyReportVOS.setQuarterlyPriceVO(quarterlyPriceVOS);
            quarterlyReportVOList.add(0,quarterlyReportVOS);
        }
        return quarterlyReportVOList;
    }

    public List<TbjlDO> getAllList(PriceTrendQueryVO priceTrendQueryVO) {
        List<TbjlDO> tbjlDOList = tbjlDao.selectPriceTrend(priceTrendQueryVO);
        return tbjlDOList;
    }

    public List<IndicatorReportVO> getIndicatorByBblx(String priceType) {
        List<IndicatorReportVO> indicatorReportVOList = bbLxDao.selectIndicatorByBblx1(priceType);
        return indicatorReportVOList;
    }
    /**
     * @Description: 收购季周报查询
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return List
     */
    public List<QuarterlyReportVO> quarterlyQueryBy(QuarterlyReportInputVO quarterlyReportInputVO) {
        List<TbjlDO> tbjlDOList = tbjlDao.selectQuarterlyQuery(quarterlyReportInputVO);
        List<QuarterlyReportVO> quarterlyReportVOList = new ArrayList<>();
        if(tbjlDOList != null && tbjlDOList.size() > 0){
            for (TbjlDO tbjlDO : tbjlDOList) {
                QuarterlyReportVO quarterlyReportVO = new QuarterlyReportVO();
                LsBeanUtils.copyPropertiesIgnoreNull(tbjlDO, quarterlyReportVO);
                quarterlyReportVO.setSbkssj(getDay(tbjlDO.getSbkssj()));
                quarterlyReportVO.setSbjssj(getDay(tbjlDO.getSbjssj()));
                QuarterlyPriceVO quarterlyPriceVO = new QuarterlyPriceVO();
                List<LyjgDO> lyjgDOList = lyjgDao.selectInfoByFid(tbjlDO.getId());
                if(lyjgDOList != null){
                    for (int i = 0; i < lyjgDOList.size(); i++) {
                        List<LyjgmxDO> lyjgmxDOList = lyjgmxDao.selectInfoByFid(lyjgDOList.get(i).getId());

                        if(lyjgmxDOList != null ){
                            if(lyjgDOList.get(i).getPzmc().equals("玉米")){
                                for (LyjgmxDO lyjgmxDO : lyjgmxDOList) {
                                    if(lyjgmxDO.getJglx().equals("地方贸易")){
                                        quarterlyPriceVO.setIddf(lyjgmxDO.getId());
                                        quarterlyPriceVO.setPlacePrice(lyjgmxDO.getSqjg());
                                        quarterlyPriceVO.setPlaceNum(lyjgmxDO.getSbsl().intValue());
                                    }else if(lyjgmxDO.getJglx().equals("深加工企业")){
                                        quarterlyPriceVO.setIdsjg(lyjgmxDO.getId());
                                        quarterlyPriceVO.setBusinessPrice(lyjgmxDO.getSqjg());
                                        quarterlyPriceVO.setBusinessNum(lyjgmxDO.getSbsl().intValue());
                                    }else if(lyjgmxDO.getJglx().equals("中粮贸易公司")){
                                        quarterlyPriceVO.setIdzl(lyjgmxDO.getId());
                                        quarterlyPriceVO.setIdymlj(lyjgmxDO.getId());
                                        quarterlyPriceVO.setCompanyPrice(lyjgmxDO.getSqjg());
                                        quarterlyPriceVO.setCompanyNum(lyjgmxDO.getSbsl().intValue());
                                    }else if(lyjgmxDO.getJglx().equals("累计")){
                                        quarterlyPriceVO.setIdymlj(lyjgmxDO.getId());
                                        quarterlyPriceVO.setYmMaxPrice(lyjgmxDO.getSqzgjg());
                                        quarterlyPriceVO.setYmMinPrice(lyjgmxDO.getSqzdjg());
                                        quarterlyPriceVO.setYmNum(lyjgmxDO.getSbsl().intValue());
                                    }
                                }
                            }else{
                                for (LyjgmxDO lyjgmxDO : lyjgmxDOList) {
                                    quarterlyPriceVO.setIddd(lyjgmxDO.getId());
                                    quarterlyPriceVO.setDdMaxPrice(lyjgmxDO.getSqzgjg());
                                    quarterlyPriceVO.setDdMinPrice(lyjgmxDO.getSqzdjg());
                                    quarterlyPriceVO.setDdNum(lyjgmxDO.getSbsl().intValue());
                                }
                            }
                        }
                    }
                }
                quarterlyReportVO.setQuarterlyPriceVO(quarterlyPriceVO);
                quarterlyReportVOList.add(quarterlyReportVO);
            }
        }
        return quarterlyReportVOList;
    }
    /**
     * @Description: 判断当前盟市下监测点是否全部上报数据
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    public Boolean isEnough(Map<String, Object> map) {
        Integer num = tbjlDao.selectNumByQuery(map);
        System.out.println(num);
        Integer trueNum = Integer.parseInt(map.get("num").toString());
        System.out.println(trueNum);

        if(trueNum > num){
            return false;
        }else{
            return true;
        }
    }

    /**
     *
     * 当期是否存在驳回数据
     * @return
     */
    public boolean hasNotReport(String orgId){
        ReportRecordListVO reportRecordListVO = new ReportRecordListVO();
        Map<String, Object> weekDate = getWeekDate();
        String startDate = getDay((Date)weekDate.get("mondayDate"));
        String endDate = getDay((Date)weekDate.get("sundayDate"));
        reportRecordListVO.setStartDate(startDate);
        reportRecordListVO.setEndDate(endDate);
        reportRecordListVO.setReportStatus("3");
        reportRecordListVO.setOrgId(orgId);
        List<TbjlDO> tbjlDOS = tbjlDao.selectByQuery(reportRecordListVO);
        if (tbjlDOS !=null && tbjlDOS.size()!=0){
            return true;
        }
        return false;
    }

    /**
     * @Description: 发布当期上报数据
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    public void release(Map<String, Object> map) {
        tbjlDao.updateByMap(map);
    }

    /**
     * @Description: 生成当期本级数据
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    public void level(Map<String, Object> map) {
        tbjlDao.updateLevel(map);
    }

    /**
     * @Description: 预警规则新增
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    public void saveWarningRole(WarningRoleVO warningRoleVO) {
        YjgzDO yjgzDO = LsBeanUtils.copyProperties(warningRoleVO,YjgzDO.class);
        yjgzDO.setId(UUIDUtils.uuid());
        for (WarningMxVO warningMxVO:warningRoleVO.getJgmx()){
            YjgzmxDO yjgzmxDO = LsBeanUtils.copyProperties(warningMxVO,YjgzmxDO.class);
            yjgzmxDO.setId(UUIDUtils.uuid());
            yjgzmxDO.setYjgzid(yjgzDO.getId());
            yjgzMxDao.insert(yjgzmxDO);
        }
        yjgzDao.insert(yjgzDO);
    }

    /**
     * @Description: 预警规则编辑
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    public void updateWarningRole(WarningRoleVO warningRoleVO) {
        YjgzDO yjgzDO = LsBeanUtils.copyProperties(warningRoleVO,YjgzDO.class);
        yjgzDao.updateByPrimaryKeySelective(yjgzDO);
        for (WarningMxVO warningMxVO:warningRoleVO.getJgmx()){
            YjgzmxDO yjgzmxDO = LsBeanUtils.copyProperties(warningMxVO,YjgzmxDO.class);
            yjgzMxDao.updateByPrimaryKeySelective(yjgzmxDO);
        }

    }

    public WarningRoleVO getWarningRole(String id) {
        YjgzDO yjgzDO = yjgzDao.selectByPrimaryKey(id);
        WarningRoleVO warningRoleVO = LsBeanUtils.copyProperties(yjgzDO,WarningRoleVO.class);
        List<WarningMxVO> warningMxVOList = yjgzMxDao.selectListById(warningRoleVO.getId());
        warningRoleVO.setJgmx(warningMxVOList);
        return warningRoleVO;
    }

    public void deleteWarningRole(String id) {
        yjgzDao.deleteByPrimaryKey(id);
        List<WarningMxVO> warningMxVOList = yjgzMxDao.selectListById(id);
        for(WarningMxVO warningMxVO : warningMxVOList){
            yjgzMxDao.deleteByPrimaryKey(warningMxVO.getId());
        }
    }

    public Map<String, Object> getWarningRoles(WarningRoleQueryVO warningRoleQueryVO) {
        Map<String,Object> result = new HashMap<>();
        PageHelper.startPage(warningRoleQueryVO.getPage(), warningRoleQueryVO.getSize());
        List<WarningRoleVO> warningRoleVOList = yjgzDao.selectList(warningRoleQueryVO);
        for (WarningRoleVO warningRoleVO:warningRoleVOList){
            List<WarningMxVO> warningMxVOList = yjgzMxDao.selectListById(warningRoleVO.getId());
            warningRoleVO.setJgmx(warningMxVOList);
        }
        PageInfo<WarningRoleVO> pageInfo = new PageInfo<WarningRoleVO>(warningRoleVOList);
        //查所有价格类型
        Example example = new Example(JglxDO.class);
        Example.Criteria criteria = example.createCriteria();
        criteria.andIsNull("deleteTime");
        List<JglxDO> resultDOList = jgLxDao.selectByExample(example);
        List temList = new ArrayList();
        if (!resultDOList.isEmpty()) {
            for (JglxDO resultDO : resultDOList) {
                temList.add(resultDO.getPriceTypeName());
            }
        }
        result.put("priceTypeName",temList);
        result.put("total", pageInfo.getTotal());
        result.put("resultList", warningRoleVOList);
        return result;

    }

    public String getWhereWeek(String time){
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
        Date date = null;
        try {
            date = format.parse(time);
        } catch (ParseException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }

        Calendar calendar = Calendar.getInstance();
        calendar.setFirstDayOfWeek(Calendar.MONDAY);
        calendar.setTime(date);

        System.out.println(calendar.get(Calendar.WEEK_OF_YEAR));
        return calendar.get(Calendar.YEAR) + "年" + calendar.get(Calendar.WEEK_OF_YEAR) + "周";
    }

    public Map<String, Object> getStatistics(String orgId) {
        Map<String, Object> map = new HashMap<>();
        StatisticsOutputVO statisticsOutputVO = tbjlDao.selectStatistics(orgId);
        if(statisticsOutputVO != null){
            map.put("reportNum",statisticsOutputVO.getReportNum());
            map.put("rejectNum",statisticsOutputVO.getRejectNum());
            map.put("updateNum",statisticsOutputVO.getUpdateNum());
        }else{
            map.put("reportNum",0);
            map.put("rejectNum",0);
            map.put("updateNum",0);
        }
        return map;
    }

    public Integer getReportNum(Map<String, Object> queryMap) {
        Integer num = tbjlDao.selectNumByQuery(queryMap);
        return num;
    }


    public void quarterlyReportupdate(QuarterlyReportVO quarterlyReportVO) {
        TbjlDO tbjlDO = new TbjlDO();
        LsBeanUtils.copyPropertiesIgnoreNull(quarterlyReportVO,tbjlDO);

        tbjlDO.setId(quarterlyReportVO.getId());
        tbjlDO.setSbkssj(getDate(quarterlyReportVO.getSbkssj()));
        tbjlDO.setSbjssj(getDate(quarterlyReportVO.getSbjssj()));
        tbjlDO.setSbjssj(getDate(quarterlyReportVO.getSbjssj()));
        tbjlDO.setLcid(quarterlyReportVO.getLcid());
        tbjlDao.update(tbjlDO);
        QuarterlyPriceVO quarterlyPriceVO = quarterlyReportVO.getQuarterlyPriceVO();
        //玉米地方贸易明细QuarterlyReportVO
        LyjgmxDO lyjgmxDO = new LyjgmxDO();
        lyjgmxDO.setId(quarterlyPriceVO.getIddf());
        lyjgmxDO.setSqjg(quarterlyPriceVO.getPlacePrice());
        lyjgmxDO.setSbsl(Double.valueOf(quarterlyPriceVO.getPlaceNum().toString()));
        lyjgmxDao.update(lyjgmxDO);
        //玉米深加工企业明细
        LyjgmxDO lyjgmxDO1 = new LyjgmxDO();
        lyjgmxDO1.setId(quarterlyPriceVO.getIdsjg());
        lyjgmxDO1.setSqjg(quarterlyPriceVO.getBusinessPrice());
        lyjgmxDO1.setSbsl(Double.valueOf(quarterlyPriceVO.getBusinessNum().toString()));
        lyjgmxDao.update(lyjgmxDO1);

        //玉米中粮贸易公司明细
        LyjgmxDO lyjgmxDO2 = new LyjgmxDO();
        lyjgmxDO2.setId(quarterlyPriceVO.getIdzl());
        lyjgmxDO2.setSqjg(quarterlyPriceVO.getCompanyPrice());
        lyjgmxDO2.setSbsl(Double.valueOf(quarterlyPriceVO.getCompanyNum().toString()));
        lyjgmxDao.update(lyjgmxDO2);
        //玉米累计明细
        LyjgmxDO lyjgmxDO3 = new LyjgmxDO();
        lyjgmxDO3.setId(quarterlyPriceVO.getIdymlj());
        lyjgmxDO3.setSqzgjg(quarterlyReportVO.getYmMaxPrice());
        lyjgmxDO3.setSqzdjg(quarterlyReportVO.getYmMinPrice());
        lyjgmxDO3.setSbsl(Double.valueOf(quarterlyReportVO.getYmNum().toString()));
        lyjgmxDao.update(lyjgmxDO3);
        //大豆累计明细
        LyjgmxDO lyjgmxDO4 = new LyjgmxDO();
        lyjgmxDO4.setId(quarterlyPriceVO.getIddd());
        lyjgmxDO4.setSqzgjg(quarterlyPriceVO.getDdMaxPrice());
        lyjgmxDO4.setSqzdjg(quarterlyPriceVO.getDdMinPrice());
        lyjgmxDO4.setSbsl(Double.valueOf(quarterlyPriceVO.getDdNum().toString()));
        lyjgmxDao.update(lyjgmxDO4);
    }

    /**
     * @param
     * @return ResponseWrapper
     * @Description: 价格走势图表(周 / 月)
     * @date
     * @author renyu
     * @version v1.0
     */
    public List<Map<String, Object>> getTrendChartByZs(PriceTrendQueryVO priceTrendQueryVO) {
        Double   yzhSum ;
        //查询报表类型对应周/月的指标类别

        List<Map<String, Object>> list = new ArrayList<>();

        List<String> indicatorTypes = tbjlDao.selectIndicatorType(priceTrendQueryVO);
        if("1".equals(priceTrendQueryVO.getYzh())){
            if (indicatorTypes != null) {
                for (int i = 0; i < indicatorTypes.size(); i++) {
                    Map<String, Object> resultMap = new HashMap<>();
                    Map<String, Object> map = new HashMap<>();
                    map.put("ZBLB", indicatorTypes.get(i));
                    //获取周/月报列表
                    List<TbjlDO> tbjlDOList = tbjlDao.selectTrendChart(priceTrendQueryVO);
                    List<String> timeList = new ArrayList<>();
                    List<String> monthTimeList = new ArrayList<>();
                    List<String> indicatorList = new ArrayList<>();
                    List<Map<String, Object>> seriesLists = new ArrayList<>();
                    List<Map<String, Object>> pricesList = new ArrayList<>();
                    Map<String, Object> timeMap = new HashMap<>();
                    List<TrendChartVO> headList = new ArrayList<>();
                    if (tbjlDOList != null) {
                        for (int i1 = 0; i1 < tbjlDOList.size(); i1++) {
                            //异常数据过滤
                            if (tbjlDOList.get(i1).getSbkssj() != null) {
                                TrendChartVO trendChartVO = new TrendChartVO();
                                timeList.add(getWhereWeek(getDay(tbjlDOList.get(i1).getSbkssj())));
                                monthTimeList.add(getMonth(tbjlDOList.get(i1).getSbkssj()));
                                List<String> indicatorList1 = new ArrayList<>();
                                Map<String, Object> queryMap = new HashMap<>();
                                queryMap.put("id", tbjlDOList.get(i1).getId());
                                if (indicatorTypes.get(i).equals("原粮")) {
                                    queryMap.put("pzlb", "1");
                                } else if (indicatorTypes.get(i).equals("成品粮")) {
                                    queryMap.put("pzlb", "2");
                                } else if (indicatorTypes.get(i).equals("油料类")) {
                                    queryMap.put("pzlb", "3");
                                } else {
                                    queryMap.put("pzlb", "4");
                                }

                                queryMap.put("indicators", priceTrendQueryVO.getIndicators());
                                queryMap.put("priceType", priceTrendQueryVO.getPriceType());
                                if (priceTrendQueryVO.getPriceDateType() != null && "周报".equals(priceTrendQueryVO.getPriceDateType())) {
                                    trendChartVO.setLable(getWhereWeek(getDay(tbjlDOList.get(i1).getSbkssj())));
                                    trendChartVO.setProp("price" + (i1 + 1));
                                    timeMap.put("price" + (i1 + 1), getDay(tbjlDOList.get(i1).getSbkssj()) + "至" + getDay(tbjlDOList.get(i1).getSbjssj()));
                                } else {
                                    trendChartVO.setLable(getMonth(tbjlDOList.get(i1).getSbkssj()));
                                    timeMap.put("price" + (i1 + 1), getMonth(tbjlDOList.get(i1).getSbkssj()));
                                    trendChartVO.setProp("price" + (i1 + 1));
                                }
                                headList.add(trendChartVO);
                                //获取日报表指标及详情
                                List<IndicatorReportVO> indicatorReportVOList = bbLxDao.selectIndicatorByQuery(queryMap);

                                /*List<LyjgInfoDO> lyjgInfoDOList = lyjgDao.selectInfoByQuery(queryMap);*/
                                if (seriesLists != null && seriesLists.size() > 0) {
                                    if (indicatorReportVOList != null) {
                                        for (int i2 = 0; i2 < indicatorReportVOList.size(); i2++) {
                                            queryMap.put("indicator", indicatorReportVOList.get(i2).getPzmc());
                                            queryMap.put("jlbz", indicatorReportVOList.get(i2).getJlbz());
                                   /*     String type = "08综合";
                                        String type1 =priceTrendQueryVO.getPriceType();*/
                                            //权重代码
                                            //   String qzDM = qzjcxxDao.findQzDMByName(type,type1);
                                            String qzDM = "QZ04pNewXevhXstRaosYG";
                                            //计算08综合
                                            //根据权重代码查询权重值
                                            Double qzz = qzzDao.findQzzByQZDM(qzDM,indicatorReportVOList.get(i2).getPzmc());
                                            String price1 = tbjlDao.selectPriceByMapByZs(queryMap);
                                            List<String> priceList = (List<String>) seriesLists.get(i2).get("data");
                                            Map<String, Object> priceMap = pricesList.get(i2);
                                            if (price1 != null) {
                                                Double price = (Double.valueOf(qzz)) * (Double.valueOf(price1));

                                                priceMap.put("price" + (i1 + 1), price);
                                                priceList.add(String.valueOf(price));
                                            } else {
                                                priceMap.put("price" + (i1 + 1), "0.0");
                                                priceList.add("0.0");
                                            }
                                        }
                                    }
                                } else {
                                    //获取粮油价格信息
                                    if (indicatorReportVOList != null) {
                                        for (int i2 = 0; i2 < indicatorReportVOList.size(); i2++) {
                                            Map<String, Object> seriesMap = new HashMap<>();
                                            Map<String, Object> priceMap = new HashMap<>();
                                            //设置表格行属性设置坐标属性值
                                            if (indicatorReportVOList.get(i2).getJlbz() != null) {
                                                priceMap.put("name", indicatorReportVOList.get(i2).getPzmc() +  "(" + indicatorReportVOList.get(i2).getJlbz() + ")");
                                                seriesMap.put("name", indicatorReportVOList.get(i2).getPzmc() + "(" + indicatorReportVOList.get(i2).getJlbz() + ")");
                                            } else {
                                                priceMap.put("name", indicatorReportVOList.get(i2).getPzmc());
                                                seriesMap.put("name", indicatorReportVOList.get(i2).getPzmc());
                                            }

                                            List<String> priceList = new ArrayList<>();
                                            queryMap.put("indicator", indicatorReportVOList.get(i2).getPzmc());
                                            queryMap.put("jlbz", indicatorReportVOList.get(i2).getJlbz());
                                        /*String type = "08综合";
                                        String type1 =priceTrendQueryVO.getPriceType();*/
                                            //权重代码
                                            String qzDM = "QZpR1gC6POn2BhZZjDjwP";
                                            String qzDM1 = indicatorReportVOList.get(i2).getPzmc();
                                            //计算08综合
                                            //根据权重代码查询权重值
                                            Double qzz = qzzDao.findQzzByQZDM(qzDM,qzDM1);
                                            String price1 = tbjlDao.selectPriceByMapByZs(queryMap);
                                            if (price1 != null) {
                                                Double price = (Double.valueOf(qzz)) * (Double.valueOf(price1));

                                                priceMap.put("price" + (i1 + 1), price);
                                                priceList.add(String.valueOf(price));
                                                //  yzhSum += price;
                                            } else {
                                                priceMap.put("price" + (i1 + 1), "0.0");
                                                priceList.add("0.0");
                                            }

                                            indicatorList1.add(indicatorReportVOList.get(i2).getPzmc() + "(" + indicatorReportVOList.get(i2).getJlbz() + ")");
                                            seriesMap.put("data", priceList);
                                            seriesLists.add(seriesMap);
                                            pricesList.add(priceMap);
                                        }
                                        indicatorList = indicatorList1;
                                    }
                                }
                            }
                        }
                    }
                    List<Map<String, Object>> listMap = new ArrayList<>();
                    map.put("lineList", headList);
                    map.put("pricesList", pricesList);
                    map.put("legend", indicatorList);
                    map.put("xAxisDay", timeList);
                    map.put("xAxisMonth", monthTimeList);
                    map.put("series", seriesLists);
                    resultMap.put("ZBLB", map);
                    list.add(resultMap);
                }
            }}
        else {
            if (indicatorTypes != null) {
                for (int i = 0; i < indicatorTypes.size(); i++) {
                    Map<String, Object> resultMap = new HashMap<>();
                    Map<String, Object> map = new HashMap<>();
                    map.put("ZBLB", indicatorTypes.get(i));
                    //获取周/月报列表
                    List<TbjlDO> tbjlDOList = tbjlDao.selectTrendChart(priceTrendQueryVO);
                    List<String> timeList = new ArrayList<>();
                    List<String> monthTimeList = new ArrayList<>();
                    List<String> indicatorList = new ArrayList<>();
                    List<Map<String, Object>> seriesLists = new ArrayList<>();
                    List<Map<String, Object>> pricesList = new ArrayList<>();
                    Map<String, Object> timeMap = new HashMap<>();
                    List<TrendChartVO> headList = new ArrayList<>();
                    if (tbjlDOList != null) {
                        for (int i1 = 0; i1 < tbjlDOList.size(); i1++) {
                            //异常数据过滤
                            if (tbjlDOList.get(i1).getSbkssj() != null) {
                                TrendChartVO trendChartVO = new TrendChartVO();
                                timeList.add(getWhereWeek(getDay(tbjlDOList.get(i1).getSbkssj())));
                                monthTimeList.add(getMonth(tbjlDOList.get(i1).getSbkssj()));
                                List<String> indicatorList1 = new ArrayList<>();
                                Map<String, Object> queryMap = new HashMap<>();
                                queryMap.put("id", tbjlDOList.get(i1).getId());
                                if (indicatorTypes.get(i).equals("原粮")) {
                                    queryMap.put("pzlb", "1");
                                } else if (indicatorTypes.get(i).equals("成品粮")) {
                                    queryMap.put("pzlb", "2");
                                } else if (indicatorTypes.get(i).equals("油料类")) {
                                    queryMap.put("pzlb", "3");
                                } else {
                                    queryMap.put("pzlb", "4");
                                }

                                queryMap.put("indicators", priceTrendQueryVO.getIndicators());
                                queryMap.put("priceType", priceTrendQueryVO.getPriceType());
                                if (priceTrendQueryVO.getPriceDateType() != null && "周报".equals(priceTrendQueryVO.getPriceDateType())) {
                                    trendChartVO.setLable(getWhereWeek(getDay(tbjlDOList.get(i1).getSbkssj())));
                                    trendChartVO.setProp("price" + (i1 + 1));
                                    timeMap.put("price" + (i1 + 1), getDay(tbjlDOList.get(i1).getSbkssj()) + "至" + getDay(tbjlDOList.get(i1).getSbjssj()));
                                } else {
                                    trendChartVO.setLable(getMonth(tbjlDOList.get(i1).getSbkssj()));
                                    timeMap.put("price" + (i1 + 1), getMonth(tbjlDOList.get(i1).getSbkssj()));
                                    trendChartVO.setProp("price" + (i1 + 1));
                                }
                                headList.add(trendChartVO);
                                //获取日报表指标及详情
                                List<IndicatorReportVO> indicatorReportVOList = bbLxDao.selectIndicatorByQuery(queryMap);

                                /*List<LyjgInfoDO> lyjgInfoDOList = lyjgDao.selectInfoByQuery(queryMap);*/
                                if (seriesLists != null && seriesLists.size() > 0) {
                                    if (indicatorReportVOList != null) {
                                        for (int i2 = 0; i2 < indicatorReportVOList.size(); i2++) {
                                            queryMap.put("indicator", indicatorReportVOList.get(i2).getPzmc());
                                            queryMap.put("jlbz", indicatorReportVOList.get(i2).getJlbz());
                                   /*     String type = "08综合";
                                        String type1 =priceTrendQueryVO.getPriceType();*/
                                            //权重代码
                                            //   String qzDM = qzjcxxDao.findQzDMByName(type,type1);
                                            String qzDM = "QZ5HZbfpp8IHVG7vpXano";
                                            //计算08综合
                                            //根据权重代码查询权重值
                                            Double qzz = qzzDao.findQzzByQZDM(qzDM,indicatorReportVOList.get(i2).getPzmc());
                                            String price1 = tbjlDao.selectPriceByMapByZs(queryMap);
                                            List<String> priceList = (List<String>) seriesLists.get(i2).get("data");
                                            Map<String, Object> priceMap = pricesList.get(i2);
                                            if (price1 != null) {
                                                Double price = (Double.valueOf(qzz)) * (Double.valueOf(price1));

                                                priceMap.put("price" + (i1 + 1), price);
                                                priceList.add(String.valueOf(price));
                                            } else {
                                                priceMap.put("price" + (i1 + 1), "0.0");
                                                priceList.add("0.0");
                                            }
                                        }
                                    }
                                } else {
                                    //获取粮油价格信息
                                    if (indicatorReportVOList != null) {
                                        for (int i2 = 0; i2 < indicatorReportVOList.size(); i2++) {
                                            Map<String, Object> seriesMap = new HashMap<>();
                                            Map<String, Object> priceMap = new HashMap<>();
                                            //设置表格行属性设置坐标属性值
                                            if (indicatorReportVOList.get(i2).getJlbz() != null) {
                                                priceMap.put("name", indicatorReportVOList.get(i2).getPzmc() +  "(" + indicatorReportVOList.get(i2).getJlbz() + ")");
                                                seriesMap.put("name", indicatorReportVOList.get(i2).getPzmc() + "(" + indicatorReportVOList.get(i2).getJlbz() + ")");
                                            } else {
                                                priceMap.put("name", indicatorReportVOList.get(i2).getPzmc());
                                                seriesMap.put("name", indicatorReportVOList.get(i2).getPzmc());
                                            }

                                            List<String> priceList = new ArrayList<>();
                                            queryMap.put("indicator", indicatorReportVOList.get(i2).getPzmc());
                                            queryMap.put("jlbz", indicatorReportVOList.get(i2).getJlbz());
                                        /*String type = "08综合";
                                        String type1 =priceTrendQueryVO.getPriceType();*/
                                            //权重代码
                                            String qzDM = "QZ5HZbfpp8IHVG7vpXano";
                                            String qzDM1 = indicatorReportVOList.get(i2).getPzmc();
                                            //计算08综合
                                            //根据权重代码查询权重值
                                            Double qzz = qzzDao.findQzzByQZDM(qzDM,qzDM1);
                                            String price1 = tbjlDao.selectPriceByMapByZs(queryMap);
                                            if (price1 != null) {
                                                Double price = (Double.valueOf(qzz)) * (Double.valueOf(price1));

                                                priceMap.put("price" + (i1 + 1), price);
                                                priceList.add(String.valueOf(price));

                                                //  yzhSum += price;
                                            } else {
                                                priceMap.put("price" + (i1 + 1), "0.0");
                                                priceList.add("0.0");
                                            }

                                            indicatorList1.add(indicatorReportVOList.get(i2).getPzmc() + "(" + indicatorReportVOList.get(i2).getJlbz() + ")");
                                            seriesMap.put("data", priceList);
                                            seriesLists.add(seriesMap);
                                            pricesList.add(priceMap);
                                        }
                                        indicatorList = indicatorList1;
                                    }
                                }
                            }
                        }
                    }
                    List<Map<String, Object>> listMap = new ArrayList<>();
                    map.put("lineList", headList);
                    map.put("pricesList", pricesList);
                    map.put("legend", indicatorList);
                    map.put("xAxisDay", timeList);
                    map.put("xAxisMonth", monthTimeList);
                    map.put("series", seriesLists);
                    resultMap.put("ZBLB", map);
                    list.add(resultMap);
                }
            }}
        return list;
    }

    /**
     * @param priceStatisticsInputVO
     * @return resultMap
     * @Description: 周报月统计
     * @date
     * @author yangshengjie
     * @version v1.0
     */
    public List<Map<String, Object>> getPriceMonthAvg(PriceStatisticsInputVO priceStatisticsInputVO) throws Exception {

        if (priceStatisticsInputVO.getCreateMonth() == null || "".equals(priceStatisticsInputVO.getCreateMonth())) {
            String mon = getLastMonth(new Date());
            priceStatisticsInputVO.setCreateMonth(mon);
        }
        PriceStatisticsAvgVO priceStatisticsAvgVO1 = tbjlDao.selectTimeAvgPrice(priceStatisticsInputVO);


        if (priceStatisticsAvgVO1 != null) {

            priceStatisticsAvgVO1.setName(priceStatisticsInputVO.getStatisticsType());
            priceStatisticsAvgVO1.setCreateMonth(priceStatisticsInputVO.getCreateMonth());

            //计算较月初
            if(priceStatisticsAvgVO1.getStartWPrice() != null &&  priceStatisticsAvgVO1.getEndWPrice() != null && priceStatisticsAvgVO1.getStartWPrice() != 0){
                Double wcs = (priceStatisticsAvgVO1.getEndWPrice() - priceStatisticsAvgVO1.getStartWPrice()) / priceStatisticsAvgVO1.getStartWPrice();
                wcs = wcs * 100;
                priceStatisticsAvgVO1.setWCompareStart(wcs+"%");
            }
            if(priceStatisticsAvgVO1.getStartRPrice() != null && priceStatisticsAvgVO1.getEndRPrice() != null && priceStatisticsAvgVO1.getStartRPrice() != 0){
                Double rcs = (priceStatisticsAvgVO1.getEndRPrice() - priceStatisticsAvgVO1.getStartRPrice()) / priceStatisticsAvgVO1.getStartRPrice();
                rcs = rcs *100;
                priceStatisticsAvgVO1.setRCompareStart(rcs+"%");
            }

            //计算环比
            SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM");
            Date date = simpleDateFormat.parse(priceStatisticsInputVO.getCreateMonth());
            priceStatisticsInputVO.setCreateMonth(getLastMonth(date));
            PriceStatisticsAvgVO priceStatisticsAvgVO2 = tbjlDao.selectTimeAvgPrice(priceStatisticsInputVO);
            if (priceStatisticsAvgVO2 != null) {
                if (priceStatisticsAvgVO1.getAvgWPrice() != null && priceStatisticsAvgVO2.getAvgWPrice() != null && priceStatisticsAvgVO2.getAvgWPrice() != 0) {
                    Double whb = (priceStatisticsAvgVO1.getAvgWPrice() - priceStatisticsAvgVO2.getAvgWPrice()) / priceStatisticsAvgVO2.getAvgWPrice();
                    priceStatisticsAvgVO1.setWhb(whb * 100 + "%");
                }
                if (priceStatisticsAvgVO1.getAvgRPrice() != null && priceStatisticsAvgVO2.getAvgRPrice() != null && priceStatisticsAvgVO2.getAvgRPrice() != 0) {
                    Double rhb = (priceStatisticsAvgVO1.getAvgRPrice() - priceStatisticsAvgVO2.getAvgRPrice()) / priceStatisticsAvgVO2.getAvgRPrice();
                    priceStatisticsAvgVO1.setRhb(rhb * 100 + "%");
                }
            }

            //计算同比
            priceStatisticsInputVO.setCreateMonth(getLastYear(date));
            PriceStatisticsAvgVO priceStatisticsAvgVO3 = tbjlDao.selectTimeAvgPrice(priceStatisticsInputVO);
            if (priceStatisticsAvgVO3 != null) {
                if (priceStatisticsAvgVO1.getAvgWPrice() != null && priceStatisticsAvgVO3.getAvgWPrice() != null && priceStatisticsAvgVO3.getAvgWPrice() != 0) {
                    Double wtb = (priceStatisticsAvgVO1.getAvgWPrice() - priceStatisticsAvgVO3.getAvgWPrice()) / priceStatisticsAvgVO3.getAvgWPrice();
                    priceStatisticsAvgVO1.setWtb(wtb * 100 + "%");
                }
                if (priceStatisticsAvgVO1.getAvgRPrice() != null && priceStatisticsAvgVO3.getAvgRPrice() != null && priceStatisticsAvgVO3.getAvgRPrice() != 0) {
                    Double rtb = (priceStatisticsAvgVO1.getAvgRPrice() - priceStatisticsAvgVO3.getAvgRPrice()) / priceStatisticsAvgVO3.getAvgRPrice();
                    priceStatisticsAvgVO1.setRtb(rtb * 100 + "%");
                }
            }
        }
        List<Map<String, Object>> list = new ArrayList<>();
        Map<String,Object> mPF =new HashMap<String,Object>();
        mPF.put("name","批发价");
        mPF.put("startPrice",null);
        mPF.put("endPrice",null);
        mPF.put("compareStart",null);
        mPF.put("avgPrice",null);
        mPF.put("hb",null);
        mPF.put("tb",null);
        if(priceStatisticsAvgVO1 != null){
            mPF.put("startPrice",priceStatisticsAvgVO1.getStartWPrice());
            mPF.put("endPrice",priceStatisticsAvgVO1.getEndWPrice());
            mPF.put("compareStart",priceStatisticsAvgVO1.getWCompareStart());
            mPF.put("avgPrice",priceStatisticsAvgVO1.getAvgWPrice());
            mPF.put("hb",priceStatisticsAvgVO1.getWhb());
            mPF.put("tb",priceStatisticsAvgVO1.getWtb());
        }
        list.add(mPF);
        Map<String,Object> mLS =new HashMap<String,Object>();
        mLS.put("name","零售价");
        mLS.put("startPrice",null);
        mLS.put("endPrice",null);
        mLS.put("compareStart",null);
        mLS.put("avgPrice",null);
        mLS.put("hb",null);
        mLS.put("tb",null);
        if (priceStatisticsAvgVO1 != null){
            mLS.put("startPrice",priceStatisticsAvgVO1.getStartRPrice());
            mLS.put("endPrice",priceStatisticsAvgVO1.getEndRPrice());
            mLS.put("compareStart",priceStatisticsAvgVO1.getRCompareStart());
            mLS.put("avgPrice",priceStatisticsAvgVO1.getAvgRPrice());
            mLS.put("hb",priceStatisticsAvgVO1.getRhb());
            mLS.put("tb",priceStatisticsAvgVO1.getRtb());
        }
        list.add(mLS);
         return list;
    }

    /**
     * @param priceStatisticsInputVO
     * @return list
     * @Description: 周均价统计
     * @date
     * @author yangshengjie
     * @version v1.0
     */
    public List<Map<String, Object>> getPriceWeekAvg(PriceStatisticsInputVO priceStatisticsInputVO) {
        List<Map<String, Object>> list = new ArrayList<>();
        Map<String, Object> pfMap = new HashMap<>();
        pfMap.put("name","全市批发价");
        Map<String, Object> lsMap = new HashMap<>();
        lsMap.put("name","全市零售价");

        //如果没有输入时间默认获取上周时间
        if (priceStatisticsInputVO.getStartDate() == null) {
            Map<String, Object> map = getWeekDate();
            priceStatisticsInputVO.setStartDate(getLastWeekDate((Date) map.get("mondayDate")));
            priceStatisticsInputVO.setEndDate(getLastWeekDate((Date) map.get("sundayDate")));
        }

        //计算本周均价
        PriceStatisticsAvgVO thisPriceStatisticsAvgVO = tbjlDao.selectWeekAvgPrice(priceStatisticsInputVO);

        //获取上周周一到周日时间
        priceStatisticsInputVO.setStartDate(getLastWeekDate(priceStatisticsInputVO.getStartDate()));
        priceStatisticsInputVO.setEndDate(getLastWeekDate(priceStatisticsInputVO.getEndDate()));

        //计算上周均价
        PriceStatisticsAvgVO lastPriceStatisticsAvgVO = tbjlDao.selectWeekAvgPrice(priceStatisticsInputVO);
        pfMap.put("avgPrice",null);
        lsMap.put("avgPrice",null);
        pfMap.put("lastAvgPrice",null);
        lsMap.put("lastAvgPrice",null);
        if(thisPriceStatisticsAvgVO != null){
            pfMap.put("avgPrice",thisPriceStatisticsAvgVO.getAvgWPrice());
            lsMap.put("avgPrice",thisPriceStatisticsAvgVO.getAvgRPrice());
        }
        if(lastPriceStatisticsAvgVO != null){
            pfMap.put("lastAvgPrice",lastPriceStatisticsAvgVO.getAvgWPrice());
            lsMap.put("lastAvgPrice",lastPriceStatisticsAvgVO.getAvgRPrice());
        }

        pfMap.put("compareLastWeek",null);
        lsMap.put("compareLastWeek",null);
        if(thisPriceStatisticsAvgVO != null){
            //计算较上周
            if(thisPriceStatisticsAvgVO.getAvgWPrice() != null && lastPriceStatisticsAvgVO.getAvgWPrice() != null &&lastPriceStatisticsAvgVO.getAvgWPrice() !=0){
                Double compareLastWeekW = (thisPriceStatisticsAvgVO.getAvgWPrice() - lastPriceStatisticsAvgVO.getAvgWPrice()) / lastPriceStatisticsAvgVO.getAvgWPrice();
                BigDecimal a = new BigDecimal(compareLastWeekW);
                BigDecimal b = new BigDecimal("100");
                int i = a.multiply(b).intValue();
                //compareLastWeekW = compareLastWeekW * 100;
                thisPriceStatisticsAvgVO.setWCompareStart(i+"%");
            }
            if(thisPriceStatisticsAvgVO.getAvgRPrice() != null && lastPriceStatisticsAvgVO.getAvgRPrice() != null &&lastPriceStatisticsAvgVO.getAvgRPrice() !=0){
                Double compareLastWeekR = (thisPriceStatisticsAvgVO.getAvgRPrice() - lastPriceStatisticsAvgVO.getAvgRPrice()) / lastPriceStatisticsAvgVO.getAvgRPrice();
                BigDecimal a = new BigDecimal(compareLastWeekR);
                BigDecimal b = new BigDecimal("100");
                int i = a.multiply(b).intValue();
               // compareLastWeekR = compareLastWeekR * 100;
                thisPriceStatisticsAvgVO.setRCompareStart(i+"%");
            }
            pfMap.put("compareLastWeek",thisPriceStatisticsAvgVO.getWCompareStart());
            lsMap.put("compareLastWeek",thisPriceStatisticsAvgVO.getRCompareStart());
        }

        list.add(pfMap);
        list.add(lsMap);

        return list;
    }
    
    /**
     * 
     * @Description: 修改填报记录品种编码和现有指标编码对应
     * @author: 王帅
     * @param: @param formType
     * @param: @return  参数
     * @return: boolean    返回类型
     */
    @Transactional
    public boolean modifyReportFormsRecordVarietyCode(String formType) {
    	// 获取所有指标集合
    	List<ZbDO> indicatorList = indicatorDao.selectAll();
    	Map<String,String> nameAndCodeMap = indicatorList.stream().collect(Collectors.toMap(ZbDO::getIndName, ZbDO::getIndCode));
    	if(CollectionUtils.isEmpty(indicatorList)) {
    		// 集合为空则返回false
    		return false;
    	}
    	// 集合不为空 循环所有指标
    	for(ZbDO obj : indicatorList) {
    		String name = obj.getIndName(); // 指标名称
    		String code = obj.getIndCode(); // 指标编码
    		// 任一为空则跳过执行下一次
    		if(StringUtils.isEmpty(name) || StringUtils.isEmpty(code)) {
    			continue;
    		}
    		// 查询记录是否为唯一记录
    		List<LyjgDO> recordList = lyjgDao.queryCompleteVarieties(formType, code);
    		// 查询报表选用指标标准名称
    		Example example = new Example(BbzbDO.class);
    		Criteria criteria = example.createCriteria();
    		criteria.andEqualTo("reportTypeId", formType);
    		criteria.andEqualTo("indicatorId", obj.getId());
    		BbzbDO entity = reportDao.selectOneByExample(example);
    		if(!ObjectUtils.isEmpty(entity)) {
    			String thebenchmarkName = entity.getZbbzMc();
    			if(!StringUtils.isEmpty(thebenchmarkName)) {
    				lyjgDao.modifyReportVarietiesThebenchmarkName(code, thebenchmarkName, formType);
    			}
    		}
    		// 如果结果集大于一行 则比对记录中哪个品种编码与指标记录中的数据不对应，然后修改记录中品种编码
    		if(!CollectionUtils.isEmpty(recordList) && recordList.size() > 1) {
    			for(LyjgDO record : recordList) {
    				String recordName = record.getPzmc();
    				if(StringUtils.isEmpty(recordName)) {
    					continue;
    				}
    				if(!name.equals(recordName)) {
    					String recordCode = nameAndCodeMap.get(recordName);
    					lyjgDao.modifyRecordVarietiesCode(recordCode, code, recordName, formType);
    				}
    			}
    		}
    	}
    	
    	return true;
    }
    
	/**
	 * 
	 * @Description: 全国价格指数走势统计图（津粮网）
	 * @author: 王帅
	 * @param: @param  record
	 * @param: @return 参数
	 * @return: JSONObject 返回类型
	 */
	public JSONObject showNationalPriceIndexTrend(ReportRecordVO record) {
		// 通过查询条件获取列表-暂定品种 和 时间筛选
		// 必须要有报表类型
		String reportType = record.getBblx();
		if (StringUtils.isEmpty(reportType)) {
			return null;
		}
		// 获取填报品种
		String variety = record.getPzmc();
		Example example = new Example(TbjlDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andEqualTo("bblxId", reportType);
		example.orderBy("sbkssj").asc();
		List<TbjlDO> reportList = fileInReportDao.selectByExample(example);
		List<Map<String, Object>> seriesLists = new ArrayList<>();
		List<Map<String, Object>> legends = new ArrayList<>();
		Set<String> varietys = Sets.newHashSet();
		Map<String, List<String>> indexData = Maps.newHashMap();
		List<String> timeList = Lists.newArrayList();
		for (TbjlDO report : reportList) {
			// 添加时间轴
			if (null != report.getSbkssj()) {
				String formateTime = DateUtil.getDateFormat(report.getSbkssj(), "yyyy-MM");
				timeList.add(formateTime);
			}
			// 一次报表信息
			Example nationalExample = new Example(QgjgzsDO.class);
			Criteria nationalCriteria = nationalExample.createCriteria();
			nationalCriteria.andEqualTo("tbjlId", report.getId());
			if (!StringUtils.isEmpty(variety)) {
				nationalCriteria.andEqualTo("pzmc", variety);
			}
			List<QgjgzsDO> nationalRecordList = nationalPriceIndexDao.selectByExample(nationalExample);
			if (nationalRecordList != null) {
				for (QgjgzsDO indexRecord : nationalRecordList) {
					// 获取品种
					String name = indexRecord.getPzmc();
					if (!varietys.contains(name)) {
						Map<String, Object> legendMap = new HashMap<>();
						legendMap.put("name", name);
						legendMap.put("icon", "circle");
						legends.add(legendMap);
					}
					// 获取价格指数
					Double data = indexRecord.getZs();
					String dataStr = "";
					if(ObjectUtils.isEmpty(data)) {
						dataStr = null;
					} else {
						dataStr = String.valueOf(data);
					}
					List<String> index = indexData.get(name);
					if (CollectionUtils.isEmpty(index)) {
						index = Lists.newArrayList();
						index.add(dataStr);
					} else {
						index.add(dataStr);
					}
					indexData.put(name, index);
					varietys.add(name);
				}
			}
		}
		for (String key : indexData.keySet()) {
			Map<String, Object> resultMap = Maps.newHashMap();
			resultMap.put("name", key);
			resultMap.put("data", indexData.get(key));
			seriesLists.add(resultMap);
		}
		JSONObject obj = new JSONObject();
		obj.put("xAxis", timeList);
		obj.put("legend", legends);
		obj.put("series", seriesLists);

		return obj;
	}
	
	/**
	 * 
	 * @Description: 获取全国价格指数走势所有品种
	 * @author: 王帅
	 * @param: @param formType
	 * @param: @return  参数
	 * @return: JSONObject    返回类型
	 */
	public JSONObject getNationalPriceIndexVarietys(String formType) {
		if (StringUtils.isEmpty(formType)) {
			return null;
		}
		Example example = new Example(TbjlDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andEqualTo("bblxId", formType);
		example.orderBy("sbkssj").desc();
		List<TbjlDO> reportList = fileInReportDao.selectByExample(example);
		Set<String> varietys = Sets.newHashSet();
		if (!CollectionUtils.isEmpty(reportList)) {
			// 一次报表信息,一次记录中会包含所有信息
			Example nationalExample = new Example(QgjgzsDO.class);
			Criteria nationalCriteria = nationalExample.createCriteria();
			nationalCriteria.andEqualTo("tbjlId", reportList.get(0).getId());
			List<QgjgzsDO> nationalRecordList = nationalPriceIndexDao.selectByExample(nationalExample);
			if (nationalRecordList != null) {
				for (QgjgzsDO indexRecord : nationalRecordList) {
					// 获取品种
					String name = indexRecord.getPzmc();
					varietys.add(name);
				}
			}
		}
		JSONObject obj = new JSONObject();
		obj.put("varietys", varietys);
		return obj;
	}
	
	public void addReportRecordVariety(String reportType, String startTime, Date endTime, String recordId,
			String varietyName, String varietyCode, String detailId) {
		// 查询出现有品种记录
		Example examplePrice = new Example(LyjgDO.class);
		Criteria criteriaPrice = examplePrice.createCriteria();
		criteriaPrice.andEqualTo("tbjlId", recordId);
		criteriaPrice.andEqualTo("pzmc", varietyName);
		criteriaPrice.andEqualTo("zbbm", varietyCode);
		LyjgDO priceRecord = grainAndOilPricesDao.selectOneByExample(examplePrice);
		// 查询详情记录
		Example examplePriceDetail = new Example(LyjgmxDO.class);
		Criteria criteriaPriceDetail = examplePriceDetail.createCriteria();
		criteriaPriceDetail.andEqualTo("lyjgId", priceRecord.getId());
		LyjgmxDO priceDetail = grainAndOilPricesDetailDao.selectOneByExample(examplePriceDetail);

		// 查询需要修改填报记录
		Example exampleRecord = new Example(TbjlDO.class);
		Criteria criteriaRecord = exampleRecord.createCriteria();
		criteriaRecord.andEqualTo("bblxId", reportType);
//		criteriaRecord.andEqualTo("orgId", "LS001013");
//		criteriaRecord.andEqualTo("deptId", "DP014");
		criteriaRecord.andEqualTo("id", "98ke3L4lOiaQLySXeyq");
		criteriaRecord.andEqualTo("orgId", "LS001005");
		criteriaRecord.andEqualTo("deptId", "DP006");
//		criteriaRecord.andGreaterThanOrEqualTo("createTime", startTime);

		List<TbjlDO> recordList = fileInReportDao.selectByExample(exampleRecord);
		recordList.parallelStream().forEach(record -> {
			String id = record.getId();
			LyjgDO entity = new LyjgDO();
			LsBeanUtils.copyPropertiesIgnoreNull(priceRecord, entity);
			entity.setId(UUIDUtils.uuid());
			entity.setTbjlId(id);
			// 保存粮油价格信息
			grainAndOilPricesDao.insertSelective(entity);
			
			LyjgmxDO detail = new LyjgmxDO();
			LsBeanUtils.copyPropertiesIgnoreNull(priceDetail, detail);
			detail.setId(UUIDUtils.uuid());
			detail.setLyjgId(entity.getId());
			grainAndOilPricesDetailDao.insertSelective(detail);
			
//			Example example = new Example(LyjgDO.class);
//			Criteria criteria = example.createCriteria();
//			criteria.andEqualTo("tbjlId", id);
//			criteria.andEqualTo("pzmc", varietyName);
//			criteriaPrice.andEqualTo("zbbm", varietyCode);
//			LyjgDO entity = grainAndOilPricesDao.selectOneByExample(example);
//			String priceId = entity.getId();
//			LsBeanUtils.copyPropertiesIgnoreNull(priceRecord, entity);
//			entity.setId(priceId);
//			entity.setTbjlId(id);
//			// 保存粮油价格信息
//			grainAndOilPricesDao.updateByPrimaryKeySelective(entity);
//			// 明细
//			// 查询详情记录
//			Example exampleDetail = new Example(LyjgmxDO.class);
//			Criteria criteriaDetail = exampleDetail.createCriteria();
//			criteriaDetail.andEqualTo("lyjgId", priceId);
//			LyjgmxDO detail = grainAndOilPricesDetailDao.selectOneByExample(exampleDetail);
//			String priceDetailId = detail.getId();
//			LsBeanUtils.copyPropertiesIgnoreNull(priceDetail, detail);
//			detail.setId(priceDetailId);
//			detail.setLyjgId(priceId);
//			grainAndOilPricesDetailDao.updateByPrimaryKeySelective(detail);
		});
	}

    /**
     * @param taskVO
     * @return ResponseWrapper
     * @Description: 任务调度根据上一期价格新增数据
     * @date 2019年8月16日, 下午5:54:00
     * @author 任宇
     * @version v1.0
     */
    public void lYPriceDailyTaskAdd(TaskVO taskVO) {
        //上期填报记录
        TbjlDO tbjlDO = tbjlDao.selectLastReport(taskVO);
        if (tbjlDO != null) {
            //新增当日记录
            TbjlDO newTbjlDO = new TbjlDO();
            newTbjlDO.setId(UUIDUtils.uuid());
            newTbjlDO.setCreateTime(new Date());
            newTbjlDO.setBblxId(taskVO.getPriceType());

            //设置时间为当日
            Calendar c = Calendar.getInstance();
            c.set(Calendar.HOUR_OF_DAY,0);
            c.set(Calendar.MINUTE, 0);
            c.set(Calendar.SECOND, 0);
            c.set(Calendar.MILLISECOND, 0);
            Date currentDate = c.getTime();

            newTbjlDO.setSbkssj(currentDate);
            newTbjlDO.setSbjssj(currentDate);
            newTbjlDO.setLcid("2");
            newTbjlDO.setOrgId(tbjlDO.getOrgId());
            newTbjlDO.setOrgName(tbjlDO.getOrgName());
            newTbjlDO.setDeptName(tbjlDO.getDeptName());
            newTbjlDO.setDeptId(tbjlDO.getDeptId());
            newTbjlDO.setAreaCode(tbjlDO.getAreaCode());
            newTbjlDO.setAreaName(tbjlDO.getAreaName());
            tbjlDao.insert(newTbjlDO);
            //获取粮油价格信息
            List<LyjgInfoDO> lyjgInfoDOList = lyjgDao.selectTjInfoByFid(tbjlDO.getId());
            if (lyjgInfoDOList != null) {
                for (LyjgInfoDO lyjgInfoDO : lyjgInfoDOList) {
                    LyjgDO lyjgDO = new LyjgDO();
                    LsBeanUtils.copyPropertiesIgnoreNull(lyjgInfoDO, lyjgDO);
                    lyjgDO.setId(UUIDUtils.uuid());
                    lyjgDO.setTbjlId(newTbjlDO.getId());
                    //保存粮油价格信息
                    lyjgDao.insert(lyjgDO);

                    LyjgmxDO lyjgmxDO = new LyjgmxDO();
                    LsBeanUtils.copyPropertiesIgnoreNull(lyjgInfoDO, lyjgmxDO);
                    if (lyjgInfoDO.getSqjg() != null) {
                        //修复自动生成的上期价格错误问题
                        // lyjgmxDO.setSqjg(Double.parseDouble(getDoubleString(lyjgInfoDO.getSqjg())));
                        lyjgmxDO.setSqjg(Double.parseDouble(getDoubleString(lyjgInfoDO.getBqjg())));
                    }
                    if (lyjgInfoDO.getBqjg() != null) {
                        lyjgmxDO.setBqjg(Double.parseDouble(getDoubleString(lyjgInfoDO.getBqjg())));
                    }
                    lyjgmxDO.setId(UUIDUtils.uuid());
                    lyjgmxDO.setLyjgId(lyjgDO.getId());

                    //保存粮油明细信息
                    lyjgmxDao.insert(lyjgmxDO);
                }
            }

        }

    }
}
