package com.unis.indicator.server.domain;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.ValidationUtil;
import com.unis.indicator.common.vo.PriceTypeVO;
import com.unis.indicator.common.vo.bbzb.ReportTypePriceVO;
import com.unis.indicator.common.vo.bbzb.ReportTypeVO;
import com.unis.indicator.server.config.SecurityUtil;
import com.unis.indicator.server.dao.BbLxDao;
import com.unis.indicator.server.dao.BbLxJgLxDao;
import com.unis.indicator.server.dao.ZbJgLxDao;
import com.unis.indicator.server.entity.indicator.BblxDO;
import com.unis.indicator.server.entity.indicator.BblxJglxDO;
import com.unis.indicator.server.entity.indicator.ZbjglxDO;
import lombok.Getter;
import lombok.Setter;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import tk.mybatis.mapper.entity.Example;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @ClassName WeeklyReportDomain
 * @Description indicator报表类型领域对象
 * @Author xmpu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@Getter
@Setter
@Component
@Transactional(rollbackFor={Exception.class})
public class ReportTypeDomain {

	@Autowired
	private BbLxDao dao;

	@Autowired
	private ZbJgLxDao indicatorPriceDao;

	@Autowired
	private BbLxJgLxDao bbLxJgLxDao;

	@Autowired
	private PriceTypeDomain priceTypeDomain;

	/**
	 *
	 * @Description: 通过id查询indicator报表信息
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param id
	 * @return BblxDO
	 */
	public BblxDO findWeeklyReportTypeById(String id) throws Exception {
		Example example = new Example(BblxDO.class);
		Example.Criteria criteria = example.createCriteria();
//		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("id", id);
		BblxDO resDO = dao.selectOneByExample(example);
		if (ObjectUtils.equals(resDO, null)) {
			return null;
		}
		return resDO;
	}

	/**
	 *
	 * @Description: 查询所有indicator报表信息 模糊查询的条件可以包含：名称
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public Map<String, Object> findWeeklyReportTypesByPage(ReportTypeVO VO, Integer page, Integer size) throws Exception {

		Example example = new Example(BblxDO.class);
		Example.Criteria criteria = example.createCriteria();
		example.setDistinct(true);
		String	reportTypeName= SecurityUtil.filterStrSqlJs(VO.getReportTypeName());

		// 添加按名称查询
		if (!"".equals(reportTypeName) && null != reportTypeName) {
			criteria.andLike("reportTypeName", "%" + reportTypeName + "%");
		}
		// 未删除
//		criteria.andIsNull("deleteTime");
		PageHelper.startPage(page, size, "BBLXMC");
		List<BblxDO> resultDOList = dao.selectByExample(example);
		PageInfo<BblxDO> pageInfo = new PageInfo<BblxDO>(resultDOList);

		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<ReportTypeVO> resultVOList = new ArrayList<>();
		if (!resultDOList.isEmpty()) {
			for (BblxDO resultDO : resultDOList) {
				ReportTypeVO resultVO = LsBeanUtils.copyProperties(resultDO, ReportTypeVO.class);
				if(StringUtils.isNotEmpty(resultVO.getReportTimeTypeName())) {
					resultVO.setReportTypeName(resultVO.getReportTypeName() + resultVO.getReportTimeTypeName());
				}
				resultVOList.add(resultVO);
			}
		}
		resultMap.put("total", pageInfo.getTotal());
		resultMap.put("resultList", resultVOList);
		return resultMap;
	}

	public List<ReportTypeVO> findDistinct() throws Exception {

		Example example = new Example(BblxDO.class);
		Example.Criteria criteria = example.createCriteria();
		example.setDistinct(true);
		List<BblxDO> resultDOList = dao.selectByExample(example);
		for  (int i = 0; i < resultDOList.size() - 1 ; i ++)  {
			for (int j = resultDOList.size() - 1 ; j > i; j--)  {
				if (resultDOList.get(j).getReportTypeName().equals(resultDOList.get(i).getReportTypeName()))  {
					resultDOList.remove(j);
				}
			}
		}
		List<ReportTypeVO> resultVOList = new ArrayList<>();
		if (!resultDOList.isEmpty()) {
			for (BblxDO resultDO : resultDOList) {
				ReportTypeVO resultVO = LsBeanUtils.copyProperties(resultDO, ReportTypeVO.class);
				resultVOList.add(resultVO);
			}
		}
		return resultVOList;
	}

	/**
	 *
	 * @Description: indicator报表多选删除
	 * @date 2019年7月24日,下午8:58:47
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param ids
	 * @param userId
	 * @return Boolean
	 * @throws Exception
	 */
	public boolean deleteWeeklyReportTypes(String[] ids, String userId) throws Exception {
		for (String id : ids) {
			Example example = new Example(BblxDO.class);
			Example.Criteria criteria = example.createCriteria();
			criteria.andEqualTo("id", id);
//			criteria.andIsNull("deleteTime");
			BblxDO udpDO = dao.selectOneByExample(example);
			if (ObjectUtils.notEqual(udpDO, null)) {
				dao.delete(udpDO);
			}
		}
		return true;
	}

	/**
	 *
	 * @Description: 保存indicator报表信息
	 * @date 2019年7月24日,下午8:58:56
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean saveWeeklyReportType(ReportTypeVO VO) throws Exception {
		ValidationUtil.validate(VO);
//		Example example = new Example(BblxDO.class);
//		Example.Criteria criteria = example.createCriteria();
//		if (!"".equals(VO.getProvName()) && null != VO.getProvName()) {
//			criteria.andEqualTo("provName", VO.getProvName());
//		}
//		criteria.andIsNull("deleteTime");
//		if (dao.selectCountByExample(example) > 0) {
//			throw new RuntimeException("已存在");
//		}
		BblxDO insDO = new BblxDO();
		LsBeanUtils.copyPropertiesIgnoreNull(VO, insDO);

		if (dao.insertSelective(insDO) < 1) {
			throw new RuntimeException("无法保存成功，请检查数据。");
		}
		return true;
	}

	/**
	 *
	 * @Description: 更新indicator报表
	 * @date 2019年7月24日,下午8:59:05
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean updateWeeklyReportType(ReportTypeVO VO) throws Exception {
		ValidationUtil.validate(VO);
		BblxDO udpDO = findWeeklyReportTypeById(VO.getId());
		if (ObjectUtils.equals(udpDO, null)) {
			return false;
		}
		LsBeanUtils.copyPropertiesIgnoreNull(VO, udpDO);

		if (dao.updateByPrimaryKey(udpDO) < 1) {
			return false;
		}
		return true;
	}

	/**
	 *
	 * @Description: 价格类型与报表类型保存
	 * @date 2019年7月24日,下午8:58:47
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param vo
	 * @return Boolean
	 * @throws Exception
	 */
	public boolean saveReportTypePriceType(ReportTypePriceVO vo) throws Exception {

		Example example = new Example(BblxJglxDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andEqualTo("reportTypeId", vo.getReportTypeId());
		List<BblxJglxDO> IPList = bbLxJgLxDao.selectByExample(example);
		// 先删除
		if(IPList != null && IPList.size() > 0) {
			for (BblxJglxDO ip : IPList) {
				bbLxJgLxDao.delete(ip);
			}
		}
		// 再插入
		for (PriceTypeVO priceType : vo.getPriceTypeVO()) {
			BblxJglxDO insDO = new BblxJglxDO();
			if (priceType != null) {
				insDO.setPriceTypeId(priceType.getId());
				insDO.setPriceTypeName(priceType.getPriceTypeName());
				insDO.setReportTypeId(vo.getReportTypeId());
				insDO.setReportTypeName(vo.getReportTypeName());
				bbLxJgLxDao.insertSelective(insDO);
			}
		}
		return true;
	}

	/**
	 *
	 * @Description: 查询报表类型对应勾选了的价格类型
	 * @date 2019年7月24日,下午8:59:05
	 * @author xmpu
	 * @version v1.0
	 *
	 * @return ReportTypePriceVO
	 * @throws Exception
	 */
	public ReportTypePriceVO findReportTypePriceType(String rtId) throws Exception {

		Example example = new Example(BblxJglxDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andEqualTo("reportTypeId", rtId);
		List<BblxJglxDO> ISList = bbLxJgLxDao.selectByExample(example);

		ReportTypePriceVO res = new ReportTypePriceVO();
		List<PriceTypeVO> priceList = new ArrayList<>();
		// 价格类型包装
		for (BblxJglxDO ip : ISList) {
			res.setReportTypeId(ip.getReportTypeId());
			PriceTypeVO pt  = new PriceTypeVO();
			pt.setId(ip.getPriceTypeId());
			pt.setPriceTypeName(ip.getPriceTypeName());
			priceList.add(pt);
		}
		res.setPriceTypeVO(priceList);
		return res;
	}
}
