package com.unis.indicator.server.domain;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.ValidationUtil;
import com.unis.indicator.common.vo.IndicatorReportVO;
import com.unis.indicator.common.vo.PriceTrendQueryVO;
import com.unis.indicator.common.vo.StandardVO;
import com.unis.indicator.common.vo.TrendChartVO;
import com.unis.indicator.server.config.SecurityUtil;
import com.unis.indicator.server.dao.BzDao;
import com.unis.indicator.server.dao.ZbBzDao;
import com.unis.indicator.server.entity.indicator.BzDO;
import com.unis.indicator.server.entity.indicator.ZbbzDO;
import com.unis.indicator.server.entity.report.TbjlDO;
import lombok.Getter;
import lombok.Setter;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import tk.mybatis.mapper.entity.Example;

import java.util.*;

/**
 * @ClassName StandardDomain
 * @Description 指标标准领域对象
 * @Author xmpu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@Getter
@Setter
@Component
public class StandardDomain {

	@Autowired
	private BzDao dao;

	@Autowired
	private ZbBzDao indicatorStandardDao;

	/**
	 *
	 * @Description: 通过standardId查询指标标准关联信息
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param standardId
	 * @return boolean
	 */
	public boolean findStdRelById(String standardId) throws Exception {
		Example example = new Example(ZbbzDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andEqualTo("standardId", standardId);
		List res = indicatorStandardDao.selectByExample(example);
		if (res != null
				&& res.size() > 0) {
			return true;
		}
		return false;
	}

	/**
	 *
	 * @Description: 通过id查询指标标准信息
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param id
	 * @return BzDO
	 */
	public BzDO findStdById(String id) throws Exception {
		Example example = new Example(BzDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("id", id);
		BzDO resDO = dao.selectOneByExample(example);
		if (ObjectUtils.equals(resDO, null)) {
			return null;
		}
		return resDO;
	}

	/**
	 *
	 * @Description: 查询所有指标标准信息 模糊查询的条件可以包含：名称
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public Map<String, Object> findStdsByPage(StandardVO VO, Integer page, Integer size) throws Exception {

		Example example = new Example(BzDO.class);
		Example.Criteria criteria = example.createCriteria();
		String	standardName= SecurityUtil.filterStrSqlJs(VO.getStandardName());

		// 添加按名称查询
		if (!"".equals(standardName) && null != standardName) {
			criteria.andLike("standardName", "%" + standardName + "%");
		}
		// 未删除
		criteria.andIsNull("deleteTime");
		PageHelper.startPage(page, size, "CREATE_TIME DESC");
		List<BzDO> resultDOList = dao.selectByExample(example);
		PageInfo<BzDO> pageInfo = new PageInfo<BzDO>(resultDOList);

		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<StandardVO> resultVOList = new ArrayList<>();
		if (!resultDOList.isEmpty()) {
			for (BzDO resultDO : resultDOList) {
				StandardVO resultVO = LsBeanUtils.copyProperties(resultDO, StandardVO.class);
				resultVOList.add(resultVO);
			}
		}
		resultMap.put("total", pageInfo.getTotal());
		resultMap.put("resultList", resultVOList);
		return resultMap;
	}

	/**
	 *
	 * @Description: 指标标准多选删除
	 * @date 2019年7月24日,下午8:58:47
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param ids
	 * @param userId
	 * @return Boolean
	 * @throws Exception
	 */
	public boolean deleteStds(String[] ids, String userId) throws Exception {
		for (String id : ids) {
			Example example = new Example(BzDO.class);
			Example.Criteria criteria = example.createCriteria();
			criteria.andEqualTo("id", id);
			criteria.andIsNull("deleteTime");
			BzDO udpDO = dao.selectOneByExample(example);
			if (ObjectUtils.notEqual(udpDO, null)) {
				udpDO.setDeleteBy(userId);
				udpDO.setDeleteTime(DateUtil.getNowDate());
				dao.updateByPrimaryKey(udpDO);
			}
		}
		return true;
	}

	/**
	 *
	 * @Description: 保存指标标准信息
	 * @date 2019年7月24日,下午8:58:56
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean saveStd(StandardVO VO) throws Exception {
		ValidationUtil.validate(VO);
		Example example = new Example(BzDO.class);
		Example.Criteria criteria = example.createCriteria();
		if (!"".equals(VO.getStandardName()) && null != VO.getStandardName()) {
			criteria.andEqualTo("standardName", VO.getStandardName());
		}
		criteria.andIsNull("deleteTime");
		if (dao.selectCountByExample(example) > 0) {
			throw new RuntimeException(VO.getStandardName() + "已存在");
		}
		BzDO insDO = new BzDO();
		LsBeanUtils.copyPropertiesIgnoreNull(VO, insDO);
		insDO.setCreateBy(VO.getOperator());
		insDO.setCreateTime(new Date());

		if (dao.insertSelective(insDO) < 1) {
			throw new RuntimeException(insDO.getStandardName() + "无法保存成功，请检查数据。");
		}
		return true;
	}

	/**
	 *
	 * @Description: 更新指标标准
	 * @date 2019年7月24日,下午8:59:05
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean updateStd(StandardVO VO) throws Exception {
		ValidationUtil.validate(VO);
		BzDO udpDO = findStdById(VO.getId());
		if (ObjectUtils.equals(udpDO, null)) {
			return false;
		}
		LsBeanUtils.copyPropertiesIgnoreNull(VO, udpDO);

		udpDO.setUpdateBy(VO.getOperator());
		udpDO.setUpdateTime(DateUtil.getNowDate());
		if (dao.updateByPrimaryKey(udpDO) < 1) {
			return false;
		}
		return true;
	}

}
