package com.unis.indicator.server.domain;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.ValidationUtil;
import com.unis.indicator.common.vo.UnitVO;
import com.unis.indicator.server.dao.DwDao;
import com.unis.indicator.server.dao.ZbDao;
import com.unis.indicator.server.entity.indicator.DwDO;
import com.unis.indicator.server.entity.indicator.ZbDO;
import lombok.Getter;
import lombok.Setter;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import tk.mybatis.mapper.entity.Example;

import java.util.*;

/**
 * @ClassName StandardDomain
 * @Description 指标单位领域对象
 * @Author xmpu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@Getter
@Setter
@Component
public class UnitDomain {

	@Autowired
	private DwDao dao;

	@Autowired
	private ZbDao indicatorDao;

	/**
	 *
	 * @Description: 通过unitId查询指标和单位关联信息
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param unitId
	 * @return boolean
	 */
	public boolean findUnitIndRel(String unitId) throws Exception {
		Example example = new Example(ZbDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andEqualTo("unitId", unitId);
		List res = indicatorDao.selectByExample(example);
		if (res != null
				&& res.size() > 0) {
			return true;
		}
		return false;
	}

	/**
	 *
	 * @Description: 通过id查询指标单位信息
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param id
	 * @return DwDO
	 */
	public DwDO findUnitById(String id) throws Exception {
		Example example = new Example(DwDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("id", id);
		DwDO resDO = dao.selectOneByExample(example);
		if (ObjectUtils.equals(resDO, null)) {
			return null;
		}
		return resDO;
	}

	/**
	 *
	 * @Description: 查询所有指标单位信息 模糊查询的条件可以包含：名称
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public Map<String, Object> findUnitsByPage(UnitVO VO, Integer page, Integer size) throws Exception {

		Example example = new Example(DwDO.class);
		Example.Criteria criteria = example.createCriteria();

		// 添加按名称查询
		if (!"".equals(VO.getUnitName()) && null != VO.getUnitName()) {
			criteria.andLike("unitName", "%" + VO.getUnitName() + "%");
		}
		// 未删除
		criteria.andIsNull("deleteTime");
		PageHelper.startPage(page, size, "CREATE_TIME DESC");
		List<DwDO> resultDOList = dao.selectByExample(example);
		PageInfo<DwDO> pageInfo = new PageInfo<DwDO>(resultDOList);

		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<UnitVO> resultVOList = new ArrayList<>();
		if (!resultDOList.isEmpty()) {
			for (DwDO resultDO : resultDOList) {
				UnitVO resultVO = LsBeanUtils.copyProperties(resultDO, UnitVO.class);
				resultVOList.add(resultVO);
			}
		}
		resultMap.put("total", pageInfo.getTotal());
		resultMap.put("resultList", resultVOList);
		return resultMap;
	}

	/**
	 *
	 * @Description: 指标单位多选删除
	 * @date 2019年7月24日,下午8:58:47
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param ids
	 * @param userId
	 * @return Boolean
	 * @throws Exception
	 */
	public boolean deleteUnits(String[] ids, String userId) throws Exception {
		for (String id : ids) {
			Example example = new Example(DwDO.class);
			Example.Criteria criteria = example.createCriteria();
			criteria.andEqualTo("id", id);
			criteria.andIsNull("deleteTime");
			DwDO udpDO = dao.selectOneByExample(example);
			if (ObjectUtils.notEqual(udpDO, null)) {
				udpDO.setDeleteBy(userId);
				udpDO.setDeleteTime(DateUtil.getNowDate());
				dao.updateByPrimaryKey(udpDO);
			}
		}
		return true;
	}

	/**
	 *
	 * @Description: 保存指标单位信息
	 * @date 2019年7月24日,下午8:58:56
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean saveUnit(UnitVO VO) throws Exception {
		ValidationUtil.validate(VO);
		Example example = new Example(DwDO.class);
		Example.Criteria criteria = example.createCriteria();
		if (!"".equals(VO.getUnitName()) && null != VO.getUnitName()) {
			criteria.andEqualTo("unitName", VO.getUnitName());
		}
		criteria.andIsNull("deleteTime");
		if (dao.selectCountByExample(example) > 0) {
			throw new RuntimeException(VO.getUnitName() + "已存在");
		}
		DwDO insDO = new DwDO();
		LsBeanUtils.copyPropertiesIgnoreNull(VO, insDO);
		insDO.setCreateBy(VO.getOperator());
		insDO.setCreateTime(new Date());

		if (dao.insertSelective(insDO) < 1) {
			throw new RuntimeException(insDO.getUnitName() + "无法保存成功，请检查数据。");
		}
		return true;
	}

	/**
	 *
	 * @Description: 更新指标单位
	 * @date 2019年7月24日,下午8:59:05
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean updateUnit(UnitVO VO) throws Exception {
		ValidationUtil.validate(VO);
		DwDO udpDO = findUnitById(VO.getId());
		if (ObjectUtils.equals(udpDO, null)) {
			return false;
		}
		LsBeanUtils.copyPropertiesIgnoreNull(VO, udpDO);

		udpDO.setUpdateBy(VO.getOperator());
		udpDO.setUpdateTime(DateUtil.getNowDate());
		if (dao.updateByPrimaryKey(udpDO) < 1) {
			return false;
		}
		return true;
	}

}
