package com.unis.indicator.server.domain;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.UUIDUtils;
import com.unis.common.utils.ValidationUtil;
import com.unis.indicator.common.vo.IndicatorVO;
import com.unis.indicator.common.vo.WeightVO;
import com.unis.indicator.common.vo.WeightValueVO;
import com.unis.indicator.server.dao.QzjcxxDao;
import com.unis.indicator.server.dao.QzzDao;
import com.unis.indicator.server.entity.indicator.QzjcxxDO;
import com.unis.indicator.server.entity.indicator.QzzDO;
import com.unis.indicator.server.entity.indicator.ZbDO;
import lombok.Getter;
import lombok.Setter;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import tk.mybatis.mapper.entity.Example;

import java.util.*;

/**
 * @ClassName WeightDomain
 * @Description 权重领域对象
 * @Author xmpu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@Getter
@Setter
@Component
public class WeightDomain {

	@Autowired
	private QzjcxxDao dao;

	@Autowired
	private QzzDao qzzDao;

	/**
	 *
	 * @Description: 通过id查询权重信息
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param weightCode
	 * @return QzjcxxDO
	 */
	public QzjcxxDO findWeightByWeightCode(String weightCode) throws Exception {
		Example example = new Example(QzjcxxDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("weightCode", weightCode);
		QzjcxxDO resDO = dao.selectOneByExample(example);
		if (ObjectUtils.equals(resDO, null)) {
			return null;
		}
		return resDO;
	}

	/**
	 *
	 * @Description: 查询所有权重信息 模糊查询的条件可以包含：名称
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public Map<String, Object> findWeightsByPage(WeightVO VO, Integer page, Integer size) throws Exception {

		Example example = new Example(QzjcxxDO.class);
		Example.Criteria criteria = example.createCriteria();

		// 添加按名称查询
		if (!"".equals(VO.getWeightName()) && null != VO.getWeightName()) {
			criteria.andLike("weightName", "%" + VO.getWeightName() + "%");
		}
		// 添加按类型查询
		if (!"".equals(VO.getWeightTypeName()) && null != VO.getWeightTypeName()) {
			criteria.andEqualTo("weightTypeName", VO.getWeightTypeName());
		}
		// 添加按日期查询
		if (null == VO.getDateFrom() && null != VO.getDateTo()) {
			VO.setDateFrom(new Date());
		}
		if (null != VO.getDateFrom() && null == VO.getDateTo()) {
			VO.setDateTo(new Date());
		}
		if (null != VO.getDateFrom() || null != VO.getDateTo()) {
			criteria.andCondition(" UPDATE_TIME BETWEEN to_date('" + DateUtil.turnJavaUtilDateToStrDate(VO.getDateFrom(), DateUtil.YYYYMMDDHHMMSS) + "', 'yyyy-mm-dd hh24:mi:ss') and to_date('" + DateUtil.turnJavaUtilDateToStrDate(VO.getDateTo(), DateUtil.YYYYMMDDHHMMSS) + "', 'yyyy-mm-dd hh24:mi:ss')");
		}
		 // 未删除
		criteria.andIsNull("deleteTime");
		PageHelper.startPage(page, size, "CREATE_TIME DESC");
		List<QzjcxxDO> resultDOList = dao.selectByExample(example);
		PageInfo<QzjcxxDO> pageInfo = new PageInfo<QzjcxxDO>(resultDOList);

		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<WeightVO> resultVOList = new ArrayList<>();
		if (!resultDOList.isEmpty()) {
			for (QzjcxxDO resultDO : resultDOList) {
				WeightVO resultVO = LsBeanUtils.copyProperties(resultDO, WeightVO.class);
				if("0".equals(resultVO.getIsPublish())) {
					resultVO.setIsPublishName("禁用");
				}
				if("1".equals(resultVO.getIsPublish())) {
					resultVO.setIsPublishName("启用");
				}
				resultVOList.add(resultVO);
			}
		}
		resultMap.put("total", pageInfo.getTotal());
		resultMap.put("resultList", resultVOList);
		return resultMap;
	}

	/**
	 *
	 * @Description: 权重多选删除
	 * @date 2019年7月24日,下午8:58:47
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param ids
	 * @param userId
	 * @return Boolean
	 * @throws Exception
	 */
	public boolean deleteWeights(String[] ids, String userId) throws Exception {
		for (String id : ids) {
			Example example = new Example(QzjcxxDO.class);
			Example.Criteria criteria = example.createCriteria();
			criteria.andEqualTo("id", id);
			criteria.andIsNull("deleteTime");
			QzjcxxDO udpDO = dao.selectOneByExample(example);
			if (ObjectUtils.notEqual(udpDO, null)) {
				udpDO.setDeleteBy(userId);
				udpDO.setDeleteTime(DateUtil.getNowDate());
				dao.updateByPrimaryKey(udpDO);
			}
		}
		return true;
	}

	/**
	 *
	 * @Description: 保存权重信息
	 * @date 2019年7月24日,下午8:58:56
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean saveWeight(WeightVO VO) throws Exception {
		ValidationUtil.validate(VO);
		Example example = new Example(QzjcxxDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andEqualTo("weightName", VO.getWeightName());
		criteria.andEqualTo("weightType", VO.getWeightType());
		criteria.andIsNull("deleteTime");
		if (dao.selectCountByExample(example) > 0) {
			throw new RuntimeException(VO.getWeightName() + "权重名称和权重类别重复。");
		}
		QzjcxxDO insDO = new QzjcxxDO();
		LsBeanUtils.copyPropertiesIgnoreNull(VO, insDO);
//		String weightCode = "QZ" + UUIDUtils.uuid();
//		insDO.setWeightCode(VO.getWeightCode());
//		insDO.setIsPublish("1");
		insDO.setCreateBy(VO.getOperator());
		insDO.setCreateTime(new Date());

		if (dao.insertSelective(insDO) < 1) {
			throw new RuntimeException(insDO.getWeightName() + "无法保存成功，请检查数据。");
		}
		// 保存权重值
		saveWeightVal(VO.getWeightValueList(), VO.getWeightCode());

		return true;
	}

	/**
	 *
	 * @Description: 更新权重
	 * @date 2019年7月24日,下午8:59:05
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean updateWeight(WeightVO VO) throws Exception {
		ValidationUtil.validate(VO);
		QzjcxxDO udpDO = findWeightByWeightCode(VO.getWeightCode());
		if (ObjectUtils.equals(udpDO, null)) {
			return false;
		}
		LsBeanUtils.copyPropertiesIgnoreNull(VO, udpDO);

		udpDO.setUpdateBy(VO.getOperator());
		udpDO.setUpdateTime(DateUtil.getNowDate());
		if (dao.updateByPrimaryKey(udpDO) < 1) {
			return false;
		}
		// 更新权重值
		saveWeightVal(VO.getWeightValueList(), VO.getWeightCode());
		return true;
	}

	/**
	 *
	 * @Description: 通过权重code查询权重值信息
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param code
	 * @return List<QzzDO>
	 */
	public List<QzzDO> findWeightValByWeightCode(String code) throws Exception {
		Example example = new Example(QzzDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andEqualTo("weightCode", code);
		List<QzzDO> resDO = qzzDao.selectByExample(example);
		if (ObjectUtils.equals(resDO, null)) {
			return null;
		}
		return resDO;
	}

	/**
	 *
	 * @Description: 通过权重type查询权重值信息
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param type
	 * @return List<IndicatorVO>
	 */
	public List<IndicatorVO> findWeightValByWeightType(String type) throws Exception {
		Map<String, Object> param = new HashMap<>();
		param.put("typeId", type);
		List<IndicatorVO> resList = qzzDao.findIndicatorByWeightType(param);
//		List<IndicatorVO> resVOList = new ArrayList<IndicatorVO>();
//		LsBeanUtils.copyCollection(resDOList, resVOList, IndicatorVO.class);
		return resList;
	}

	/**
	 *
	 * @Description: 权重值保存
	 * @date 2019年7月24日,下午8:58:47
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param voList
	 * @param weightCode
	 * @return Boolean
	 * @throws Exception
	 */
	public boolean saveWeightVal(List<WeightValueVO> voList, String weightCode) throws Exception {

		if(StringUtils.isEmpty(weightCode) || voList == null || voList.size() < 1) {
			return false;
		}
		Example example = new Example(QzzDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andEqualTo("weightCode", weightCode);
		List<QzzDO> delList = qzzDao.selectByExample(example);
		// 先删除
		if(delList != null && delList.size() > 0) {
			for (QzzDO ip : delList) {
				if (qzzDao.delete(ip) < 1) {
					return false;
				}
			}
		}
		// 再插入
		for (WeightValueVO ins : voList) {
			QzzDO insDO = new QzzDO();
			LsBeanUtils.copyNoNullProperties(ins, insDO);
			insDO.setWeightCode(weightCode);
			insDO.setWeightVal(ins.getWeightVal());
			if (qzzDao.insertSelective(insDO) < 1) {
				return false;
			}
		}
		return true;
	}

}
