package com.unis.indicator.server.excel.utils;

import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.web.multipart.MultipartFile;

import com.alibaba.excel.EasyExcelFactory;
import com.alibaba.excel.ExcelReader;
import com.alibaba.excel.ExcelWriter;
import com.alibaba.excel.metadata.BaseRowModel;
import com.alibaba.excel.metadata.Sheet;
import com.alibaba.excel.metadata.Table;
import com.google.common.collect.Lists;
import com.unis.indicator.server.excel.exception.RrException;
import com.unis.indicator.server.excel.listener.ExcelListener;

import cn.hutool.core.io.FileUtil;

/**
 * excel工具类
 */
public class ExcelUtils {

	public static final String OFFICE_EXCEL_2003_POSTFIX = "xls";
	public static final String OFFICE_EXCEL_2010_POSTFIX = "xlsx";
	public static final String EMPTY = "";
	public static final String POINT = ".";

	/**
	 * 获得path的后缀名
	 * 
	 * @param path
	 * @return
	 */
	public static String getPostfix(String path) {
		if (path == null || EMPTY.equals(path.trim())) {
			return EMPTY;
		}
		if (path.contains(POINT)) {
			return path.substring(path.lastIndexOf(POINT) + 1, path.length());
		}
		return EMPTY;
	}

	/**
	 * 生成excel文件
	 * 
	 * @param args
	 * @throws IOException
	 */
	public static void easyExcel(HttpServletRequest request, HttpServletResponse response, String sheetName,
			String fileName, String filePath, List<List<String>> arr, int sheetNo, int headLineMun,
			Class<? extends BaseRowModel> clazz) {
		String agent = request.getHeader("USER-AGENT");
		OutputStream outputStream = null;
		FileInputStream fileInputStream = null;
		File dbfFile = new File(filePath);
		ExcelWriter wwb = null;
		OutputStream out = null;
		try {
			String visiterbrowser = ClientInfoUtil.getOsAndBrowserInfo(agent);
			if (null != visiterbrowser
					&& (-1 != visiterbrowser.indexOf("IE") || -1 != visiterbrowser.indexOf("Edge"))) {// IE
				fileName = java.net.URLEncoder.encode(fileName, "UTF-8");
			} else if (null != visiterbrowser
					&& (-1 != visiterbrowser.indexOf("Chrome") || -1 != visiterbrowser.indexOf("Firefox"))) {
				fileName = new String(fileName.getBytes("UTF-8"), "iso-8859-1");
			} else {
				fileName = java.net.URLEncoder.encode(fileName, "UTF-8");
			}
			response.setContentType("application/vnd.ms-excel;charset=utf-8");
			response.addHeader("Content-Disposition", "attachment;filename=" + fileName);
			response.addHeader("cache-control", "no-cache");
			response.addHeader("cache-control", "Private");
			response.flushBuffer();
			// 如果文件不存在，则创建一个新的文件
			if (!dbfFile.exists() || dbfFile.isDirectory()) {
				dbfFile.createNewFile();
			}
			// 使用 Workbook 类的工厂方法创建一个可写入的工作薄(Workbook)对象
			out = new FileOutputStream(dbfFile);
			wwb = EasyExcelFactory.getWriter(out);
			// 创建一个可写入的工作表
			Sheet sheet = new Sheet(sheetNo, 0, clazz);
			sheet.setSheetName(sheetName);
			wwb.write0(arr, sheet);
			wwb.finish();
			outputStream = response.getOutputStream();
			fileInputStream = new FileInputStream(filePath);
			byte[] b = new byte[1024];
			int j;
			while ((j = fileInputStream.read(b)) > 0) {
				outputStream.write(b, headLineMun, j);
			}
		} catch (Exception e1) {
			e1.printStackTrace();
		} finally {
			try {
				fileInputStream.close();
				out.flush();
				out.close();
				outputStream.flush();
				outputStream.close();
			} catch (IOException e) {
				e.printStackTrace();
			}
			FileUtil.del(dbfFile);
		}
	}

	/**
	 * 
	 * @Description: 动态添加title
	 * @author: 王帅
	 * @param: @param request
	 * @param: @param response
	 * @param: @param sheetName
	 * @param: @param fileName
	 * @param: @param filePath
	 * @param: @param arr
	 * @param: @param sheetNo
	 * @param: @param headLineMun
	 * @param: @param headTitleList
	 * @param: @param headTitle  参数
	 * @return: void    返回类型
	 */
	public static void dynamicHeadEasyExcel(HttpServletRequest request, HttpServletResponse response, String sheetName,
			String fileName, String filePath, List<List<String>> arr, int sheetNo, int headLineMun, List<String> headTitleList, String headTitle) {
		String agent = request.getHeader("USER-AGENT");
		OutputStream outputStream = null;
		FileInputStream fileInputStream = null;
		File dbfFile = new File(filePath);
		ExcelWriter wwb = null;
		OutputStream out = null;
		try {
			String visiterbrowser = ClientInfoUtil.getOsAndBrowserInfo(agent);
			if (null != visiterbrowser
					&& (-1 != visiterbrowser.indexOf("IE") || -1 != visiterbrowser.indexOf("Edge"))) {// IE
				fileName = java.net.URLEncoder.encode(fileName, "UTF-8");
			} else if (null != visiterbrowser
					&& (-1 != visiterbrowser.indexOf("Chrome") || -1 != visiterbrowser.indexOf("Firefox"))) {
				fileName = new String(fileName.getBytes("UTF-8"), "iso-8859-1");
			} else {
				fileName = java.net.URLEncoder.encode(fileName, "UTF-8");
			}
			response.setContentType("application/vnd.ms-excel;charset=utf-8");
			response.addHeader("Content-Disposition", "attachment;filename=" + fileName);
			response.addHeader("cache-control", "no-cache");
			response.addHeader("cache-control", "Private");
			response.flushBuffer();
			// 如果文件不存在，则创建一个新的文件
			if (!dbfFile.exists() || dbfFile.isDirectory()) {
				dbfFile.createNewFile();
			}
			// 使用 Workbook 类的工厂方法创建一个可写入的工作薄(Workbook)对象
			out = new FileOutputStream(dbfFile);
			wwb = EasyExcelFactory.getWriter(out);
			// 创建一个可写入的工作表
			Sheet sheet = new Sheet(sheetNo, 0);
			sheet.setSheetName(sheetName);
			// 创建一个表格
            Table table = new Table(1);
            // 动态添加 表头 headList --> 所有表头行集合
            List<List<String>> headList = new ArrayList<List<String>>();
            headTitleList.forEach( obj -> {
            	List<String> head = Lists.newLinkedList();
            	head.add(headTitle);
            	head.add(obj);
            	headList.add(head);
            });
            table.setHead(headList);
			wwb.write0(arr, sheet, table);
			wwb.finish();
			outputStream = response.getOutputStream();
			fileInputStream = new FileInputStream(filePath);
			byte[] b = new byte[1024];
			int j;
			while ((j = fileInputStream.read(b)) > 0) {
				outputStream.write(b, headLineMun, j);
			}
		} catch (Exception e1) {
			e1.printStackTrace();
		} finally {
			try {
				fileInputStream.close();
				out.flush();
				out.close();
				outputStream.flush();
				outputStream.close();
			} catch (IOException e) {
				e.printStackTrace();
			}
			FileUtil.del(dbfFile);
		}
	}

	/**
	 * 读取 Excel(多个 sheet)
	 *
	 * @param excel    文件
	 * @param rowModel 实体类映射，继承 BaseRowModel 类
	 * @return Excel 数据 list
	 */
	public static List<Object> readExcel(MultipartFile excel, BaseRowModel rowModel) {
		ExcelListener excelListener = new ExcelListener();
		ExcelReader reader = getReader(excel, excelListener);
		if (reader == null) {
			return null;
		}
		for (Sheet sheet : reader.getSheets()) {
			if (rowModel != null) {
				sheet.setClazz(rowModel.getClass());
			}
			reader.read(sheet);
		}
		return excelListener.getDatas();
	}

	/**
	 * 读取某个 sheet 的 Excel
	 *
	 * @param excel    文件
	 * @param rowModel 实体类映射，继承 BaseRowModel 类
	 * @param sheetNo  sheet 的序号 从1开始
	 * @return Excel 数据 list
	 */
	public static List<Object> readExcel(MultipartFile excel, BaseRowModel rowModel, int sheetNo) {
		return readExcel(excel, rowModel, sheetNo, 1);
	}

	/**
	 * 读取某个 sheet 的 Excel
	 *
	 * @param excel       文件
	 * @param rowModel    实体类映射，继承 BaseRowModel 类
	 * @param sheetNo     sheet 的序号 从1开始
	 * @param headLineNum 表头行数，默认为1
	 * @return Excel 数据 list
	 */
	public static List<Object> readExcel(MultipartFile excel, BaseRowModel rowModel, int sheetNo, int headLineNum) {
		ExcelListener excelListener = new ExcelListener();
		ExcelReader reader = getReader(excel, excelListener);
		if (reader == null) {
			return null;
		}
		reader.read(new Sheet(sheetNo, headLineNum, rowModel.getClass()));
		return excelListener.getDatas();
	}

	/**
	 * 返回 ExcelReader
	 *
	 * @param excel         需要解析的 Excel 文件
	 * @param excelListener new ExcelListener()
	 */
	private static ExcelReader getReader(MultipartFile excel, ExcelListener excelListener) {
		String filename = excel.getOriginalFilename();
		if (filename == null
				|| (!filename.toLowerCase().endsWith(".xls") && !filename.toLowerCase().endsWith(".xlsx"))) {
			throw new RrException("文件格式错误！");
		}
		InputStream inputStream;
		try {
			inputStream = new BufferedInputStream(excel.getInputStream());
			return new ExcelReader(inputStream, null, excelListener, false);
		} catch (IOException e) {
			e.printStackTrace();
		}
		return null;
	}

}
