package com.unis.indicator.server.schedule;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

import com.unis.indicator.common.vo.TbsjVO;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.unis.common.utils.UUIDUtils;
import com.unis.indicator.common.vo.ReportRecordDateVO;
import com.unis.indicator.server.dao.FillInRecordDao;
import com.unis.indicator.server.dao.GrainAndOilPricesDao;
import com.unis.indicator.server.dao.GrainAndOilPricesDetailDao;
import com.unis.indicator.server.dao.ReportBaseDao;
import com.unis.indicator.server.dao.ReportingOfIndexPriceDao;
import com.unis.indicator.server.dao.ReportingOfIndexPriceDetailDao;
import com.unis.indicator.server.dao.TbjlDao;
import com.unis.indicator.server.entity.indicator.ReportBaseDO;
import com.unis.indicator.server.entity.report.LyjgDO;
import com.unis.indicator.server.entity.report.LyjgmxDO;
import com.unis.indicator.server.entity.report.ReportingOfIndexPriceDO;
import com.unis.indicator.server.entity.report.ReportingOfIndexPriceDetailDO;
import com.unis.indicator.server.entity.report.TbjlDO;
import com.unis.indicator.server.enums.ReportTypeEnum;

import io.jsonwebtoken.lang.Collections;
import lombok.extern.slf4j.Slf4j;
import tk.mybatis.mapper.entity.Example;
import tk.mybatis.mapper.entity.Example.Criteria;

/**
 * 
 * @Description：报表定时任务
 * @author：王帅
 * @date: 2020年4月10
 */
@Slf4j
@Component
public class ReportingOfIndexPriceTask {

	@Autowired
	private ReportBaseDao reportInfoDao;

	@Autowired
	private TbjlDao recordDao;

	@Autowired
	private FillInRecordDao fillInRecordDao;

	@Autowired
	private GrainAndOilPricesDao grainAndOilPricesDao;

	@Autowired
	private GrainAndOilPricesDetailDao grainAndOilPricesDetailDao;

	@Autowired
	private ReportingOfIndexPriceDao reportingOfIndexPriceDao;

	@Autowired
	private ReportingOfIndexPriceDetailDao reportingOfIndexPriceDetailDao;

	/**
	 *
	 * @Description:  测试---触发生成历史的周报报表
	 * @author: 王帅---lph修改
	 * @param: 参数
	 * @return: void 返回类型
	 */
	public void  testTriggerWeekReportTaskExec() throws ParseException {
		Date dateEnd=new Date();
		Date date=new SimpleDateFormat("yyyy-MM-dd").parse("2020-01-05");
		Calendar calendar= Calendar.getInstance();
		calendar.setTime(date);

		while(calendar.getTime().getTime()<dateEnd.getTime()){
			date=calendar.getTime();
			System.out.println("date  "+date);
			// 获取集贸零售报表指标数据 -> 指标与基期价
			Map<String, Object> retailMap = this.varietyCollection("BPgRZ6VVTcJs0sVmQ9S");
			// 获取集贸批发报表指数数据 -> 指标与基期价
			Map<String, Object> wholesaleMap = this.varietyCollection("JAqcOZ136Tp8lFyuFlV");
			// 获取当前周开始日期和结束日期
			Map<String, Object> map = this.genMonday(date);
			// 获取集贸零售填报数据
			List<TbjlDO> retailFillInList = this.fillInList(map, "BPgRZ6VVTcJs0sVmQ9S");
			if (CollectionUtils.isNotEmpty(retailFillInList)) {
				// 添加品种与价格集合 -> 集贸零售
				Map<String, TbsjVO> retailVarietyPriceMap = this.varietyPriceMap(retailFillInList);
				// 添加周报填报记录 -> 集贸零售
				this.insertIndexPriceRecord(map, ReportTypeEnum.WEEKLY.getCode(), retailVarietyPriceMap, retailMap,
						"9NjKwnlSuIo6m55HuAO", "集贸零售价格", "BPgRZ6VVTcJs0sVmQ9S",false);
			}
			// 获取集贸批发填报数据
			List<TbjlDO> wholesaleFillInList = this.fillInList(map, "JAqcOZ136Tp8lFyuFlV");

			if (CollectionUtils.isNotEmpty(wholesaleFillInList)) {
				// 添加品种与价格集合 -> 集贸批发
				Map<String, TbsjVO> wholesaleVarietyPriceMap = this.varietyPriceMap(wholesaleFillInList);

				// 添加周报填报记录 -> 集贸批发
				this.insertIndexPriceRecord(map, ReportTypeEnum.WEEKLY.getCode(), wholesaleVarietyPriceMap, wholesaleMap,
						"NOrp6PUmnYCzNOonngt", "集贸批发价格", "JAqcOZ136Tp8lFyuFlV",false);
			}
			log.info("==============周报执行结束==============");
			calendar.add(Calendar.DAY_OF_YEAR,7);
			date=calendar.getTime();
		}
	}

	/**
	 *getActualMaximum
	 * @Description: 测试---月报表（触发生成历史的月报报表
	 * @author: 王帅
	 * @param: 参数
	 * @return: void 返回类型
	 */
	public void  testTriggerMonthReportTaskExec() throws ParseException {
		log.info("==============月报执行开始==============");
		Date dateEnd=new Date();
		Date date=new SimpleDateFormat("yyyy-MM-dd mm:ss").parse("2020-01-31 23:30");
		Calendar calendar= Calendar.getInstance();
		calendar.setTime(date);

		while(calendar.getTime().getTime()<dateEnd.getTime()) {
			date = calendar.getTime();
			System.out.println("date  " + date);
			// 是最后一天 执行逻辑
			// 获取当前周开始日期和结束日期
			Map<String, Object> map = this.getMonthStartAndEnd(date);
			// 获取集贸零售报表指标数据 -> 指标与基期价
			Map<String, Object> retailMap = this.varietyCollection("BPgRZ6VVTcJs0sVmQ9S");
			// 获取集贸零售填报数据
			List<TbjlDO> retailFillInList = this.fillInList(map, "BPgRZ6VVTcJs0sVmQ9S");
			if (CollectionUtils.isNotEmpty(retailFillInList)) {
				// 添加品种与价格集合 -> 集贸零售
				Map<String, TbsjVO> retailVarietyPriceMap = this.varietyPriceMap(retailFillInList);
				// 添加周报填报记录 -> 集贸零售
				this.insertIndexPriceRecord(map, ReportTypeEnum.MONTHLY.getCode(), retailVarietyPriceMap, retailMap,
						"9NjKwnlSuIo6m55HuAO", "集贸零售价格", "BPgRZ6VVTcJs0sVmQ9S",false);
			}
			// 获取集贸批发报表指数数据 -> 指标与基期价
			Map<String, Object> wholesaleMap = this.varietyCollection("JAqcOZ136Tp8lFyuFlV");
			// 获取集贸批发填报数据
			List<TbjlDO> wholesaleFillInList = this.fillInList(map, "JAqcOZ136Tp8lFyuFlV");
			if (CollectionUtils.isNotEmpty(wholesaleFillInList)) {
				// 添加品种与价格集合 -> 集贸批发
				Map<String, TbsjVO> wholesaleVarietyPriceMap = this.varietyPriceMap(wholesaleFillInList);

				// 添加周报填报记录 -> 集贸批发
				this.insertIndexPriceRecord(map, ReportTypeEnum.MONTHLY.getCode(), wholesaleVarietyPriceMap,
						wholesaleMap, "NOrp6PUmnYCzNOonngt", "集贸批发价格", "JAqcOZ136Tp8lFyuFlV",false);
			}
			calendar.add(Calendar.MONTH,1);
			calendar.set(Calendar.DAY_OF_MONTH,calendar.getActualMaximum(Calendar.DAY_OF_MONTH));
			date=calendar.getTime();
			log.info("==============月报执行结束==============");
		}
	}

	/**
	 *
	 * @Description:  测试---触发生成历史的企业周报报表
	 * @author: 王帅---lph修改
	 * @param: 参数
	 * @return: void 返回类型
	 */
	public void  testTriggerCompanyWeekReportTaskExec() throws ParseException {
		Date dateEnd=new Date();
		Date date=new SimpleDateFormat("yyyy-MM-dd").parse("2020-06-15");
		Calendar calendar= Calendar.getInstance();
		calendar.setTime(date);

		while(calendar.getTime().getTime()<dateEnd.getTime()){
			date=calendar.getTime();
			System.out.println("date  "+date);
			// 获取当前周开始日期和结束日期
			Map<String, Object> map = this.genMonday(date);
			// 获取企业填报数据
			Map<String, Object> companyWholesaleMap = this.varietyCollection("qiyebaojia-week");
			List<TbjlDO> companyFillInList = this.fillInList(map, "qiyebaojia-week");
			if (CollectionUtils.isNotEmpty(companyFillInList)) {
				// 添加品种与价格集合 -> 企业
				Map<String, TbsjVO> wholesaleVarietyPriceMap = this.varietyPriceMap(companyFillInList);

				// 添加周报填报记录 -> 企业
				this.insertIndexPriceRecord(map, ReportTypeEnum.WEEKLY.getCode(), wholesaleVarietyPriceMap,
						companyWholesaleMap, "price-type-qiye", "企业报价", "qiyebaojia-week",true);
			}
			log.info("==============周报执行结束==============");
			calendar.add(Calendar.DAY_OF_YEAR,7);
			date=calendar.getTime();
		}
	}

	/**
	 *
	 * @Description:  测试---触发生成历史的企业周报报表
	 * @author: 王帅---lph修改
	 * @param: 参数
	 * @return: void 返回类型
	 */
	public void  testTriggerCompanyMonthReportTaskExec() throws ParseException {
		Date dateEnd=new Date();
		Date date=new SimpleDateFormat("yyyy-MM-dd").parse("2020-06-30");
		Calendar calendar= Calendar.getInstance();
		calendar.setTime(date);

		while(calendar.getTime().getTime()<dateEnd.getTime()){
			date=calendar.getTime();
			System.out.println("date  "+date);
			// 获取当前周开始日期和结束日期
			Map<String, Object> map = this.getMonthStartAndEnd(date);

			// 获取集贸批发报表指数数据 -> 指标与基期价
			Map<String, Object> companyMap = this.varietyCollection("qiyebaojia-week");
			// 获取集贸批发填报数据
			List<TbjlDO>companyFillInList = this.fillInList(map, "qiyebaojia-week");
			if (CollectionUtils.isNotEmpty(companyFillInList)) {
				// 添加品种与价格集合 -> 集贸批发
				Map<String, TbsjVO> companyVarietyPriceMap = this.varietyPriceMap(companyFillInList);

				// 添加月报填报记录 -> 集贸批发
				this.insertIndexPriceRecord(map, ReportTypeEnum.MONTHLY.getCode(), companyVarietyPriceMap,
						companyMap, "price-type-qiye", "企业报价", "qiyebaojia-week",true);
			}

			log.info("==============月报执行结束==============");
			calendar.add(Calendar.MONTH,1);
			calendar.set(Calendar.DAY_OF_MONTH,calendar.getActualMaximum(Calendar.DAY_OF_MONTH));
			date=calendar.getTime();
		}
	}

	/**
	 *
	 * @Description: 测试---只生成 集贸批发 月报
	 * @author: 王帅
	 * @param: 参数
	 * @return: void 返回类型
	 */
	public void testDoMonthReportTaskExec(Date date){
		// 是最后一天 执行逻辑
		// 获取当前周开始日期和结束日期
		Map<String, Object> map = this.getMonthStartAndEnd(date);
		// 获取集贸零售报表指标数据 -> 指标与基期价
		/*Map<String, Object> retailMap = this.varietyCollection("BPgRZ6VVTcJs0sVmQ9S");
		// 获取集贸零售填报数据
		List<TbjlDO> retailFillInList = this.fillInList(map, "BPgRZ6VVTcJs0sVmQ9S");
		if (CollectionUtils.isNotEmpty(retailFillInList)) {
			// 添加品种与价格集合 -> 集贸零售
			Map<String, List<Double>> retailVarietyPriceMap = this.varietyPriceMap(retailFillInList);
			// 添加周报填报记录 -> 集贸零售
			this.insertIndexPriceRecord(map, ReportTypeEnum.MONTHLY.getCode(), retailVarietyPriceMap, retailMap,
					"9NjKwnlSuIo6m55HuAO", "集贸零售价格", "BPgRZ6VVTcJs0sVmQ9S");
		}*/
		// 获取集贸批发报表指数数据 -> 指标与基期价
		Map<String, Object> wholesaleMap = this.varietyCollection("JAqcOZ136Tp8lFyuFlV");
		// 获取集贸批发填报数据
		List<TbjlDO> wholesaleFillInList = this.fillInList(map, "JAqcOZ136Tp8lFyuFlV");
		if (CollectionUtils.isNotEmpty(wholesaleFillInList)) {
			// 添加品种与价格集合 -> 集贸批发
			Map<String, TbsjVO> wholesaleVarietyPriceMap = this.varietyPriceMap(wholesaleFillInList);

			// 添加周报填报记录 -> 集贸批发
			this.insertIndexPriceRecord(map, ReportTypeEnum.MONTHLY.getCode(), wholesaleVarietyPriceMap,
					wholesaleMap, "NOrp6PUmnYCzNOonngt", "集贸批发价格", "JAqcOZ136Tp8lFyuFlV",false);
		}
	}

	/**
	 *
	 * @Description: 测试删除上周周报数据
	 * @author: 王帅
	 * @param: 参数
	 * @return: void 返回类型
	 */
	/*@Scheduled(cron = "0 21 16 * * ?")
	public void testDeleteLaskWeekReportTaskExec() throws ParseException {
		log.info("==============周报测试删除==============");
		Date date=new SimpleDateFormat("yyyy-MM-dd mm:ss").parse("2020-06-14 22:00:00");
		Calendar calendar= Calendar.getInstance();
		calendar.setTime(date);
		deleteLastWeekReportTaskExec(date,"WEEK");
	}*/

	/**
	 *
	 * @Description: 测试删除上周周报数据
	 * @author: 王帅
	 * @param: 参数
	 * @return: void 返回类型
	 */
	/*@Scheduled(cron = "0 32 16 * * ?")
	public void testDeleteLaskWeekReportTaskExec() throws ParseException {
		log.info("==============月报测试删除==============");
		Date date=new SimpleDateFormat("yyyy-MM-dd mm:ss").parse("2020-05-31 22:00:00");
		Calendar calendar= Calendar.getInstance();
		calendar.setTime(date);
		deleteLastMonthReportTaskExec(date,"MONTH");
	}*/

	/**
	 * 
	 * @Description: 周报报表（每周日执行）
	 * @author: 王帅
	 * @param: 参数
	 * @return: void 返回类型
	 */
	@Scheduled(cron = "0 0 22 ? * SUN")
	public void weekReportTaskExec() throws ParseException {
		log.info("==============周报执行开始==============");
		Date date=new Date();
		Calendar calendar=Calendar.getInstance();
		calendar.setTime(date);

		calendar.add(Calendar.DAY_OF_MONTH,-7);
		Date lastWeek=calendar.getTime();
		if(calendar.get(Calendar.DAY_OF_WEEK)==1){
			log.info("==============周报---删除上周数据==============");
			deleteLastWeekReportTaskExec(lastWeek,"WEEK");
			log.info("==============周报---重新生成上周数据==============");
			doWeekReportTaskExec(lastWeek);
			log.info("==============周报---生成本周数据==============");
			doWeekReportTaskExec(date);
		}
		log.info("==============周报执行结束==============");
	}

	public void doWeekReportTaskExec(Date date){
				// 获取集贸零售报表指标数据 -> 指标与基期价
		Map<String, Object> retailMap = this.varietyCollection("BPgRZ6VVTcJs0sVmQ9S");
		// 获取集贸批发报表指数数据 -> 指标与基期价
		Map<String, Object> wholesaleMap = this.varietyCollection("JAqcOZ136Tp8lFyuFlV");
		// 获取当前周开始日期和结束日期
		Map<String, Object> map = this.genMonday(date);
		// 获取集贸零售填报数据
		List<TbjlDO> retailFillInList = this.fillInList(map, "BPgRZ6VVTcJs0sVmQ9S");
		if (CollectionUtils.isNotEmpty(retailFillInList)) {
			// 添加品种与价格集合 -> 集贸零售
			Map<String, TbsjVO> retailVarietyPriceMap = this.varietyPriceMap(retailFillInList);
			// 添加周报填报记录 -> 集贸零售
			this.insertIndexPriceRecord(map, ReportTypeEnum.WEEKLY.getCode(), retailVarietyPriceMap, retailMap,
					"9NjKwnlSuIo6m55HuAO", "集贸零售价格", "BPgRZ6VVTcJs0sVmQ9S",false);
		}
		// 获取集贸批发填报数据
		List<TbjlDO> wholesaleFillInList = this.fillInList(map, "JAqcOZ136Tp8lFyuFlV");

		if (CollectionUtils.isNotEmpty(wholesaleFillInList)) {
			// 添加品种与价格集合 -> 集贸批发
			Map<String, TbsjVO> wholesaleVarietyPriceMap = this.varietyPriceMap(wholesaleFillInList);

			// 添加周报填报记录 -> 集贸批发
			this.insertIndexPriceRecord(map, ReportTypeEnum.WEEKLY.getCode(), wholesaleVarietyPriceMap, wholesaleMap,
					"NOrp6PUmnYCzNOonngt", "集贸批发价格", "JAqcOZ136Tp8lFyuFlV",false);
		}

		// 获取企业填报数据
		Map<String, Object> companyWholesaleMap = this.varietyCollection("qiyebaojia-week");
		List<TbjlDO> companyFillInList = this.fillInList(map, "qiyebaojia-week");
		if (CollectionUtils.isNotEmpty(companyFillInList)) {
			// 添加品种与价格集合 -> 企业
			Map<String, TbsjVO> wholesaleVarietyPriceMap = this.varietyPriceMap(companyFillInList);

			// 添加周报填报记录 -> 企业
			this.insertIndexPriceRecord(map, ReportTypeEnum.WEEKLY.getCode(), wholesaleVarietyPriceMap,
					companyWholesaleMap, "price-type-qiye", "企业报价", "qiyebaojia-week",true);
		}
	}
	public void deleteLastWeekReportTaskExec(Date lastWeekEnd,String type) throws ParseException {
		SimpleDateFormat smp=new SimpleDateFormat("yyyy-MM-dd");
		lastWeekEnd=smp.parse(smp.format(lastWeekEnd));

		Calendar calendar=Calendar.getInstance();
		calendar.setTime(lastWeekEnd);
		calendar.add(Calendar.DAY_OF_MONTH,-6);
		Date lastWeekStart=calendar.getTime();

		ReportingOfIndexPriceDO indexPriceEntity = new ReportingOfIndexPriceDO();
		indexPriceEntity.setSbkssj(lastWeekStart);
		indexPriceEntity.setSbjssj(lastWeekEnd);
		indexPriceEntity.setType(type);

		//ReportingOfIndexPriceDetailDO detailEntity = new ReportingOfIndexPriceDetailDO();
		reportingOfIndexPriceDetailDao.deleteByEntity(indexPriceEntity);

		reportingOfIndexPriceDao.deleteByEntity(indexPriceEntity);
	}
	public void deleteLastMonthReportTaskExec(Date lastWeekEnd,String type) throws ParseException {
		SimpleDateFormat smp=new SimpleDateFormat("yyyy-MM-dd");
		lastWeekEnd=smp.parse(smp.format(lastWeekEnd));

		Calendar calendar=Calendar.getInstance();
		calendar.setTime(lastWeekEnd);
		calendar.set(Calendar.DAY_OF_MONTH,1);
		Date lastWeekStart=calendar.getTime();

		ReportingOfIndexPriceDO indexPriceEntity = new ReportingOfIndexPriceDO();
		indexPriceEntity.setSbkssj(lastWeekStart);
		indexPriceEntity.setSbjssj(lastWeekEnd);
		indexPriceEntity.setType(type);

		//ReportingOfIndexPriceDetailDO detailEntity = new ReportingOfIndexPriceDetailDO();
		reportingOfIndexPriceDetailDao.deleteByEntity(indexPriceEntity);

		reportingOfIndexPriceDao.deleteByEntity(indexPriceEntity);
	}

	public void weekHistoryRecordImport() {
		log.info("==============周报执行开始==============");
		// 获取集贸零售报表指标数据 -> 指标与基期价
		Map<String, Object> retailMap = this.varietyCollection("BPgRZ6VVTcJs0sVmQ9S");
		// 获取集贸批发报表指数数据 -> 指标与基期价
		Map<String, Object> wholesaleMap = this.varietyCollection("JAqcOZ136Tp8lFyuFlV");
		List<ReportRecordDateVO> recordDateList = recordDao.findReportDateList();
		recordDateList.forEach(obj -> {
			String start = obj.getSbkssj();
			String end = obj.getSbjssj();
			SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
			// 获取当前周开始日期和结束日期
			Map<String, Object> map = Maps.newHashMap();
			map.put("start", start);
			map.put("end", end);
			try {
				Date startDate = sdf.parse(start);
				Date endDate = sdf.parse(end);
				map.put("startDate", startDate);
				map.put("endDate", endDate);
			} catch (ParseException e) {
				e.printStackTrace();
			}
			// 获取集贸零售填报数据
			List<TbjlDO> retailFillInList = this.fillInList(map, "BPgRZ6VVTcJs0sVmQ9S");
			if (CollectionUtils.isNotEmpty(retailFillInList)) {
				// 添加品种与价格集合 -> 集贸零售
				Map<String,TbsjVO> retailVarietyPriceMap = this.varietyPriceMap(retailFillInList);
				// 添加周报填报记录 -> 集贸零售
				this.insertIndexPriceRecord(map, ReportTypeEnum.WEEKLY.getCode(), retailVarietyPriceMap, retailMap,
						"9NjKwnlSuIo6m55HuAO", "集贸零售价格", "BPgRZ6VVTcJs0sVmQ9S",false);
			}

			// 获取集贸批发填报数据
			List<TbjlDO> wholesaleFillInList = this.fillInList(map, "JAqcOZ136Tp8lFyuFlV");
			if (CollectionUtils.isNotEmpty(wholesaleFillInList)) {
				// 添加品种与价格集合 -> 集贸批发
				Map<String, TbsjVO> wholesaleVarietyPriceMap = this.varietyPriceMap(wholesaleFillInList);

				// 添加周报填报记录 -> 集贸批发
				this.insertIndexPriceRecord(map, ReportTypeEnum.WEEKLY.getCode(), wholesaleVarietyPriceMap,
						wholesaleMap, "NOrp6PUmnYCzNOonngt", "集贸批发价格", "JAqcOZ136Tp8lFyuFlV",false);
			}
		});
	}

	/**
	 * 
	 * @Description: 月报表（每月最后一天执行）
	 * @author: 王帅
	 * @param: 参数
	 * @return: void 返回类型
	 */
	@Scheduled(cron = "0 30 23 28-31 * ?")
	public void monthReportTaskExec() throws ParseException {
		log.info("==============月报执行开始==============");
		final Calendar c = Calendar.getInstance();

		if (c.get(Calendar.DATE) == c.getActualMaximum(Calendar.DATE)) {

			c.add(Calendar.MONTH,-1);
			c.set(Calendar.DAY_OF_MONTH, c.getActualMaximum(Calendar.DAY_OF_MONTH));
			Date lastMonth=c.getTime();

			Date date	=new Date();
			log.info("==============月报---删除上月数据==============");
			deleteLastMonthReportTaskExec(lastMonth,"MONTH");
			log.info("==============月报---重新生成上月数据==============");
			doMonthReportTaskExec(lastMonth);
			log.info("==============月报---生成本月数据==============");
			doMonthReportTaskExec(date);
		}
		log.info("==============月报执行结束==============");
	}

	public void doMonthReportTaskExec(Date date){
		// 是最后一天 执行逻辑
		// 获取当前周开始日期和结束日期
		Map<String, Object> map = this.getMonthStartAndEnd(date);
		// 获取集贸零售报表指标数据 -> 指标与基期价
		Map<String, Object> retailMap = this.varietyCollection("BPgRZ6VVTcJs0sVmQ9S");
		// 获取集贸零售填报数据
		List<TbjlDO> retailFillInList = this.fillInList(map, "BPgRZ6VVTcJs0sVmQ9S");
		if (CollectionUtils.isNotEmpty(retailFillInList)) {
			// 添加品种与价格集合 -> 集贸零售
			Map<String, TbsjVO> retailVarietyPriceMap = this.varietyPriceMap(retailFillInList);
			// 添加周报填报记录 -> 集贸零售
			this.insertIndexPriceRecord(map, ReportTypeEnum.MONTHLY.getCode(), retailVarietyPriceMap, retailMap,
					"9NjKwnlSuIo6m55HuAO", "集贸零售价格", "BPgRZ6VVTcJs0sVmQ9S"
			,false);
		}
		// 获取集贸批发报表指数数据 -> 指标与基期价
		Map<String, Object> wholesaleMap = this.varietyCollection("JAqcOZ136Tp8lFyuFlV");
		// 获取集贸批发填报数据
		List<TbjlDO> wholesaleFillInList = this.fillInList(map, "JAqcOZ136Tp8lFyuFlV");
		if (CollectionUtils.isNotEmpty(wholesaleFillInList)) {
			// 添加品种与价格集合 -> 集贸批发
			Map<String, TbsjVO> wholesaleVarietyPriceMap = this.varietyPriceMap(wholesaleFillInList);

			// 添加周报填报记录 -> 集贸批发
			this.insertIndexPriceRecord(map, ReportTypeEnum.MONTHLY.getCode(), wholesaleVarietyPriceMap,
					wholesaleMap, "NOrp6PUmnYCzNOonngt", "集贸批发价格", "JAqcOZ136Tp8lFyuFlV",false);
		}

		// 获取集贸批发报表指数数据 -> 指标与基期价
		Map<String, Object> companyMap = this.varietyCollection("qiyebaojia-week");
		// 获取集贸批发填报数据
		List<TbjlDO>companyFillInList = this.fillInList(map, "qiyebaojia-week");
		if (CollectionUtils.isNotEmpty(companyFillInList)) {
			// 添加品种与价格集合 -> 集贸批发
			Map<String, TbsjVO> companyVarietyPriceMap = this.varietyPriceMap(companyFillInList);

			// 添加月报填报记录 -> 集贸批发
			this.insertIndexPriceRecord(map, ReportTypeEnum.MONTHLY.getCode(), companyVarietyPriceMap,
					companyMap, "price-type-qiye", "企业报价", "qiyebaojia-week",true);
		}
	}

	/**
	 * 
	 * @Description: 获取报表信息-基期价 指标名称
	 * @author: 王帅
	 * @param: @param  reportTypeId
	 * @param: @return 参数
	 * @return: Map<String,Object> 返回类型
	 */
	public Map<String, Object> varietyCollection(String reportTypeId) {
		List<ReportBaseDO> reportListRetail = reportInfoDao.findListByReportTypeId(reportTypeId);
		// 指标编码与基期价
		/*Map<String, Double> reportMap = reportListRetail.stream()
				.collect(Collectors.toMap(ReportBaseDO::getIndicatorId, ReportBaseDO::getJqj));*/
		Map<String, Double> reportMap =new LinkedHashMap<>();
		for(ReportBaseDO reportBaseDO: reportListRetail){
			reportMap.put(reportBaseDO.getIndicatorId()+"-"+reportBaseDO.getZbbzId(),reportBaseDO.getJqj());
		}

		// 指标编码与名称
		Map<String, String> varietyCodeAndName =new LinkedHashMap<>();
	/*	Map<String, String> varietyCodeAndName = reportListRetail.stream()
				.collect(Collectors.toMap(ReportBaseDO::getIndicatorId, ReportBaseDO::getIndicatorName));*/
		for(ReportBaseDO reportBaseDO: reportListRetail){
			varietyCodeAndName.put(reportBaseDO.getIndicatorId()+"-"+reportBaseDO.getZbbzId(),reportBaseDO.getIndicatorName());
		}

		// 指标编码与顺序
		Map<String, Integer> varietyCodeAndOrder = new LinkedHashMap<>();
		/*Map<String, Integer> varietyCodeAndOrder = reportListRetail.stream()
				.collect(Collectors.toMap(ReportBaseDO::getIndicatorId, ReportBaseDO::getPzsx));*/
		for(ReportBaseDO reportBaseDO: reportListRetail){
			varietyCodeAndOrder.put(reportBaseDO.getIndicatorId()+"-"+reportBaseDO.getZbbzId(),reportBaseDO.getPzsx());
		}

		Map<String, Object> collection = Maps.newHashMap();
		collection.put("price", reportMap);
		collection.put("variety", varietyCodeAndName);
		collection.put("order", varietyCodeAndOrder);

		return collection;
	}

	/**
	 * 
	 * @Description: 获取填报记录集合 根据 报表类型
	 * @author: 王帅
	 * @param: @param  map
	 * @param: @param  reportTypeId
	 * @param: @return 参数
	 * @return: List<TbjlDO> 返回类型
	 */
	public List<TbjlDO> fillInList(Map<String, Object> map, String reportTypeId) {
		Example exampleFillIn = new Example(TbjlDO.class);
		Criteria criteriaFillIn = exampleFillIn.createCriteria();
		criteriaFillIn.andGreaterThanOrEqualTo("sbkssj", map.get("start"));
		criteriaFillIn.andLessThan("sbkssj", map.get("end"));
//		criteriaFillIn.andGreaterThan("sbkssj", "2020-03-30");
//		criteriaFillIn.andLessThanOrEqualTo("sbjssj", "2020-04-06");
		criteriaFillIn.andEqualTo("bblxId", reportTypeId); // 报表类型
		criteriaFillIn.andNotEqualTo("lcid",1);
		// 数据列表
		return fillInRecordDao.selectByExample(exampleFillIn);
	}

	/**
	 * 
	 * @Description: 添加品种与价格集合
	 * @author: 王帅
	 * @param: @param  fillInList
	 * @param: @return 参数
	 * @return: Map<String,List<Double>> 返回类型
	 */
	public Map<String, TbsjVO> varietyPriceMap(List<TbjlDO> fillInList) {
		Map<String, TbsjVO> varietyPriceMap = Maps.newHashMap();
		for (TbjlDO fillIn : fillInList) {
			String parentId = fillIn.getId();
			Example exampleIndex = new Example(LyjgDO.class);
			Criteria criteriaIndex = exampleIndex.createCriteria();
			criteriaIndex.andEqualTo("tbjlId", parentId);
			// 获取填报指标记录
			List<LyjgDO> indexList = grainAndOilPricesDao.selectByExample(exampleIndex);
			for (LyjgDO index : indexList) {
				Example exampleIndexDetail = new Example(LyjgmxDO.class);
				Criteria criteriaIndexDetail = exampleIndexDetail.createCriteria();
				criteriaIndexDetail.andEqualTo("lyjgId", index.getId());
				// 获取指标价格详情
				LyjgmxDO detail = grainAndOilPricesDetailDao.selectOneByExample(exampleIndexDetail);
				// 获取指标编码
				String variety = index.getZbbm()+"-"+index.getJlbzbm();
				// 获取已添加指标价格记录
				TbsjVO tbsjVO = varietyPriceMap.get(variety);
				if (!varietyPriceMap.containsKey(variety)) {
					List<Double> priceList = Lists.newArrayList();
					tbsjVO=new TbsjVO();
					Double price = detail.getBqjg();
					if (null != price && price > 0D) {
						priceList.add(detail.getBqjg());
					}
					tbsjVO.setDataList(priceList);
					tbsjVO.setZbbm(index.getZbbm());
					tbsjVO.setJlbzbm(index.getJlbzbm());
					tbsjVO.setJlbz(index.getJlbz());

					varietyPriceMap.put(variety, tbsjVO);
				} else {
					List<Double> priceList=tbsjVO.getDataList();
					Double price = detail.getBqjg();
					if (null != price && price > 0D) {
						priceList.add(detail.getBqjg());
					}
				}

			}
		}

		return varietyPriceMap;
	}

	/**
	 * 
	 * @Description: 添加报表填报记录
	 * @author: 王帅
	 * @param: @param map
	 * @param: @param type
	 * @param: @param varietyPriceMap
	 * @param: @param varitysMap 参数
	 * @return: void 返回类型
	 */
	@SuppressWarnings("unchecked")
	public void insertIndexPriceRecord(Map<String, Object> map, String type, Map<String, TbsjVO> varietyPriceMap,
			Map<String, Object> varitysMap, String priceTypeId, String priceTypeName, String reportTypeId, boolean withZl) {
		Map<String, Double> reportMap = (Map<String, Double>) varitysMap.get("price");
		Map<String, String> varietyCodeAndName = (Map<String, String>) varitysMap.get("variety");
		Map<String, Integer> varietyCodeAndOrder = (Map<String, Integer>) varitysMap.get("order");
		ReportingOfIndexPriceDO indexPriceEntity = new ReportingOfIndexPriceDO();
		indexPriceEntity.setId(UUIDUtils.uuid());
		indexPriceEntity.setCreateTime(new Date());
		indexPriceEntity.setType(type);
		indexPriceEntity.setSbkssj((Date) map.get("startDate"));
		indexPriceEntity.setSbjssj((Date) map.get("endDate"));
		indexPriceEntity.setPriceTypeId(priceTypeId);
		indexPriceEntity.setPriceTypeName(priceTypeName);
		indexPriceEntity.setReportTypeId(reportTypeId);
		int result = reportingOfIndexPriceDao.insertSelective(indexPriceEntity);
		if (result > 0) {
			for (String key : varietyPriceMap.keySet()) {
				ReportingOfIndexPriceDetailDO detailEntity = new ReportingOfIndexPriceDetailDO();

				TbsjVO tbsjVO =varietyPriceMap.get(key);

				detailEntity.setId(UUIDUtils.uuid());
				detailEntity.setZbbm(tbsjVO.getZbbm());
				detailEntity.setXh(varietyCodeAndOrder.get(key));

				//标准编码和标准名称
				if(withZl){
					detailEntity.setJlbzbm(tbsjVO.getJlbzbm());
					detailEntity.setJlbz(tbsjVO.getJlbz());
				}

				detailEntity.setPzmc(varietyCodeAndName.get(key));
				detailEntity.setReportId(indexPriceEntity.getId());

				List<Double> prices = tbsjVO.getDataList();
				if (!Collections.isEmpty(prices)) {
					Double price = 0D;
					for (Double obj : prices) {
						price += obj;
					}
					detailEntity.setJg(price / prices.size());
					Double dbZS= reportMap.get(key);
					if(dbZS!=null && !dbZS.isNaN()){
						try {
							detailEntity.setZs((detailEntity.getJg() * 100) / reportMap.get(key));
						}catch (Exception  e){
							e.printStackTrace();
						}
					}
				}
				reportingOfIndexPriceDetailDao.insertSelective(detailEntity);
			}
		}
	}

	// 根据输入时间返回所在周周一日期
	public Map<String, Object> genMonday(Date date) {
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
		Calendar cal = Calendar.getInstance();
		cal.setTime(date);
		if (cal.get(Calendar.DAY_OF_WEEK) == 1) {
			cal.add(Calendar.DATE, -1);
		}

		Calendar cf = Calendar.getInstance();
		cf.setTime(cal.getTime());
		cf.set(Calendar.DAY_OF_WEEK, cf.getFirstDayOfWeek());
		cf.add(Calendar.DATE, 1);

		Map<String, Object> result = Maps.newHashMap();
		result.put("end", sdf.format(date));
		result.put("endDate", date);
		result.put("startDate", cf.getTime());
		result.put("start", sdf.format(cf.getTime()));
		return result;
	}

	// 获取给定日期月初和月末
	public Map<String, Object> getMonthStartAndEnd(Date date) {
		Calendar c = Calendar.getInstance();
		c.setTime(date);
		int lastMonthMaxDay = c.getActualMaximum(Calendar.DAY_OF_MONTH);
		c.set(c.get(Calendar.YEAR), c.get(Calendar.MONTH), lastMonthMaxDay, 23, 59, 59);

		Map<String, Object> result = Maps.newHashMap();
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
		result.put("end", sdf.format(c.getTime()));
		result.put("endDate", c.getTime());
		// 获取月第一天
		int firstMonthMaxDay = c.getActualMinimum(Calendar.DAY_OF_MONTH);
		c.set(c.get(Calendar.YEAR), c.get(Calendar.MONTH), firstMonthMaxDay, 00, 00, 00);

		SimpleDateFormat start = new SimpleDateFormat("yyyy-MM");
		result.put("start", start.format(date) + "-01");
		result.put("startDate", c.getTime());

		return result;
	}

}
