package com.unis.indicator.server.service;

import com.unis.indicator.common.vo.IndicatorMonitorVO;
import com.unis.indicator.common.vo.IndicatorPriceVO;
import com.unis.indicator.common.vo.IndicatorStandardVO;
import com.unis.indicator.common.vo.IndicatorVO;

import java.util.List;
import java.util.Map;

/**
 * @author xmpu
 * @version 1.0
 * @Title: IndicatorService
 * @ProjectName IndicatorService
 * @Description: 指标service
 * @date 2019/7/24 17:04
 */
public interface IndicatorService {

    /**
     *
     * @Description: 通过id查询指标信息
     * @author xmpu
     * @version v1.0
     *
     * @param id
     * @return MonitoringPlaceDO
     */
    public IndicatorVO findById(String id) throws Exception;

    public boolean findIndMonRel(String id) throws Exception;

    /**
     *
     * @Description: 查询所有指标信息 模糊查询的条件可以包含：名称
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @param page
     * @param size
     * @return Map
     * @throws Exception
     */
    public Map<String, Object> findByPage(IndicatorVO VO, Integer page, Integer size) throws Exception;

    /**
     *
     * @Description: 查询所有用户(按品种分组)
     * @date 2019/12/17 16:06
     * @author yangshengjie
     * @version v1.0
     *
     * @param VO
     * @param page
     * @param size
     * @return List
     * @throws Exception
     */
    public List findByPageGroup(IndicatorVO VO, Integer page, Integer size) throws Exception;

    /**
     *
     * @Description: 多选删除指标
     * @date 2019年7月24日,下午8:58:47
     * @author xmpu
     * @version v1.0
     *
     * @param ids
     * @param userId
     * @return Boolean
     * @throws Exception
     */
    public boolean deletes(String[] ids, String userId) throws Exception;

    /**
     *
     * @Description: 保存指标信息
     * @date 2019年7月24日,下午8:58:56
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @return boolean
     * @throws Exception
     */
    public boolean save(IndicatorVO VO) throws Exception;

    /**
     *
     * @Description: 更新指标信息
     * @date 2019年7月24日,下午8:59:05
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @return boolean
     * @throws Exception
     */
    public boolean update(IndicatorVO VO) throws Exception;

    /**
     *
     * @Description: 查询所有指标信息树形结构
     * @date 2019年7月24日,下午8:59:05
     * @author xmpu
     * @version v1.0
     *
     * @return List
     * @throws Exception
     */
    public List<IndicatorVO> findIndsTree(String treeCode) throws Exception;

    /**
     *
     * @Description: 查询监测点对应勾选了的指标
     * @date 2019年7月24日,下午8:59:05
     * @author xmpu
     * @version v1.0
     *
     * @return IndicatorMonitorVO
     * @throws Exception
     */
    public IndicatorMonitorVO findIndicatorMonitor(String monitorId) throws Exception;

    /**
     *
     * @Description: 指标与监测点保存
     * @date 2019年7月24日,下午8:58:47
     * @author xmpu
     * @version v1.0
     *
     * @param vo
     * @return Boolean
     * @throws Exception
     */
    public boolean saveIndicatorMonitor(IndicatorMonitorVO vo) throws Exception;

    /**
     *
     * @Description: 查询指标对应勾选了的指标标准
     * @date 2019年7月24日,下午8:59:05
     * @author xmpu
     * @version v1.0
     *
     * @return IndicatorStandardVO
     * @throws Exception
     */
    public IndicatorStandardVO findIndicatorStandard(String indicatorId) throws Exception;

    /**
     *
     * @Description: 指标标准与指标保存
     * @date 2019年7月24日,下午8:58:47
     * @author xmpu
     * @version v1.0
     *
     * @param vo
     * @return Boolean
     * @throws Exception
     */
    public boolean saveIndicatorStandard(IndicatorStandardVO vo) throws Exception;

    /**
     *
     * @Description: 查询指标对应勾选了的价格类型
     * @date 2019年7月24日,下午8:59:05
     * @author xmpu
     * @version v1.0
     *
     * @return IndicatorStandardVO
     * @throws Exception
     */
    public IndicatorPriceVO findIndicatorPriceType(String indicatorId) throws Exception;

    /**
     *
     * @Description: 价格类型与指标保存
     * @date 2019年7月24日,下午8:58:47
     * @author xmpu
     * @version v1.0
     *
     * @param vo
     * @return Boolean
     * @throws Exception
     */
    public boolean saveIndicatorPriceType(IndicatorPriceVO vo) throws Exception;
}

