package com.unis.indicator.server.service;

import com.alibaba.fastjson.JSONObject;
import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.text.ParseException;
import java.util.Date;
import java.util.List;
import java.util.Map;

public interface ReportRecordService {

    /**
     * 价格趋势查询
     * @param bbvo
     */
    Map<String, Object> findByQuery(ReportRecordVO bbvo);

    /**
     * @Description: 内蒙粮油价格上报
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    Boolean save(ReportRecordInfoVO reportRecordInfoVO);

    /**
     * @Description: 天津粮油价格详情
     * @date
     * @author yangshengjie
     * @version v1.0
     *
     * @param
     * @return ReportRecordInfoVO
     */
    ReportRecordInfoVO getOneByIdTj(String id,String jglx);

    /**
     * @Description: 内蒙粮油价格详情
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    ReportRecordInfoVO getById(String id);

    /**
     * @Description: 填报记录列表
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    Map<String, Object> getByQuery(ReportRecordListVO reportRecordListVO, Integer page, Integer size);

    /**
     * @Description: 内蒙粮油价格编辑
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    void update(ReportRecordInfoVO reportRecordInfoVO);

    /**
     * @Description: 内蒙古获取上期数据
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    ReportRecordInfoVO lastInfo(ReportRecordListVO reportRecordListVO);

    /**
     * @Description: 全国价格指数上报
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    Boolean saveQgjgzs(NationIndexReportInfoVO nationIndexReportInfoVO);

    /**
     * @Description: 全国价格指数报表编辑
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    void updateQgjgzs(NationIndexReportInfoVO nationIndexReportInfoVO);

    /**
     * @Description: 全国价格指数报表查看
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    NationIndexReportInfoVO getQgjgzsById(String id);

    Map<String, Object> getQgjgzsByQuery(ReportRecordListVO reportRecordListVO, Integer page, Integer size);

    /**
     * @Description: 天津获取上一期数据
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
   /* LastReportRecordInfoVO lastInfot(ReportRecordListVO reportRecordListVO);*/

    /**
     * @Description: 天津粮油价格上报
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    Boolean saveOne(ReportRecordInfoVO reportRecordInfoVO) throws ParseException;

    /**
     * @Description: 天津粮油价格编辑
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    ResponseWrapper updateOne(ReportRecordInfoVO reportRecordInfoVO) throws ParseException;

    /**
     * @Description: 天津粮油价格详情
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    ReportRecordInfoVO getOneById(String id);

    ReportRecordInfoVO reportOneLastest(PriceTrendQueryVO vo);

    /**
     * @Description: 填报记录状态修改
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    void updateStatus(ReportRecordStatusVo reportRecordStatusVo);

    /**
     * @Description: 根据当前登录检测点 获取驳回数据
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param bblxId
     * @return ResponseWrapper
     */
    Map<String, Object> getRejectReport(String bblxId, String pointId);
    Map<String, Object> getRejectReportBy(String bblxId, String pointId);
    /**
     * @Description: 天津上报统计查询
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param statisticsInputVO
     * @return ResponseWrapper
     */
    Map<String, Object> getTjStatistics(StatisticsInputVO statisticsInputVO);

    /**
     * @Description: 天津上报统计详情
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    Map<String, Object> getTjStatisticsInfo(StatisticsInputVO statisticsInputVO);

    /**
     * @Description: 内蒙上报统计查询
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    Map<String, Object> getNmStatistics(StatisticsInputVO statisticsInputVO);

    /**
     * @Description: 价格统计日报表
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    Map<String, Object> getPriceDay(PriceStatisticsInputVO priceStatisticsInputVO);

    /**
     * @Description: 价格统计周报表
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    Map<String, Object> getPriceWeek(PriceStatisticsInputVO priceStatisticsInputVO);

    /**
     * @Description: 价格统计月报表
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    Map<String, Object> getPriceMonth(PriceStatisticsInputVO priceStatisticsInputVO);

    /**
     * @Description: 价格走势录入(周/月)列表
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    Map<String, Object> getPriceTrend(PriceTrendQueryVO priceTrendQueryVO);

    Map<String, Object> getPriceTrendTj(PriceTrendQueryVO priceTrendQueryVO);

    Map<String, Object> getPriceTrendCT(PriceTrendQueryVO priceTrendQueryVO);

    /**
     * @Description: (周/月)价格走势录入回显
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    Map<String,Object> getHistoryPrice(PriceTrendQueryVO priceTrendQueryVO) throws ParseException;

    /**
     * @Description: 无固定时间统计
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    Map<String, Object> getTimePrice(PriceStatisticsInputVO priceStatisticsInputVO);

    /**
     * @Description: 周刊报表列表
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param weeklyReportVO
     * @return
     */
    Map<String, Object> getWeeklyReportList(WeeklyReportVO weeklyReportVO);

    /**
     * @Description: 周刊报表详情
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    Map<String, Object> getWeeklyReportInfo(WeeklyReportVO weeklyReportVO);

    /**
     * @Description: 价格走势图表(周/月)
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    List<Map<String,Object>> getTrendChart(PriceTrendQueryVO priceTrendQueryVO);
    List<Map<String,Object>> getTrendChartByZs(PriceTrendQueryVO priceTrendQueryVO);
    /**
     * @Description: 价格走势月批量导入
     * @date 2019年8月16日,下午5:54:00
     * @author 任宇
     * @version v1.0
     *
     * @param file
     * @return ResponseWrapper
     */
    Map<String, Object> excelInput(MultipartFile file, String bblxId);

    /**
     * @Description: 定时任务调度(根据监测点、价格类型、日期判断并填充数据(1:判断当日有无上报过该类型数据2:如未上报则按上一期数据记录填充3如已上报则不执行操作))
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return
     */
    void taskAdd(TaskVO taskVO);

    /**
     * @Description: 价格上报相关导出
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return
     */
    void excelOutput(String id, HttpServletResponse response);

    /**
     * @Description: 价格走势月录入模版下载
     * @date 2019年8月16日,下午5:54:00
     * @author 任宇
     * @version v1.0
     *
     * @param bblxId
     * @return ResponseWrapper
     */
    void excelModel(HttpServletResponse response, String bblxId);

    /**
     * @Description: 获取价格类型对应月报表的价格类型
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return String
     */
    String monthPriceType(String bblxId);

    /**
     * @Description: 查询指定时间报表是否已存在
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    Integer isReport(ReportRecordInfoVO info);

    /**
     * @Description: 收购季周报上报
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    void quarterlyReport(QuarterlyReportVO quarterlyReportVO);

    /**
     * @Description: 收购季周报汇总查询
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return Map
     */
    Map<String, Object> quarterlyPool(QuarterlyReportInputVO quarterlyReportInputVO);

    /**
     * @Description: 收购季周报监测点上报回显
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    Map<String, Object> quarterlyPoint(QuarterlyReportInputVO quarterlyReportInputVO);

    /**
     * @Description: 价格走势录入月计算
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    void calculation();

    /**
     * @Description: 数据维护发布(盟市功能 )
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    Boolean release(String orgId, Integer num);

    /**
     * @Description: 生成本级数据(盟市功能 )
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    Boolean level(String orgId, Integer num);

    /**
     * @Description: 预警规则新增
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    void saveWarningRole(WarningRoleVO warningRoleVO);

    /**
     * @Description: 预警规则编辑
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    void updateWarningRole(WarningRoleVO warningRoleVO);

    /**
     * @Description: 预警规则详情
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    WarningRoleVO getWarningRole(String id);

    /**
     * @Description: 预警规则删除
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    void deleteWarningRole(String id);

    /**
     * @Description: 预警规则列表()
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param5
     * @return ResponseWrapper
     */
    Map<String, Object> getWarningRoles(WarningRoleQueryVO warningRoleQueryVO);

    /**
     * @Description: 我的工作平台-用户信息(org_id登录用户组织机构 num本期需要填报的监测点数量)
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return ResponseWrapper
     */
    Map<String, Object> getInformation(String orgId, Integer num);

    void quarterlyReportupdate(QuarterlyReportVO quarterlyReportVO);

    /**
     * @Description: 周报月统计
     * @date
     * @author yangshengjie
     * @version v1.0
     *
     * @param
     * @return list
     */
    List<Map<String, Object>> getPriceMonthAvg(PriceStatisticsInputVO priceStatisticsInputVO) throws  Exception ;

    /**
     * @Description: 周均价统计
     * @date
     * @author yangshengjie
     * @version v1.0
     *
     * @param
     * @return list
     */
    List<Map<String, Object>> getPriceWeekAvg(PriceStatisticsInputVO priceStatisticsInputVO) throws  Exception ;
    
    /**
     * 
     * @Description: 修改填报记录品种编码和现有指标编码对应
     * @author: 王帅
     * @param: @param formType
     * @param: @return  参数
     * @return: boolean    返回类型
     */
    public boolean modifyReportFormsRecordVarietyCode(String formType);
    

    /**
     * 
     * @Description: 全国价格指数走势统计图（津粮网）
     * @author: 王帅
     * @param: @param record
     * @param: @return  参数
     * @return: JSONObject    返回类型
     */
	public JSONObject showNationalPriceIndexTrend(ReportRecordVO record);
	
	/**
	 * 
	 * @Description: 获取全国价格指数走势所有品种
	 * @author: 王帅
	 * @param: @param formType
	 * @param: @return  参数
	 * @return: JSONObject    返回类型
	 */
	public JSONObject getNationalPriceIndexVarietys(String formType);
	
	/**
	 * 
	 * @Description: 添加粮油价格品种根据现存记录
	 * @author: 王帅
	 * @param: @param reportType
	 * @param: @param startTime
	 * @param: @param endTime
	 * @param: @param recordId
	 * @param: @param varietyName
	 * @param: @param varietyCode
	 * @param: @param detailId 参数
	 * @return: void 返回类型
	 */
	public void addReportRecordVariety(String reportType, String startTime, Date endTime, String recordId,
			String varietyName, String varietyCode, String detailId);

    /**
     * @Description: 定时任务调度(根据监测点、价格类型、日期判断并填充数据(1:判断当日有无上报过该类型数据2:如未上报则按上一期数据记录填充3如已上报则不执行操作))
     * @date
     * @author renyu
     * @version v1.0
     *
     * @param
     * @return
     */
    void lYPriceDailyTaskAdd(TaskVO taskVO);
}
