package com.unis.indicator.server.service;

import com.unis.indicator.common.vo.IndicatorVO;
import com.unis.indicator.common.vo.WeightVO;
import com.unis.indicator.common.vo.WeightValueVO;
import com.unis.indicator.server.entity.indicator.QzzDO;

import java.util.List;
import java.util.Map;

/**
 * @author xmpu
 * @version 1.0
 * @Title: WeightService
 * @ProjectName WeightService
 * @Description: 权重service
 * @date 2019/7/24 17:04
 */
public interface WeightService {

    /**
     *
     * @Description: 通过id查询权重信息
     * @author xmpu
     * @version v1.0
     *
     * @param id
     * @return WeightVO
     */
    public WeightVO findById(String id) throws Exception;

    /**
     *
     * @Description: 查询所有权重信息 模糊查询的条件可以包含：名称
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @param page
     * @param size
     * @return Map
     * @throws Exception
     */
    public Map<String, Object> findByPage(WeightVO VO, Integer page, Integer size) throws Exception;

    /**
     *
     * @Description: 多选删除权重
     * @date 2019年7月24日,下午8:58:47
     * @author xmpu
     * @version v1.0
     *
     * @param ids
     * @param userId
     * @return Boolean
     * @throws Exception
     */
    public boolean deletes(String[] ids, String userId) throws Exception;

    /**
     *
     * @Description: 保存权重信息
     * @date 2019年7月24日,下午8:58:56
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @return boolean
     * @throws Exception
     */
    public boolean save(WeightVO VO) throws Exception;

    /**
     *
     * @Description: 更新权重信息
     * @date 2019年7月24日,下午8:59:05
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @return boolean
     * @throws Exception
     */
    public boolean update(WeightVO VO) throws Exception;

    /**
     *
     * @Description: 通过权重code查询权重值信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param code
     * @return List<WeightValueVO>
     */
    public List<WeightValueVO> findWeightValByWeightCode(String code) throws Exception;

    /**
     *
     * @Description: 权重值保存
     * @date 2019年7月24日,下午8:58:47
     * @author xmpu
     * @version v1.0
     *
     * @param voList
     * @param weightCode
     * @return Boolean
     * @throws Exception
     */
    public boolean saveWeightVal(List<WeightValueVO> voList, String weightCode) throws Exception;

    /**
     *
     * @Description: 通过权重type查询权重值信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param type
     * @return List<IndicatorVO>
     */
    public List<IndicatorVO> findWeightValByWeightType(String type) throws Exception;
}

