package com.unis.indicator.server.service.impl;

import java.io.UnsupportedEncodingException;
import java.text.SimpleDateFormat;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.ObjectUtils;

import com.unis.common.utils.LsBeanUtils;
import com.unis.indicator.common.vo.ContributeArticleVO;
import com.unis.indicator.server.domain.ContributeArticleDomain;
import com.unis.indicator.server.enums.AuditingStatusEnum;
import com.unis.indicator.server.service.ContributeArticleService;

import lombok.extern.slf4j.Slf4j;

/**
 * @ClassName ContributeArticleServiceImpl
 * @Description 文章投稿
 * @Author xmpu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@Slf4j
@Service
public class ContributeArticleServiceImpl implements ContributeArticleService {

	@Autowired
	private ContributeArticleDomain domain;

	@Override
	public ContributeArticleVO findById(String id) throws Exception {
        ContributeArticleVO res =  LsBeanUtils.copyProperties(domain.findArtById(id), ContributeArticleVO.class);
		if(!ObjectUtils.isEmpty(res)) {
			changeIdToName(res);
		}
        
        return res;
	}
	
	@Override
	public Map<String, Object> findByPage(ContributeArticleVO VO, Integer page, Integer size, String isUser) throws Exception {
		Map<String, Object> resMap  = domain.findArtsByPage(VO, page, size, isUser);
		List<ContributeArticleVO> resultList = (List<ContributeArticleVO>) resMap.get("resultList");
		for(ContributeArticleVO res : resultList) {
			if(StringUtils.isNotEmpty(res.getStatus())) {
				changeIdToName(res);
			}
		}
		resMap.put("resultList", resultList);

		return resMap;
	}
	@Override
	public Map<String, Object> findByPageBy(ContributeArticleVO VO, Integer page, Integer size, String isUser) throws Exception {
		Map<String, Object> resMap  = domain.findArtsByPageBy(VO, page, size, isUser);
		List<ContributeArticleVO> resultList = (List<ContributeArticleVO>) resMap.get("resultList");
		for(ContributeArticleVO res : resultList) {
			if(StringUtils.isNotEmpty(res.getStatus())) {
				changeIdToName(res);
			}
		}
		resMap.put("resultList", resultList);

		return resMap;
	}
    @Override
    public Map<String, Object> articles(String orgId,String dateFrom,String dateTo, Integer page, Integer size) throws Exception {
        ContributeArticleVO VO = new ContributeArticleVO();
        VO.setOrgId(orgId);
        if(!"".equals(dateFrom) && dateFrom != null && !"".equals(dateTo) && dateTo != null){
			VO.setDateFrom(new SimpleDateFormat("yyyy-MM-dd").parse(dateFrom));
			VO.setDateTo(new SimpleDateFormat("yyyy-MM-dd").parse(dateTo));
		}
        Map<String, Object> resMap  = domain.findArtsByPagedl(VO, page, size, "1");
        List<ContributeArticleVO> resultList = (List<ContributeArticleVO>) resMap.get("resultList");
        for(ContributeArticleVO res : resultList) {
            if("6".equals(res.getStatus())) {
                res.setStatusName("已转入津粮网");
            } else {
                res.setStatusName("未转入津粮网");
            }
        }
        resMap.put("resultList", resultList);

        return resMap;
    }

	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean deletes(String[] ids, String userId) throws Exception {
		return domain.deleteArts(ids, userId);
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean save(ContributeArticleVO VO) throws Exception {
		return domain.saveArt(VO);
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean update(ContributeArticleVO VO) throws Exception {
		return domain.updateArt(VO);
	}

	@Override
	public Map<String, Object> articleGather(ContributeArticleVO param, Integer page, Integer size) throws Exception {
		return domain.articleGather(param, page, size);
	}

	/**
	 * @Description 各种id转换成名字
	 *
	 * @param res
	 * @throws Exception
	 */
	private void changeIdToName(ContributeArticleVO res) throws Exception {
		String status = res.getStatus();
		if (StringUtils.isEmpty(status)) {
			return;
		}

		// 类型转换成汉字
		switch (AuditingStatusEnum.getByValue(status)) {
		case SUBMITED:
			res.setStatusName(AuditingStatusEnum.SUBMITED.getMessage());
			break;
		case NOT_SUBMITED:
			res.setStatusName(AuditingStatusEnum.NOT_SUBMITED.getMessage());
			break;
		case NOT_AUDITING:
			res.setStatusName(AuditingStatusEnum.NOT_AUDITING.getMessage());
			break;
		case APPROVAL:
			res.setStatusName(AuditingStatusEnum.APPROVAL.getMessage());
			break;
		case REJECT:
			res.setStatusName(AuditingStatusEnum.REJECT.getMessage());
			break;
		case PUBLISHED:
			res.setStatusName(AuditingStatusEnum.PUBLISHED.getMessage());
			break;
		case UNPUBLISHED:
			res.setStatusName(AuditingStatusEnum.UNPUBLISHED.getMessage());
			break;
		default:
		}

	}

	@Override
	public boolean updateArticleStatus(String id, String status) throws Exception {
		return domain.updateArticleStatus(id, status);
	}
}
