/*
 * DataFloatServiceImpl.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2020-08-11 15:36:32 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.indicator.server.service.impl;

import com.github.pagehelper.Page;
import com.unis.common.utils.ResponseWrapper;
import com.unis.common.vo.base.PageResult;
import com.unis.indicator.common.vo.log.DataFloatVO;
import com.unis.indicator.server.domain.DataFloatDomain;
import com.unis.indicator.server.entity.log.DataFloatDO;
import com.unis.indicator.server.service.DataFloatService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * DATA_FLOAT-数据浮动记录表
 * @author lipenghe at 2020-08-11 15:36:32
 */
@Component
@Transactional
public class DataFloatServiceImpl implements DataFloatService {

    @Autowired
    DataFloatDomain dataFloatDomain;

    /**
    * <DATA_FLOAT-数据浮动记录表>选择性保存,包含新增和修改
    * @param dataFloatVO    <数据浮动记录表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public ResponseWrapper saveEntitySelectiveResult(DataFloatVO dataFloatVO) {
        return dataFloatDomain.saveEntitySelective(dataFloatVO);
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>
     * 插入全部字段
     * @param dataFloatVO    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper insertEntityResult(DataFloatVO dataFloatVO) {
        return dataFloatDomain.insertEntity(dataFloatVO);
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>
     * 选择性插入字段
     * @param dataFloatVO    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper insertEntitySelectiveResult(DataFloatVO dataFloatVO) {
        return dataFloatDomain.insertEntitySelective(dataFloatVO);
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>
     * 更改状态
     * @param dataFloatVO    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateStatusByEntityResult(DataFloatVO dataFloatVO, String limit) {
        return dataFloatDomain.updateStatusByEntity(dataFloatVO);
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>
     * 根据实体某些属性更新全部字段
     * @param dataFloatVO    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateByEntityResult(DataFloatVO dataFloatVO, String limit) {
        return dataFloatDomain.updateByEntity(dataFloatVO);
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>
     * 根据实体不为空的属性,选择性更新字段
     * @param dataFloatVO    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateByEntitySelectiveResult(DataFloatVO dataFloatVO, String limit) {
        return dataFloatDomain.updateByEntitySelective(dataFloatVO);
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>
     * 根据实体不为空的属性,选择性更新字段
     * @param entity    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateByEntitySelectiveResult(DataFloatDO entity, String limit) {
        int num= dataFloatDomain.updateByEntitySelective(entity);
        return ResponseWrapper.choose(num);
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>
     * [真删除]根据实体的某些属性进行单条或者批量删除
     * @param dataFloatVO    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper deleteByEntityResult(DataFloatVO dataFloatVO, String limit) {
        return dataFloatDomain.deleteShamByEntity(dataFloatVO);
    }

    /**
    * <DATA_FLOAT-数据浮动记录表>
    * 根据实体(唯一标示)查询一条数据
    * @param dataFloatVO    <数据浮动记录表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    @Override
    public ResponseWrapper selectByIdResult(DataFloatVO dataFloatVO) {
        DataFloatVO dataFloatVODb=dataFloatDomain.selectById(dataFloatVO);
        if(dataFloatVODb!=null){
            return ResponseWrapper.success(dataFloatVODb);
        }
        return ResponseWrapper.notFound();
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>
     * 根据实体(唯一标示)查询一条数据
     * @param entity    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectByIdResult(DataFloatDO entity) {
        DataFloatVO dataFloatVO=dataFloatDomain.selectById(entity);
        if(dataFloatVO!=null){
            return ResponseWrapper.success(dataFloatVO);
        }
        return ResponseWrapper.notFound();
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>
     * 根据实体的某些属性查询分页数据
     * @param dataFloatVO    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectPageByEntityResult(int pageNo, int pageSize
        , DataFloatVO dataFloatVO, String order) {
        Page<DataFloatVO> dataFloatVOPage=dataFloatDomain.selectPageByEntity(pageNo,pageSize,dataFloatVO,order);
        PageResult<DataFloatVO> dataFloatVOPageResult=new PageResult<>(dataFloatVOPage);
        return ResponseWrapper.success(dataFloatVOPageResult);
    }

    /**
    * <DATA_FLOAT-数据浮动记录表>
    * 根据实体的某些属性查询列表
    * @param dataFloatVO    <数据浮动记录表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    @Override
    public ResponseWrapper selectByEntityResult(DataFloatVO dataFloatVO) {
        List<DataFloatVO> dataFloatVOList=dataFloatDomain.selectByEntity(dataFloatVO);
        return ResponseWrapper.success(dataFloatVOList);
    }

    /**
    * <DATA_FLOAT-数据浮动记录表>
    * 根据实体的某些属性查询列表
    * @param entity    <数据浮动记录表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    @Override
    public ResponseWrapper selectByEntityResult(DataFloatDO entity) {
        List<DataFloatVO> dataFloatVOList=dataFloatDomain.selectByEntity(entity);
        return ResponseWrapper.success(dataFloatVOList);
    }

    /**
     * <DATA_FLOAT-数据浮动记录表>
     * 根据实体查询初始化数据
     * @param dataFloatVO    <数据浮动记录表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectInitDataResult(DataFloatVO dataFloatVO) {
        return ResponseWrapper.success(dataFloatVO);
    }

}
