package com.unis.indicator.server.service.impl;

import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.StringUtil;
import com.unis.indicator.common.vo.IndicatorMonitorVO;
import com.unis.indicator.common.vo.IndicatorPriceVO;
import com.unis.indicator.common.vo.IndicatorStandardVO;
import com.unis.indicator.common.vo.IndicatorVO;
import com.unis.indicator.server.domain.IndicatorDomain;
import com.unis.indicator.server.entity.indicator.ZbDO;
import com.unis.indicator.server.enums.IndIsChildEnum;
import com.unis.indicator.server.enums.IndLevelEnum;
import com.unis.indicator.server.enums.IndTypeEnum;
import com.unis.indicator.server.service.IndicatorService;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;

/**
 * @ClassName IndicatorServiceImpl
 * @Description 指标服务
 * @Author xmpu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@Service
public class IndicatorServiceImpl implements IndicatorService {

	@Autowired
	private IndicatorDomain indicatorDomain;

	@Override
	public boolean findIndMonRel(String id) throws Exception {
		return indicatorDomain.findIndMonRel(id);
	}

	@Override
	public IndicatorVO findById(String id) throws Exception {
        IndicatorVO res =  LsBeanUtils.copyProperties(indicatorDomain.findIndById(id), IndicatorVO.class);
        List<String> pIndList  = new ArrayList<>();
        if(res != null) {
			// 父节点名称转换
			if(StringUtils.isNotEmpty(res.getPInd()) && !"0".equals(res.getPInd())){
				ZbDO pRes = indicatorDomain.findIndById(res.getPInd());
				if(pRes != null) {
					res.setPIndName(pRes.getIndName());
				}
				else {
					res.setPIndName(res.getIndName());
				}
			}
//            pIndList.add(res.getId());
            // 递归获取pid
            idsTree(res.getPInd(), pIndList);
            // 逆序，前端需要。
            Collections.reverse(pIndList);
            res.setPIndList(pIndList);
        }
		return res;
	}

	private void idsTree(String pInd, List<String> pIndList) throws Exception{
		if(StringUtils.isNotEmpty(pInd) && !"0".equals(pInd)){
			ZbDO pRes = indicatorDomain.findIndById(pInd);
			if(pRes != null) {
				pIndList.add(pRes.getId());
				if("0".equals(pRes.getPInd())) {
					return;
				}
				idsTree(pRes.getPInd(), pIndList);
			}
		}
    }

	@Override
	public Map<String, Object> findByPage(IndicatorVO VO, Integer page, Integer size) throws Exception {

        Map<String, Object> resMap =  indicatorDomain.findIndsByPage(VO, page, size);
        List<IndicatorVO> resultList = (List<IndicatorVO>) resMap.get("resultList");
                                ;
        for(IndicatorVO res : resultList) {
            changeIdToName(res);
        }
        listToNull(resultList);
        resMap.put("resultList", resultList);

		return resMap;
	}

	@Override
	public List findByPageGroup(IndicatorVO VO, Integer page, Integer size) throws Exception {
		List resList =  indicatorDomain.findIndsByPageGroup(VO, page, size);
		return resList;
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean deletes(String[] ids, String userId) throws Exception {
		return indicatorDomain.deleteInds(ids, userId);
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean save(IndicatorVO VO) throws Exception {
        if(!(IndLevelEnum.levelOne.getCode().equals(VO.getIndLevel())
                || IndLevelEnum.levelTwo.getCode().equals(VO.getIndLevel())
                || IndLevelEnum.levelThree.getCode().equals(VO.getIndLevel())
				|| IndLevelEnum.levelFour.getCode().equals(VO.getIndLevel())
        )) {
            throw new RuntimeException("请填写正确的指标等级。");
        }
		if(!(IndTypeEnum.GRAIN.getCode().equals(VO.getIndType())
				|| IndTypeEnum.FINISHED_GOODS.getCode().equals(VO.getIndType())
				|| IndTypeEnum.OILSEEDS.getCode().equals(VO.getIndType())
				|| IndTypeEnum.GREASE.getCode().equals(VO.getIndType())
		)) {
			throw new RuntimeException("请填写正确的指标类型。");
		}
		return indicatorDomain.saveInd(VO);
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean update(IndicatorVO VO) throws Exception {
		return indicatorDomain.updateInd(VO);
	}

	@Override
	public List<IndicatorVO> findIndsTree(String treeCode) throws Exception{

		List<IndicatorVO> resVO  = indicatorDomain.findIndsTree(treeCode);
		for(IndicatorVO res : resVO) {
            changeIdToName(res);
        }
		listToNull(resVO);
		return resVO;
	}

	private void listToNull(List<IndicatorVO> voList) {
		if(voList == null) {
			return;
		}
		for (IndicatorVO vo : voList){
			if(vo == null) {
				break;
			}
			if(vo.getChildren() == null || vo.getChildren().size() == 0) {
				// 放null，前端需要。
				vo.setChildren(null);
			}
			else {
				listToNull(vo.getChildren());
			}
		}
	}

    /**
     * @Description 各种id转换成名字
     *
     * @param res
     * @throws Exception
     */
    private void changeIdToName(IndicatorVO res) throws Exception{

//        if(res == null) {
//            return ;
//        }
        // 级别转换成汉字
        switch (IndLevelEnum.getByValue(res.getIndLevel())){
            case levelOne :
                res.setIndLevel(IndLevelEnum.levelOne.getMessage());
                break;
            case levelTwo :
                res.setIndLevel(IndLevelEnum.levelTwo.getMessage());
                break;
            case levelThree :
                res.setIndLevel(IndLevelEnum.levelThree.getMessage());
                break;
			case levelFour :
				res.setIndLevel(IndLevelEnum.levelFour.getMessage());
				break;
            default :
        }

		// 类型转换成汉字
		switch (IndTypeEnum.getByValue(res.getIndType())){
			case GRAIN :
				res.setIndType(IndTypeEnum.GRAIN.getMessage());
				break;
			case FINISHED_GOODS :
				res.setIndType(IndTypeEnum.FINISHED_GOODS.getMessage());
				break;
			case OILSEEDS :
				res.setIndType(IndTypeEnum.OILSEEDS.getMessage());
				break;
			case GREASE :
				res.setIndType(IndTypeEnum.GREASE.getMessage());
				break;
			default :
		}

        // 是否子节点转换成汉字
        switch (IndIsChildEnum.getByValue(res.getIsChild())){
            case YES :
                res.setIsChildName(IndIsChildEnum.YES.getMessage());
                break;
            case NO :
                res.setIsChildName(IndIsChildEnum.NO.getMessage());
                break;
            default :
        }

        // 父节点名称转换
		if(StringUtils.isNotEmpty(res.getPInd()) && !"0".equals(res.getPInd())){
			ZbDO pRes = indicatorDomain.findIndById(res.getPInd());
			if(pRes != null) {
				res.setPIndName(pRes.getIndName());
			}
			else {
				res.setPIndName(res.getIndName());
			}
		}
    }

	@Override
	public IndicatorMonitorVO findIndicatorMonitor(String monitorId) throws Exception {
		return indicatorDomain.findIndicatorMonitor(monitorId);
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean saveIndicatorMonitor(IndicatorMonitorVO vo) throws Exception {
		return indicatorDomain.saveIndicatorMonitor(vo);
	}

	@Override
	public IndicatorStandardVO findIndicatorStandard(String indicatorId) throws Exception {
		return indicatorDomain.findIndicatorStandard(indicatorId);
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean saveIndicatorStandard(IndicatorStandardVO vo) throws Exception {
		return indicatorDomain.saveIndicatorStandard(vo);
	}

	@Override
	public IndicatorPriceVO findIndicatorPriceType(String indicatorId) throws Exception {
		return indicatorDomain.findIndicatorPriceType(indicatorId);
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean saveIndicatorPriceType(IndicatorPriceVO vo) throws Exception {
		return indicatorDomain.saveIndicatorPriceType(vo);
	}
}
