/*
 * LogDataChangeServiceImpl.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2020-08-06 15:42:51 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.indicator.server.service.impl;

import com.github.pagehelper.Page;
import com.unis.common.utils.ResponseWrapper;
import com.unis.common.vo.base.PageResult;
import com.unis.indicator.common.vo.log.LogDataChangeVO;
import com.unis.indicator.server.domain.LogDataChangeDomain;
import com.unis.indicator.server.entity.log.LogDataChangeDO;
import com.unis.indicator.server.service.LogDataChangeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * LOG_DATA_CHANGE-数据变动日志表
 * @author lipenghe at 2020-08-06 15:42:51
 */
@Component
@Transactional
public class LogDataChangeServiceImpl implements LogDataChangeService {

    @Autowired
    LogDataChangeDomain logDataChangeDomain;

    /**
    * <LOG_DATA_CHANGE-数据变动日志表>
    * 选择性保存,包含新增和修改
    * @param dataChangeVO    <数据变动日志表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public ResponseWrapper saveEntitySelectiveResult(LogDataChangeVO dataChangeVO) {
        return logDataChangeDomain.saveEntitySelective(dataChangeVO);
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>
     * 插入全部字段
     * @param dataChangeVO    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper insertEntityResult(LogDataChangeVO dataChangeVO) {
        return logDataChangeDomain.insertEntity(dataChangeVO);
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>
     * 选择性插入字段
     * @param dataChangeVO    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper insertEntitySelectiveResult(LogDataChangeVO dataChangeVO) {
        return logDataChangeDomain.insertEntitySelective(dataChangeVO);
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>
     * 更改状态
     * @param dataChangeVO    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateStatusByEntityResult(LogDataChangeVO dataChangeVO, String limit) {
        return logDataChangeDomain.updateStatusByEntity(dataChangeVO);
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>
     * 根据实体某些属性更新全部字段
     * @param dataChangeVO    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateByEntityResult(LogDataChangeVO dataChangeVO, String limit) {
        return logDataChangeDomain.updateByEntity(dataChangeVO);
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>
     * 根据实体不为空的属性,选择性更新字段
     * @param dataChangeVO    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateByEntitySelectiveResult(LogDataChangeVO dataChangeVO, String limit) {
        return logDataChangeDomain.updateByEntitySelective(dataChangeVO);
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>
     * 根据实体不为空的属性,选择性更新字段
     * @param entity    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateByEntitySelectiveResult(LogDataChangeDO entity, String limit) {
        int num= logDataChangeDomain.updateByEntitySelective(entity);
        return ResponseWrapper.choose(num);
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>
     * [真删除]根据实体的某些属性进行单条或者批量删除
     * @param dataChangeVO    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper deleteByEntityResult(LogDataChangeVO dataChangeVO, String limit) {
        return logDataChangeDomain.deleteShamByEntity(dataChangeVO);
    }

    /**
    * <LOG_DATA_CHANGE-数据变动日志表>
    * 根据实体(唯一标示)查询一条数据
    * @param dataChangeVO    <数据变动日志表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    @Override
    public ResponseWrapper selectByIdResult(LogDataChangeVO dataChangeVO) {
        LogDataChangeVO dataChangeVODb=logDataChangeDomain.selectById(dataChangeVO);
        if(dataChangeVODb!=null){
            return ResponseWrapper.success(dataChangeVODb);
        }
        return ResponseWrapper.notFound();
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>
     * 根据实体(唯一标示)查询一条数据
     * @param entity    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectByIdResult(LogDataChangeDO entity) {
        LogDataChangeVO dataChangeVO=logDataChangeDomain.selectById(entity);
        if(dataChangeVO!=null){
            return ResponseWrapper.success(dataChangeVO);
        }
        return ResponseWrapper.notFound();
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>
     * 根据实体的某些属性查询分页数据
     * @param dataChangeVO    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectPageByEntityResult(int pageNo, int pageSize
        , LogDataChangeVO dataChangeVO, String order) {
        Page<LogDataChangeVO> dataChangeVOPage=logDataChangeDomain.selectPageByEntity(pageNo,pageSize,dataChangeVO,order);
        PageResult<LogDataChangeVO> dataChangeVOPageResult=new PageResult<>(dataChangeVOPage);
        return ResponseWrapper.success(dataChangeVOPageResult);
    }

    /**
    * <LOG_DATA_CHANGE-数据变动日志表>
    * 根据实体的某些属性查询列表
    * @param dataChangeVO    <数据变动日志表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    @Override
    public ResponseWrapper selectByEntityResult(LogDataChangeVO dataChangeVO) {
        List<LogDataChangeVO> dataChangeVOList=logDataChangeDomain.selectByEntity(dataChangeVO);
        return ResponseWrapper.success(dataChangeVOList);
    }

    /**
    * <LOG_DATA_CHANGE-数据变动日志表>
    * 根据实体的某些属性查询列表
    * @param entity    <数据变动日志表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    @Override
    public ResponseWrapper selectByEntityResult(LogDataChangeDO entity) {
        List<LogDataChangeVO> dataChangeVOList=logDataChangeDomain.selectByEntity(entity);
        return ResponseWrapper.success(dataChangeVOList);
    }

    /**
     * <LOG_DATA_CHANGE-数据变动日志表>
     * 根据实体查询初始化数据
     * @param dataChangeVO    <数据变动日志表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectInitDataResult(LogDataChangeVO dataChangeVO) {
        return ResponseWrapper.success(dataChangeVO);
    }

}
