package com.unis.indicator.server.service.impl;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.unis.indicator.server.domain.IndicatorDomain;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.indicator.common.vo.ReportRecordVO;
import com.unis.indicator.server.domain.MarketTrendDomain;
import com.unis.indicator.server.service.MarketTrendService;

@Service
public class MarketTrendServiceImpl implements MarketTrendService{
	@Autowired
	private MarketTrendDomain domain;

	@Autowired
	private IndicatorDomain indicatorDomain;

	/**
	 * @Description: 查询本周行情--查询上报开始、结束时间
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	@Override
	public Map<String, Object> queryReportTime(ReportRecordVO VO, Integer page, Integer size) throws Exception{
		return  domain.queryReportTime(VO, page, size);
	}
	
	/**
	 * @Description: 查询本周行情--查询上国家局详情
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	@Override
	public Map<String, Object> queryCountryDetails(ReportRecordVO VO, Integer page, Integer size) throws Exception {
		return domain.queryCountryDetails(VO, page, size);
	}
	
	/**
	 * @Description: 查询本周行情--查询库点详情
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	@Override
	public Map<String, Object> queryPointDetails(ReportRecordVO VO, Integer page, Integer size) throws Exception {
		return domain.queryPointDetails(VO, page, size);
	}
	
	/**
	 * @Description: 查询价格走势--原粮
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	@Override
	public Map<String, Object> queryPriceYl(ReportRecordVO VO) throws Exception {
	return domain.queryPriceYL(VO);
	}
	
	/**
	 * @Description: 查询价格走势--成品粮
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	@Override
	public Map<String, Object> queryPriceCPL(ReportRecordVO VO) throws Exception {
		return domain.queryPriceCPL(VO);
	}
	
	/**
	 * @Description: 查询价格走势--食用油及油料
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	@Override
	public Map<String, Object> queryPriceSYY(ReportRecordVO VO) throws Exception {
		try {
			if(indicatorDomain.findIndTypeByName(VO.getPzmc()).equals("3")){
				return domain.queryPriceSYYT(VO);
			}else {
				return domain.queryPriceSYYF(VO);
			}
		} catch (Exception e) {
			return domain.queryPriceSYYT(VO);
		}
	}
	
	/**
	 * @Description: 查询价格走势--监测点原粮
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	@Override
	public Map<String, Object> queryPricePointYL(ReportRecordVO VO) throws Exception {
	return domain.queryPricePointYL(VO);
	}
	
	/**
	 * @Description: 查询价格走势--成品粮
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	@Override
	public Map<String, Object> queryPricePointCPL(ReportRecordVO VO) throws Exception {
		return domain.queryPricePointCPL(VO);
	}
	
	/**
	 * @Description: 查询价格走势--食用油及油料
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	@Override
	public Map<String, Object> queryPricePointSYY(ReportRecordVO VO) throws Exception {
		try {
			if(indicatorDomain.findIndTypeByName(VO.getPzmc()).equals("3")){
				return domain.queryPricePointSYYT(VO);
			}else {
				return domain.queryPricePointSYYF(VO);
			}
		} catch (Exception e) {
			return domain.queryPricePointSYYT(VO);
		}
	}
	
	/**
	 * @Description: 查询价格走势--原粮--指定价格
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	@Override
	public Map<String, Object> queryPriceYLZD(ReportRecordVO VO) throws Exception{
		return domain.queryPriceYLZD(VO);
	}
	
	/**
	 * @Description: 查询价格走势--成品粮--指定价格
	 * @date 2019年8月28日15:00:44
	 * @author lifx
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	@Override
	public Map<String, Object> queryPriceCPLZD(ReportRecordVO VO) throws Exception{
		return domain.queryPriceCPLZD(VO);
	}

	/**
	 * @Description: 工作台价格走势(每月均价)
	 * @date 2019/12/12 10:51
	 * @author yangshengjie
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	@Override
	public List<List> workbenchQueryPriceY(ReportRecordVO VO) throws Exception {
		VO.setPzlb(indicatorDomain.findIndTypeByName(VO.getPzmc()));
		return domain.workbenchQueryPriceY(VO);
	}

	/**
	 * @Description: 工作台价格走势(品种多选)
	 * @date 2019/12/12 17:42
	 * @author yangshengjie
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	@Override
	public List workbenchQueryPriceM(ReportRecordVO VO) throws Exception {
	    List<String> pzlbsz = new ArrayList<>();
		for (String tem : VO.getPzmcsz()){
            pzlbsz.add(indicatorDomain.findIndTypeByName(tem));
		}
		VO.setPzlbsz(pzlbsz);
		return domain.workbenchQueryPriceM(VO);
	}

}
