package com.unis.indicator.server.service.impl;

import com.unis.common.utils.LsBeanUtils;
import com.unis.indicator.common.vo.IndicatorVO;
import com.unis.indicator.common.vo.bbzb.ReportConfigVO;
import com.unis.indicator.common.vo.bbzb.ReportIndicatorVO;
import com.unis.indicator.common.vo.bbzb.ReportTypeVO;
import com.unis.indicator.server.domain.IndicatorDomain;
import com.unis.indicator.server.domain.ReportIndicatorDomain;
import com.unis.indicator.server.domain.ReportTypeDomain;
import com.unis.indicator.server.entity.indicator.BbzbDO;
import com.unis.indicator.server.service.ReportIndicatorService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @ClassName ReportIndicatorServiceImpl
 * @Description 报表指标服务
 * @Author xmpu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@Service
public class ReportIndicatorServiceImpl implements ReportIndicatorService {

	@Autowired
	private ReportIndicatorDomain domain;

	@Autowired
	private IndicatorDomain indicatorDomain;

	@Autowired
	private ReportTypeDomain reportTypeDomain;

	@Override
	public ReportIndicatorVO findById(String id) throws Exception {
        ReportIndicatorVO res =  LsBeanUtils.copyProperties(domain.findZkbbzbById(id), ReportIndicatorVO.class);
		if(res != null){
			res.setIndicatorVO(findIndById(res.getIndicatorId()));
			res.setReportTypeVO(findReportTypeById(res.getReportTypeId()));
		}
		return res;
	}

	@Override
	public List<IndicatorVO> findByReportTypeId(String id) throws Exception {
		List<BbzbDO> resDO  = domain.findZkbbzbByReportTypeId(id);
		List<IndicatorVO> res = new ArrayList<>();

		if(resDO != null && resDO.size() > 0){
			for (BbzbDO bbzb : resDO){
				res.add(findIndById(bbzb.getIndicatorId()));
			}
		}
		return res;
	}

	private IndicatorVO findIndById(String id) throws Exception {
		return LsBeanUtils.copyProperties(indicatorDomain.findIndById(id), IndicatorVO.class);
	}

	private ReportTypeVO findReportTypeById(String id) throws Exception {
		return LsBeanUtils.copyProperties(reportTypeDomain.findWeeklyReportTypeById(id), ReportTypeVO.class);
	}
	@Override
	public Map<String, Object> findByPage(ReportIndicatorVO VO, Integer page, Integer size) throws Exception {

		Map<String, Object> resMap = domain.findZkbbzsByPage(VO, page, size);
		List<ReportIndicatorVO> resultVOList = (List<ReportIndicatorVO>)resMap.get("resultList");
		for (ReportIndicatorVO resVO : resultVOList){
			IndicatorVO indicator = findIndById(resVO.getIndicatorId());
			if(indicator != null){
				resVO.setIndicatorName(indicator.getIndName());
			}
		}

		return resMap;
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean deletes(String[] ids, String userId) throws Exception {
		return domain.deleteZkbbzbs(ids, userId);
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean save(ReportIndicatorVO VO) throws Exception {
		return domain.saveZkbbzb(VO);
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public boolean update(ReportIndicatorVO VO) throws Exception {
		return domain.updateZkbbzb(VO);
	}

	@Override
	public ReportConfigVO findZkbbpz(ReportConfigVO VO) throws Exception{
		return domain.findZkbbpz(VO);
	}

	@Override
	public boolean saveOrUpdateZkbbpz(ReportConfigVO VO) throws Exception{
		return domain.saveOrUpdateZkbbpz(VO);
	}
}
