package com.unis.indicator.server.service.impl;

import java.math.RoundingMode;
import java.text.DecimalFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.ObjectUtils;

import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.google.common.collect.Sets;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.UUIDUtils;
import com.unis.indicator.common.vo.ReportingOfIndexPriceAddVO;
import com.unis.indicator.common.vo.ReportingOfIndexPriceDetailVO;
import com.unis.indicator.common.vo.ReportingOfIndexPriceListVO;
import com.unis.indicator.common.vo.ReportingOfIndexPriceParamVO;
import com.unis.indicator.server.dao.BbzbDao;
import com.unis.indicator.server.dao.ReportingOfIndexPriceDao;
import com.unis.indicator.server.dao.ReportingOfIndexPriceDetailDao;
import com.unis.indicator.server.entity.indicator.BbzbDO;
import com.unis.indicator.server.entity.report.ReportingOfIndexPriceDO;
import com.unis.indicator.server.entity.report.ReportingOfIndexPriceDetailDO;
import com.unis.indicator.server.enums.ReportTypeEnum;
import com.unis.indicator.server.service.ReportingOfIndexPriceService;

import io.jsonwebtoken.lang.Collections;
import tk.mybatis.mapper.entity.Example;
import tk.mybatis.mapper.entity.Example.Criteria;

/**
 * 
 * @Description：指标价格填报记录
 * @author：王帅
 * @date: 2020年4月10
 */
@Service
public class ReportingOfIndexPriceServiceImpl implements ReportingOfIndexPriceService {

	@Autowired
	private ReportingOfIndexPriceDao indexPriceDao;

	@Autowired
	private ReportingOfIndexPriceDetailDao indexPriceDetailDao;

	@Autowired
	private BbzbDao reportInfoDao;

	// 零售指数品种
	private static List<String> retailVarietysCode = Lists.newArrayList();

	// 批发指数品种
	private static List<String> wholesaleVarietysCode = Lists.newArrayList();

	// 企业指数品种
	private static List<String> companyVarietysCode = Lists.newArrayList();

	/**
	 * 价格指数报表中默认指数只展示的品种 零售：面粉 大米 玉米面 绿豆 大豆 一级豆油 四级豆油 花生油 批发：小麦 大米 玉米 面粉 大豆 一级豆油
	 * 四级豆油 花生油
	 */
	static {
		// 零售
		retailVarietysCode.add("0001");
		retailVarietysCode.add("0005");
		retailVarietysCode.add("0006");
		retailVarietysCode.add("0007");
		retailVarietysCode.add("0009");
		retailVarietysCode.add("0010");
		retailVarietysCode.add("0011");
		retailVarietysCode.add("0012");
		// 批发
		wholesaleVarietysCode.add("0001");
		wholesaleVarietysCode.add("0005");
		wholesaleVarietysCode.add("0007");
		wholesaleVarietysCode.add("0010");
		wholesaleVarietysCode.add("0011");
		wholesaleVarietysCode.add("0012");
		wholesaleVarietysCode.add("0026");
		wholesaleVarietysCode.add("0027");
	}

	@Transactional
	@Override
	public boolean insertReportedRecord(ReportingOfIndexPriceAddVO record) {
		ReportingOfIndexPriceDO indexPriceEntity = new ReportingOfIndexPriceDO();
		LsBeanUtils.copyPropertiesIgnoreNull(record, indexPriceEntity);
		indexPriceEntity.setId(UUIDUtils.uuid());
		indexPriceEntity.setCreateTime(new Date());
		int result = indexPriceDao.insertSelective(indexPriceEntity);
		if (result > 0) {
			// 添加填报记录详情
			List<ReportingOfIndexPriceDetailVO> detailAddList = record.getDetailList();
			if (!CollectionUtils.isEmpty(detailAddList)) {
				detailAddList.parallelStream().forEach(detail -> {
					ReportingOfIndexPriceDetailDO detailEntity = new ReportingOfIndexPriceDetailDO();
					LsBeanUtils.copyPropertiesIgnoreNull(detail, detailEntity);
					detailEntity.setId(UUIDUtils.uuid());
					detailEntity.setReportId(indexPriceEntity.getId());
					Double basePrice = detail.getJqj();
					Double price = detail.getJg();
					detailEntity.setZs((price * 100) / basePrice); // 指数等于价格乘以100 除以基期价
					indexPriceDetailDao.insertSelective(detailEntity);
				});
			}
			return true;
		}
		return false;
	}

	@Override
	public boolean updateReportedRecord(ReportingOfIndexPriceAddVO record) {
		ReportingOfIndexPriceDO indexPriceEntity = new ReportingOfIndexPriceDO();
		LsBeanUtils.copyPropertiesIgnoreNull(record, indexPriceEntity);
		int result = indexPriceDao.updateByPrimaryKeySelective(indexPriceEntity);
		if (result > 0) {
			// 更新成功则先删除子集再重新添加
			Example example = new Example(ReportingOfIndexPriceDetailDO.class);
			Criteria criteria = example.createCriteria();
			criteria.andEqualTo("reportId", record.getId());

			int delete = indexPriceDetailDao.deleteByExample(example);
			if (delete > 0) {
				List<ReportingOfIndexPriceDetailVO> detailAddList = record.getDetailList();
				if (!CollectionUtils.isEmpty(detailAddList)) {
					detailAddList.parallelStream().forEach(detail -> {
						ReportingOfIndexPriceDetailDO detailEntity = new ReportingOfIndexPriceDetailDO();
						LsBeanUtils.copyPropertiesIgnoreNull(detail, detailEntity);
						detailEntity.setId(UUIDUtils.uuid());
						detailEntity.setReportId(indexPriceEntity.getId());
						Double basePrice = detail.getJqj();
						Double price = detail.getJg();
						detailEntity.setZs((price * 100) / basePrice); // 指数等于价格乘以100 除以基期价
						indexPriceDetailDao.insertSelective(detailEntity);
					});
				}
			}

			return true;
		}
		return false;
	}

	@Override
	public ReportingOfIndexPriceAddVO showDetail(ReportingOfIndexPriceParamVO param) {
		ReportingOfIndexPriceAddVO showVO = new ReportingOfIndexPriceAddVO();
		List<ReportingOfIndexPriceDetailVO> detailList = Lists.newArrayList();
		String id = param.getId();
		if (StringUtils.isEmpty(id)) {
			Example reportInfo = new Example(BbzbDO.class);
			Criteria criteria = reportInfo.createCriteria();
			criteria.andEqualTo("reportTypeId", param.getReportTypeId());
			List<BbzbDO> reportInfoList = reportInfoDao.selectByExample(reportInfo);
			for (BbzbDO entity : reportInfoList) {
				ReportingOfIndexPriceDetailVO detail = new ReportingOfIndexPriceDetailVO();
				detail.setXh(entity.getPzsx());
				detail.setPzmc(entity.getIndicatorName());
				detail.setZbbm(entity.getZbbzId());
				detail.setJqj(entity.getJqj());
				detailList.add(detail);
			}
		} else {
			ReportingOfIndexPriceDO parentRecord = indexPriceDao.selectByPrimaryKey(id);
			if (!ObjectUtils.isEmpty(parentRecord)) {
				LsBeanUtils.copyPropertiesIgnoreNull(parentRecord, showVO);
				Example example = new Example(ReportingOfIndexPriceDetailDO.class);
				Criteria criteria = example.createCriteria();
				criteria.andEqualTo("reportId", id);
				List<ReportingOfIndexPriceDetailDO> recordList = indexPriceDetailDao.selectByExample(example);

				for (ReportingOfIndexPriceDetailDO entity : recordList) {
					ReportingOfIndexPriceDetailVO detail = new ReportingOfIndexPriceDetailVO();
					LsBeanUtils.copyPropertiesIgnoreNull(entity, detail);
					detailList.add(detail);
				}
			}
		}

		showVO.setDetailList(detailList);
		return showVO;
	}

	@Override
	public Map<String, Object> showListByPage(ReportingOfIndexPriceParamVO param, Integer pageSize, Integer pageNum) {
		Example example = new Example(ReportingOfIndexPriceDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andEqualTo("type", param.getReportType());
		String priceType = param.getPriceTypeId();
		if (StringUtils.isNotEmpty(priceType)) {
			criteria.andEqualTo("priceTypeId", priceType);
		}
		String reportedDate = param.getRecordStartDate();
		if (StringUtils.isNotEmpty(reportedDate)) {
			criteria.andGreaterThanOrEqualTo("sbkssj", reportedDate);
		}
		example.orderBy("createTime").desc();
		PageHelper.startPage(pageNum, pageSize);
		List<ReportingOfIndexPriceDO> indexPriceList = indexPriceDao.selectByExample(example);
		PageInfo<ReportingOfIndexPriceDO> pageInfo = new PageInfo<ReportingOfIndexPriceDO>(indexPriceList);
		List<ReportingOfIndexPriceListVO> showList = Lists.newArrayList();
		if (!Collections.isEmpty(indexPriceList)) {
			for (ReportingOfIndexPriceDO entity : indexPriceList) {
				ReportingOfIndexPriceListVO show = new ReportingOfIndexPriceListVO();
				LsBeanUtils.copyPropertiesIgnoreNull(entity, show);
				showList.add(show);
			}
		}

		Map<String, Object> result = new HashMap<>(pageSize);
		result.put("total", pageInfo.getTotal());
		result.put("resultList", showList);
		return result;
	}

	@Override
	public List<ReportingOfIndexPriceAddVO> showDetailList(String reportId, String reportType) {

		return null;
	}

	@Override
	public Map<String, Object> showPriceIndexTrend(ReportingOfIndexPriceParamVO param) {
		String type = param.getReportType();
		List<ReportingOfIndexPriceDO> indexPriceList = this.indexPriceList(param);
		List<ReportingOfIndexPriceListVO> showList = Lists.newArrayList();
		Map<String, Object> result = new HashMap<>();
		if (!Collections.isEmpty(indexPriceList)) {
			List<String> varietyList = param.getVarietys();
			List<ReportingOfIndexPriceDetailVO> priceDetailVOList= param.getDetailVOList();
			List<String> timeList = Lists.newArrayList();
			List<Map<String, Object>> seriesLists = new ArrayList<>();
			List<Map<String, Object>> legends = new ArrayList<>();
			Set<String> varietys = Sets.newHashSet();
			Map<String, List<String>> indexData = Maps.newLinkedHashMap();
			Integer i=0;
			for (ReportingOfIndexPriceDO entity : indexPriceList) {
				ReportingOfIndexPriceListVO show = new ReportingOfIndexPriceListVO();
				LsBeanUtils.copyPropertiesIgnoreNull(entity, show);
				// 添加时间轴
				Date startDate = entity.getSbkssj();
				if (null != startDate && ReportTypeEnum.MONTHLY.getCode().equals(type)) {
					String formateTime = DateUtil.getDateFormat(entity.getSbkssj(), "yyyy-MM");
					timeList.add(formateTime);
					show.setShowTime(formateTime);
				} else if (null != startDate && ReportTypeEnum.WEEKLY.getCode().equals(type)) {
					String formateTime = this.getWeekOfYearByInputDate(startDate);
					timeList.add(formateTime);
					show.setShowTime(formateTime);
				}
				List<ReportingOfIndexPriceDetailDO> recordList = this.indexPriceDetailList(param, entity, varietyList , priceDetailVOList);
				List<ReportingOfIndexPriceDetailVO> detailList = Lists.newArrayList();
				for (ReportingOfIndexPriceDetailDO entityDetail : recordList) {
					ReportingOfIndexPriceDetailVO detail = new ReportingOfIndexPriceDetailVO();
					LsBeanUtils.copyPropertiesIgnoreNull(entityDetail, detail);
					String priceOrIndex = param.getPriceOrIndex();
					String wholesalePrice = "";
					Double data = 0D;
					if (StringUtils.isNotEmpty(priceOrIndex) ) {
						// 当价格类型为批发时价格去除两位小数
						data = detail.getJg();
						if(!ObjectUtils.isEmpty(data) && "JAqcOZ136Tp8lFyuFlV".equals(param.getReportTypeId())) {
							//批发
							DecimalFormat df = new DecimalFormat("0");
							df.setRoundingMode(RoundingMode.HALF_UP);
							wholesalePrice = df.format(data);
							detail.setWholesalePrice(wholesalePrice);

							detail.setJg(Double.valueOf(wholesalePrice));
						} else if(!ObjectUtils.isEmpty(data) && "BPgRZ6VVTcJs0sVmQ9S".equals(param.getReportTypeId())) {
							//零售
							DecimalFormat df = new DecimalFormat("0.00");
							df.setRoundingMode(RoundingMode.HALF_UP);
							wholesalePrice = df.format(data);
							detail.setWholesalePrice(wholesalePrice);

							detail.setJg(Double.valueOf(wholesalePrice));
						}else if(!ObjectUtils.isEmpty(data) && "qiyebaojia-week".equals(param.getReportTypeId())) {
							//企业
							DecimalFormat df = new DecimalFormat("0");
							df.setRoundingMode(RoundingMode.HALF_UP);
							wholesalePrice = df.format(data);
							detail.setWholesalePrice(wholesalePrice);
							detail.setJg(Double.valueOf(wholesalePrice));
						}
						if(ObjectUtils.isEmpty(data) ){
							detail.setJg(null);
							detail.setWholesalePrice("---");
						}
					}
					detailList.add(detail);
					if(StringUtils.isEmpty(detail.getPzmc())){
						System.out.println(111);
					}
					// 获取品种 图表展示数据
					this.indexPriceTrend(i,wholesalePrice, param, legends, detail, varietys, indexData);
				}
				i++;
				show.setDetailList(detailList);

				showList.add(show);
			}
			result.put("trend", this.getTrendJSONObj(indexData, seriesLists, timeList, legends));
		} else {
			result.put("trend", null);
		}
		result.put("resultList", showList);

		return result;
	}

	@Override
	public Map<String, Object> showPriceIndexList(ReportingOfIndexPriceParamVO param) {
		String type = param.getReportType();
		List<ReportingOfIndexPriceDO> indexPriceList = this.indexPriceList(param);
		List<ReportingOfIndexPriceListVO> showList = Lists.newLinkedList();
		Map<String, Object> result = new HashMap<>();
		if (!Collections.isEmpty(indexPriceList)) {
			List<String> varietyList = param.getVarietys();
			List<ReportingOfIndexPriceDetailVO> priceDetailVOList= param.getDetailVOList();
			for (ReportingOfIndexPriceDO entity : indexPriceList) {
				ReportingOfIndexPriceListVO parentVO = new ReportingOfIndexPriceListVO();
				// 添加时间
				Date startDate = entity.getSbkssj();
				String formateTime = "";
				if (null != startDate && ReportTypeEnum.MONTHLY.getCode().equals(type)) {
					formateTime = DateUtil.getDateFormat(entity.getSbkssj(), "yyyy-MM");
				} else if (null != startDate && ReportTypeEnum.WEEKLY.getCode().equals(type)) {
					formateTime = this.getWeekOfYearByInputDate(startDate);
				}
				parentVO.setShowTime(formateTime);
				List<ReportingOfIndexPriceDetailVO> detailVOList = Lists.newLinkedList();
				List<ReportingOfIndexPriceDetailDO> recordList = this.indexPriceDetailList(param, entity, varietyList, priceDetailVOList);
				for (ReportingOfIndexPriceDetailDO entityDetail : recordList) {
					ReportingOfIndexPriceDetailVO detail = new ReportingOfIndexPriceDetailVO();
					LsBeanUtils.copyPropertiesIgnoreNull(entityDetail, detail);
					String priceOrIndex = param.getPriceOrIndex();
					String wholesalePrice = "";
					Double data = 0D;
					if (StringUtils.isNotEmpty(priceOrIndex) ) {
						// 当价格类型为批发时价格去除两位小数
						data = detail.getJg();
						if(!ObjectUtils.isEmpty(data) && "JAqcOZ136Tp8lFyuFlV".equals(param.getReportTypeId())) {
							DecimalFormat df = new DecimalFormat("0");
							df.setRoundingMode(RoundingMode.HALF_UP);
							wholesalePrice = df.format(data);
							detail.setWholesalePrice(wholesalePrice);
						} else if(!ObjectUtils.isEmpty(data) && "BPgRZ6VVTcJs0sVmQ9S".equals(param.getReportTypeId())) {
							DecimalFormat df = new DecimalFormat("0.00");
							df.setRoundingMode(RoundingMode.HALF_UP);
							wholesalePrice = df.format(data);
							detail.setWholesalePrice(wholesalePrice);
						}else if(!ObjectUtils.isEmpty(data) && "qiyebaojia-week".equals(param.getReportTypeId())) {
							DecimalFormat df = new DecimalFormat("0");
							df.setRoundingMode(RoundingMode.HALF_UP);
							wholesalePrice = df.format(data);
							detail.setWholesalePrice(wholesalePrice);
						}
					}
					detailVOList.add(detail);
				}
				parentVO.setDetailList(detailVOList);
				showList.add(parentVO);
			}
		}
		result.put("resultList", showList);

		return result;
	}

	@Override
	public JSONObject showMonthTrend(ReportingOfIndexPriceParamVO param) {
		String type = param.getReportType();
		List<ReportingOfIndexPriceDO> indexPriceList = this.indexPriceList(param);
		if (!Collections.isEmpty(indexPriceList)) {
			List<String> varietyList = param.getVarietys();
			List<ReportingOfIndexPriceDetailVO> priceDetailVOList= param.getDetailVOList();
			List<String> timeList = Lists.newArrayList();
			List<Map<String, Object>> seriesLists = new ArrayList<>();
			List<Map<String, Object>> legends = new ArrayList<>();
			Set<String> varietys = Sets.newHashSet();
			Map<String, List<String>> indexData = Maps.newLinkedHashMap();
			Integer i=0;
			for (ReportingOfIndexPriceDO entity : indexPriceList) {
				// 添加时间轴
				Date startDate = entity.getSbkssj();
				if (null != startDate && ReportTypeEnum.MONTHLY.getCode().equals(type)) {
					String formateTime = DateUtil.getDateFormat(entity.getSbkssj(), "yyyy-MM");
					timeList.add(formateTime);
				} else if (null != startDate && ReportTypeEnum.WEEKLY.getCode().equals(type)) {
					String formateTime = this.getWeekOfYearByInputDate(startDate);
					timeList.add(formateTime);
				}
				List<ReportingOfIndexPriceDetailDO> recordList = this.indexPriceDetailList(param, entity, varietyList, priceDetailVOList);
				List<ReportingOfIndexPriceDetailVO> detailList = Lists.newArrayList();
				for (ReportingOfIndexPriceDetailDO entityDetail : recordList) {
					ReportingOfIndexPriceDetailVO detail = new ReportingOfIndexPriceDetailVO();
					LsBeanUtils.copyPropertiesIgnoreNull(entityDetail, detail);
					detailList.add(detail);
					String priceOrIndex = param.getPriceOrIndex();
					String wholesalePrice = "";
					Double data = 0D;
					if (StringUtils.isNotEmpty(priceOrIndex) ) {
						// 当价格类型为批发时价格去除两位小数
						data = detail.getJg();
						if(!ObjectUtils.isEmpty(data) && "JAqcOZ136Tp8lFyuFlV".equals(param.getReportTypeId())) {
							//批发
							DecimalFormat df = new DecimalFormat("0");
							df.setRoundingMode(RoundingMode.HALF_UP);
							wholesalePrice = df.format(data);
							detail.setWholesalePrice(wholesalePrice);
						} else if(!ObjectUtils.isEmpty(data) && "BPgRZ6VVTcJs0sVmQ9S".equals(param.getReportTypeId())) {
							//零售
							DecimalFormat df = new DecimalFormat("0.00");
							df.setRoundingMode(RoundingMode.HALF_UP);
							wholesalePrice = df.format(data);
							detail.setWholesalePrice(wholesalePrice);
						}else if(!ObjectUtils.isEmpty(data) && "qiyebaojia-week".equals(param.getReportTypeId())) {
							//企业
							DecimalFormat df = new DecimalFormat("0");
							df.setRoundingMode(RoundingMode.HALF_UP);
							wholesalePrice = df.format(data);
							detail.setWholesalePrice(wholesalePrice);
						}
					}
					detailList.add(detail);
					// 获取品种 图表展示数据
					this.indexPriceTrend(i ,wholesalePrice, param, legends, detail, varietys, indexData);
				}
				i++;
			}
			return this.getTrendJSONObj(indexData, seriesLists, timeList, legends);
		}
		JSONObject obj = new JSONObject();
		obj.put("xAxis", null);
		obj.put("legend", null);
		obj.put("series", null);
		return obj;
	}

	public List<ReportingOfIndexPriceDO> indexPriceList(ReportingOfIndexPriceParamVO param) {
		Example example = new Example(ReportingOfIndexPriceDO.class);
		Criteria criteria = example.createCriteria();
		String type = param.getReportType();
		criteria.andEqualTo("type", type);
		String priceType = param.getPriceTypeId();
		if (StringUtils.isNotEmpty(priceType)) {
			criteria.andEqualTo("priceTypeId", priceType);
		}
		String reportTypeId = param.getReportTypeId();
		if (StringUtils.isNotEmpty(reportTypeId)) {
			criteria.andEqualTo("reportTypeId", reportTypeId);
		}
		String reportedDate = param.getRecordStartDate();
		if (StringUtils.isNotEmpty(reportedDate)) {
			criteria.andGreaterThanOrEqualTo("sbkssj", reportedDate);
		}
		String reportEndDate = param.getRecordEndDate();
		if (StringUtils.isNotEmpty(reportEndDate)) {
			if("MONTH".equals(param.getReportType())){
				// 获取月末日期
				Map<String, Object> monthEnd = getMonthStartAndEnd(reportEndDate);
				criteria.andLessThan("sbkssj", monthEnd.get("end"));
			}else if("WEEK".equals(param.getReportType())){
				// 获取周末日期
				Map<String, Object> monthEnd = getWeekStartAndEnd(reportEndDate);
				criteria.andLessThan("sbkssj", monthEnd.get("end"));
			}
		}
		example.orderBy("sbkssj").asc();

		return indexPriceDao.selectByExample(example);
	}

	public List<ReportingOfIndexPriceDetailDO> indexPriceDetailList(ReportingOfIndexPriceParamVO param,
			ReportingOfIndexPriceDO entity, List<String> varietyList, List<ReportingOfIndexPriceDetailVO> priceDetailVOList) {
		String priceOrIndex = param.getPriceOrIndex();
		// 当前报表类型为指数时
		if (StringUtils.isNotEmpty(priceOrIndex) && ReportTypeEnum.INDEX.getCode().equals(priceOrIndex)) {
			String reportTypeId = param.getReportTypeId();
			// 批发
			if (StringUtils.isNotEmpty(reportTypeId) && "JAqcOZ136Tp8lFyuFlV".equals(reportTypeId)) {
				varietyList = wholesaleVarietysCode;
			} else if (StringUtils.isNotEmpty(reportTypeId) && "BPgRZ6VVTcJs0sVmQ9S".equals(reportTypeId)) {
				// 零售
				varietyList = retailVarietysCode;
			}else{
				varietyList=null;
			}
		}
		Map<String,Object> map=new HashMap<>();
		map.put("reportId",entity.getId());
		map.put("zbbmList", varietyList);
		map.put("priceDetailVOList", priceDetailVOList);

		List<ReportingOfIndexPriceDetailDO> list= indexPriceDetailDao.selectByEntity(map);
		Example exampleDetail = new Example(ReportingOfIndexPriceDetailDO.class);
		Criteria criteriaDetail = exampleDetail.createCriteria();
		criteriaDetail.andEqualTo("reportId", entity.getId());
		criteriaDetail.andIn("zbbm", varietyList);
		exampleDetail.orderBy("xh").asc();

		List<ReportingOfIndexPriceDetailDO> list2= indexPriceDetailDao.selectByExample(exampleDetail);
		return list2;
	}

	public void indexPriceTrend(Integer i,String wholesalePrice, ReportingOfIndexPriceParamVO param, List<Map<String, Object>> legends,
			ReportingOfIndexPriceDetailVO detail, Set<String> varietys, Map<String, List<String>> indexData) {
		// 获取品种
		String bzmc=detail.getJlbz();
		String name = detail.getPzmc();
		if(StringUtils.isNotEmpty(bzmc)){
			name=name+"("+detail.getJlbz()+")";
		}
		if (!varietys.contains(name)) {
			Map<String, Object> legendMap = new HashMap<>();
			legendMap.put("name", name);
			legendMap.put("icon", "circle");
			legends.add(legendMap);
		}
		// 获取价格 指数
		Double data = null;
		String dataStr = "";
		String priceOrIndex = param.getPriceOrIndex();
		if (StringUtils.isNotEmpty(priceOrIndex) && ReportTypeEnum.PRICE.getCode().equals(priceOrIndex)) {
			// 当价格类型为批发时价格去除两位小数
			dataStr = wholesalePrice;
		} else if (StringUtils.isNotEmpty(priceOrIndex) && ReportTypeEnum.INDEX.getCode().equals(priceOrIndex)) {
			data = detail.getZs();
		}
		
		if(StringUtils.isEmpty(dataStr)) {
			if (ObjectUtils.isEmpty(data)) {
				dataStr = "---";
			} else {
				if(!"BPgRZ6VVTcJs0sVmQ9S".equals(param.getReportTypeId())){
					dataStr = String.format("%.0f", data);
				}else{
					dataStr = String.valueOf(data);
				}
			}
		}
		List<String> index = indexData.get(name);
		if (CollectionUtils.isEmpty(index)) {
			index = Lists.newArrayList();
			if(i !=null){
				for(int n=0;n<i;n++){
					index.add(null);
				}
			}
			index.add(dataStr);
		} else {
			index.add(dataStr);
		}
		indexData.put(name, index);
		varietys.add(name);
	}

	public JSONObject getTrendJSONObj(Map<String, List<String>> indexData, List<Map<String, Object>> seriesLists,
			List<String> timeList, List<Map<String, Object>> legends) {
		for (String key : indexData.keySet()) {
			Map<String, Object> resultMap = Maps.newHashMap();
			resultMap.put("name", key);
			resultMap.put("data", indexData.get(key));
			seriesLists.add(resultMap);
		}
		JSONObject obj = new JSONObject();
		obj.put("xAxis", timeList);
		obj.put("legend", legends);
		obj.put("series", seriesLists);

		return obj;
	}

	// 获取给定日期是第几周
	public String getWeekOfYearByInputDate(Date input) {
		// 获取一个Calendar对象
		Calendar calendar = Calendar.getInstance();
		// 设置星期一为一周开始的第一天
		calendar.setFirstDayOfWeek(Calendar.MONDAY);
		// 设置在一年中第一个星期所需最少天数
		calendar.setMinimalDaysInFirstWeek(4);
		// 格式化日期
		SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");
		Date parse = null;
		try {
			parse = simpleDateFormat.parse(simpleDateFormat.format(input));
			System.out.println("转换后的日期为：" + parse);
		} catch (ParseException e) {
			e.printStackTrace();
		}
		calendar.setTime(parse);
		// 获得给定日期所属年
		int weekYear = calendar.get(Calendar.YEAR);
		// 获得给定日期属于今年的第几周
		int weekOfYear = calendar.get(Calendar.WEEK_OF_YEAR);

		return weekYear + "年" + weekOfYear + "周";
	}

	// 获取给定日期月末
	public static Map<String, Object> getMonthStartAndEnd(String date) {
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM");
		Calendar c = Calendar.getInstance();
		try {
			Date sdfDate = sdf.parse(date);
			c.setTime(sdfDate);
			int lastMonthMaxDay = c.getActualMaximum(Calendar.DAY_OF_MONTH);
			c.set(c.get(Calendar.YEAR), c.get(Calendar.MONTH), lastMonthMaxDay, 23, 59, 59);
		} catch (ParseException e) {
			e.printStackTrace();
		}

		SimpleDateFormat sdf2 = new SimpleDateFormat("yyyy-MM-dd");
		Map<String, Object> result = Maps.newHashMap();
		result.put("end", sdf2.format(c.getTime()));
		result.put("endDate", c.getTime());

		return result;
	}
	// 获取给定日期周末
	public static Map<String, Object> getWeekStartAndEnd(String date) {
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
		Calendar c = Calendar.getInstance();
		Date sdfDate =null;
		try {
			sdfDate = sdf.parse(date);
			c.setTime(sdfDate);
		} catch (ParseException e) {
			e.printStackTrace();
		}

		Map<String, Object> result = Maps.newHashMap();
		result.put("end", c.getTime());
		result.put("endDate", c.getTime());

		return result;
	}

}
